	.section .MIPS.xhash
	.dc.l	0
	.section .bss
	.dc.l	0
	.section .data
	.dc.l	0
	.section .gcc_compiled_long32
	.dc.l	0
	.section .gcc_compiled_long64
	.dc.l	0
	.section .got
	.dc.l	0
	.section .got.plt
	.dc.l	0
	.section .gptab.sbss
	.dc.l	0
	.section .gptab.sdata
	.dc.l	0
	.section .interp
	.dc.l	0
	.section .lit4
	.dc.l	0
	.section .lit8
	.dc.l	0
	.section .mdebug.abi32
	.dc.l	0
	.section .mdebug.abi64
	.dc.l	0
	.section .mdebug.abiN32
	.dc.l	0
	.section .mdebug.abiO64
	.dc.l	0
	.section .mdebug.eabi32
	.dc.l	0
	.section .mdebug.eabi64
	.dc.l	0
	.section .rodata
	.dc.l	0
	.section .sbss
	.dc.l	0
	.section .sdata
	.dc.l	0
	.section .text
	.dc.l	0
