.*: Assembler messages:
.*:57: Warning: can't find matching low-part relocation for %hi operator
.*:56: Warning: can't find matching low-part relocation for %hi operator
.*:55: Warning: can't find matching low-part relocation for %dtprel_hi operator
.*:54: Warning: can't find matching low-part relocation for %dtprel_hi operator
.*:53: Warning: can't find matching low-part relocation for %tprel_hi operator
.*:52: Warning: can't find matching low-part relocation for %tprel_hi operator
.*:38: Warning: can't find matching low-part relocation for %hi operator
.*:37: Warning: can't find matching low-part relocation for %hi operator
.*:36: Warning: can't find matching low-part relocation for %dtprel_hi operator
.*:35: Warning: can't find matching low-part relocation for %dtprel_hi operator
.*:34: Warning: can't find matching low-part relocation for %tprel_hi operator
.*:33: Warning: can't find matching low-part relocation for %tprel_hi operator
