#source: attr-merge-user-ext-rv32i2p1_a2p0.s
#source: attr-merge-user-ext-rv32i2p1_a2p1.s
#as:
#ld: -r -m[riscv_choose_ilp32_emul]
#readelf: -A

Attribute Section: riscv
File Attributes
  Tag_RISCV_arch: "rv32i2p1_a2p1_zaamo1p0_zalrsc1p0"
