.arch armv8-a
TLBI    alle1is, x0
TLBI    alle1os, x0
TLBI    alle1, x0
TLBI    alle2is, x0
TLBI    alle2os, x0
TLBI    alle2, x0
TLBI    alle3is, x0
TLBI    alle3, x0
TLBI    vmalle1os, x0
TLBI    vmalle1os, x0
TLBI    vmalle1, x0
TLBI    vmalls12e1is, x0
TLBI    vmalls12e1os, x0
TLBI    vmalls12e1, x0
TLBI    vmallws2e1is, x0
TLBI    vmallws2e1os, x0

.arch armv9.4-a
TLBI    alle3os, x0
TLBI    vmallws2e1, x0

.arch armv8-a+xs
TLBI    alle1isnxs, x0
TLBI    alle1osnxs, x0
TLBI    alle1nxs, x0
TLBI    alle2isnxs, x0
TLBI    alle2osnxs, x0
TLBI    alle2nxs, x0
TLBI    alle3isnxs, x0
TLBI    alle3nxs, x0
TLBI    vmalle1osnxs, x0
TLBI    vmalle1osnxs, x0
TLBI    vmalle1nxs, x0
TLBI    vmalls12e1isnxs, x0
TLBI    vmalls12e1osnxs, x0
TLBI    vmalls12e1nxs, x0
TLBI    vmallws2e1isnxs, x0
TLBI    vmallws2e1osnxs, x0

.arch armv9.4-a+xs
TLBI    alle3osnxs, x0
TLBI    vmallws2e1nxs, x0
