#as: --gsframe-3
#readelf: --sframe
#name: Generate SFrame V3 section
Contents of the SFrame section .sframe:
  Header :

    Version: SFRAME_VERSION_3
    Flags: SFRAME_F_FDE_FUNC_START_PCREL
#...
    Num FDEs: 1
    Num FREs: 1

#...
