# This should match the output of gas linefile.s.
.*linefile\.s: Assembler messages:
#?.*linefile\.s:1: Error: .*
.*linefile\.s:2: Warning: line 2
.*linefile\.s:4: Error: .*
.*linefile\.s:5: Warning: line 5
.*linefile\.s:8: Warning: line 8
#pass
