#as:
#source: diag-parname.s
#ld: -shared --ctf-variables
#name: Diagnostics - No parent dictionary
#warning: CTF linking failed; output will have no CTF section: The parent CTF dictionary is needed but unavailable
