[^:]*: Assembler messages:
.*: Error: selected processor does not support `fmmla v0.8h,v0.16b,v0.16b'
.*: Error: selected processor does not support `fmmla v0.8h,v0.16b,v31.16b'
.*: Error: selected processor does not support `fmmla v0.8h,v31.16b,v0.16b'
.*: Error: selected processor does not support `fmmla v0.8h,v31.16b,v31.16b'
.*: Error: selected processor does not support `fmmla v31.8h,v0.16b,v0.16b'
.*: Error: selected processor does not support `fmmla v31.8h,v0.16b,v31.16b'
.*: Error: selected processor does not support `fmmla v31.8h,v31.16b,v0.16b'
.*: Error: selected processor does not support `fmmla v31.8h,v31.16b,v31.16b'
