.*: Assembler messages:
.*: Error: selected processor does not support system register name 'alle1'
.*: Error: selected processor does not support `plbi alle1'
.*: Error: selected processor does not support system register name 'alle1is'
.*: Error: selected processor does not support `plbi alle1is'
.*: Error: selected processor does not support system register name 'alle1isnxs'
.*: Error: selected processor does not support `plbi alle1isnxs'
.*: Error: selected processor does not support system register name 'alle1nxs'
.*: Error: selected processor does not support `plbi alle1nxs'
.*: Error: selected processor does not support system register name 'alle1os'
.*: Error: selected processor does not support `plbi alle1os'
.*: Error: selected processor does not support system register name 'alle1osnxs'
.*: Error: selected processor does not support `plbi alle1osnxs'
.*: Error: selected processor does not support system register name 'alle2'
.*: Error: selected processor does not support `plbi alle2'
.*: Error: selected processor does not support system register name 'alle2is'
.*: Error: selected processor does not support `plbi alle2is'
.*: Error: selected processor does not support system register name 'alle2isnxs'
.*: Error: selected processor does not support `plbi alle2isnxs'
.*: Error: selected processor does not support system register name 'alle2nxs'
.*: Error: selected processor does not support `plbi alle2nxs'
.*: Error: selected processor does not support system register name 'alle2os'
.*: Error: selected processor does not support `plbi alle2os'
.*: Error: selected processor does not support system register name 'alle2osnxs'
.*: Error: selected processor does not support `plbi alle2osnxs'
.*: Error: selected processor does not support system register name 'alle3'
.*: Error: selected processor does not support `plbi alle3'
.*: Error: selected processor does not support system register name 'alle3is'
.*: Error: selected processor does not support `plbi alle3is'
.*: Error: selected processor does not support system register name 'alle3isnxs'
.*: Error: selected processor does not support `plbi alle3isnxs'
.*: Error: selected processor does not support system register name 'alle3nxs'
.*: Error: selected processor does not support `plbi alle3nxs'
.*: Error: selected processor does not support system register name 'alle3os'
.*: Error: selected processor does not support `plbi alle3os'
.*: Error: selected processor does not support system register name 'alle3osnxs'
.*: Error: selected processor does not support `plbi alle3osnxs'
.*: Error: selected processor does not support system register name 'aside1'
.*: Error: missing register at operand 2 -- `plbi aside1'
.*: Error: selected processor does not support system register name 'aside1is'
.*: Error: missing register at operand 2 -- `plbi aside1is'
.*: Error: selected processor does not support system register name 'aside1isnxs'
.*: Error: missing register at operand 2 -- `plbi aside1isnxs'
.*: Error: selected processor does not support system register name 'aside1nxs'
.*: Error: missing register at operand 2 -- `plbi aside1nxs'
.*: Error: selected processor does not support system register name 'aside1os'
.*: Error: missing register at operand 2 -- `plbi aside1os'
.*: Error: selected processor does not support system register name 'aside1osnxs'
.*: Error: missing register at operand 2 -- `plbi aside1osnxs'
.*: Error: selected processor does not support system register name 'permae1'
.*: Error: missing register at operand 2 -- `plbi permae1'
.*: Error: selected processor does not support system register name 'permae1is'
.*: Error: missing register at operand 2 -- `plbi permae1is'
.*: Error: selected processor does not support system register name 'permae1isnxs'
.*: Error: missing register at operand 2 -- `plbi permae1isnxs'
.*: Error: selected processor does not support system register name 'permae1nxs'
.*: Error: missing register at operand 2 -- `plbi permae1nxs'
.*: Error: selected processor does not support system register name 'permae1os'
.*: Error: missing register at operand 2 -- `plbi permae1os'
.*: Error: selected processor does not support system register name 'permae1osnxs'
.*: Error: missing register at operand 2 -- `plbi permae1osnxs'
.*: Error: selected processor does not support system register name 'perme1'
.*: Error: missing register at operand 2 -- `plbi perme1'
.*: Error: selected processor does not support system register name 'perme1is'
.*: Error: missing register at operand 2 -- `plbi perme1is'
.*: Error: selected processor does not support system register name 'perme1isnxs'
.*: Error: missing register at operand 2 -- `plbi perme1isnxs'
.*: Error: selected processor does not support system register name 'perme1nxs'
.*: Error: missing register at operand 2 -- `plbi perme1nxs'
.*: Error: selected processor does not support system register name 'perme1os'
.*: Error: missing register at operand 2 -- `plbi perme1os'
.*: Error: selected processor does not support system register name 'perme1osnxs'
.*: Error: missing register at operand 2 -- `plbi perme1osnxs'
.*: Error: selected processor does not support system register name 'perme2'
.*: Error: missing register at operand 2 -- `plbi perme2'
.*: Error: selected processor does not support system register name 'perme2is'
.*: Error: missing register at operand 2 -- `plbi perme2is'
.*: Error: selected processor does not support system register name 'perme2isnxs'
.*: Error: missing register at operand 2 -- `plbi perme2isnxs'
.*: Error: selected processor does not support system register name 'perme2nxs'
.*: Error: missing register at operand 2 -- `plbi perme2nxs'
.*: Error: selected processor does not support system register name 'perme2os'
.*: Error: missing register at operand 2 -- `plbi perme2os'
.*: Error: selected processor does not support system register name 'perme2osnxs'
.*: Error: missing register at operand 2 -- `plbi perme2osnxs'
.*: Error: selected processor does not support system register name 'perme3'
.*: Error: missing register at operand 2 -- `plbi perme3'
.*: Error: selected processor does not support system register name 'perme3is'
.*: Error: missing register at operand 2 -- `plbi perme3is'
.*: Error: selected processor does not support system register name 'perme3isnxs'
.*: Error: missing register at operand 2 -- `plbi perme3isnxs'
.*: Error: selected processor does not support system register name 'perme3nxs'
.*: Error: missing register at operand 2 -- `plbi perme3nxs'
.*: Error: selected processor does not support system register name 'perme3os'
.*: Error: missing register at operand 2 -- `plbi perme3os'
.*: Error: selected processor does not support system register name 'perme3osnxs'
.*: Error: missing register at operand 2 -- `plbi perme3osnxs'
.*: Error: selected processor does not support system register name 'vmalle1'
.*: Error: selected processor does not support `plbi vmalle1'
.*: Error: selected processor does not support system register name 'vmalle1is'
.*: Error: selected processor does not support `plbi vmalle1is'
.*: Error: selected processor does not support system register name 'vmalle1isnxs'
.*: Error: selected processor does not support `plbi vmalle1isnxs'
.*: Error: selected processor does not support system register name 'vmalle1nxs'
.*: Error: selected processor does not support `plbi vmalle1nxs'
.*: Error: selected processor does not support system register name 'vmalle1os'
.*: Error: selected processor does not support `plbi vmalle1os'
.*: Error: selected processor does not support system register name 'vmalle1osnxs'
.*: Error: selected processor does not support `plbi vmalle1osnxs'
