.*: Assembler messages:
.*: Error: operand type mismatch for .blendvps.
.*: Error: operand type mismatch for .blendvps.
.*: Error: operand type mismatch for .bsf.
.*: Error: operand type mismatch for .bswap.
.*: Error: operand type mismatch for .bswap.
.*: Error: operand type mismatch for .bswap.
.*: Error: operand type mismatch for .fcomi.
.*: Error: operand type mismatch for .fcomi.
.*: Error: operand type mismatch for .in.
.*: Error: operand type mismatch for .in.
.*: Error: operand type mismatch for .movntdqa.
.*: Error: operand type mismatch for .movntdq.
