[^ :]+: Assembler messages:
.*: Error: selected processor does not support `famax v0.4h,v0.4h,v0.4h'
.*: Error: selected processor does not support `famax v31.4h,v0.4h,v0.4h'
.*: Error: selected processor does not support `famax v0.4h,v31.4h,v0.4h'
.*: Error: selected processor does not support `famax v0.4h,v0.4h,v31.4h'
.*: Error: selected processor does not support `famax v17.4h,v21.4h,v27.4h'
.*: Error: selected processor does not support `famax v0.8h,v0.8h,v0.8h'
.*: Error: selected processor does not support `famax v31.8h,v0.8h,v0.8h'
.*: Error: selected processor does not support `famax v0.8h,v31.8h,v0.8h'
.*: Error: selected processor does not support `famax v0.8h,v0.8h,v31.8h'
.*: Error: selected processor does not support `famax v2.8h,v7.8h,v4.8h'
.*: Error: selected processor does not support `famax v0.2s,v0.2s,v0.2s'
.*: Error: selected processor does not support `famax v31.2s,v0.2s,v0.2s'
.*: Error: selected processor does not support `famax v0.2s,v31.2s,v0.2s'
.*: Error: selected processor does not support `famax v0.2s,v0.2s,v31.2s'
.*: Error: selected processor does not support `famax v3.2s,v1.2s,v19.2s'
.*: Error: selected processor does not support `famax v0.4s,v0.4s,v0.4s'
.*: Error: selected processor does not support `famax v31.4s,v0.4s,v0.4s'
.*: Error: selected processor does not support `famax v0.4s,v31.4s,v0.4s'
.*: Error: selected processor does not support `famax v0.4s,v0.4s,v31.4s'
.*: Error: selected processor does not support `famax v9.4s,v8.4s,v7.4s'
.*: Error: selected processor does not support `famax v0.2d,v0.2d,v0.2d'
.*: Error: selected processor does not support `famax v31.2d,v0.2d,v0.2d'
.*: Error: selected processor does not support `famax v0.2d,v31.2d,v0.2d'
.*: Error: selected processor does not support `famax v0.2d,v0.2d,v31.2d'
.*: Error: selected processor does not support `famax v18.2d,v14.2d,v16.2d'
.*: Error: selected processor does not support `famin v0.4h,v0.4h,v0.4h'
.*: Error: selected processor does not support `famin v31.4h,v0.4h,v0.4h'
.*: Error: selected processor does not support `famin v0.4h,v31.4h,v0.4h'
.*: Error: selected processor does not support `famin v0.4h,v0.4h,v31.4h'
.*: Error: selected processor does not support `famin v17.4h,v21.4h,v27.4h'
.*: Error: selected processor does not support `famin v0.8h,v0.8h,v0.8h'
.*: Error: selected processor does not support `famin v31.8h,v0.8h,v0.8h'
.*: Error: selected processor does not support `famin v0.8h,v31.8h,v0.8h'
.*: Error: selected processor does not support `famin v0.8h,v0.8h,v31.8h'
.*: Error: selected processor does not support `famin v2.8h,v7.8h,v4.8h'
.*: Error: selected processor does not support `famin v0.2s,v0.2s,v0.2s'
.*: Error: selected processor does not support `famin v31.2s,v0.2s,v0.2s'
.*: Error: selected processor does not support `famin v0.2s,v31.2s,v0.2s'
.*: Error: selected processor does not support `famin v0.2s,v0.2s,v31.2s'
.*: Error: selected processor does not support `famin v3.2s,v1.2s,v19.2s'
.*: Error: selected processor does not support `famin v0.4s,v0.4s,v0.4s'
.*: Error: selected processor does not support `famin v31.4s,v0.4s,v0.4s'
.*: Error: selected processor does not support `famin v0.4s,v31.4s,v0.4s'
.*: Error: selected processor does not support `famin v0.4s,v0.4s,v31.4s'
.*: Error: selected processor does not support `famin v9.4s,v8.4s,v7.4s'
.*: Error: selected processor does not support `famin v0.2d,v0.2d,v0.2d'
.*: Error: selected processor does not support `famin v31.2d,v0.2d,v0.2d'
.*: Error: selected processor does not support `famin v0.2d,v31.2d,v0.2d'
.*: Error: selected processor does not support `famin v0.2d,v0.2d,v31.2d'
.*: Error: selected processor does not support `famin v18.2d,v14.2d,v16.2d'
