.* Assembler messages:
.*:4: Error: operand size mismatch for `pushp'
.*:5: Error: operand size mismatch for `popp'
.*:6: Error: operand type mismatch for `pushp'
.*:7: Error: operand type mismatch for `popp'
