#name: s390/s390x register names in CFI directives errors
.*: Assembler messages:
# Invalid general register names
.*:4: Error: bad register expression
.*:5: Error: bad register expression
# Invalid floating-point register names
.*:7: Error: bad register expression
.*:8: Error: bad register expression
# Invalid vector register names
.*:10: Error: bad register expression
.*:11: Error: bad register expression
# Invalid access register names
.*:13: Error: bad register expression
.*:14: Error: bad register expression
