    cv.bclr x0, x0, 20, 20
    cv.bclr x1, x1, 20, 20
    cv.bclr x2, x2, 20, 20
    cv.bclr x8, x8, 20, 20
    cv.bclr x20, x20, 20, 20
    cv.bclr x31, x31, 20, 20
    cv.bclr x6, x7, 0, 0
    cv.bclr x6, x7, 31, 31
    cv.bclrr x0, x0, x0
    cv.bclrr x1, x1, x1
    cv.bclrr x2, x2, x2
    cv.bclrr x8, x8, x8
    cv.bclrr x20, x20, x20
    cv.bclrr x31, x31, x31
    cv.bitrev x0, x0, 2, 20
    cv.bitrev x1, x1, 2, 20
    cv.bitrev x2, x2, 2, 20
    cv.bitrev x8, x8, 2, 20
    cv.bitrev x20, x20, 2, 20
    cv.bitrev x31, x31, 2, 20
    cv.bitrev x6, x7, 0, 0
    cv.bitrev x6, x7, 3, 31
    cv.bset x0, x0, 20, 20
    cv.bset x1, x1, 20, 20
    cv.bset x2, x2, 20, 20
    cv.bset x8, x8, 20, 20
    cv.bset x20, x20, 20, 20
    cv.bset x31, x31, 20, 20
    cv.bset x6, x7, 0, 0
    cv.bset x6, x7, 31, 31
    cv.bsetr x0, x0, x0
    cv.bsetr x1, x1, x1
    cv.bsetr x2, x2, x2
    cv.bsetr x8, x8, x8
    cv.bsetr x20, x20, x20
    cv.bsetr x31, x31, x31
    cv.clb x0, x0
    cv.clb x1, x1
    cv.clb x2, x2
    cv.clb x8, x8
    cv.clb x20, x20
    cv.clb x31, x31
    cv.cnt x0, x0
    cv.cnt x1, x1
    cv.cnt x2, x2
    cv.cnt x8, x8
    cv.cnt x20, x20
    cv.cnt x31, x31
    cv.extract x0, x0, 20, 20
    cv.extract x1, x1, 20, 20
    cv.extract x2, x2, 20, 20
    cv.extract x8, x8, 20, 20
    cv.extract x20, x20, 20, 20
    cv.extract x31, x31, 20, 20
    cv.extract x6, x7, 0, 0
    cv.extract x6, x7, 31, 31
    cv.extractr x0, x0, x0
    cv.extractr x1, x1, x1
    cv.extractr x2, x2, x2
    cv.extractr x8, x8, x8
    cv.extractr x20, x20, x20
    cv.extractr x31, x31, x31
    cv.extractu x0, x0, 20, 20
    cv.extractu x1, x1, 20, 20
    cv.extractu x2, x2, 20, 20
    cv.extractu x8, x8, 20, 20
    cv.extractu x20, x20, 20, 20
    cv.extractu x31, x31, 20, 20
    cv.extractu x6, x7, 0, 0
    cv.extractu x6, x7, 31, 31
    cv.extractur x0, x0, x0
    cv.extractur x1, x1, x1
    cv.extractur x2, x2, x2
    cv.extractur x8, x8, x8
    cv.extractur x20, x20, x20
    cv.extractur x31, x31, x31
    cv.ff1 x0, x0
    cv.ff1 x1, x1
    cv.ff1 x2, x2
    cv.ff1 x8, x8
    cv.ff1 x20, x20
    cv.ff1 x31, x31
    cv.fl1 x0, x0
    cv.fl1 x1, x1
    cv.fl1 x2, x2
    cv.fl1 x8, x8
    cv.fl1 x20, x20
    cv.fl1 x31, x31
    cv.insert x0, x0, 20, 20
    cv.insert x1, x1, 20, 20
    cv.insert x2, x2, 20, 20
    cv.insert x8, x8, 20, 20
    cv.insert x20, x20, 20, 20
    cv.insert x31, x31, 20, 20
    cv.insert x6, x7, 0, 0
    cv.insert x6, x7, 31, 31
    cv.insertr x0, x0, x0
    cv.insertr x1, x1, x1
    cv.insertr x2, x2, x2
    cv.insertr x8, x8, x8
    cv.insertr x20, x20, x20
    cv.insertr x31, x31, x31
    cv.ror x0, x0, x0
    cv.ror x1, x1, x1
    cv.ror x2, x2, x2
    cv.ror x8, x8, x8
    cv.ror x20, x20, x20
    cv.ror x31, x31, x31
