[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z31\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z28\.d ?- ?z31\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z0\.h,{ ?z0\.d ?- ?z3\.d ?},#64'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrn z25\.h,{ ?z20\.d ?- ?z23\.d ?},#50'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshrun z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z31\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z28\.d ?- ?z31\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z0\.h,{ ?z0\.d ?- ?z3\.d ?},#64'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshrn z25\.h,{ ?z20\.d ?- ?z23\.d ?},#50'
