/* MOVAZ (array to vector, two registers).  */
movaz {z0.s - z1.s} , za.d[w8, 0, vgx2]
movaz {z30.h - z31.h} , za.d[w8, 0, vgx2]
movaz {z0.d - z1.d} , za.d[w13, 7, vgx2]
movaz {z30.d - z31.d} , za.d[w11, 15, vgx2]
movaz {z14.d - z15.d} , za.d[w9, 4, vgx3]
movaz {z6.d - z7.d} , za.d[w10]
movaz {z2.d - z4.d} , za.d[w10 6]

/* MOVAZ (array to vector, four registers).  */
movaz {z0.s - z3.s} , za.d[w8, 0, vgx4]
movaz {z28.h - z31.h} , za.d[w8, 0, vgx4]
movaz {z0.d - z3.d} , za.d[w14, 7, vgx4]
movaz {z28.d - z31.d} , za.d[w11, 11, vgx3]
movaz {z14.d - z17.d} , za.d[w9, 4, vgx4]
movaz {z4.d - z8.d} , za.d[w10, 3, vgx4]
movaz {z0.d, z3.d} , za.d[w10]
movaz {z1.d, z4.d} , za.d[w10 , 20]
