#as:
#objdump: -dr

.*:     file format elf32-epiphany

Disassembly of section \.text:

0+ <\.text>:
   0:	01b2      	idle
   2:	01a2      	nop
   4:	01a2      	nop
   6:	01a2      	nop
   8:	01b2      	idle
   a:	01b2      	idle
   c:	01a2      	nop
   e:	01a2      	nop
