.*: Assembler messages:
.*:4: Error: same .*
.*:5: Error: same .*
.*:6: Error: same .*
.*:7: Error: same .*
.*:9: Error: .* REX/REX2 .*
.*:10: Error: .* REX/REX2 .*
.*:12: Error: .* REX/REX2 .*
.*:13: Error: .* REX/REX2 .*
#pass
