.*: Assembler messages:
.*: Error: selected processor does not support `addqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `addqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `addqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `addqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `addqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `addqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `addqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `andqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `andqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `andqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `andqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `andqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `andqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `andqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `smaxqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `smaxqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `smaxqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `smaxqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `smaxqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `smaxqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `smaxqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `umaxqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `umaxqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `umaxqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `umaxqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `umaxqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `umaxqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `umaxqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `sminqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `sminqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `sminqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `sminqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `sminqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `sminqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `sminqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `dupq z10.b,z20.b\[0\]'
.*: Error: selected processor does not support `dupq z10.b,z20.b\[15\]'
.*: Error: selected processor does not support `dupq z10.h,z20.h\[0\]'
.*: Error: selected processor does not support `dupq z10.h,z20.h\[7\]'
.*: Error: selected processor does not support `dupq z10.s,z20.s\[0\]'
.*: Error: selected processor does not support `dupq z10.s,z20.s\[3\]'
.*: Error: selected processor does not support `dupq z10.d,z20.d\[0\]'
.*: Error: selected processor does not support `dupq z10.d,z20.d\[1\]'
.*: Error: selected processor does not support `uminqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `uminqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `uminqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `uminqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `uminqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `uminqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `uminqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `extq z0.b,z0.b,z0.b,#0'
.*: Error: selected processor does not support `extq z31.b,z31.b,z0.b,#0'
.*: Error: selected processor does not support `extq z0.b,z0.b,z31.b,#0'
.*: Error: selected processor does not support `extq z0.b,z0.b,z0.b,#15'
.*: Error: selected processor does not support `extq z31.b,z31.b,z31.b,#15'
.*: Error: selected processor does not support `extq z15.b,z15.b,z31.b,#7'
.*: Error: selected processor does not support `eorqv v0.16b,p0,z0.b'
.*: Error: selected processor does not support `eorqv v31.16b,p0,z0.b'
.*: Error: selected processor does not support `eorqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `eorqv v0.16b,p7,z0.b'
.*: Error: selected processor does not support `eorqv v0.16b,p0,z31.b'
.*: Error: selected processor does not support `eorqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `eorqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `faddqv v0.8h,p0,z0.h'
.*: Error: selected processor does not support `faddqv v31.8h,p0,z0.h'
.*: Error: selected processor does not support `faddqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `faddqv v0.8h,p7,z0.h'
.*: Error: selected processor does not support `faddqv v0.8h,p0,z31.h'
.*: Error: selected processor does not support `faddqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `faddqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `fmaxnmqv v0.8h,p0,z0.h'
.*: Error: selected processor does not support `fmaxnmqv v31.8h,p0,z0.h'
.*: Error: selected processor does not support `fmaxnmqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `fmaxnmqv v0.8h,p7,z0.h'
.*: Error: selected processor does not support `fmaxnmqv v0.8h,p0,z31.h'
.*: Error: selected processor does not support `fmaxnmqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `fmaxnmqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `fmaxqv v0.8h,p0,z0.h'
.*: Error: selected processor does not support `fmaxqv v31.8h,p0,z0.h'
.*: Error: selected processor does not support `fmaxqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `fmaxqv v0.8h,p7,z0.h'
.*: Error: selected processor does not support `fmaxqv v0.8h,p0,z31.h'
.*: Error: selected processor does not support `fmaxqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `fmaxqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `fminnmqv v0.8h,p0,z0.h'
.*: Error: selected processor does not support `fminnmqv v31.8h,p0,z0.h'
.*: Error: selected processor does not support `fminnmqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `fminnmqv v0.8h,p7,z0.h'
.*: Error: selected processor does not support `fminnmqv v0.8h,p0,z31.h'
.*: Error: selected processor does not support `fminnmqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `fminnmqv v10.4s,p3,z20.s'
.*: Error: selected processor does not support `fminqv v0.8h,p0,z0.h'
.*: Error: selected processor does not support `fminqv v31.8h,p0,z0.h'
.*: Error: selected processor does not support `fminqv v0.2d,p0,z0.d'
.*: Error: selected processor does not support `fminqv v0.8h,p7,z0.h'
.*: Error: selected processor does not support `fminqv v0.8h,p0,z31.h'
.*: Error: selected processor does not support `fminqv v31.2d,p7,z31.d'
.*: Error: selected processor does not support `fminqv v10.4s,p3,z20.s'
