[^:]+: Assembler messages:
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgom \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgom \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgoe \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgoe \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgomt \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgomt \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgoet \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgoet \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgomn \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgomn \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgoen \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgoen \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgomtn \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgomtn \[x0]!,x2!'
[^:]+:[0-9]+: Warning: destination register differs from preceding instruction at operand 1 -- `setgoetn \[x2]!,x1!'
[^:]+:[0-9]+: Warning: size register differs from preceding instruction at operand 2 -- `setgoetn \[x0]!,x2!'
