.*: Assembler messages:
.*: Error: selected processor does not support system register name 'cigdvaps'
.*: Error: selected processor does not support system register name 'civaps'
.*: Error: selected processor does not support system register name 'cigdvaps'
.*: Error: selected processor does not support system register name 'civaps'
.*: Error: selected processor does not support system register name 'cigdvaps'
.*: Error: comma expected between operands at operand 2 -- `dc civaps'
.*: Error: comma expected between operands at operand 2 -- `dc cigdvaps'
