[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z14\.h,{ ?z22\.s ?- ?z23\.s ?},#7'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#x0'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#z0\.s'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#p0'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#pn0'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z31\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z28\.d ?- ?z31\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z0\.h,{ ?z0\.d ?- ?z3\.d ?},#64'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshr z25\.h,{ ?z20\.d ?- ?z23\.d ?},#50'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z14\.h,{ ?z22\.s ?- ?z23\.s ?},#7'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z31\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z28\.d ?- ?z31\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z0\.h,{ ?z0\.d ?- ?z3\.d ?},#64'
[^ :]+:[0-9]+: Error: selected processor does not support `sqrshru z25\.h,{ ?z20\.d ?- ?z23\.d ?},#50'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z31\.h,{ ?z0\.s ?- ?z1\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z30\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z0\.s ?- ?z1\.s ?},#16'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z14\.h,{ ?z22\.s ?- ?z23\.s ?},#7'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z31\.b,{ ?z0\.s ?- ?z3\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.b,{ ?z28\.s ?- ?z31\.s ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.b,{ ?z0\.s ?- ?z3\.s ?},#32'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z6\.b,{ ?z12\.s ?- ?z15\.s ?},#25'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z31\.h,{ ?z0\.d ?- ?z3\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z28\.d ?- ?z31\.d ?},#1'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z0\.h,{ ?z0\.d ?- ?z3\.d ?},#64'
[^ :]+:[0-9]+: Error: selected processor does not support `uqrshr z25\.h,{ ?z20\.d ?- ?z23\.d ?},#50'
