[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w11,0:3\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,12:15\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],z31\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],z0\.b,z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],z0\.b,z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w9,8:11\],z21\.b,z9\.b\[9\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w9,4:7\],{ ?z18\.b ?- ?z19\.b ?},z9\.b\[12\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w10,0:3\],{ ?z24\.b ?- ?z27\.b ?},z14\.b\[6\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z31\.b,z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z31\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w9,4:7\],{ ?z19\.b ?- ?z20\.b ?},z13\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z29\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z30\.b,z31\.b,z0\.b,z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z31\.b ?- ?z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sumlall za\.s\[w9,0:3\],{ ?z25\.b ?- ?z28\.b ?},z14\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,12:15\],z0\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z31\.b,z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z0\.b,z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z0\.b,z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w9,8:11\],z21\.b,z9\.b\[9\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w9,4:7\],{ ?z18\.b ?- ?z19\.b ?},z9\.b\[12\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[15\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w10,0:3\],{ ?z24\.b ?- ?z27\.b ?},z14\.b\[6\]'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z0\.b,z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],z0\.b,z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,12:15\],z0\.b,z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z31\.b,z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],z0\.b,z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w10,4:7\],z25\.b,z7\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z31\.b,z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z31\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w9,4:7\],{ ?z19\.b ?- ?z20\.b ?},z13\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z29\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z30\.b,z31\.b,z0\.b,z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z31\.b ?- ?z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w9,0:3\],{ ?z25\.b ?- ?z28\.b ?},z14\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx2\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z1\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z30\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z1\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z1\.b ?},{ ?z30\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w10,4:7\],{ ?z22\.b ?- ?z23\.b ?},{ ?z18\.b ?- ?z19\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3,vgx4\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,4:7\],{ ?z0\.b ?- ?z3\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z28\.b ?- ?z31\.b ?},{ ?z0\.b ?- ?z3\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w8,0:3\],{ ?z0\.b ?- ?z3\.b ?},{ ?z28\.b ?- ?z31\.b ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `usmlall za\.s\[w11,0:3\],{ ?z16\.b ?- ?z19\.b ?},{ ?z24\.b ?- ?z27\.b ?}'
