[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z14\.h,{ ?z20\.s ?- ?z21\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z26\.h,{ ?z14\.s ?- ?z15\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z31\.h,{ ?z0\.s ?- ?z1\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.h,{ ?z30\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z29\.h,{ ?z6\.s ?- ?z7\.s ?}'
