#source: attr-syntax.s
#notarget: *-*-pe
#as:
#error: \A[^\n]+: Assembler messages:
#error: \n[^\n]+: Error: unknown identifier 'made_up_tag' in this context
#error: \n[^\n]+: Error: could not parse attribute tag
#error: \n[^\n]+: Error: syntax error, comma not expected here
#error: \n[^\n]+: Error: syntax error, comma missing here\Z
