.*Assembler messages:
.*:4: Error: invalid J-type offset \(\+1048576\)
.*:5: Error: invalid J-type offset \(-1048578\)
.*:8: Error: invalid J-type offset \(\+1048576\)
.*:10: Error: invalid J-type offset \(-1048578\)
.*:14: Error: invalid J-type offset \(\+1048576\)
.*:17: Error: invalid J-type offset \(-1048578\)
.*:20: Error: invalid CJ-type offset \(\+1\)
