.*: Assembler messages:
.*: Error: operand mismatch -- `addqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	addqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	addqv v0.8h, p0, z0.h
.*: Info:    	addqv v0.4s, p0, z0.s
.*: Info:    	addqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `addqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `addqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	addqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	addqv v0.8h, p7, z0.h
.*: Info:    	addqv v0.4s, p7, z0.s
.*: Info:    	addqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `addqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `smaxqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	smaxqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	smaxqv v0.8h, p0, z0.h
.*: Info:    	smaxqv v0.4s, p0, z0.s
.*: Info:    	smaxqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `smaxqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `smaxqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	smaxqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	smaxqv v0.8h, p7, z0.h
.*: Info:    	smaxqv v0.4s, p7, z0.s
.*: Info:    	smaxqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `smaxqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `andqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	andqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	andqv v0.8h, p0, z0.h
.*: Info:    	andqv v0.4s, p0, z0.s
.*: Info:    	andqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `andqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `andqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	andqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	andqv v0.8h, p7, z0.h
.*: Info:    	andqv v0.4s, p7, z0.s
.*: Info:    	andqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `andqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `umaxqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	umaxqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	umaxqv v0.8h, p0, z0.h
.*: Info:    	umaxqv v0.4s, p0, z0.s
.*: Info:    	umaxqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `umaxqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `umaxqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	umaxqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	umaxqv v0.8h, p7, z0.h
.*: Info:    	umaxqv v0.4s, p7, z0.s
.*: Info:    	umaxqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `umaxqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `sminqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	sminqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	sminqv v0.8h, p0, z0.h
.*: Info:    	sminqv v0.4s, p0, z0.s
.*: Info:    	sminqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `sminqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `sminqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	sminqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	sminqv v0.8h, p7, z0.h
.*: Info:    	sminqv v0.4s, p7, z0.s
.*: Info:    	sminqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `sminqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `uminqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	uminqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	uminqv v0.8h, p0, z0.h
.*: Info:    	uminqv v0.4s, p0, z0.s
.*: Info:    	uminqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `uminqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `uminqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	uminqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	uminqv v0.8h, p7, z0.h
.*: Info:    	uminqv v0.4s, p7, z0.s
.*: Info:    	uminqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `uminqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `eorqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	eorqv v0.16b, p0, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	eorqv v0.8h, p0, z0.h
.*: Info:    	eorqv v0.4s, p0, z0.s
.*: Info:    	eorqv v0.2d, p0, z0.d
.*: Error: p0-p7 expected at operand 2 -- `eorqv v31.16b,p8,z0.b'
.*: Error: operand mismatch -- `eorqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	eorqv v0.16b, p7, z0.b
.*: Info:    other valid variant\(s\):
.*: Info:    	eorqv v0.8h, p7, z0.h
.*: Info:    	eorqv v0.4s, p7, z0.s
.*: Info:    	eorqv v0.2d, p7, z0.d
.*: Error: bad vector arrangement type at operand 1 -- `eorqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `faddqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	faddqv v0.8h, p0, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	faddqv v0.4s, p0, z0.s
.*: Info:    	faddqv v0.2d, p0, z0.d
.*: Error: operand mismatch -- `faddqv v31.16b,p8,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	faddqv v31.8h, p8, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	faddqv v31.4s, p8, z0.s
.*: Info:    	faddqv v31.2d, p8, z0.d
.*: Error: operand mismatch -- `faddqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	faddqv v0.2d, p7, z0.d
.*: Info:    other valid variant\(s\):
.*: Info:    	faddqv v0.8h, p7, z0.h
.*: Info:    	faddqv v0.4s, p7, z0.s
.*: Error: bad vector arrangement type at operand 1 -- `faddqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `fmaxnmqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxnmqv v0.8h, p0, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxnmqv v0.4s, p0, z0.s
.*: Info:    	fmaxnmqv v0.2d, p0, z0.d
.*: Error: operand mismatch -- `fmaxnmqv v31.16b,p8,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxnmqv v31.8h, p8, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxnmqv v31.4s, p8, z0.s
.*: Info:    	fmaxnmqv v31.2d, p8, z0.d
.*: Error: operand mismatch -- `fmaxnmqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxnmqv v0.2d, p7, z0.d
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxnmqv v0.8h, p7, z0.h
.*: Info:    	fmaxnmqv v0.4s, p7, z0.s
.*: Error: bad vector arrangement type at operand 1 -- `fmaxnmqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `fmaxqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxqv v0.8h, p0, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxqv v0.4s, p0, z0.s
.*: Info:    	fmaxqv v0.2d, p0, z0.d
.*: Error: operand mismatch -- `fmaxqv v31.16b,p8,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxqv v31.8h, p8, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxqv v31.4s, p8, z0.s
.*: Info:    	fmaxqv v31.2d, p8, z0.d
.*: Error: operand mismatch -- `fmaxqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fmaxqv v0.2d, p7, z0.d
.*: Info:    other valid variant\(s\):
.*: Info:    	fmaxqv v0.8h, p7, z0.h
.*: Info:    	fmaxqv v0.4s, p7, z0.s
.*: Error: bad vector arrangement type at operand 1 -- `fmaxqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `fminnmqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminnmqv v0.8h, p0, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fminnmqv v0.4s, p0, z0.s
.*: Info:    	fminnmqv v0.2d, p0, z0.d
.*: Error: operand mismatch -- `fminnmqv v31.16b,p8,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminnmqv v31.8h, p8, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fminnmqv v31.4s, p8, z0.s
.*: Info:    	fminnmqv v31.2d, p8, z0.d
.*: Error: operand mismatch -- `fminnmqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminnmqv v0.2d, p7, z0.d
.*: Info:    other valid variant\(s\):
.*: Info:    	fminnmqv v0.8h, p7, z0.h
.*: Info:    	fminnmqv v0.4s, p7, z0.s
.*: Error: bad vector arrangement type at operand 1 -- `fminnmqv v0.2b,p7,z0.b'
.*: Error: operand mismatch -- `fminqv v0.8h,p0,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminqv v0.8h, p0, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fminqv v0.4s, p0, z0.s
.*: Info:    	fminqv v0.2d, p0, z0.d
.*: Error: operand mismatch -- `fminqv v31.16b,p8,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminqv v31.8h, p8, z0.h
.*: Info:    other valid variant\(s\):
.*: Info:    	fminqv v31.4s, p8, z0.s
.*: Info:    	fminqv v31.2d, p8, z0.d
.*: Error: operand mismatch -- `fminqv v0.2d,p7,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	fminqv v0.2d, p7, z0.d
.*: Info:    other valid variant\(s\):
.*: Info:    	fminqv v0.8h, p7, z0.h
.*: Info:    	fminqv v0.4s, p7, z0.s
.*: Error: bad vector arrangement type at operand 1 -- `fminqv v0.2b,p7,z0.b'
