[^:]*: Assembler messages:
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:6: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:11: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:13: Error: syntax error -- `vandeq q0,q1,q2'
[^:]*:15: Error: instruction missing MVE vector predication code -- `vand q0,q1,q2'
[^:]*:16: Error: vector predicated instruction should be in VPT/VPST block -- `vandt q0,q1,q2'
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:20: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:25: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:27: Error: syntax error -- `vandeq.i16 q0,#255'
[^:]*:29: Error: instruction missing MVE vector predication code -- `vand.i16 q0,#255'
[^:]*:30: Error: vector predicated instruction should be in VPT/VPST block -- `vandt.i16 q0,#255'
[^:]*:31: Error: bad type in SIMD instruction -- `vand.i8 q0,#255'
[^:]*:32: Error: bad type in SIMD instruction -- `vand.i64 q0,#255'
[^:]*:33: Error: immediate value out of range -- `vand.i16 q0,#0'
[^:]*:34: Error: immediate value out of range -- `vand.i32 q0,#0'
