	sttrb	w0, [x0]
	sttrb	wzr, [x0, #0]
	sttrb	w0, [sp]
	sttrb	w0, [x0, #-1]

	ldtrb	w0, [x0]
	ldtrb	wzr, [x0, #0]
	ldtrb	w0, [sp]
	ldtrb	w0, [x0, #-1]

	ldtrsb	x0, [x0]
	ldtrsb	xzr, [x0, #0]
	ldtrsb	x0, [sp]
	ldtrsb	x0, [x0, #-1]

	ldtrsb	w0, [x0]
	ldtrsb	wzr, [x0, #0]
	ldtrsb	w0, [sp]
	ldtrsb	w0, [x0, #-1]

	sttrh	w0, [x0]
	sttrh	wzr, [x0, #0]
	sttrh	w0, [sp]
	sttrh	w0, [x0, #-1]

	ldtrh	w0, [x0]
	ldtrh	wzr, [x0, #0]
	ldtrh	w0, [sp]
	ldtrh	w0, [x0, #-1]

	ldtrsh	x0, [x0]
	ldtrsh	xzr, [x0, #0]
	ldtrsh	x0, [sp]
	ldtrsh	x0, [x0, #-1]

	ldtrsh	w0, [x0]
	ldtrsh	wzr, [x0, #0]
	ldtrsh	w0, [sp]
	ldtrsh	w0, [x0, #-1]

	sttr	w0, [x0]
	sttr	wzr, [x0, #0]
	sttr	w0, [sp]
	sttr	w0, [x0, #-1]

	ldtr	w0, [x0]
	ldtr	wzr, [x0, #0]
	ldtr	w0, [sp]
	ldtr	w0, [x0, #-1]

	ldtrsw	x0, [x0]
	ldtrsw	xzr, [x0, #0]
	ldtrsw	x0, [sp]
	ldtrsw	x0, [x0, #-1]

	sttr	x0, [x0]
	sttr	xzr, [x0, #0]
	sttr	x0, [sp]
	sttr	x0, [x0, #-1]

	ldtr	x0, [x0]
	ldtr	xzr, [x0, #0]
	ldtr	x0, [sp]
	ldtr	x0, [x0, #-1]
