.*Assembler messages:
.*Error: can't have 64-bit ABI on 32-bit ISA
.*Error: only ilp32e/lp64e ABI are supported for e extension
.*Error: ilp32q/lp64q ABI can't be used when q extension isn't supported
