.* Assembler messages:
.*:5: Error: `movrs' is only supported in 64-bit mode
.*:6: Error: `movrs' is only supported in 64-bit mode
.*:7: Error: `movrs' is only supported in 64-bit mode
.*:8: Error: `movrs' is only supported in 64-bit mode
.*:9: Error: `vmovrsb' is only supported in 64-bit mode
.*:10: Error: `vmovrsd' is only supported in 64-bit mode
.*:11: Error: `vmovrsq' is only supported in 64-bit mode
.*:12: Error: `vmovrsw' is only supported in 64-bit mode
