[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H ?- ?Z1\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z30\.h ?- ?z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z12\.h ?- ?z13\.h ?},pn13/z,\[x11,#-10,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H ?- ?Z3\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z28\.h ?- ?z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z8\.h ?- ?z11\.h ?},pn11/z,\[x17,#20,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H,Z8\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z1\.h,z9\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z2\.h,z10\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z3\.h,z11\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z4\.h,z12\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z5\.h,z13\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z6\.h,z14\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z7\.h,z15\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z16\.h,z24\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z17\.h,z25\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z18\.h,z26\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z19\.h,z27\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z20\.h,z28\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z21\.h,z29\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z22\.h,z30\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z23\.h,z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z3\.h,z11\.h ?},pn10/z,\[x22,#6,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn14/z,\[x29,#8,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H ?- ?Z1\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z30\.h ?- ?z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z14\.h ?- ?z15\.h ?},pn9/z,\[x26,x3,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H ?- ?Z3\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z28\.h ?- ?z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z8\.h ?- ?z11\.h ?},pn11/z,\[x27,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H,Z8\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z1\.h,z9\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z2\.h,z10\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z3\.h,z11\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z4\.h,z12\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z5\.h,z13\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z6\.h,z14\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z7\.h,z15\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z16\.h,z24\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z17\.h,z25\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z18\.h,z26\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z19\.h,z27\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z20\.h,z28\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z21\.h,z29\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z22\.h,z30\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z23\.h,z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z5\.h,z13\.h ?},pn14/z,\[x15,x24,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ld1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn11/z,\[x4,x6,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H ?- ?Z1\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z30\.h ?- ?z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z12\.h ?- ?z13\.h ?},pn13/z,\[x11,#-10,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H ?- ?Z3\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z28\.h ?- ?z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z8\.h ?- ?z11\.h ?},pn11/z,\[x17,#20,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H,Z8\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z1\.h,z9\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z2\.h,z10\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z3\.h,z11\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z4\.h,z12\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z5\.h,z13\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z6\.h,z14\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z7\.h,z15\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z16\.h,z24\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z17\.h,z25\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z18\.h,z26\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z19\.h,z27\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z20\.h,z28\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z21\.h,z29\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z22\.h,z30\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z23\.h,z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z3\.h,z11\.h ?},pn10/z,\[x22,#6,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8/Z,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15/z,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn14/z,\[x29,#8,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H ?- ?Z1\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z30\.h ?- ?z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z1\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z14\.h ?- ?z15\.h ?},pn9/z,\[x26,x3,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H ?- ?Z3\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z28\.h ?- ?z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h ?- ?z3\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z8\.h ?- ?z11\.h ?},pn11/z,\[x27,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H,Z8\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z1\.h,z9\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z2\.h,z10\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z3\.h,z11\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z4\.h,z12\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z5\.h,z13\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z6\.h,z14\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z7\.h,z15\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z16\.h,z24\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z17\.h,z25\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z18\.h,z26\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z19\.h,z27\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z20\.h,z28\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z21\.h,z29\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z22\.h,z30\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z23\.h,z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z8\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z5\.h,z13\.h ?},pn14/z,\[x15,x24,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8/Z,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15/z,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8/z,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `ldnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn11/z,\[x4,x6,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H ?- ?Z1\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z30\.h ?- ?z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z12\.h ?- ?z13\.h ?},pn13,\[x11,#-10,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H ?- ?Z3\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z28\.h ?- ?z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z8\.h ?- ?z11\.h ?},pn11,\[x17,#20,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H,Z8\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z1\.h,z9\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z2\.h,z10\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z3\.h,z11\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z4\.h,z12\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z5\.h,z13\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z6\.h,z14\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z7\.h,z15\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z16\.h,z24\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z17\.h,z25\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z18\.h,z26\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z19\.h,z27\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z20\.h,z28\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z21\.h,z29\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z22\.h,z30\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z23\.h,z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z3\.h,z11\.h ?},pn10,\[x22,#6,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn14,\[x29,#8,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H ?- ?Z1\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z30\.h ?- ?z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z14\.h ?- ?z15\.h ?},pn9,\[x26,x3,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H ?- ?Z3\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z28\.h ?- ?z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z8\.h ?- ?z11\.h ?},pn11,\[x27,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H,Z8\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z1\.h,z9\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z2\.h,z10\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z3\.h,z11\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z4\.h,z12\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z5\.h,z13\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z6\.h,z14\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z7\.h,z15\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z16\.h,z24\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z17\.h,z25\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z18\.h,z26\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z19\.h,z27\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z20\.h,z28\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z21\.h,z29\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z22\.h,z30\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z23\.h,z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z8\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z5\.h,z13\.h ?},pn14,\[x15,x24,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `st1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn11,\[x4,x6,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H ?- ?Z1\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z30\.h ?- ?z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z12\.h ?- ?z13\.h ?},pn13,\[x11,#-10,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H ?- ?Z3\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z28\.h ?- ?z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z8\.h ?- ?z11\.h ?},pn11,\[x17,#20,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H,Z8\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z1\.h,z9\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z2\.h,z10\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z3\.h,z11\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z4\.h,z12\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z5\.h,z13\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z6\.h,z14\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z7\.h,z15\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z16\.h,z24\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z17\.h,z25\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z18\.h,z26\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z19\.h,z27\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z20\.h,z28\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z21\.h,z29\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z22\.h,z30\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z23\.h,z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,#-16,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,#14,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z3\.h,z11\.h ?},pn10,\[x22,#6,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#0,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8,\[X0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15,\[x0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x30\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[sp\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#-32,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,#28,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn14,\[x29,#8,mul vl\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H ?- ?Z1\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z30\.h ?- ?z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z1\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z14\.h ?- ?z15\.h ?},pn9,\[x26,x3,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H ?- ?Z3\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z28\.h ?- ?z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h ?- ?z3\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z8\.h ?- ?z11\.h ?},pn11,\[x27,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H,Z8\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z1\.h,z9\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z2\.h,z10\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z3\.h,z11\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z4\.h,z12\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z5\.h,z13\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z6\.h,z14\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z7\.h,z15\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z16\.h,z24\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z17\.h,z25\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z18\.h,z26\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z19\.h,z27\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z20\.h,z28\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z21\.h,z29\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z22\.h,z30\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z23\.h,z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z8\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z5\.h,z13\.h ?},pn14,\[x15,x24,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x1,lsl 1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?Z0\.H,Z4\.H,Z8\.H,Z12\.H ?},PN8,\[X0,X1,LSL ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z1\.h,z5\.h,z9\.h,z13\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z2\.h,z6\.h,z10\.h,z14\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z3\.h,z7\.h,z11\.h,z15\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z16\.h,z20\.h,z24\.h,z28\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z18\.h,z22\.h,z26\.h,z30\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z19\.h,z23\.h,z27\.h,z31\.h ?},pn8,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn15,\[x0,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x30,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[sp,x1,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,x30,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z0\.h,z4\.h,z8\.h,z12\.h ?},pn8,\[x0,xzr,lsl ?#1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `stnt1h { ?z17\.h,z21\.h,z25\.h,z29\.h ?},pn11,\[x4,x6,lsl ?#1\]'
