    cv.abs.b x32, x32
    cv.abs.b x33, x33
    cv.abs.h x32, x32
    cv.abs.h x33, x33
    cv.add.b x32, x32, x32
    cv.add.b x33, x33, x33
    cv.add.div2 x32, x32, x32
    cv.add.div2 x33, x33, x33
    cv.add.div4 x32, x32, x32
    cv.add.div4 x33, x33, x33
    cv.add.div8 x32, x32, x32
    cv.add.div8 x33, x33, x33
    cv.add.h x32, x32, x32
    cv.add.h x33, x33, x33
    cv.add.sc.b x32, x32, x32
    cv.add.sc.b x33, x33, x33
    cv.add.sc.h x32, x32, x32
    cv.add.sc.h x33, x33, x33
    cv.add.sci.b x32, x32, 20
    cv.add.sci.b x33, x33, 20
    cv.add.sci.b x6, x7, -33
    cv.add.sci.b x6, x7, 32
    cv.add.sci.h x32, x32, 20
    cv.add.sci.h x33, x33, 20
    cv.add.sci.h x6, x7, -33
    cv.add.sci.h x6, x7, 32
    cv.and.b x32, x32, x32
    cv.and.b x33, x33, x33
    cv.and.h x32, x32, x32
    cv.and.h x33, x33, x33
    cv.and.sc.b x32, x32, x32
    cv.and.sc.b x33, x33, x33
    cv.and.sc.h x32, x32, x32
    cv.and.sc.h x33, x33, x33
    cv.and.sci.b x32, x32, 20
    cv.and.sci.b x33, x33, 20
    cv.and.sci.b x6, x7, -33
    cv.and.sci.b x6, x7, 32
    cv.and.sci.h x32, x32, 20
    cv.and.sci.h x33, x33, 20
    cv.and.sci.h x6, x7, -33
    cv.and.sci.h x6, x7, 32
    cv.avg.b x32, x32, x32
    cv.avg.b x33, x33, x33
    cv.avg.h x32, x32, x32
    cv.avg.h x33, x33, x33
    cv.avg.sc.b x32, x32, x32
    cv.avg.sc.b x33, x33, x33
    cv.avg.sc.h x32, x32, x32
    cv.avg.sc.h x33, x33, x33
    cv.avg.sci.b x32, x32, 20
    cv.avg.sci.b x33, x33, 20
    cv.avg.sci.b x6, x7, -33
    cv.avg.sci.b x6, x7, 32
    cv.avg.sci.h x32, x32, 20
    cv.avg.sci.h x33, x33, 20
    cv.avg.sci.h x6, x7, -33
    cv.avg.sci.h x6, x7, 32
    cv.avgu.b x32, x32, x32
    cv.avgu.b x33, x33, x33
    cv.avgu.h x32, x32, x32
    cv.avgu.h x33, x33, x33
    cv.avgu.sc.b x32, x32, x32
    cv.avgu.sc.b x33, x33, x33
    cv.avgu.sc.h x32, x32, x32
    cv.avgu.sc.h x33, x33, x33
    cv.avgu.sci.b x32, x32, 20
    cv.avgu.sci.b x33, x33, 20
    cv.avgu.sci.b x6, x7, -1
    cv.avgu.sci.b x6, x7, 64
    cv.avgu.sci.h x32, x32, 20
    cv.avgu.sci.h x33, x33, 20
    cv.avgu.sci.h x6, x7, -1
    cv.avgu.sci.h x6, x7, 64
    cv.cmpeq.b x32, x32, x32
    cv.cmpeq.b x33, x33, x33
    cv.cmpeq.h x32, x32, x32
    cv.cmpeq.h x33, x33, x33
    cv.cmpeq.sc.b x32, x32, x32
    cv.cmpeq.sc.b x33, x33, x33
    cv.cmpeq.sc.h x32, x32, x32
    cv.cmpeq.sc.h x33, x33, x33
    cv.cmpeq.sci.b x32, x32, 20
    cv.cmpeq.sci.b x33, x33, 20
    cv.cmpeq.sci.b x6, x7, -33
    cv.cmpeq.sci.b x6, x7, 32
    cv.cmpeq.sci.h x32, x32, 20
    cv.cmpeq.sci.h x33, x33, 20
    cv.cmpeq.sci.h x6, x7, -33
    cv.cmpeq.sci.h x6, x7, 32
    cv.cmpge.b x32, x32, x32
    cv.cmpge.b x33, x33, x33
    cv.cmpge.h x32, x32, x32
    cv.cmpge.h x33, x33, x33
    cv.cmpge.sc.b x32, x32, x32
    cv.cmpge.sc.b x33, x33, x33
    cv.cmpge.sc.h x32, x32, x32
    cv.cmpge.sc.h x33, x33, x33
    cv.cmpge.sci.b x32, x32, 20
    cv.cmpge.sci.b x33, x33, 20
    cv.cmpge.sci.b x6, x7, -33
    cv.cmpge.sci.b x6, x7, 32
    cv.cmpge.sci.h x32, x32, 20
    cv.cmpge.sci.h x33, x33, 20
    cv.cmpge.sci.h x6, x7, -33
    cv.cmpge.sci.h x6, x7, 32
    cv.cmpgeu.b x32, x32, x32
    cv.cmpgeu.b x33, x33, x33
    cv.cmpgeu.h x32, x32, x32
    cv.cmpgeu.h x33, x33, x33
    cv.cmpgeu.sc.b x32, x32, x32
    cv.cmpgeu.sc.b x33, x33, x33
    cv.cmpgeu.sc.h x32, x32, x32
    cv.cmpgeu.sc.h x33, x33, x33
    cv.cmpgeu.sci.b x32, x32, 20
    cv.cmpgeu.sci.b x33, x33, 20
    cv.cmpgeu.sci.b x6, x7, -1
    cv.cmpgeu.sci.b x6, x7, 64
    cv.cmpgeu.sci.h x32, x32, 20
    cv.cmpgeu.sci.h x33, x33, 20
    cv.cmpgeu.sci.h x6, x7, -1
    cv.cmpgeu.sci.h x6, x7, 64
    cv.cmpgt.b x32, x32, x32
    cv.cmpgt.b x33, x33, x33
    cv.cmpgt.h x32, x32, x32
    cv.cmpgt.h x33, x33, x33
    cv.cmpgt.sc.b x32, x32, x32
    cv.cmpgt.sc.b x33, x33, x33
    cv.cmpgt.sc.h x32, x32, x32
    cv.cmpgt.sc.h x33, x33, x33
    cv.cmpgt.sci.b x32, x32, 20
    cv.cmpgt.sci.b x33, x33, 20
    cv.cmpgt.sci.b x6, x7, -33
    cv.cmpgt.sci.b x6, x7, 32
    cv.cmpgt.sci.h x32, x32, 20
    cv.cmpgt.sci.h x33, x33, 20
    cv.cmpgt.sci.h x6, x7, -33
    cv.cmpgt.sci.h x6, x7, 32
    cv.cmpgtu.b x32, x32, x32
    cv.cmpgtu.b x33, x33, x33
    cv.cmpgtu.h x32, x32, x32
    cv.cmpgtu.h x33, x33, x33
    cv.cmpgtu.sc.b x32, x32, x32
    cv.cmpgtu.sc.b x33, x33, x33
    cv.cmpgtu.sc.h x32, x32, x32
    cv.cmpgtu.sc.h x33, x33, x33
    cv.cmpgtu.sci.b x32, x32, 20
    cv.cmpgtu.sci.b x33, x33, 20
    cv.cmpgtu.sci.b x6, x7, -1
    cv.cmpgtu.sci.b x6, x7, 64
    cv.cmpgtu.sci.h x32, x32, 20
    cv.cmpgtu.sci.h x33, x33, 20
    cv.cmpgtu.sci.h x6, x7, -1
    cv.cmpgtu.sci.h x6, x7, 64
    cv.cmple.b x32, x32, x32
    cv.cmple.b x33, x33, x33
    cv.cmple.h x32, x32, x32
    cv.cmple.h x33, x33, x33
    cv.cmple.sc.b x32, x32, x32
    cv.cmple.sc.b x33, x33, x33
    cv.cmple.sc.h x32, x32, x32
    cv.cmple.sc.h x33, x33, x33
    cv.cmple.sci.b x32, x32, 20
    cv.cmple.sci.b x33, x33, 20
    cv.cmple.sci.b x6, x7, -33
    cv.cmple.sci.b x6, x7, 32
    cv.cmple.sci.h x32, x32, 20
    cv.cmple.sci.h x33, x33, 20
    cv.cmple.sci.h x6, x7, -33
    cv.cmple.sci.h x6, x7, 32
    cv.cmpleu.b x32, x32, x32
    cv.cmpleu.b x33, x33, x33
    cv.cmpleu.h x32, x32, x32
    cv.cmpleu.h x33, x33, x33
    cv.cmpleu.sc.b x32, x32, x32
    cv.cmpleu.sc.b x33, x33, x33
    cv.cmpleu.sc.h x32, x32, x32
    cv.cmpleu.sc.h x33, x33, x33
    cv.cmpleu.sci.b x32, x32, 20
    cv.cmpleu.sci.b x33, x33, 20
    cv.cmpleu.sci.b x6, x7, -1
    cv.cmpleu.sci.b x6, x7, 64
    cv.cmpleu.sci.h x32, x32, 20
    cv.cmpleu.sci.h x33, x33, 20
    cv.cmpleu.sci.h x6, x7, -1
    cv.cmpleu.sci.h x6, x7, 64
    cv.cmplt.b x32, x32, x32
    cv.cmplt.b x33, x33, x33
    cv.cmplt.h x32, x32, x32
    cv.cmplt.h x33, x33, x33
    cv.cmplt.sc.b x32, x32, x32
    cv.cmplt.sc.b x33, x33, x33
    cv.cmplt.sc.h x32, x32, x32
    cv.cmplt.sc.h x33, x33, x33
    cv.cmplt.sci.b x32, x32, 20
    cv.cmplt.sci.b x33, x33, 20
    cv.cmplt.sci.b x6, x7, -33
    cv.cmplt.sci.b x6, x7, 32
    cv.cmplt.sci.h x32, x32, 20
    cv.cmplt.sci.h x33, x33, 20
    cv.cmplt.sci.h x6, x7, -33
    cv.cmplt.sci.h x6, x7, 32
    cv.cmpltu.b x32, x32, x32
    cv.cmpltu.b x33, x33, x33
    cv.cmpltu.h x32, x32, x32
    cv.cmpltu.h x33, x33, x33
    cv.cmpltu.sc.b x32, x32, x32
    cv.cmpltu.sc.b x33, x33, x33
    cv.cmpltu.sc.h x32, x32, x32
    cv.cmpltu.sc.h x33, x33, x33
    cv.cmpltu.sci.b x32, x32, 20
    cv.cmpltu.sci.b x33, x33, 20
    cv.cmpltu.sci.b x6, x7, -1
    cv.cmpltu.sci.b x6, x7, 64
    cv.cmpltu.sci.h x32, x32, 20
    cv.cmpltu.sci.h x33, x33, 20
    cv.cmpltu.sci.h x6, x7, -1
    cv.cmpltu.sci.h x6, x7, 64
    cv.cmpne.b x32, x32, x32
    cv.cmpne.b x33, x33, x33
    cv.cmpne.h x32, x32, x32
    cv.cmpne.h x33, x33, x33
    cv.cmpne.sc.b x32, x32, x32
    cv.cmpne.sc.b x33, x33, x33
    cv.cmpne.sc.h x32, x32, x32
    cv.cmpne.sc.h x33, x33, x33
    cv.cmpne.sci.b x32, x32, 20
    cv.cmpne.sci.b x33, x33, 20
    cv.cmpne.sci.b x6, x7, -33
    cv.cmpne.sci.b x6, x7, 32
    cv.cmpne.sci.h x32, x32, 20
    cv.cmpne.sci.h x33, x33, 20
    cv.cmpne.sci.h x6, x7, -33
    cv.cmpne.sci.h x6, x7, 32
    cv.cplxconj x32, x32
    cv.cplxconj x33, x33
    cv.cplxmul.i.div2 x32, x32, x32
    cv.cplxmul.i.div2 x33, x33, x33
    cv.cplxmul.i.div4 x32, x32, x32
    cv.cplxmul.i.div4 x33, x33, x33
    cv.cplxmul.i.div8 x32, x32, x32
    cv.cplxmul.i.div8 x33, x33, x33
    cv.cplxmul.i x32, x32, x32
    cv.cplxmul.i x33, x33, x33
    cv.cplxmul.r.div2 x32, x32, x32
    cv.cplxmul.r.div2 x33, x33, x33
    cv.cplxmul.r.div4 x32, x32, x32
    cv.cplxmul.r.div4 x33, x33, x33
    cv.cplxmul.r.div8 x32, x32, x32
    cv.cplxmul.r.div8 x33, x33, x33
    cv.cplxmul.r x32, x32, x32
    cv.cplxmul.r x33, x33, x33
    cv.dotsp.b x32, x32, x32
    cv.dotsp.b x33, x33, x33
    cv.dotsp.h x32, x32, x32
    cv.dotsp.h x33, x33, x33
    cv.dotsp.sc.b x32, x32, x32
    cv.dotsp.sc.b x33, x33, x33
    cv.dotsp.sc.h x32, x32, x32
    cv.dotsp.sc.h x33, x33, x33
    cv.dotsp.sci.b x32, x32, 20
    cv.dotsp.sci.b x33, x33, 20
    cv.dotsp.sci.b x6, x7, -33
    cv.dotsp.sci.b x6, x7, 32
    cv.dotsp.sci.h x32, x32, 20
    cv.dotsp.sci.h x33, x33, 20
    cv.dotsp.sci.h x6, x7, -33
    cv.dotsp.sci.h x6, x7, 32
    cv.dotup.b x32, x32, x32
    cv.dotup.b x33, x33, x33
    cv.dotup.h x32, x32, x32
    cv.dotup.h x33, x33, x33
    cv.dotup.sc.b x32, x32, x32
    cv.dotup.sc.b x33, x33, x33
    cv.dotup.sc.h x32, x32, x32
    cv.dotup.sc.h x33, x33, x33
    cv.dotup.sci.b x32, x32, 20
    cv.dotup.sci.b x33, x33, 20
    cv.dotup.sci.b x6, x7, -1
    cv.dotup.sci.b x6, x7, 64
    cv.dotup.sci.h x32, x32, 20
    cv.dotup.sci.h x33, x33, 20
    cv.dotup.sci.h x6, x7, -1
    cv.dotup.sci.h x6, x7, 64
    cv.dotusp.b x32, x32, x32
    cv.dotusp.b x33, x33, x33
    cv.dotusp.h x32, x32, x32
    cv.dotusp.h x33, x33, x33
    cv.dotusp.sc.b x32, x32, x32
    cv.dotusp.sc.b x33, x33, x33
    cv.dotusp.sc.h x32, x32, x32
    cv.dotusp.sc.h x33, x33, x33
    cv.dotusp.sci.b x32, x32, 20
    cv.dotusp.sci.b x33, x33, 20
    cv.dotusp.sci.b x6, x7, -33
    cv.dotusp.sci.b x6, x7, 32
    cv.dotusp.sci.h x32, x32, 20
    cv.dotusp.sci.h x33, x33, 20
    cv.dotusp.sci.h x6, x7, -33
    cv.dotusp.sci.h x6, x7, 32
    cv.extract.b x32, x32, 2
    cv.extract.b x33, x33, 2
    cv.extract.b x6, x7, -1
    cv.extract.b x6, x7, 4
    cv.extract.h x32, x32, 1
    cv.extract.h x33, x33, 1
    cv.extract.h x6, x7, -1
    cv.extract.h x6, x7, 2
    cv.extractu.b x32, x32, 2
    cv.extractu.b x33, x33, 2
    cv.extractu.b x6, x7, -1
    cv.extractu.b x6, x7, 4
    cv.extractu.h x32, x32, 1
    cv.extractu.h x33, x33, 1
    cv.extractu.h x6, x7, -1
    cv.extractu.h x6, x7, 2
    cv.insert.b x32, x32, 2
    cv.insert.b x33, x33, 2
    cv.insert.b x6, x7, -1
    cv.insert.b x6, x7, 4
    cv.insert.h x32, x32, 1
    cv.insert.h x33, x33, 1
    cv.insert.h x6, x7, -1
    cv.insert.h x6, x7, 2
    cv.max.b x32, x32, x32
    cv.max.b x33, x33, x33
    cv.max.h x32, x32, x32
    cv.max.h x33, x33, x33
    cv.max.sc.b x32, x32, x32
    cv.max.sc.b x33, x33, x33
    cv.max.sc.h x32, x32, x32
    cv.max.sc.h x33, x33, x33
    cv.max.sci.b x32, x32, 20
    cv.max.sci.b x33, x33, 20
    cv.max.sci.b x6, x7, -33
    cv.max.sci.b x6, x7, 32
    cv.max.sci.h x32, x32, 20
    cv.max.sci.h x33, x33, 20
    cv.max.sci.h x6, x7, -33
    cv.max.sci.h x6, x7, 32
    cv.maxu.b x32, x32, x32
    cv.maxu.b x33, x33, x33
    cv.maxu.h x32, x32, x32
    cv.maxu.h x33, x33, x33
    cv.maxu.sc.b x32, x32, x32
    cv.maxu.sc.b x33, x33, x33
    cv.maxu.sc.h x32, x32, x32
    cv.maxu.sc.h x33, x33, x33
    cv.maxu.sci.b x32, x32, 20
    cv.maxu.sci.b x33, x33, 20
    cv.maxu.sci.b x6, x7, -1
    cv.maxu.sci.b x6, x7, 64
    cv.maxu.sci.h x32, x32, 20
    cv.maxu.sci.h x33, x33, 20
    cv.maxu.sci.h x6, x7, -1
    cv.maxu.sci.h x6, x7, 64
    cv.min.b x32, x32, x32
    cv.min.b x33, x33, x33
    cv.min.h x32, x32, x32
    cv.min.h x33, x33, x33
    cv.min.sc.b x32, x32, x32
    cv.min.sc.b x33, x33, x33
    cv.min.sc.h x32, x32, x32
    cv.min.sc.h x33, x33, x33
    cv.min.sci.b x32, x32, 20
    cv.min.sci.b x33, x33, 20
    cv.min.sci.b x6, x7, -33
    cv.min.sci.b x6, x7, 32
    cv.min.sci.h x32, x32, 20
    cv.min.sci.h x33, x33, 20
    cv.min.sci.h x6, x7, -33
    cv.min.sci.h x6, x7, 32
    cv.minu.b x32, x32, x32
    cv.minu.b x33, x33, x33
    cv.minu.h x32, x32, x32
    cv.minu.h x33, x33, x33
    cv.minu.sc.b x32, x32, x32
    cv.minu.sc.b x33, x33, x33
    cv.minu.sc.h x32, x32, x32
    cv.minu.sc.h x33, x33, x33
    cv.minu.sci.b x32, x32, 20
    cv.minu.sci.b x33, x33, 20
    cv.minu.sci.b x6, x7, -1
    cv.minu.sci.b x6, x7, 64
    cv.minu.sci.h x32, x32, 20
    cv.minu.sci.h x33, x33, 20
    cv.minu.sci.h x6, x7, -1
    cv.minu.sci.h x6, x7, 64
    cv.or.b x32, x32, x32
    cv.or.b x33, x33, x33
    cv.or.h x32, x32, x32
    cv.or.h x33, x33, x33
    cv.or.sc.b x32, x32, x32
    cv.or.sc.b x33, x33, x33
    cv.or.sc.h x32, x32, x32
    cv.or.sc.h x33, x33, x33
    cv.or.sci.b x32, x32, 20
    cv.or.sci.b x33, x33, 20
    cv.or.sci.b x6, x7, -33
    cv.or.sci.b x6, x7, 32
    cv.or.sci.h x32, x32, 20
    cv.or.sci.h x33, x33, 20
    cv.or.sci.h x6, x7, -33
    cv.or.sci.h x6, x7, 32
    cv.pack x32, x32, x32
    cv.pack x33, x33, x33
    cv.pack.h x32, x32, x32
    cv.pack.h x33, x33, x33
    cv.packhi.b x32, x32, x32
    cv.packhi.b x33, x33, x33
    cv.packlo.b x32, x32, x32
    cv.packlo.b x33, x33, x33
    cv.sdotsp.b x32, x32, x32
    cv.sdotsp.b x33, x33, x33
    cv.sdotsp.h x32, x32, x32
    cv.sdotsp.h x33, x33, x33
    cv.sdotsp.sc.b x32, x32, x32
    cv.sdotsp.sc.b x33, x33, x33
    cv.sdotsp.sc.h x32, x32, x32
    cv.sdotsp.sc.h x33, x33, x33
    cv.sdotsp.sci.b x32, x32, 20
    cv.sdotsp.sci.b x33, x33, 20
    cv.sdotsp.sci.b x6, x7, -33
    cv.sdotsp.sci.b x6, x7, 32
    cv.sdotsp.sci.h x32, x32, 20
    cv.sdotsp.sci.h x33, x33, 20
    cv.sdotsp.sci.h x6, x7, -33
    cv.sdotsp.sci.h x6, x7, 32
    cv.sdotup.b x32, x32, x32
    cv.sdotup.b x33, x33, x33
    cv.sdotup.h x32, x32, x32
    cv.sdotup.h x33, x33, x33
    cv.sdotup.sc.b x32, x32, x32
    cv.sdotup.sc.b x33, x33, x33
    cv.sdotup.sc.h x32, x32, x32
    cv.sdotup.sc.h x33, x33, x33
    cv.sdotup.sci.b x32, x32, 20
    cv.sdotup.sci.b x33, x33, 20
    cv.sdotup.sci.b x6, x7, -1
    cv.sdotup.sci.b x6, x7, 64
    cv.sdotup.sci.h x32, x32, 20
    cv.sdotup.sci.h x33, x33, 20
    cv.sdotup.sci.h x6, x7, -1
    cv.sdotup.sci.h x6, x7, 64
    cv.sdotusp.b x32, x32, x32
    cv.sdotusp.b x33, x33, x33
    cv.sdotusp.h x32, x32, x32
    cv.sdotusp.h x33, x33, x33
    cv.sdotusp.sc.b x32, x32, x32
    cv.sdotusp.sc.b x33, x33, x33
    cv.sdotusp.sc.h x32, x32, x32
    cv.sdotusp.sc.h x33, x33, x33
    cv.sdotusp.sci.b x32, x32, 20
    cv.sdotusp.sci.b x33, x33, 20
    cv.sdotusp.sci.b x6, x7, -33
    cv.sdotusp.sci.b x6, x7, 32
    cv.sdotusp.sci.h x32, x32, 20
    cv.sdotusp.sci.h x33, x33, 20
    cv.sdotusp.sci.h x6, x7, -33
    cv.sdotusp.sci.h x6, x7, 32
    cv.shuffle2.b x32, x32, x32
    cv.shuffle2.b x33, x33, x33
    cv.shuffle2.h x32, x32, x32
    cv.shuffle2.h x33, x33, x33
    cv.shuffle.b x32, x32, x32
    cv.shuffle.b x33, x33, x33
    cv.shuffle.h x32, x32, x32
    cv.shuffle.h x33, x33, x33
    cv.shufflei0.sci.b x32, x32, 20
    cv.shufflei0.sci.b x33, x33, 20
    cv.shufflei0.sci.b x6, x7, -1
    cv.shufflei0.sci.b x6, x7, 64
    cv.shufflei1.sci.b x32, x32, 20
    cv.shufflei1.sci.b x33, x33, 20
    cv.shufflei1.sci.b x6, x7, -1
    cv.shufflei1.sci.b x6, x7, 64
    cv.shufflei2.sci.b x32, x32, 20
    cv.shufflei2.sci.b x33, x33, 20
    cv.shufflei2.sci.b x6, x7, -1
    cv.shufflei2.sci.b x6, x7, 64
    cv.shufflei3.sci.b x32, x32, 20
    cv.shufflei3.sci.b x33, x33, 20
    cv.shufflei3.sci.b x6, x7, -1
    cv.shufflei3.sci.b x6, x7, 64
    cv.shuffle.sci.h x32, x32, 20
    cv.shuffle.sci.h x33, x33, 20
    cv.shuffle.sci.h x6, x7, -1
    cv.shuffle.sci.h x6, x7, 64
    cv.sll.b x32, x32, x32
    cv.sll.b x33, x33, x33
    cv.sll.h x32, x32, x32
    cv.sll.h x33, x33, x33
    cv.sll.sc.b x32, x32, x32
    cv.sll.sc.b x33, x33, x33
    cv.sll.sc.h x32, x32, x32
    cv.sll.sc.h x33, x33, x33
    cv.sll.sci.b x32, x32, 4
    cv.sll.sci.b x33, x33, 4
    cv.sll.sci.b x6, x7, -1
    cv.sll.sci.b x6, x7, 8
    cv.sll.sci.h x32, x32, 12
    cv.sll.sci.h x33, x33, 12
    cv.sll.sci.h x6, x7, -1
    cv.sll.sci.h x6, x7, 16
    cv.sra.b x32, x32, x32
    cv.sra.b x33, x33, x33
    cv.sra.h x32, x32, x32
    cv.sra.h x33, x33, x33
    cv.sra.sc.b x32, x32, x32
    cv.sra.sc.b x33, x33, x33
    cv.sra.sc.h x32, x32, x32
    cv.sra.sc.h x33, x33, x33
    cv.sra.sci.b x32, x32, 4
    cv.sra.sci.b x33, x33, 4
    cv.sra.sci.b x6, x7, -1
    cv.sra.sci.b x6, x7, 8
    cv.sra.sci.h x32, x32, 12
    cv.sra.sci.h x33, x33, 12
    cv.sra.sci.h x6, x7, -1
    cv.sra.sci.h x6, x7, 16
    cv.srl.b x32, x32, x32
    cv.srl.b x33, x33, x33
    cv.srl.h x32, x32, x32
    cv.srl.h x33, x33, x33
    cv.srl.sc.b x32, x32, x32
    cv.srl.sc.b x33, x33, x33
    cv.srl.sc.h x32, x32, x32
    cv.srl.sc.h x33, x33, x33
    cv.srl.sci.b x32, x32, 4
    cv.srl.sci.b x33, x33, 4
    cv.srl.sci.b x6, x7, -1
    cv.srl.sci.b x6, x7, 8
    cv.srl.sci.h x32, x32, 12
    cv.srl.sci.h x33, x33, 12
    cv.srl.sci.h x6, x7, -1
    cv.srl.sci.h x6, x7, 16
    cv.sub.b x32, x32, x32
    cv.sub.b x33, x33, x33
    cv.sub.div2 x32, x32, x32
    cv.sub.div2 x33, x33, x33
    cv.sub.div4 x32, x32, x32
    cv.sub.div4 x33, x33, x33
    cv.sub.div8 x32, x32, x32
    cv.sub.div8 x33, x33, x33
    cv.sub.h x32, x32, x32
    cv.sub.h x33, x33, x33
    cv.subrotmj.div2 x32, x32, x32
    cv.subrotmj.div2 x33, x33, x33
    cv.subrotmj.div4 x32, x32, x32
    cv.subrotmj.div4 x33, x33, x33
    cv.subrotmj.div8 x32, x32, x32
    cv.subrotmj.div8 x33, x33, x33
    cv.subrotmj x32, x32, x32
    cv.subrotmj x33, x33, x33
    cv.sub.sc.b x32, x32, x32
    cv.sub.sc.b x33, x33, x33
    cv.sub.sc.h x32, x32, x32
    cv.sub.sc.h x33, x33, x33
    cv.sub.sci.b x32, x32, 20
    cv.sub.sci.b x33, x33, 20
    cv.sub.sci.b x6, x7, -33
    cv.sub.sci.b x6, x7, 32
    cv.sub.sci.h x32, x32, 20
    cv.sub.sci.h x33, x33, 20
    cv.sub.sci.h x6, x7, -33
    cv.sub.sci.h x6, x7, 32
    cv.xor.b x32, x32, x32
    cv.xor.b x33, x33, x33
    cv.xor.h x32, x32, x32
    cv.xor.h x33, x33, x33
    cv.xor.sc.b x32, x32, x32
    cv.xor.sc.b x33, x33, x33
    cv.xor.sc.h x32, x32, x32
    cv.xor.sc.h x33, x33, x33
    cv.xor.sci.b x32, x32, 20
    cv.xor.sci.b x33, x33, 20
    cv.xor.sci.b x6, x7, -33
    cv.xor.sci.b x6, x7, 32
    cv.xor.sci.h x32, x32, 20
    cv.xor.sci.h x33, x33, 20
    cv.xor.sci.h x6, x7, -33
    cv.xor.sci.h x6, x7, 32
