.*: Assembler messages:
.*: Error: bad index value for cm.jt, range: \[0, 31\]
.*: Error: illegal operands `cm.jt -1'
.*: Error: bad index value for cm.jt, range: \[0, 31\]
.*: Error: illegal operands `cm.jt 256'
.*: Error: bad index value for cm.jt, range: \[0, 31\]
.*: Error: illegal operands `cm.jt x0'
.*: Error: bad index value for cm.jalt, range: \[32, 255\]
.*: Error: illegal operands `cm.jalt -1'
.*: Error: bad index value for cm.jalt, range: \[32, 255\]
.*: Error: illegal operands `cm.jalt 256'
.*: Error: bad index value for cm.jalt, range: \[32, 255\]
.*: Error: illegal operands `cm.jalt x0'
