.*: Assembler messages:
.*: Error: unrecognized opcode `cv.elw x5,-2048\(x6\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x5,0\(x6\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x5,20\(x6\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x5,2047\(x6\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x31,2047\(x31\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x0,0\(x0\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x1,1024\(x1\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x2,1024\(x2\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x3,1024\(x3\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x4,1024\(x4\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x5,1024\(x5\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x6,1024\(x6\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x7,1024\(x7\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x8,1024\(x8\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x9,1024\(x9\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x10,1024\(x10\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x11,1024\(x11\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x12,1024\(x12\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x13,1024\(x13\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x14,1024\(x14\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x15,1024\(x15\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x16,1024\(x16\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x17,1024\(x17\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x18,1024\(x18\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x19,1024\(x19\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x20,1024\(x20\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x21,1024\(x21\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x22,1024\(x22\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x23,1024\(x23\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x24,1024\(x24\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x25,1024\(x25\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x26,1024\(x26\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x27,1024\(x27\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x28,1024\(x28\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x29,1024\(x29\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x30,1024\(x30\)', extension `xcvelw' required
.*: Error: unrecognized opcode `cv.elw x31,1024\(x31\)', extension `xcvelw' required
.*: Error: illegal operands `cv.elw x5,-2049\(x6\)'
.*: Error: illegal operands `cv.elw x5,2048\(x6\)'
.*: Error: illegal operands `cv.elw x-1,1024\(x-1\)'
.*: Error: illegal operands `cv.elw x32,1024\(x32\)'
