.*: Assembler messages:
.*: Error: illegal operands `amocas.d a1,a0,\(a0\)'
.*: Error: illegal operands `amocas.d a0,a1,\(a0\)'
.*: Error: illegal operands `amocas.d.aq a1,a0,\(a0\)'
.*: Error: illegal operands `amocas.d.aq a0,a1,\(a0\)'
.*: Error: illegal operands `amocas.d.rl a1,a0,\(a0\)'
.*: Error: illegal operands `amocas.d.rl a0,a1,\(a0\)'
.*: Error: illegal operands `amocas.d.aqrl a1,a0,\(a0\)'
.*: Error: illegal operands `amocas.d.aqrl a0,a1,\(a0\)'
.*: Error: unrecognized opcode `amocas.q a1,a0,\(a0\)'
.*: Error: unrecognized opcode `amocas.q a0,a1,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.aq a1,a0,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.aq a0,a1,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.rl a1,a0,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.rl a0,a1,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.aqrl a1,a0,\(a0\)'
.*: Error: unrecognized opcode `amocas.q.aqrl a0,a1,\(a0\)'
