/* FMOPA.  */
fmopa ZA1.h, p0, p0/m, z0.h, z0.h
fmopa ZA0.h, p7/m, p0, z0.h, z0.h
fmopa ZA0.h, p0/m, p7/m, z0.s, z0.s
fmopa ZA0.h, p0/m, p0/m, z31.d, z0.d
fmopa ZA2.h, p0/m, p8/m, z0.s, z31.b
fmopa ZA4.h, p15/m, p11/m, z0.s, z31.b

/* FMOPS.  */
fmops ZA1.h, p0, p0/m, z0.h, z0.h
fmops ZA0.h, p7/m, p0, z0.h, z0.h
fmops ZA0.h, p0/m, p7/m, z0.s, z0.s
fmops ZA0.h, p0/m, p0/m, z31.d, z0.d
fmops ZA2.h, p0/m, p8/m, z0.s, z31.b
fmops ZA4.h, p15/m, p11/m, z0.s, z31.b
