.* Assembler messages:
.*:6: Error: operand size mismatch for `vsm4key4'
.*:7: Error: operand size mismatch for `vsm4rnds4'
.*:8: Error: no EVEX encoding for `vsm4key4'
.*:9: Error: no EVEX encoding for `vsm4rnds4'
