.*: Assembler messages:
.*:2: Error: .*
.*:4: Error: .*
.*:6: Error: .*
.*:9: Error: .*
.*:10: Warning: .* shortened to .*
.*:11: Error: .*
.*:12: Warning: .* shortened to .*
.*:13: Error: .*
.*:14: Warning: .* shortened to .*
.*:16: Error: .*
.*:17: Warning: .* shortened to .*
.*:18: Error: .*
.*:19: Warning: .* shortened to .*
.*:20: Error: .*
.*:21: Warning: .* shortened to .*
.*:23: Error: .*
.*:24: Warning: .* shortened to .*
.*:25: Error: .*
.*:26: Warning: .* shortened to .*
.*:27: Error: .*
.*:28: Warning: .* shortened to .*
