.*: Assembler messages:
.*:3: Error: opcode not supported on this processor: .* \(.*\) `c0 0x00'
.*:4: Error: opcode not supported on this processor: .* \(.*\) `c0 0x01'
.*:5: Error: opcode not supported on this processor: .* \(.*\) `c0 0x02'
.*:6: Error: opcode not supported on this processor: .* \(.*\) `c0 0x03'
.*:7: Error: opcode not supported on this processor: .* \(.*\) `c0 0x04'
.*:8: Error: opcode not supported on this processor: .* \(.*\) `c0 0x05'
.*:9: Error: opcode not supported on this processor: .* \(.*\) `c0 0x06'
.*:10: Error: opcode not supported on this processor: .* \(.*\) `c0 0x07'
.*:11: Error: opcode not supported on this processor: .* \(.*\) `c0 0x08'
.*:12: Error: opcode not supported on this processor: .* \(.*\) `c0 0x09'
.*:13: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0a'
.*:14: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0b'
.*:15: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0c'
.*:16: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0d'
.*:17: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0e'
.*:18: Error: opcode not supported on this processor: .* \(.*\) `c0 0x0f'
.*:19: Error: opcode not supported on this processor: .* \(.*\) `c0 0x10'
.*:20: Error: opcode not supported on this processor: .* \(.*\) `c0 0x11'
.*:21: Error: opcode not supported on this processor: .* \(.*\) `c0 0x12'
.*:22: Error: opcode not supported on this processor: .* \(.*\) `c0 0x13'
.*:23: Error: opcode not supported on this processor: .* \(.*\) `c0 0x14'
.*:24: Error: opcode not supported on this processor: .* \(.*\) `c0 0x15'
.*:25: Error: opcode not supported on this processor: .* \(.*\) `c0 0x16'
.*:26: Error: opcode not supported on this processor: .* \(.*\) `c0 0x17'
.*:27: Error: opcode not supported on this processor: .* \(.*\) `c0 0x18'
.*:28: Error: opcode not supported on this processor: .* \(.*\) `c0 0x19'
.*:29: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1a'
.*:30: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1b'
.*:31: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1c'
.*:32: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1d'
.*:33: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1e'
.*:34: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1f'
.*:35: Error: opcode not supported on this processor: .* \(.*\) `c0 0x20'
.*:36: Error: opcode not supported on this processor: .* \(.*\) `c0 0x21'
.*:37: Error: opcode not supported on this processor: .* \(.*\) `c0 0x22'
.*:38: Error: opcode not supported on this processor: .* \(.*\) `c0 0x23'
.*:39: Error: opcode not supported on this processor: .* \(.*\) `c0 0x24'
.*:40: Error: opcode not supported on this processor: .* \(.*\) `c0 0x25'
.*:41: Error: opcode not supported on this processor: .* \(.*\) `c0 0x26'
.*:42: Error: opcode not supported on this processor: .* \(.*\) `c0 0x27'
.*:43: Error: opcode not supported on this processor: .* \(.*\) `c0 0x28'
.*:44: Error: opcode not supported on this processor: .* \(.*\) `c0 0x29'
.*:45: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2a'
.*:46: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2b'
.*:47: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2c'
.*:48: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2d'
.*:49: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2e'
.*:50: Error: opcode not supported on this processor: .* \(.*\) `c0 0x2f'
.*:51: Error: opcode not supported on this processor: .* \(.*\) `c0 0x30'
.*:52: Error: opcode not supported on this processor: .* \(.*\) `c0 0x31'
.*:53: Error: opcode not supported on this processor: .* \(.*\) `c0 0x32'
.*:54: Error: opcode not supported on this processor: .* \(.*\) `c0 0x33'
.*:55: Error: opcode not supported on this processor: .* \(.*\) `c0 0x34'
.*:56: Error: opcode not supported on this processor: .* \(.*\) `c0 0x35'
.*:57: Error: opcode not supported on this processor: .* \(.*\) `c0 0x36'
.*:58: Error: opcode not supported on this processor: .* \(.*\) `c0 0x37'
.*:59: Error: opcode not supported on this processor: .* \(.*\) `c0 0x38'
.*:60: Error: opcode not supported on this processor: .* \(.*\) `c0 0x39'
.*:61: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3a'
.*:62: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3b'
.*:63: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3c'
.*:64: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3d'
.*:65: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3e'
.*:66: Error: opcode not supported on this processor: .* \(.*\) `c0 0x3f'
.*:68: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000000'
.*:69: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000001'
.*:70: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000002'
.*:71: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000003'
.*:72: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000004'
.*:73: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000005'
.*:74: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000006'
.*:75: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000007'
.*:76: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000008'
.*:77: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000009'
.*:78: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000a'
.*:79: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000b'
.*:80: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000c'
.*:81: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000d'
.*:82: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000e'
.*:83: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100000f'
.*:84: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000010'
.*:85: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000011'
.*:86: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000012'
.*:87: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000013'
.*:88: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000014'
.*:89: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000015'
.*:90: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000016'
.*:91: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000017'
.*:92: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000018'
.*:93: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000019'
.*:94: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001a'
.*:95: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001b'
.*:96: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001c'
.*:97: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001d'
.*:98: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001e'
.*:99: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100001f'
.*:100: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000020'
.*:101: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000021'
.*:102: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000022'
.*:103: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000023'
.*:104: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000024'
.*:105: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000025'
.*:106: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000026'
.*:107: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000027'
.*:108: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000028'
.*:109: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000029'
.*:110: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002a'
.*:111: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002b'
.*:112: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002c'
.*:113: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002d'
.*:114: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002e'
.*:115: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100002f'
.*:116: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000030'
.*:117: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000031'
.*:118: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000032'
.*:119: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000033'
.*:120: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000034'
.*:121: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000035'
.*:122: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000036'
.*:123: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000037'
.*:124: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000038'
.*:125: Error: opcode not supported on this processor: .* \(.*\) `c0 0x1000039'
.*:126: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003a'
.*:127: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003b'
.*:128: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003c'
.*:129: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003d'
.*:130: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003e'
.*:131: Error: opcode not supported on this processor: .* \(.*\) `c0 0x100003f'
.*:133: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x00'
.*:134: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x01'
.*:135: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x02'
.*:136: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x03'
.*:137: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x04'
.*:138: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x05'
.*:139: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x06'
.*:140: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x07'
.*:141: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x08'
.*:142: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x09'
.*:143: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0a'
.*:144: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0b'
.*:145: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0c'
.*:146: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0d'
.*:147: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0e'
.*:148: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x0f'
.*:149: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x10'
.*:150: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x11'
.*:151: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x12'
.*:152: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x13'
.*:153: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x14'
.*:154: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x15'
.*:155: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x16'
.*:156: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x17'
.*:157: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x18'
.*:158: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x19'
.*:159: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1a'
.*:160: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1b'
.*:161: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1c'
.*:162: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1d'
.*:163: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1e'
.*:164: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1f'
.*:165: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x20'
.*:166: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x21'
.*:167: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x22'
.*:168: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x23'
.*:169: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x24'
.*:170: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x25'
.*:171: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x26'
.*:172: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x27'
.*:173: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x28'
.*:174: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x29'
.*:175: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2a'
.*:176: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2b'
.*:177: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2c'
.*:178: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2d'
.*:179: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2e'
.*:180: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x2f'
.*:181: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x30'
.*:182: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x31'
.*:183: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x32'
.*:184: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x33'
.*:185: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x34'
.*:186: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x35'
.*:187: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x36'
.*:188: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x37'
.*:189: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x38'
.*:190: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x39'
.*:191: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3a'
.*:192: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3b'
.*:193: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3c'
.*:194: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3d'
.*:195: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3e'
.*:196: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x3f'
.*:198: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000000'
.*:199: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000001'
.*:200: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000002'
.*:201: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000003'
.*:202: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000004'
.*:203: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000005'
.*:204: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000006'
.*:205: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000007'
.*:206: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000008'
.*:207: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000009'
.*:208: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000a'
.*:209: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000b'
.*:210: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000c'
.*:211: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000d'
.*:212: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000e'
.*:213: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100000f'
.*:214: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000010'
.*:215: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000011'
.*:216: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000012'
.*:217: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000013'
.*:218: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000014'
.*:219: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000015'
.*:220: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000016'
.*:221: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000017'
.*:222: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000018'
.*:223: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000019'
.*:224: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001a'
.*:225: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001b'
.*:226: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001c'
.*:227: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001d'
.*:228: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001e'
.*:229: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100001f'
.*:230: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000020'
.*:231: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000021'
.*:232: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000022'
.*:233: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000023'
.*:234: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000024'
.*:235: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000025'
.*:236: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000026'
.*:237: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000027'
.*:238: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000028'
.*:239: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000029'
.*:240: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002a'
.*:241: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002b'
.*:242: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002c'
.*:243: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002d'
.*:244: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002e'
.*:245: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100002f'
.*:246: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000030'
.*:247: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000031'
.*:248: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000032'
.*:249: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000033'
.*:250: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000034'
.*:251: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000035'
.*:252: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000036'
.*:253: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000037'
.*:254: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000038'
.*:255: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x1000039'
.*:256: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003a'
.*:257: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003b'
.*:258: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003c'
.*:259: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003d'
.*:260: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003e'
.*:261: Error: opcode not supported on this processor: .* \(.*\) `cop0 0x100003f'
