[^:]*: Assembler messages:
[^:]*:438: Warning: s suffix on comparison instruction is deprecated
[^:]*:450: *Info: macro .*
[^:]*:440: Warning: s suffix on comparison instruction is deprecated
[^:]*:450: *Info: macro .*
[^:]*:444: Warning: s suffix on comparison instruction is deprecated
[^:]*:450: *Info: macro .*
[^:]*:445: Warning: s suffix on comparison instruction is deprecated
[^:]*:450: *Info: macro .*
[^:]*:438: Warning: s suffix on comparison instruction is deprecated
[^:]*:451: *Info: macro .*
[^:]*:440: Warning: s suffix on comparison instruction is deprecated
[^:]*:451: *Info: macro .*
[^:]*:444: Warning: s suffix on comparison instruction is deprecated
[^:]*:451: *Info: macro .*
[^:]*:445: Warning: s suffix on comparison instruction is deprecated
[^:]*:451: *Info: macro .*
[^:]*:438: Warning: s suffix on comparison instruction is deprecated
[^:]*:452: *Info: macro .*
[^:]*:440: Warning: s suffix on comparison instruction is deprecated
[^:]*:452: *Info: macro .*
[^:]*:444: Warning: s suffix on comparison instruction is deprecated
[^:]*:452: *Info: macro .*
[^:]*:445: Warning: s suffix on comparison instruction is deprecated
[^:]*:452: *Info: macro .*
[^:]*:438: Warning: s suffix on comparison instruction is deprecated
[^:]*:453: *Info: macro .*
[^:]*:440: Warning: s suffix on comparison instruction is deprecated
[^:]*:453: *Info: macro .*
[^:]*:444: Warning: s suffix on comparison instruction is deprecated
[^:]*:453: *Info: macro .*
[^:]*:445: Warning: s suffix on comparison instruction is deprecated
[^:]*:453: *Info: macro .*
