#objdump: -dr --prefix-addresses --show-raw-insn -M gpr-names=numeric,cp1-names=r3900
#name: MIPS CP1 register disassembly (r3900)
#as: -32 -march=r3900
#source: cp1-names.s
#dump: cp1-names-numeric.d
