.*: Assembler messages:
.*: Error: selected processor does not support `addpt x0,x0,x0'
.*: Error: selected processor does not support `addpt sp,x0,x0'
.*: Error: selected processor does not support `addpt x0,sp,x0'
.*: Error: selected processor does not support `addpt x0,x0,xzr'
.*: Error: selected processor does not support `addpt x0,x0,x0,lsl ?#0'
.*: Error: selected processor does not support `addpt x0,x0,x0,lsl ?#7'
.*: Error: selected processor does not support `addpt x8,x13,x29,lsl ?#5'
.*: Error: selected processor does not support `subpt x0,x0,x0'
.*: Error: selected processor does not support `subpt sp,x0,x0'
.*: Error: selected processor does not support `subpt x0,sp,x0'
.*: Error: selected processor does not support `subpt x0,x0,xzr'
.*: Error: selected processor does not support `subpt x0,x0,x0,lsl ?#0'
.*: Error: selected processor does not support `subpt x0,x0,x0,lsl ?#7'
.*: Error: selected processor does not support `subpt x1,x10,x22,lsl ?#2'
.*: Error: selected processor does not support `maddpt x0,x0,x0,x0'
.*: Error: selected processor does not support `maddpt xzr,x0,x0,x0'
.*: Error: selected processor does not support `maddpt x0,xzr,x0,x0'
.*: Error: selected processor does not support `maddpt x0,x0,xzr,x0'
.*: Error: selected processor does not support `maddpt x0,x0,x0,xzr'
.*: Error: selected processor does not support `maddpt x19,x10,x1,x28'
.*: Error: selected processor does not support `msubpt x0,x0,x0,x0'
.*: Error: selected processor does not support `msubpt xzr,x0,x0,x0'
.*: Error: selected processor does not support `msubpt x0,xzr,x0,x0'
.*: Error: selected processor does not support `msubpt x0,x0,xzr,x0'
.*: Error: selected processor does not support `msubpt x0,x0,x0,xzr'
.*: Error: selected processor does not support `msubpt x4,x13,x9,x21'
