	sqdmlal	s0, h0, h0
	sqdmlal	s31, h0, h0
	sqdmlal	s0, h31, h0
	sqdmlal	s0, h0, h31
	sqdmlal	d0, s0, s0
	sqdmlal	d31, s0, s0
	sqdmlal	d0, s31, s0
	sqdmlal	d0, s0, s31

	sqdmlsl	s0, h0, h0
	sqdmlsl	s31, h0, h0
	sqdmlsl	s0, h31, h0
	sqdmlsl	s0, h0, h31
	sqdmlsl	d0, s0, s0
	sqdmlsl	d31, s0, s0
	sqdmlsl	d0, s31, s0
	sqdmlsl	d0, s0, s31

	sqdmull	s0, h0, h0
	sqdmull	s31, h0, h0
	sqdmull	s0, h31, h0
	sqdmull	s0, h0, h31
	sqdmull	d0, s0, s0
	sqdmull	d31, s0, s0
	sqdmull	d0, s31, s0
	sqdmull	d0, s0, s31

	sqdmlal	s0, h0, v0.h[0]
	sqdmlal	s31, h0, v0.h[0]
	sqdmlal	s0, h31, v0.h[0]
	sqdmlal	s0, h0, v15.h[0]
	sqdmlal	s0, h0, v0.h[1]
	sqdmlal	s0, h0, v0.h[3]
	sqdmlal	s0, h0, v0.h[7]
	sqdmlal	d0, s0, v0.s[0]
	sqdmlal	d31, s0, v0.s[0]
	sqdmlal	d0, s31, v0.s[0]
	sqdmlal	d0, s0, v31.s[0]
	sqdmlal	d0, s0, v0.s[1]
	sqdmlal	d0, s0, v0.s[3]

	sqdmlsl	s0, h0, v0.h[0]
	sqdmlsl	s31, h0, v0.h[0]
	sqdmlsl	s0, h31, v0.h[0]
	sqdmlsl	s0, h0, v15.h[0]
	sqdmlsl	s0, h0, v0.h[1]
	sqdmlsl	s0, h0, v0.h[3]
	sqdmlsl	s0, h0, v0.h[7]
	sqdmlsl	d0, s0, v0.s[0]
	sqdmlsl	d31, s0, v0.s[0]
	sqdmlsl	d0, s31, v0.s[0]
	sqdmlsl	d0, s0, v31.s[0]
	sqdmlsl	d0, s0, v0.s[1]
	sqdmlsl	d0, s0, v0.s[3]

	sqdmull	s0, h0, v0.h[0]
	sqdmull	s31, h0, v0.h[0]
	sqdmull	s0, h31, v0.h[0]
	sqdmull	s0, h0, v15.h[0]
	sqdmull	s0, h0, v0.h[1]
	sqdmull	s0, h0, v0.h[3]
	sqdmull	s0, h0, v0.h[7]
	sqdmull	d0, s0, v0.s[0]
	sqdmull	d31, s0, v0.s[0]
	sqdmull	d0, s31, v0.s[0]
	sqdmull	d0, s0, v31.s[0]
	sqdmull	d0, s0, v0.s[1]
	sqdmull	d0, s0, v0.s[3]

	sqdmulh	h0, h0, v0.h[0]
	sqdmulh	h31, h0, v0.h[0]
	sqdmulh	h0, h31, v0.h[0]
	sqdmulh	h0, h0, v15.h[0]
	sqdmulh	h0, h0, v0.h[1]
	sqdmulh	h0, h0, v0.h[3]
	sqdmulh	h0, h0, v0.h[7]
	sqdmulh	s0, s0, v0.s[0]
	sqdmulh	s31, s0, v0.s[0]
	sqdmulh	s0, s31, v0.s[0]
	sqdmulh	s0, s0, v31.s[0]
	sqdmulh	s0, s0, v0.s[1]
	sqdmulh	s0, s0, v0.s[3]

	sqrdmulh	h0, h0, v0.h[0]
	sqrdmulh	h31, h0, v0.h[0]
	sqrdmulh	h0, h31, v0.h[0]
	sqrdmulh	h0, h0, v15.h[0]
	sqrdmulh	h0, h0, v0.h[1]
	sqrdmulh	h0, h0, v0.h[3]
	sqrdmulh	h0, h0, v0.h[7]
	sqrdmulh	s0, s0, v0.s[0]
	sqrdmulh	s31, s0, v0.s[0]
	sqrdmulh	s0, s31, v0.s[0]
	sqrdmulh	s0, s0, v31.s[0]
	sqrdmulh	s0, s0, v0.s[1]
	sqrdmulh	s0, s0, v0.s[3]
