 .data
 .octa ~0x112233445566778899aabbcc0000
 .octa -347510587133311339321256747728896
 .octa 0x80000000
 .octa 0xffffffff
 .octa -0x80000000
 .octa -0xffffffff
 .octa ~0x80000000
 .octa ~0xffffffff
 .octa 0 - 0x80000000
 .octa 0 - 0xffffffff

 .octa ~0xfffffffffffffff
 .octa -~0xfffffffffffffff
 .octa ~-~0xfffffffffffffff
 .octa -~-~0xfffffffffffffff

 .octa -0xfffffffffffffff
 .octa ~-0xfffffffffffffff
 .octa -~-0xfffffffffffffff
 .octa ~-~-0xfffffffffffffff
