.*: Assembler messages:
.*: Error: selected processor does not support system register name 'mpamvidcr_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamvidcr_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamvidsr_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamvidsr_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamvidsr_el3'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamvidsr_el3'
.*:  Info: macro invoked from here
