[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: too many registers in vector register list at operand 1 -- `ld1 { ?v1\.2d ?- ?v0\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: too many registers in vector register list at operand 1 -- `ld1 { ?v31\.2d ?- ?v3\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: too many registers in vector register list at operand 1 -- `ld1 { ?v30\.2d ?- ?v2\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: too many registers in vector register list at operand 1 -- `ld1 { ?v29\.2d ?- ?v1\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: too many registers in vector register list at operand 1 -- `ld1 { ?v31\.2d ?- ?v30\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: invalid range in vector register list at operand 1 -- `ld1 { ?v0\.2d ?- ?v0\.2d ?},\[x0\]'
[^ :]+:[0-9]+: Error: invalid range in vector register list at operand 1 -- `ld1 { ?v31\.2d ?- ?v31\.2d ?},\[x0\]'
