.* Assembler messages:
.*:8: Error: invalid instruction `xstore' after `repne'
.*:10: Error: data size prefix invalid with `xstore'
.*:15: Error: invalid instruction `xsha1' after `repne'
.*:17: Error: data size prefix invalid with `xsha1'
