	.arch armv8.4-a
	TLBI VMALLWS2E1
	TLBI VMALLWS2E1IS
	TLBI VMALLWS2E1OS

	.arch armv8.4-a+xs
	TLBI VMALLWS2E1NXS
	TLBI VMALLWS2E1ISNXS
	TLBI VMALLWS2E1OSNXS

	.arch armv8.4-a+tlbid
	TLBI VMALLWS2E1IS, x0
	TLBI VMALLWS2E1OS, x0

	.arch armv8.4-a+tlbid+xs
	TLBI VMALLWS2E1ISNXS, x0
	TLBI VMALLWS2E1OSNXS, x0
