.*Assembler messages:
.*Warning: read-only CSR is written `csrw cycle,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw time,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw instret,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter3,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter4,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter5,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter6,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter7,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter8,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter9,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter10,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter11,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter12,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter13,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter14,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter15,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter16,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter17,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter18,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter19,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter20,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter21,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter22,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter23,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter24,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter25,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter26,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter27,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter28,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter29,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter30,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter31,a1'
.*Info: macro .*
.*Warning: invalid CSR `cycleh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `cycleh', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw cycleh,a1'
.*Info: macro .*
.*Warning: invalid CSR `timeh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `timeh', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw timeh,a1'
.*Info: macro .*
.*Warning: invalid CSR `instreth', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `instreth', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw instreth,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter3h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter3h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter4h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter4h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter4h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter5h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter5h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter5h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter6h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter6h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter6h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter7h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter7h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter7h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter8h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter8h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter8h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter9h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter9h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter9h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter10h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter10h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter10h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter11h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter11h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter11h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter12h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter12h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter12h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter13h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter13h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter13h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter14h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter14h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter14h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter15h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter15h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter15h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter16h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter16h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter16h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter17h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter17h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter17h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter18h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter18h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter18h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter19h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter19h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter19h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter20h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter20h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter20h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter21h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter21h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter21h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter22h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter22h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter22h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter23h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter23h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter23h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter24h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter24h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter24h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter25h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter25h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter25h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter26h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter26h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter26h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter27h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter27h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter27h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter28h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter28h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter28h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter29h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter29h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter29h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter30h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter30h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter30h,a1'
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter31h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hpmcounter31h', needs rv32i extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hpmcounter31h,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw mvendorid,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw marchid,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw mimpid,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw mhartid,a1'
.*Info: macro .*
.*Warning: read-only CSR is written `csrw mconfigptr,a1'
.*Info: macro .*
.*Warning: invalid CSR `medelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `medelegh' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `medelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `medelegh' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `mstatush', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstatush', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `menvcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `menvcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mseccfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mseccfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg1', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg1', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg3', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg3', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg5', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg5', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg7', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg7', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg9', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg9', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg11', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg11', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg13', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg13', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg15', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `pmpcfg15', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mcycleh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mcycleh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `minstreth', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `minstreth', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter4h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter4h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter5h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter5h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter6h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter6h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter7h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter7h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter8h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter8h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter9h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter9h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter10h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter10h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter11h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter11h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter12h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter12h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter13h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter13h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter14h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter14h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter15h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter15h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter16h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter16h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter17h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter17h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter18h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter18h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter19h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter19h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter20h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter20h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter21h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter21h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter22h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter22h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter23h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter23h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter24h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter24h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter25h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter25h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter26h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter26h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter27h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter27h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter28h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter28h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter29h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter29h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter30h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter30h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter31h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmcounter31h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstatus', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstatus', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hedeleg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hedeleg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hedelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hedelegh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hedelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hedelegh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hideleg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hideleg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hcounteren', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hcounteren', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgeie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgeie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htval', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htval', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htinst', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htinst', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgeip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgeip', needs `h' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw hgeip,a1'
.*Info: macro .*
.*Warning: invalid CSR `henvcfg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `henvcfg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `henvcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `henvcfgh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `henvcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `henvcfgh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgatp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hgatp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htimedelta', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htimedelta', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htimedeltah', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `htimedeltah', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `htimedeltah', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `htimedeltah', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsstatus', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsstatus', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsie', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstvec', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstvec', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsscratch', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsscratch', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsepc', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsepc', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vscause', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vscause', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstval', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstval', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsip', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsatp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsatp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `miselect', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `miselect', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mtopei', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mtopei', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mtopi', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mtopi', needs `smaia' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw mtopi,a1'
.*Info: macro .*
.*Warning: invalid CSR `mvien', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mvien', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mvip', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mvip', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `midelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `midelegh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `midelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `midelegh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mieh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mieh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mvienh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mvienh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mvienh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mvienh', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mviph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mviph', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `mviph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mviph', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `miph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `miph', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `miph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `miph', needs `smaia' extension
.*Info: macro .*
.*Warning: invalid CSR `miselect', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `miselect', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg', needs `smaia or smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg2', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg2', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg3', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg3', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg4', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg4', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg5', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg5', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg6', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mireg6', needs `smcsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfg', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfg', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfg', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfg', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfgh', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mcyclecfgh', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfgh', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfgh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `minstretcfgh', needs `smcntrpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mnepc', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mnepc', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mncause', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mncause', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mnscratch', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mnscratch', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mnstatus', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mnstatus', needs `smrnmi' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen0', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen0', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen1', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen1', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen2', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen2', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen3', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `sstateen3', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen0h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen1h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen2h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mstateen3h', needs `smstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen0h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen1h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen2h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hstateen3h', needs `ssstateen' extension
.*Info: macro .*
.*Warning: invalid CSR `siselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `siselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `stopei', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `stopei', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `stopi', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `stopi', needs `ssaia' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw stopi,a1'
.*Info: macro .*
.*Warning: invalid CSR `sieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `sieh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `sieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `sieh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `siph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `siph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `siph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `siph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvien', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvien', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvien', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvien', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvictl', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvictl', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvictl', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvictl', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopei', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopei', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopei', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopei', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopi', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopi', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopi', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstopi', needs `ssaia' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw vstopi,a1'
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hidelegh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hvienh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio1h', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `hviprio2h', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsieh', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiph', needs `ssaia' extension
.*Info: macro .*
.*Warning: invalid CSR `scountinhibit', needs `ssccfg' extension
.*Info: macro .*
.*Warning: invalid CSR `scountinhibit', needs `ssccfg' extension
.*Info: macro .*
.*Warning: invalid CSR `ssp', needs `zicfiss' extension
.*Info: macro .*
.*Warning: invalid CSR `ssp', needs `zicfiss' extension
.*Info: macro .*
.*Warning: invalid CSR `siselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `siselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg2', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg2', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg3', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg3', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg4', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg4', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg5', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg5', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg6', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `sireg6', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsiselect', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg', needs `ssaia or sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg2', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg2', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg2', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg3', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg3', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg3', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg3', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg4', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg4', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg4', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg4', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg5', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg5', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg5', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg5', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg6', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg6', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg6', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vsireg6', needs `sscsrind' extension
.*Info: macro .*
.*Warning: invalid CSR `scountovf', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `scountovf', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw scountovf,a1'
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent3h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent3h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent3h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent4h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent4h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent4h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent4h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent5h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent5h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent5h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent5h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent6h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent6h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent6h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent6h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent7h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent7h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent7h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent7h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent8h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent8h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent8h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent8h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent9h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent9h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent9h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent9h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent10h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent10h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent10h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent10h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent11h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent11h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent11h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent11h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent12h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent12h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent12h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent12h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent13h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent13h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent13h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent13h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent14h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent14h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent14h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent14h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent15h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent15h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent15h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent15h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent16h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent16h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent16h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent16h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent17h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent17h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent17h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent17h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent18h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent18h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent18h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent18h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent19h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent19h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent19h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent19h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent20h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent20h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent20h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent20h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent21h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent21h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent21h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent21h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent22h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent22h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent22h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent22h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent23h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent23h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent23h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent23h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent24h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent24h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent24h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent24h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent25h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent25h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent25h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent25h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent26h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent26h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent26h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent26h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent27h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent27h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent27h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent27h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent28h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent28h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent28h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent28h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent29h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent29h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent29h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent29h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent30h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent30h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent30h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent30h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent31h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent31h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent31h', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `mhpmevent31h', needs `sscofpmf' extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmp', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmp', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmph', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `stimecmph', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmp', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmp', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmp', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs rv32i extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs `h' extension
.*Info: macro .*
.*Warning: invalid CSR `vstimecmph', needs `sstc' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrctl', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrctl', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrstatus', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrstatus', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrdepth', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `sctrdepth', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `vsctrctl', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `vsctrctl', needs `ssctr' extension
.*Info: macro .*
.*Warning: invalid CSR `mctrctl', needs `smctr' extension
.*Info: macro .*
.*Warning: invalid CSR `mctrctl', needs `smctr' extension
.*Info: macro .*
.*Warning: invalid CSR `ustatus' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `ustatus' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uie' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uie' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `utvec' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `utvec' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uscratch' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uscratch' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uepc' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uepc' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `ucause' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `ucause' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `utval' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `utval' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uip' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `uip' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `sedeleg' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `sedeleg' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `sideleg' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `sideleg' for the privileged spec `1.12'
.*Info: macro .*
.*Warning: invalid CSR `fflags', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `fflags', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `frm', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `frm', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `fcsr', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `fcsr', needs `f' extension
.*Info: macro .*
.*Warning: invalid CSR `seed', needs `zkr' extension
.*Info: macro .*
.*Warning: invalid CSR `seed', needs `zkr' extension
.*Info: macro .*
.*Warning: invalid CSR `vstart', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vstart', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vxsat', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vxsat', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vxrm', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vxrm', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vcsr', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vcsr', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vl', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vl', needs `zve32x' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw vl,a1'
.*Info: macro .*
.*Warning: invalid CSR `vtype', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vtype', needs `zve32x' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw vtype,a1'
.*Info: macro .*
.*Warning: invalid CSR `vlenb', needs `zve32x' extension
.*Info: macro .*
.*Warning: invalid CSR `vlenb', needs `zve32x' extension
.*Info: macro .*
.*Warning: read-only CSR is written `csrw vlenb,a1'
.*Info: macro .*
.*Warning: invalid CSR `jvt', needs `zcmt' extension
.*Info: macro .*
.*Warning: invalid CSR `jvt', needs `zcmt' extension
.*Info: macro .*
.*Warning: invalid CSR `srmcfg', needs `ssqosid' extension
.*Info: macro .*
.*Warning: invalid CSR `srmcfg', needs `ssqosid' extension
.*Info: macro .*
