.*Assembler messages:
.*Error: rv32 does not support the `ssnpm' extension
.*Error: rv32 does not support the `smnpm' extension
.*Error: rv32 does not support the `smmpm' extension
.*Error: rv32 does not support the `sspm' extension
.*Error: rv32 does not support the `supm' extension
