extern int protected_data_1a;
extern int protected_data_1b;

extern int *protected_data_1a_p ();
extern int *protected_data_1b_p ();

extern void set_protected_data_1a (int);
extern void set_protected_data_1b (int);

extern int check_protected_data_1a (int);
extern int check_protected_data_1b (int);
