.*: Assembler messages:
.*:7: Warning: .* shortened to .*
.*:8: Warning: .* shortened to .*
.*:9: Warning: .* shortened to .*
.*:11: Warning: .* shortened to .*
.*:12: Warning: .* shortened to .*
.*:13: Warning: .* shortened to .*
.*:15: Warning: .* shortened to .*
.*:16: Warning: .* shortened to .*
.*:17: Warning: .* shortened to .*
