[^:]*: Assembler messages:
[^:]*:2: Error: illegal operand
[^:]*:3: Error: illegal operand
[^:]*:4: Error: illegal operand
[^:]*:5: Error: illegal operand
[^:]*:6: Error: illegal operand
[^:]*:7: Error: illegal operand
[^:]*:8: Error: illegal operand
[^:]*:9: Error: illegal operand
[^:]*:10: Error: illegal operand
[^:]*:11: Error: illegal operand
[^:]*:12: Error: illegal operand
[^:]*:13: Error: illegal operand
[^:]*:14: Error: illegal operand
[^:]*:15: Error: illegal operand
[^:]*:16: Error: illegal operand
[^:]*:17: Error: illegal operand
[^:]*:18: Error: illegal operand
[^:]*:19: Error: illegal operand
[^:]*:20: Error: illegal operand
[^:]*:21: Error: illegal operand
[^:]*:22: Error: illegal operand
[^:]*:23: Error: illegal operand
[^:]*:24: Error: illegal operand
[^:]*:25: Error: illegal operand
[^:]*:26: Error: illegal operand
[^:]*:27: Error: illegal operand
[^:]*:28: Error: illegal operand
[^:]*:29: Error: illegal operand
[^:]*:30: Error: illegal operand
[^:]*:31: Error: illegal operand
[^:]*:32: Error: illegal operand
[^:]*:33: Error: illegal operand
[^:]*:34: Error: illegal operand
[^:]*:35: Error: illegal operand
[^:]*:36: Error: illegal operand
[^:]*:37: Error: illegal operand
[^:]*:38: Error: illegal operand
[^:]*:39: Error: illegal operand
