.*: Assembler messages:
.*: Error: illegal operands `cv.abs.b x32,x32'
.*: Error: illegal operands `cv.abs.b x33,x33'
.*: Error: illegal operands `cv.abs.h x32,x32'
.*: Error: illegal operands `cv.abs.h x33,x33'
.*: Error: illegal operands `cv.add.b x32,x32,x32'
.*: Error: illegal operands `cv.add.b x33,x33,x33'
.*: Error: illegal operands `cv.add.div2 x32,x32,x32'
.*: Error: illegal operands `cv.add.div2 x33,x33,x33'
.*: Error: illegal operands `cv.add.div4 x32,x32,x32'
.*: Error: illegal operands `cv.add.div4 x33,x33,x33'
.*: Error: illegal operands `cv.add.div8 x32,x32,x32'
.*: Error: illegal operands `cv.add.div8 x33,x33,x33'
.*: Error: illegal operands `cv.add.h x32,x32,x32'
.*: Error: illegal operands `cv.add.h x33,x33,x33'
.*: Error: illegal operands `cv.add.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.add.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.add.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.add.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.add.sci.b x32,x32,20'
.*: Error: illegal operands `cv.add.sci.b x33,x33,20'
.*: Error: illegal operands `cv.add.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.add.sci.b x6,x7,32'
.*: Error: illegal operands `cv.add.sci.h x32,x32,20'
.*: Error: illegal operands `cv.add.sci.h x33,x33,20'
.*: Error: illegal operands `cv.add.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.add.sci.h x6,x7,32'
.*: Error: illegal operands `cv.and.b x32,x32,x32'
.*: Error: illegal operands `cv.and.b x33,x33,x33'
.*: Error: illegal operands `cv.and.h x32,x32,x32'
.*: Error: illegal operands `cv.and.h x33,x33,x33'
.*: Error: illegal operands `cv.and.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.and.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.and.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.and.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.and.sci.b x32,x32,20'
.*: Error: illegal operands `cv.and.sci.b x33,x33,20'
.*: Error: illegal operands `cv.and.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.and.sci.b x6,x7,32'
.*: Error: illegal operands `cv.and.sci.h x32,x32,20'
.*: Error: illegal operands `cv.and.sci.h x33,x33,20'
.*: Error: illegal operands `cv.and.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.and.sci.h x6,x7,32'
.*: Error: illegal operands `cv.avg.b x32,x32,x32'
.*: Error: illegal operands `cv.avg.b x33,x33,x33'
.*: Error: illegal operands `cv.avg.h x32,x32,x32'
.*: Error: illegal operands `cv.avg.h x33,x33,x33'
.*: Error: illegal operands `cv.avg.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.avg.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.avg.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.avg.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.avg.sci.b x32,x32,20'
.*: Error: illegal operands `cv.avg.sci.b x33,x33,20'
.*: Error: illegal operands `cv.avg.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.avg.sci.b x6,x7,32'
.*: Error: illegal operands `cv.avg.sci.h x32,x32,20'
.*: Error: illegal operands `cv.avg.sci.h x33,x33,20'
.*: Error: illegal operands `cv.avg.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.avg.sci.h x6,x7,32'
.*: Error: illegal operands `cv.avgu.b x32,x32,x32'
.*: Error: illegal operands `cv.avgu.b x33,x33,x33'
.*: Error: illegal operands `cv.avgu.h x32,x32,x32'
.*: Error: illegal operands `cv.avgu.h x33,x33,x33'
.*: Error: illegal operands `cv.avgu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.avgu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.avgu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.avgu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.avgu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.avgu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.avgu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.avgu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.avgu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.avgu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.avgu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.avgu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.cmpeq.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpeq.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpeq.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpeq.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpeq.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpeq.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpeq.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpeq.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpeq.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpeq.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpeq.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmpeq.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmpeq.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpeq.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpeq.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmpeq.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cmpge.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpge.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpge.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpge.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpge.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpge.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpge.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpge.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpge.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpge.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpge.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmpge.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmpge.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpge.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpge.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmpge.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cmpgeu.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgeu.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgeu.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgeu.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgeu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgeu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgeu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgeu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgeu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpgeu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpgeu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.cmpgeu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.cmpgeu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpgeu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpgeu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.cmpgeu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.cmpgt.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgt.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgt.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgt.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgt.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgt.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgt.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgt.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgt.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpgt.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpgt.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmpgt.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmpgt.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpgt.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpgt.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmpgt.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cmpgtu.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgtu.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgtu.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgtu.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgtu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpgtu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpgtu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpgtu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpgtu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpgtu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpgtu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.cmpgtu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.cmpgtu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpgtu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpgtu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.cmpgtu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.cmple.b x32,x32,x32'
.*: Error: illegal operands `cv.cmple.b x33,x33,x33'
.*: Error: illegal operands `cv.cmple.h x32,x32,x32'
.*: Error: illegal operands `cv.cmple.h x33,x33,x33'
.*: Error: illegal operands `cv.cmple.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmple.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmple.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmple.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmple.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmple.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmple.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmple.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmple.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmple.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmple.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmple.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cmpleu.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpleu.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpleu.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpleu.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpleu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpleu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpleu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpleu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpleu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpleu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpleu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.cmpleu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.cmpleu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpleu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpleu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.cmpleu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.cmplt.b x32,x32,x32'
.*: Error: illegal operands `cv.cmplt.b x33,x33,x33'
.*: Error: illegal operands `cv.cmplt.h x32,x32,x32'
.*: Error: illegal operands `cv.cmplt.h x33,x33,x33'
.*: Error: illegal operands `cv.cmplt.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmplt.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmplt.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmplt.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmplt.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmplt.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmplt.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmplt.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmplt.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmplt.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmplt.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmplt.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cmpltu.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpltu.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpltu.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpltu.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpltu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpltu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpltu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpltu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpltu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpltu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpltu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.cmpltu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.cmpltu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpltu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpltu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.cmpltu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.cmpne.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpne.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpne.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpne.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpne.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.cmpne.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.cmpne.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.cmpne.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.cmpne.sci.b x32,x32,20'
.*: Error: illegal operands `cv.cmpne.sci.b x33,x33,20'
.*: Error: illegal operands `cv.cmpne.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.cmpne.sci.b x6,x7,32'
.*: Error: illegal operands `cv.cmpne.sci.h x32,x32,20'
.*: Error: illegal operands `cv.cmpne.sci.h x33,x33,20'
.*: Error: illegal operands `cv.cmpne.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.cmpne.sci.h x6,x7,32'
.*: Error: illegal operands `cv.cplxconj x32,x32'
.*: Error: illegal operands `cv.cplxconj x33,x33'
.*: Error: illegal operands `cv.cplxmul.i.div2 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.i.div2 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.i.div4 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.i.div4 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.i.div8 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.i.div8 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.i x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.i x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.r.div2 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.r.div2 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.r.div4 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.r.div4 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.r.div8 x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.r.div8 x33,x33,x33'
.*: Error: illegal operands `cv.cplxmul.r x32,x32,x32'
.*: Error: illegal operands `cv.cplxmul.r x33,x33,x33'
.*: Error: illegal operands `cv.dotsp.b x32,x32,x32'
.*: Error: illegal operands `cv.dotsp.b x33,x33,x33'
.*: Error: illegal operands `cv.dotsp.h x32,x32,x32'
.*: Error: illegal operands `cv.dotsp.h x33,x33,x33'
.*: Error: illegal operands `cv.dotsp.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.dotsp.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.dotsp.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.dotsp.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.dotsp.sci.b x32,x32,20'
.*: Error: illegal operands `cv.dotsp.sci.b x33,x33,20'
.*: Error: illegal operands `cv.dotsp.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.dotsp.sci.b x6,x7,32'
.*: Error: illegal operands `cv.dotsp.sci.h x32,x32,20'
.*: Error: illegal operands `cv.dotsp.sci.h x33,x33,20'
.*: Error: illegal operands `cv.dotsp.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.dotsp.sci.h x6,x7,32'
.*: Error: illegal operands `cv.dotup.b x32,x32,x32'
.*: Error: illegal operands `cv.dotup.b x33,x33,x33'
.*: Error: illegal operands `cv.dotup.h x32,x32,x32'
.*: Error: illegal operands `cv.dotup.h x33,x33,x33'
.*: Error: illegal operands `cv.dotup.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.dotup.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.dotup.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.dotup.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.dotup.sci.b x32,x32,20'
.*: Error: illegal operands `cv.dotup.sci.b x33,x33,20'
.*: Error: illegal operands `cv.dotup.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.dotup.sci.b x6,x7,64'
.*: Error: illegal operands `cv.dotup.sci.h x32,x32,20'
.*: Error: illegal operands `cv.dotup.sci.h x33,x33,20'
.*: Error: illegal operands `cv.dotup.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.dotup.sci.h x6,x7,64'
.*: Error: illegal operands `cv.dotusp.b x32,x32,x32'
.*: Error: illegal operands `cv.dotusp.b x33,x33,x33'
.*: Error: illegal operands `cv.dotusp.h x32,x32,x32'
.*: Error: illegal operands `cv.dotusp.h x33,x33,x33'
.*: Error: illegal operands `cv.dotusp.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.dotusp.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.dotusp.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.dotusp.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.dotusp.sci.b x32,x32,20'
.*: Error: illegal operands `cv.dotusp.sci.b x33,x33,20'
.*: Error: illegal operands `cv.dotusp.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.dotusp.sci.b x6,x7,32'
.*: Error: illegal operands `cv.dotusp.sci.h x32,x32,20'
.*: Error: illegal operands `cv.dotusp.sci.h x33,x33,20'
.*: Error: illegal operands `cv.dotusp.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.dotusp.sci.h x6,x7,32'
.*: Error: illegal operands `cv.extract.b x32,x32,2'
.*: Error: illegal operands `cv.extract.b x33,x33,2'
.*: Error: illegal operands `cv.extract.b x6,x7,-1'
.*: Error: illegal operands `cv.extract.b x6,x7,4'
.*: Error: illegal operands `cv.extract.h x32,x32,1'
.*: Error: illegal operands `cv.extract.h x33,x33,1'
.*: Error: illegal operands `cv.extract.h x6,x7,-1'
.*: Error: illegal operands `cv.extract.h x6,x7,2'
.*: Error: illegal operands `cv.extractu.b x32,x32,2'
.*: Error: illegal operands `cv.extractu.b x33,x33,2'
.*: Error: illegal operands `cv.extractu.b x6,x7,-1'
.*: Error: illegal operands `cv.extractu.b x6,x7,4'
.*: Error: illegal operands `cv.extractu.h x32,x32,1'
.*: Error: illegal operands `cv.extractu.h x33,x33,1'
.*: Error: illegal operands `cv.extractu.h x6,x7,-1'
.*: Error: illegal operands `cv.extractu.h x6,x7,2'
.*: Error: illegal operands `cv.insert.b x32,x32,2'
.*: Error: illegal operands `cv.insert.b x33,x33,2'
.*: Error: illegal operands `cv.insert.b x6,x7,-1'
.*: Error: illegal operands `cv.insert.b x6,x7,4'
.*: Error: illegal operands `cv.insert.h x32,x32,1'
.*: Error: illegal operands `cv.insert.h x33,x33,1'
.*: Error: illegal operands `cv.insert.h x6,x7,-1'
.*: Error: illegal operands `cv.insert.h x6,x7,2'
.*: Error: illegal operands `cv.max.b x32,x32,x32'
.*: Error: illegal operands `cv.max.b x33,x33,x33'
.*: Error: illegal operands `cv.max.h x32,x32,x32'
.*: Error: illegal operands `cv.max.h x33,x33,x33'
.*: Error: illegal operands `cv.max.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.max.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.max.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.max.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.max.sci.b x32,x32,20'
.*: Error: illegal operands `cv.max.sci.b x33,x33,20'
.*: Error: illegal operands `cv.max.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.max.sci.b x6,x7,32'
.*: Error: illegal operands `cv.max.sci.h x32,x32,20'
.*: Error: illegal operands `cv.max.sci.h x33,x33,20'
.*: Error: illegal operands `cv.max.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.max.sci.h x6,x7,32'
.*: Error: illegal operands `cv.maxu.b x32,x32,x32'
.*: Error: illegal operands `cv.maxu.b x33,x33,x33'
.*: Error: illegal operands `cv.maxu.h x32,x32,x32'
.*: Error: illegal operands `cv.maxu.h x33,x33,x33'
.*: Error: illegal operands `cv.maxu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.maxu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.maxu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.maxu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.maxu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.maxu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.maxu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.maxu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.maxu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.maxu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.maxu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.maxu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.min.b x32,x32,x32'
.*: Error: illegal operands `cv.min.b x33,x33,x33'
.*: Error: illegal operands `cv.min.h x32,x32,x32'
.*: Error: illegal operands `cv.min.h x33,x33,x33'
.*: Error: illegal operands `cv.min.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.min.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.min.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.min.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.min.sci.b x32,x32,20'
.*: Error: illegal operands `cv.min.sci.b x33,x33,20'
.*: Error: illegal operands `cv.min.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.min.sci.b x6,x7,32'
.*: Error: illegal operands `cv.min.sci.h x32,x32,20'
.*: Error: illegal operands `cv.min.sci.h x33,x33,20'
.*: Error: illegal operands `cv.min.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.min.sci.h x6,x7,32'
.*: Error: illegal operands `cv.minu.b x32,x32,x32'
.*: Error: illegal operands `cv.minu.b x33,x33,x33'
.*: Error: illegal operands `cv.minu.h x32,x32,x32'
.*: Error: illegal operands `cv.minu.h x33,x33,x33'
.*: Error: illegal operands `cv.minu.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.minu.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.minu.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.minu.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.minu.sci.b x32,x32,20'
.*: Error: illegal operands `cv.minu.sci.b x33,x33,20'
.*: Error: illegal operands `cv.minu.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.minu.sci.b x6,x7,64'
.*: Error: illegal operands `cv.minu.sci.h x32,x32,20'
.*: Error: illegal operands `cv.minu.sci.h x33,x33,20'
.*: Error: illegal operands `cv.minu.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.minu.sci.h x6,x7,64'
.*: Error: illegal operands `cv.or.b x32,x32,x32'
.*: Error: illegal operands `cv.or.b x33,x33,x33'
.*: Error: illegal operands `cv.or.h x32,x32,x32'
.*: Error: illegal operands `cv.or.h x33,x33,x33'
.*: Error: illegal operands `cv.or.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.or.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.or.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.or.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.or.sci.b x32,x32,20'
.*: Error: illegal operands `cv.or.sci.b x33,x33,20'
.*: Error: illegal operands `cv.or.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.or.sci.b x6,x7,32'
.*: Error: illegal operands `cv.or.sci.h x32,x32,20'
.*: Error: illegal operands `cv.or.sci.h x33,x33,20'
.*: Error: illegal operands `cv.or.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.or.sci.h x6,x7,32'
.*: Error: illegal operands `cv.pack x32,x32,x32'
.*: Error: illegal operands `cv.pack x33,x33,x33'
.*: Error: illegal operands `cv.pack.h x32,x32,x32'
.*: Error: illegal operands `cv.pack.h x33,x33,x33'
.*: Error: illegal operands `cv.packhi.b x32,x32,x32'
.*: Error: illegal operands `cv.packhi.b x33,x33,x33'
.*: Error: illegal operands `cv.packlo.b x32,x32,x32'
.*: Error: illegal operands `cv.packlo.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotsp.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotsp.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotsp.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotsp.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotsp.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotsp.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotsp.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotsp.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotsp.sci.b x32,x32,20'
.*: Error: illegal operands `cv.sdotsp.sci.b x33,x33,20'
.*: Error: illegal operands `cv.sdotsp.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.sdotsp.sci.b x6,x7,32'
.*: Error: illegal operands `cv.sdotsp.sci.h x32,x32,20'
.*: Error: illegal operands `cv.sdotsp.sci.h x33,x33,20'
.*: Error: illegal operands `cv.sdotsp.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.sdotsp.sci.h x6,x7,32'
.*: Error: illegal operands `cv.sdotup.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotup.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotup.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotup.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotup.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotup.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotup.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotup.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotup.sci.b x32,x32,20'
.*: Error: illegal operands `cv.sdotup.sci.b x33,x33,20'
.*: Error: illegal operands `cv.sdotup.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.sdotup.sci.b x6,x7,64'
.*: Error: illegal operands `cv.sdotup.sci.h x32,x32,20'
.*: Error: illegal operands `cv.sdotup.sci.h x33,x33,20'
.*: Error: illegal operands `cv.sdotup.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.sdotup.sci.h x6,x7,64'
.*: Error: illegal operands `cv.sdotusp.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotusp.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotusp.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotusp.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotusp.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sdotusp.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sdotusp.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sdotusp.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sdotusp.sci.b x32,x32,20'
.*: Error: illegal operands `cv.sdotusp.sci.b x33,x33,20'
.*: Error: illegal operands `cv.sdotusp.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.sdotusp.sci.b x6,x7,32'
.*: Error: illegal operands `cv.sdotusp.sci.h x32,x32,20'
.*: Error: illegal operands `cv.sdotusp.sci.h x33,x33,20'
.*: Error: illegal operands `cv.sdotusp.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.sdotusp.sci.h x6,x7,32'
.*: Error: illegal operands `cv.shuffle2.b x32,x32,x32'
.*: Error: illegal operands `cv.shuffle2.b x33,x33,x33'
.*: Error: illegal operands `cv.shuffle2.h x32,x32,x32'
.*: Error: illegal operands `cv.shuffle2.h x33,x33,x33'
.*: Error: illegal operands `cv.shuffle.b x32,x32,x32'
.*: Error: illegal operands `cv.shuffle.b x33,x33,x33'
.*: Error: illegal operands `cv.shuffle.h x32,x32,x32'
.*: Error: illegal operands `cv.shuffle.h x33,x33,x33'
.*: Error: illegal operands `cv.shufflei0.sci.b x32,x32,20'
.*: Error: illegal operands `cv.shufflei0.sci.b x33,x33,20'
.*: Error: illegal operands `cv.shufflei0.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.shufflei0.sci.b x6,x7,64'
.*: Error: illegal operands `cv.shufflei1.sci.b x32,x32,20'
.*: Error: illegal operands `cv.shufflei1.sci.b x33,x33,20'
.*: Error: illegal operands `cv.shufflei1.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.shufflei1.sci.b x6,x7,64'
.*: Error: illegal operands `cv.shufflei2.sci.b x32,x32,20'
.*: Error: illegal operands `cv.shufflei2.sci.b x33,x33,20'
.*: Error: illegal operands `cv.shufflei2.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.shufflei2.sci.b x6,x7,64'
.*: Error: illegal operands `cv.shufflei3.sci.b x32,x32,20'
.*: Error: illegal operands `cv.shufflei3.sci.b x33,x33,20'
.*: Error: illegal operands `cv.shufflei3.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.shufflei3.sci.b x6,x7,64'
.*: Error: illegal operands `cv.shuffle.sci.h x32,x32,20'
.*: Error: illegal operands `cv.shuffle.sci.h x33,x33,20'
.*: Error: illegal operands `cv.shuffle.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.shuffle.sci.h x6,x7,64'
.*: Error: illegal operands `cv.sll.b x32,x32,x32'
.*: Error: illegal operands `cv.sll.b x33,x33,x33'
.*: Error: illegal operands `cv.sll.h x32,x32,x32'
.*: Error: illegal operands `cv.sll.h x33,x33,x33'
.*: Error: illegal operands `cv.sll.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sll.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sll.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sll.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sll.sci.b x32,x32,4'
.*: Error: illegal operands `cv.sll.sci.b x33,x33,4'
.*: Error: illegal operands `cv.sll.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.sll.sci.b x6,x7,8'
.*: Error: illegal operands `cv.sll.sci.h x32,x32,12'
.*: Error: illegal operands `cv.sll.sci.h x33,x33,12'
.*: Error: illegal operands `cv.sll.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.sll.sci.h x6,x7,16'
.*: Error: illegal operands `cv.sra.b x32,x32,x32'
.*: Error: illegal operands `cv.sra.b x33,x33,x33'
.*: Error: illegal operands `cv.sra.h x32,x32,x32'
.*: Error: illegal operands `cv.sra.h x33,x33,x33'
.*: Error: illegal operands `cv.sra.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sra.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sra.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sra.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sra.sci.b x32,x32,4'
.*: Error: illegal operands `cv.sra.sci.b x33,x33,4'
.*: Error: illegal operands `cv.sra.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.sra.sci.b x6,x7,8'
.*: Error: illegal operands `cv.sra.sci.h x32,x32,12'
.*: Error: illegal operands `cv.sra.sci.h x33,x33,12'
.*: Error: illegal operands `cv.sra.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.sra.sci.h x6,x7,16'
.*: Error: illegal operands `cv.srl.b x32,x32,x32'
.*: Error: illegal operands `cv.srl.b x33,x33,x33'
.*: Error: illegal operands `cv.srl.h x32,x32,x32'
.*: Error: illegal operands `cv.srl.h x33,x33,x33'
.*: Error: illegal operands `cv.srl.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.srl.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.srl.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.srl.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.srl.sci.b x32,x32,4'
.*: Error: illegal operands `cv.srl.sci.b x33,x33,4'
.*: Error: illegal operands `cv.srl.sci.b x6,x7,-1'
.*: Error: illegal operands `cv.srl.sci.b x6,x7,8'
.*: Error: illegal operands `cv.srl.sci.h x32,x32,12'
.*: Error: illegal operands `cv.srl.sci.h x33,x33,12'
.*: Error: illegal operands `cv.srl.sci.h x6,x7,-1'
.*: Error: illegal operands `cv.srl.sci.h x6,x7,16'
.*: Error: illegal operands `cv.sub.b x32,x32,x32'
.*: Error: illegal operands `cv.sub.b x33,x33,x33'
.*: Error: illegal operands `cv.sub.div2 x32,x32,x32'
.*: Error: illegal operands `cv.sub.div2 x33,x33,x33'
.*: Error: illegal operands `cv.sub.div4 x32,x32,x32'
.*: Error: illegal operands `cv.sub.div4 x33,x33,x33'
.*: Error: illegal operands `cv.sub.div8 x32,x32,x32'
.*: Error: illegal operands `cv.sub.div8 x33,x33,x33'
.*: Error: illegal operands `cv.sub.h x32,x32,x32'
.*: Error: illegal operands `cv.sub.h x33,x33,x33'
.*: Error: illegal operands `cv.subrotmj.div2 x32,x32,x32'
.*: Error: illegal operands `cv.subrotmj.div2 x33,x33,x33'
.*: Error: illegal operands `cv.subrotmj.div4 x32,x32,x32'
.*: Error: illegal operands `cv.subrotmj.div4 x33,x33,x33'
.*: Error: illegal operands `cv.subrotmj.div8 x32,x32,x32'
.*: Error: illegal operands `cv.subrotmj.div8 x33,x33,x33'
.*: Error: illegal operands `cv.subrotmj x32,x32,x32'
.*: Error: illegal operands `cv.subrotmj x33,x33,x33'
.*: Error: illegal operands `cv.sub.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.sub.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.sub.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.sub.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.sub.sci.b x32,x32,20'
.*: Error: illegal operands `cv.sub.sci.b x33,x33,20'
.*: Error: illegal operands `cv.sub.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.sub.sci.b x6,x7,32'
.*: Error: illegal operands `cv.sub.sci.h x32,x32,20'
.*: Error: illegal operands `cv.sub.sci.h x33,x33,20'
.*: Error: illegal operands `cv.sub.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.sub.sci.h x6,x7,32'
.*: Error: illegal operands `cv.xor.b x32,x32,x32'
.*: Error: illegal operands `cv.xor.b x33,x33,x33'
.*: Error: illegal operands `cv.xor.h x32,x32,x32'
.*: Error: illegal operands `cv.xor.h x33,x33,x33'
.*: Error: illegal operands `cv.xor.sc.b x32,x32,x32'
.*: Error: illegal operands `cv.xor.sc.b x33,x33,x33'
.*: Error: illegal operands `cv.xor.sc.h x32,x32,x32'
.*: Error: illegal operands `cv.xor.sc.h x33,x33,x33'
.*: Error: illegal operands `cv.xor.sci.b x32,x32,20'
.*: Error: illegal operands `cv.xor.sci.b x33,x33,20'
.*: Error: illegal operands `cv.xor.sci.b x6,x7,-33'
.*: Error: illegal operands `cv.xor.sci.b x6,x7,32'
.*: Error: illegal operands `cv.xor.sci.h x32,x32,20'
.*: Error: illegal operands `cv.xor.sci.h x33,x33,20'
.*: Error: illegal operands `cv.xor.sci.h x6,x7,-33'
.*: Error: illegal operands `cv.xor.sci.h x6,x7,32'
