.*: Assembler messages:
.*: Error: operand mismatch -- `bfadd z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfadd z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfadd z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfadd z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfadd z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfadd z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfadd z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmax z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmax z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmax z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmax z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmax z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfmax z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmax z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmax z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmax z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmax z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmax z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmax z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmaxnm z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmaxnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmaxnm z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmaxnm z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmaxnm z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfmaxnm z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmaxnm z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmaxnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmaxnm z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmaxnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmaxnm z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmaxnm z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmin z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmin z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmin z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmin z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmin z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfmin z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmin z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmin z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmin z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmin z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmin z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmin z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfminnm z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfminnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfminnm z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfminnm z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfminnm z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfminnm z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfminnm z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfminnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfminnm z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfminnm z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfminnm z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfminnm z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmla z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmla z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmla z0.h,p8/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmla z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmla z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmla z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmls z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmls z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmls z0.h,p8/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmls z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmls z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmls z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfmul z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmul z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfmul z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfmul z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfmul z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmul z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfmul z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfsub z0.s,p0/m,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfsub z0.h,p0/z,z0.h,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, p0/m, z0.h, z16.h
.*: Error: p0-p7 expected at operand 2 -- `bfsub z0.h,p8/m,z0.h,z16.h'
.*: Error: operand 3 must be the same register as operand 1 -- `bfsub z31.h,p0/m,z0.h,z16.h'
.*: Error: operand mismatch -- `bfsub z0.h,p0/z,z0.s,z16.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfsub z0.h,p0/z,z0.h,z16.d'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, p0/m, z0.h, z16.h
.*: Error: operand mismatch -- `bfsub z31.d,p7/m,z31.d,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z31.h, p7/m, z31.h, z31.h
.*: Error: operand mismatch -- `bfadd z0.b,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfadd z0.s,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfadd z0.h,z0.d,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfadd z0.h,z0.h,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfadd z31.b,z31.s,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfadd z31.h, z31.h, z31.h
.*: Error: expected a register at operand 1 -- `bfadd { ?z0.h ?},z0.h,z0.h'
.*: Error: expected a register at operand 1 -- `bfadd { ?z0.h-z0.h ?},z0.h'
.*: Error: comma expected between operands at operand 3 -- `bfadd z0.h,z0.h'
.*: Error: operand mismatch -- `bfclamp z0.b,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfclamp z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfclamp z0.s,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfclamp z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfclamp z0.h,z0.d,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfclamp z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfclamp z0.h,z0.h,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	bfclamp z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfclamp z31.b,z31.s,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfclamp z31.h, z31.h, z31.h
.*: Error: expected a list of 2 or 4 registers at operand 1 -- `bfclamp { ?z0.h ?},z0.h,z0.h'
.*: Error: invalid range in vector register list at operand 1 -- `bfclamp { ?z0.h-z0.h ?},z0.h'
.*: Error: comma expected between operands at operand 3 -- `bfclamp z0.h,z0.h'
.*: Error: operand mismatch -- `bfmla z0.b,z0.h,z0.h\[0\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, z0.h, z0.h\[0\]
.*: Error: operand mismatch -- `bfmla z0.s,z0.h,z0.h\[6\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, z0.h, z0.h\[6\]
.*: Error: operand mismatch -- `bfmla z0.h,z0.d,z0.h\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, z0.h, z0.h\[8\]
.*: Error: operand mismatch -- `bfmla z0.h,z0.h,z0.b\[2\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z0.h, z0.h, z0.h\[2\]
.*: Error: operand mismatch -- `bfmla z31.b,z31.s,z31.d\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmla z31.h, z31.h, z31.h\[8\]
.*: Error: expected a register at operand 1 -- `bfmla { ?z0.h ?},z0.h,z0.h\[1\]'
.*: Error: expected a register at operand 1 -- `bfmla { ?z0.h-z0.h ?},z0.h\[2\]'
.*: Error: expected an SVE predicate register at operand 2 -- `bfmla z0.h,z0.h\[3\]'
.*: Error: operand mismatch -- `bfmls z0.b,z0.h,z0.h\[0\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, z0.h, z0.h\[0\]
.*: Error: operand mismatch -- `bfmls z0.s,z0.h,z0.h\[6\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, z0.h, z0.h\[6\]
.*: Error: operand mismatch -- `bfmls z0.h,z0.d,z0.h\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, z0.h, z0.h\[8\]
.*: Error: operand mismatch -- `bfmls z0.h,z0.h,z0.b\[2\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z0.h, z0.h, z0.h\[2\]
.*: Error: operand mismatch -- `bfmls z31.b,z31.s,z31.d\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmls z31.h, z31.h, z31.h\[8\]
.*: Error: expected a register at operand 1 -- `bfmls { ?z0.h ?},z0.h,z0.h\[1\]'
.*: Error: expected a register at operand 1 -- `bfmls { ?z0.h-z0.h ?},z0.h\[2\]'
.*: Error: expected an SVE predicate register at operand 2 -- `bfmls z0.h,z0.h\[3\]'
.*: Error: operand mismatch -- `bfmul z0.b,z0.h,z0.h\[0\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, z0.h, z0.h\[0\]
.*: Error: operand mismatch -- `bfmul z0.s,z0.h,z0.h\[6\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, z0.h, z0.h\[6\]
.*: Error: operand mismatch -- `bfmul z0.h,z0.d,z0.h\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, z0.h, z0.h\[8\]
.*: Error: operand mismatch -- `bfmul z0.h,z0.h,z0.b\[2\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z0.h, z0.h, z0.h\[2\]
.*: Error: operand mismatch -- `bfmul z31.b,z31.s,z31.d\[8\]'
.*: Info:    did you mean this\?
.*: Info:    	bfmul z31.h, z31.h, z31.h\[8\]
.*: Error: missing braces at operand 2 -- `bfmul { ?z0.h ?},z0.h,z0.h\[1\]'
.*: Error: invalid range in vector register list at operand 1 -- `bfmul { ?z0.h-z0.h ?},z0.h\[2\]'
.*: Error: expected an SVE predicate register at operand 2 -- `bfmul z0.h,z0.h\[3\]'
.*: Error: operand mismatch -- `bfsub z0.b,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfsub z0.s,z0.h,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfsub z0.h,z0.d,z0.h'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfsub z0.h,z0.h,z0.b'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z0.h, z0.h, z0.h
.*: Error: operand mismatch -- `bfsub z31.b,z31.s,z31.d'
.*: Info:    did you mean this\?
.*: Info:    	bfsub z31.h, z31.h, z31.h
.*: Error: expected a register at operand 1 -- `bfsub { ?z0.h ?},z0.h,z0.h'
.*: Error: expected a register at operand 1 -- `bfsub { ?z0.h-z0.h ?},z0.h'
.*: Error: comma expected between operands at operand 3 -- `bfsub z0.h,z0.h'
.*: Warning: output register of preceding `movprfx' expected as output at operand 1 -- `bfclamp z1.h,z3.h,z16.h'
.*: Warning: output register of preceding `movprfx' not used in current instruction at operand 1 -- `bfmla z10.h,z16.h,z3.h\[7\]'
.*: Warning: output register of preceding `movprfx' expected as output at operand 1 -- `bfmls z1.h,z3.h,z3.h\[7\]'
.*: Warning: instruction opens new dependency sequence without ending previous one -- `movprfx z4,z5'
.*: Warning: output register of preceding `movprfx' expected as output at operand 1 -- `bfclamp z2.h,z3.h,z4.h'
