.*: Assembler messages:
.*:4: Error: invalid operands `crc32d \$5,\$4,\$4'
.*:6: Error: invalid operands `crc32d \$4,\$4,\$5'
.*:7: Error: invalid operands `crc32d \$4,\$5,\$6'
.*:9: Error: invalid operands `crc32cd \$5,\$4,\$4'
.*:11: Error: invalid operands `crc32cd \$4,\$4,\$5'
.*:12: Error: invalid operands `crc32cd \$4,\$5,\$6'
