.*: Assembler messages:
.*:4: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$0,0\(\$0\)'
.*:5: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$1,0\(\$0\)'
.*:6: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$2,0\(\$0\)'
.*:7: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$3,0\(\$0\)'
.*:8: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$4,0\(\$0\)'
.*:9: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$5,0\(\$0\)'
.*:10: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$6,0\(\$0\)'
.*:11: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$7,0\(\$0\)'
.*:12: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$8,0\(\$0\)'
.*:13: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$9,0\(\$0\)'
.*:14: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$10,0\(\$0\)'
.*:15: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$11,0\(\$0\)'
.*:16: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$12,0\(\$0\)'
.*:17: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$13,0\(\$0\)'
.*:18: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$14,0\(\$0\)'
.*:19: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$15,0\(\$0\)'
.*:20: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$16,0\(\$0\)'
.*:21: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$17,0\(\$0\)'
.*:22: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$18,0\(\$0\)'
.*:23: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$19,0\(\$0\)'
.*:24: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$20,0\(\$0\)'
.*:25: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$21,0\(\$0\)'
.*:26: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$22,0\(\$0\)'
.*:27: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$23,0\(\$0\)'
.*:28: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$24,0\(\$0\)'
.*:29: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$25,0\(\$0\)'
.*:30: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$26,0\(\$0\)'
.*:31: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$27,0\(\$0\)'
.*:32: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$28,0\(\$0\)'
.*:33: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$29,0\(\$0\)'
.*:34: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$30,0\(\$0\)'
.*:35: Error: opcode not supported on this processor: .* \(.*\) `lwc3 \$31,0\(\$0\)'
.*:37: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$0,0\(\$0\)'
.*:38: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$1,0\(\$0\)'
.*:39: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$2,0\(\$0\)'
.*:40: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$3,0\(\$0\)'
.*:41: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$4,0\(\$0\)'
.*:42: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$5,0\(\$0\)'
.*:43: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$6,0\(\$0\)'
.*:44: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$7,0\(\$0\)'
.*:45: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$8,0\(\$0\)'
.*:46: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$9,0\(\$0\)'
.*:47: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$10,0\(\$0\)'
.*:48: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$11,0\(\$0\)'
.*:49: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$12,0\(\$0\)'
.*:50: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$13,0\(\$0\)'
.*:51: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$14,0\(\$0\)'
.*:52: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$15,0\(\$0\)'
.*:53: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$16,0\(\$0\)'
.*:54: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$17,0\(\$0\)'
.*:55: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$18,0\(\$0\)'
.*:56: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$19,0\(\$0\)'
.*:57: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$20,0\(\$0\)'
.*:58: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$21,0\(\$0\)'
.*:59: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$22,0\(\$0\)'
.*:60: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$23,0\(\$0\)'
.*:61: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$24,0\(\$0\)'
.*:62: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$25,0\(\$0\)'
.*:63: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$26,0\(\$0\)'
.*:64: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$27,0\(\$0\)'
.*:65: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$28,0\(\$0\)'
.*:66: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$29,0\(\$0\)'
.*:67: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$30,0\(\$0\)'
.*:68: Error: opcode not supported on this processor: .* \(.*\) `swc3 \$31,0\(\$0\)'
