[^:]*: Assembler messages:
[^:]*:13: Warning: a NOP might be needed here, before an interrupt enable instruction
[^:]*:15: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*:17: Warning: a NOP might be needed here, before an interrupt enable instruction
[^:]*:19: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*:41: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*:48: Warning: a NOP might be needed here, after an interrupt enable instruction
[^:]*:60: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*:66: Warning: a NOP might be needed here, after an interrupt disable instruction
[^:]*: Warning: a NOP might be needed after the interrupt state change at the end of the file
