#as: --text-section-literals
#objdump: -d
#name: text-section-literals (handle text section literal in .init and .fini without .literal_position)

.*: +file format .*xtensa.*
#...
Disassembly of section .init.literal:
#...
Disassembly of section .fini.literal:
#...
Disassembly of section .init:
#...
 *0:.*l32r.*
#...
Disassembly of section .fini:
#...
 *0:.*l32r.*
#...
