.*: Assembler messages:
.*: Error: selected processor does not support system register name 'pmsdsfr_el1'
.*: Error: selected processor does not support system register name 'pmsdsfr_el1'
.*: Error: selected processor does not support system register name 'erxgsr_el1'
.*: Error: selected processor does not support system register name 'hdfgrtr2_el2'
.*: Error: selected processor does not support system register name 'hdfgrtr2_el2'
.*: Error: selected processor does not support system register name 'hdfgwtr2_el2'
.*: Error: selected processor does not support system register name 'hdfgwtr2_el2'
.*: Error: selected processor does not support system register name 'hfgrtr2_el2'
.*: Error: selected processor does not support system register name 'hfgrtr2_el2'
.*: Error: selected processor does not support system register name 'hfgwtr2_el2'
.*: Error: selected processor does not support system register name 'hfgwtr2_el2'
.*: Error: selected processor does not support system register name 'pfar_el1'
.*: Error: selected processor does not support system register name 'pfar_el1'
.*: Error: selected processor does not support system register name 'pfar_el2'
.*: Error: selected processor does not support system register name 'pfar_el2'
.*: Error: selected processor does not support system register name 'pfar_el12'
.*: Error: selected processor does not support system register name 'pfar_el12'
.*: Error: selected processor does not support system register name 's1e1a'
.*: Error: selected processor does not support system register name 's1e2a'
.*: Error: selected processor does not support system register name 's1e3a'
.*: Error: selected processor does not support system register name 'amair2_el1'
.*: Error: selected processor does not support system register name 'amair2_el1'
.*: Error: selected processor does not support system register name 'amair2_el12'
.*: Error: selected processor does not support system register name 'amair2_el12'
.*: Error: selected processor does not support system register name 'amair2_el2'
.*: Error: selected processor does not support system register name 'amair2_el2'
.*: Error: selected processor does not support system register name 'amair2_el3'
.*: Error: selected processor does not support system register name 'amair2_el3'
.*: Error: selected processor does not support system register name 'mair2_el1'
.*: Error: selected processor does not support system register name 'mair2_el1'
.*: Error: selected processor does not support system register name 'mair2_el12'
.*: Error: selected processor does not support system register name 'mair2_el12'
.*: Error: selected processor does not support system register name 'mair2_el2'
.*: Error: selected processor does not support system register name 'mair2_el2'
.*: Error: selected processor does not support system register name 'mair2_el3'
.*: Error: selected processor does not support system register name 'mair2_el3'
.*: Error: selected processor does not support system register name 'pir_el1'
.*: Error: selected processor does not support system register name 'pir_el1'
.*: Error: selected processor does not support system register name 'pir_el12'
.*: Error: selected processor does not support system register name 'pir_el12'
.*: Error: selected processor does not support system register name 'pir_el2'
.*: Error: selected processor does not support system register name 'pir_el2'
.*: Error: selected processor does not support system register name 'pir_el3'
.*: Error: selected processor does not support system register name 'pir_el3'
.*: Error: selected processor does not support system register name 'pire0_el1'
.*: Error: selected processor does not support system register name 'pire0_el1'
.*: Error: selected processor does not support system register name 'pire0_el12'
.*: Error: selected processor does not support system register name 'pire0_el12'
.*: Error: selected processor does not support system register name 'pire0_el2'
.*: Error: selected processor does not support system register name 'pire0_el2'
.*: Error: selected processor does not support system register name 's2pir_el2'
.*: Error: selected processor does not support system register name 's2pir_el2'
.*: Error: selected processor does not support system register name 'por_el0'
.*: Error: selected processor does not support system register name 'por_el0'
.*: Error: selected processor does not support system register name 'por_el1'
.*: Error: selected processor does not support system register name 'por_el1'
.*: Error: selected processor does not support system register name 'por_el12'
.*: Error: selected processor does not support system register name 'por_el12'
.*: Error: selected processor does not support system register name 'por_el2'
.*: Error: selected processor does not support system register name 'por_el2'
.*: Error: selected processor does not support system register name 'por_el3'
.*: Error: selected processor does not support system register name 'por_el3'
.*: Error: selected processor does not support system register name 's2por_el1'
.*: Error: selected processor does not support system register name 's2por_el1'
.*: Error: selected processor does not support system register name 'mdselr_el1'
.*: Error: selected processor does not support system register name 'mdselr_el1'
.*: Error: selected processor does not support system register name 'pmuacr_el1'
.*: Error: selected processor does not support system register name 'pmuacr_el1'
.*: Error: selected processor does not support system register name 'pmccntsvr_el1'
.*: Error: selected processor does not support system register name 'pmicntsvr_el1'
.*: Error: selected processor does not support system register name 'pmsscr_el1'
.*: Error: selected processor does not support system register name 'pmsscr_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr0_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr10_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr11_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr12_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr13_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr14_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr15_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr16_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr17_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr18_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr19_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr1_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr20_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr21_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr22_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr23_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr24_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr25_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr26_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr27_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr28_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr29_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr30_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr3_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr4_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr5_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr6_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr7_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr8_el1'
.*: Error: selected processor does not support system register name 'pmevcntsvr9_el1'
.*: Error: selected processor does not support system register name 'pmicntr_el0'
.*: Error: selected processor does not support system register name 'pmicntr_el0'
.*: Error: selected processor does not support system register name 'pmicfiltr_el0'
.*: Error: selected processor does not support system register name 'pmicfiltr_el0'
.*: Error: selected processor does not support system register name 'pmzr_el0'
.*: Error: selected processor does not support system register name 'spmaccessr_el1'
.*: Error: selected processor does not support system register name 'spmaccessr_el1'
.*: Error: selected processor does not support system register name 'spmaccessr_el2'
.*: Error: selected processor does not support system register name 'spmaccessr_el2'
.*: Error: selected processor does not support system register name 'spmaccessr_el3'
.*: Error: selected processor does not support system register name 'spmaccessr_el3'
.*: Error: selected processor does not support system register name 'spmcfgr_el1'
.*: Error: selected processor does not support system register name 'spmcgcr0_el1'
.*: Error: selected processor does not support system register name 'spmcgcr1_el1'
.*: Error: selected processor does not support system register name 'spmcntenclr_el0'
.*: Error: selected processor does not support system register name 'spmcntenclr_el0'
.*: Error: selected processor does not support system register name 'spmcntenset_el0'
.*: Error: selected processor does not support system register name 'spmcntenset_el0'
.*: Error: selected processor does not support system register name 'spmcr_el0'
.*: Error: selected processor does not support system register name 'spmcr_el0'
.*: Error: selected processor does not support system register name 'spmdevaff_el1'
.*: Error: selected processor does not support system register name 'spmdevarch_el1'
.*: Error: selected processor does not support system register name 'spmevcntr0_el0'
.*: Error: selected processor does not support system register name 'spmevcntr0_el0'
.*: Error: selected processor does not support system register name 'spmevcntr1_el0'
.*: Error: selected processor does not support system register name 'spmevcntr1_el0'
.*: Error: selected processor does not support system register name 'spmevcntr2_el0'
.*: Error: selected processor does not support system register name 'spmevcntr2_el0'
.*: Error: selected processor does not support system register name 'spmevcntr3_el0'
.*: Error: selected processor does not support system register name 'spmevcntr3_el0'
.*: Error: selected processor does not support system register name 'spmevcntr4_el0'
.*: Error: selected processor does not support system register name 'spmevcntr4_el0'
.*: Error: selected processor does not support system register name 'spmevcntr5_el0'
.*: Error: selected processor does not support system register name 'spmevcntr5_el0'
.*: Error: selected processor does not support system register name 'spmevcntr6_el0'
.*: Error: selected processor does not support system register name 'spmevcntr6_el0'
.*: Error: selected processor does not support system register name 'spmevcntr7_el0'
.*: Error: selected processor does not support system register name 'spmevcntr7_el0'
.*: Error: selected processor does not support system register name 'spmevcntr8_el0'
.*: Error: selected processor does not support system register name 'spmevcntr8_el0'
.*: Error: selected processor does not support system register name 'spmevcntr9_el0'
.*: Error: selected processor does not support system register name 'spmevcntr9_el0'
.*: Error: selected processor does not support system register name 'spmevcntr10_el0'
.*: Error: selected processor does not support system register name 'spmevcntr10_el0'
.*: Error: selected processor does not support system register name 'spmevcntr11_el0'
.*: Error: selected processor does not support system register name 'spmevcntr11_el0'
.*: Error: selected processor does not support system register name 'spmevcntr12_el0'
.*: Error: selected processor does not support system register name 'spmevcntr12_el0'
.*: Error: selected processor does not support system register name 'spmevcntr13_el0'
.*: Error: selected processor does not support system register name 'spmevcntr13_el0'
.*: Error: selected processor does not support system register name 'spmevcntr14_el0'
.*: Error: selected processor does not support system register name 'spmevcntr14_el0'
.*: Error: selected processor does not support system register name 'spmevcntr15_el0'
.*: Error: selected processor does not support system register name 'spmevcntr15_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r0_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r0_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r1_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r1_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r2_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r2_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r3_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r3_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r4_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r4_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r5_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r5_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r6_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r6_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r7_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r7_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r8_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r8_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r9_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r9_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r10_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r10_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r11_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r11_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r12_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r12_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r13_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r13_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r14_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r14_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r15_el0'
.*: Error: selected processor does not support system register name 'spmevfilt2r15_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr0_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr0_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr1_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr1_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr2_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr2_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr3_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr3_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr4_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr4_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr5_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr5_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr6_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr6_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr7_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr7_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr8_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr8_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr9_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr9_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr10_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr10_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr11_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr11_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr12_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr12_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr13_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr13_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr14_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr14_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr15_el0'
.*: Error: selected processor does not support system register name 'spmevfiltr15_el0'
.*: Error: selected processor does not support system register name 'spmevtyper0_el0'
.*: Error: selected processor does not support system register name 'spmevtyper0_el0'
.*: Error: selected processor does not support system register name 'spmevtyper1_el0'
.*: Error: selected processor does not support system register name 'spmevtyper1_el0'
.*: Error: selected processor does not support system register name 'spmevtyper2_el0'
.*: Error: selected processor does not support system register name 'spmevtyper2_el0'
.*: Error: selected processor does not support system register name 'spmevtyper3_el0'
.*: Error: selected processor does not support system register name 'spmevtyper3_el0'
.*: Error: selected processor does not support system register name 'spmevtyper4_el0'
.*: Error: selected processor does not support system register name 'spmevtyper4_el0'
.*: Error: selected processor does not support system register name 'spmevtyper5_el0'
.*: Error: selected processor does not support system register name 'spmevtyper5_el0'
.*: Error: selected processor does not support system register name 'spmevtyper6_el0'
.*: Error: selected processor does not support system register name 'spmevtyper6_el0'
.*: Error: selected processor does not support system register name 'spmevtyper7_el0'
.*: Error: selected processor does not support system register name 'spmevtyper7_el0'
.*: Error: selected processor does not support system register name 'spmevtyper8_el0'
.*: Error: selected processor does not support system register name 'spmevtyper8_el0'
.*: Error: selected processor does not support system register name 'spmevtyper9_el0'
.*: Error: selected processor does not support system register name 'spmevtyper9_el0'
.*: Error: selected processor does not support system register name 'spmevtyper10_el0'
.*: Error: selected processor does not support system register name 'spmevtyper10_el0'
.*: Error: selected processor does not support system register name 'spmevtyper11_el0'
.*: Error: selected processor does not support system register name 'spmevtyper11_el0'
.*: Error: selected processor does not support system register name 'spmevtyper12_el0'
.*: Error: selected processor does not support system register name 'spmevtyper12_el0'
.*: Error: selected processor does not support system register name 'spmevtyper13_el0'
.*: Error: selected processor does not support system register name 'spmevtyper13_el0'
.*: Error: selected processor does not support system register name 'spmevtyper14_el0'
.*: Error: selected processor does not support system register name 'spmevtyper14_el0'
.*: Error: selected processor does not support system register name 'spmevtyper15_el0'
.*: Error: selected processor does not support system register name 'spmevtyper15_el0'
.*: Error: selected processor does not support system register name 'spmiidr_el1'
.*: Error: selected processor does not support system register name 'spmintenclr_el1'
.*: Error: selected processor does not support system register name 'spmintenclr_el1'
.*: Error: selected processor does not support system register name 'spmintenset_el1'
.*: Error: selected processor does not support system register name 'spmintenset_el1'
.*: Error: selected processor does not support system register name 'spmovsclr_el0'
.*: Error: selected processor does not support system register name 'spmovsclr_el0'
.*: Error: selected processor does not support system register name 'spmovsset_el0'
.*: Error: selected processor does not support system register name 'spmovsset_el0'
.*: Error: selected processor does not support system register name 'spmrootcr_el3'
.*: Error: selected processor does not support system register name 'spmrootcr_el3'
.*: Error: selected processor does not support system register name 'spmscr_el1'
.*: Error: selected processor does not support system register name 'spmscr_el1'
.*: Error: selected processor does not support system register name 'spmselr_el0'
.*: Error: selected processor does not support system register name 'spmselr_el0'
.*: Error: selected processor does not support system register name 'pmecr_el1'
.*: Error: selected processor does not support system register name 'pmecr_el1'
.*: Error: selected processor does not support system register name 'pmiar_el1'
.*: Error: selected processor does not support system register name 'pmiar_el1'
