/* MOVAZ (tile to vector, single).  */
movaz z0.b, za0h.s[w12, 0]
movaz z31.d, za0h.b[w12, 0]
movaz z0.b, za0v.h[w12, 0]
movaz z0.q, za0vh.b[w15, 0]
movaz z0.s, za0h.b[w10, 15]
movaz z31.b, za1v.b[w25, 15]
movaz z15.b, za0h.b[w13, 31]
movaz z7.h, za0h.b[w14]

movaz z0.s, za0h.h[w12, 0]
movaz z31.h, za0h.d[w12, 0]
movaz z0.h, za1h.b[w12, 0]
movaz z0.q, za0vh.h[w12, 0]
movaz z0.h, za0h.h[w17, 0]
movaz z0.h, za0h.h[w12, 27]
movaz z31.h, za3v.h[w15, 7]
movaz z15.h, za0h.h[w2, 3]
movaz z7.d, za0h.h[w14]

movaz z0.b, za0h.s[w12, 0]
movaz z31.s, za0h.h[w12, 0]
movaz z0.s, za3h[w12, 0]
movaz z0.s, za0v.s[w1, 0]
movaz z0.q, za0h.s[w25, 0]
movaz z0.s, za0h.s[w12, 13]
movaz z31.s, za5v.s[w15, 3]
movaz z15.s, za1h.s[w13]
movaz z7.b, za2h.d[w14, 1]

movaz z0.b, za0h.d[w12, 0]
movaz z31.d, za0h.h[w12, 0]
movaz z0.d, za7h.s[w12, 0]
movaz z0.s, za0v.q[w12, 0]
movaz z0.d, za0vh.d[w15, 0]
movaz z0.d, za0h.d[w12, 1]
movaz z31.d, za11v.d[w1, 1]
movaz z15.d, za3h.d[w23, 0]
movaz z7.s, za4h.q[w14]

movaz z0.b, za0h.q[w12, 0]
movaz z31.q, za0vh.s[w12, 0]
movaz z0.q, za15h.h[w20, 0]
movaz z0.s, za0v.d[w12, 0]
movaz z0.q, za0h.q[w1, 0]
movaz z31.q, za15v[w15, 0]
movaz z5.q, za27.q[w13, 0]
movaz z7.q, za6h[w14]
