[^:]*: Assembler messages:
.*: Error: selected processor does not support system register name 'sctlr_el3'
.*: Error: selected processor does not support system register name 'ttbr0_el3'
.*: Error: selected processor does not support system register name 'tcr_el3'
.*: Warning: specified register cannot be written to at operand 1 -- `msr mpuir_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr mpuir_el2,x0'
.*: Error: selected processor does not support system register name 'ttbr0_el2'
.*: Error: selected processor does not support system register name 'ttbr0_el2'
.*: Error: selected processor does not support system register name 'ttbr1_el2'
.*: Error: selected processor does not support system register name 'ttbr1_el2'
.*: Error: selected processor does not support system register name 'vsttbr_el2'
.*: Error: selected processor does not support system register name 'vsttbr_el2'
.*: Error: selected processor does not support system register name 'vttbr_el2'
.*: Error: selected processor does not support system register name 'vttbr_el2'
