[^:]*: Assembler messages:
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addha za4.s,p0/m,p1/m,z1.s'
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addha za15.s,p2/m,p3/m,z2.s'
[^:]*:[0-9]+: Error: operand mismatch -- `addha za0.s,p2/m,p3/m,z2.d'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	addha za0.d, p2/m, p3/m, z2.d
[^:]*:[0-9]+: Error: expected a ZA tile at operand 1 -- `addha z0.s,p0/m,p1/m,z1.s'
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addha za8.d,p0/m,p1/m,z1.d'
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addha za15.d,p2/m,p3/m,z2.d'
[^:]*:[0-9]+: Error: operand mismatch -- `addha za0.d,p2/m,p3/m,z2.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	addha za0.d, p2/m, p3/m, z2.d
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addva za4.s,p0/m,p1/m,z1.s'
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addva za15.s,p2/m,p3/m,z2.s'
[^:]*:[0-9]+: Error: operand mismatch -- `addva za0.s,p2/m,p3/m,z2.d'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	addva za0.d, p2/m, p3/m, z2.d
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addva za8.d,p0/m,p1/m,z1.d'
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `addva za15.d,p2/m,p3/m,z2.d'
[^:]*:[0-9]+: Error: operand mismatch -- `addva za0.d,p2/m,p3/m,z2.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	addva za0.d, p2/m, p3/m, z2.d
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `bfmopa za4.s,p0/m,p1/m,z1.h,z4.h'
[^:]*:[0-9]+: Error: operand mismatch -- `bfmopa za0.s,p2/m,p3/m,z2.s,z3.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	bfmopa za0.s, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `bfmops za4.s,p0/m,p1/m,z1.h,z4.h'
[^:]*:[0-9]+: Error: operand mismatch -- `bfmops za0.s,p2/m,p3/m,z2.s,z3.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	bfmops za0.s, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmopa za4.s,p0/m,p1/m,z1.s,z4.s'
[^:]*:[0-9]+: Error: operand mismatch -- `fmopa za0.s,p6/m,p7/m,z4.d,z1.d'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmopa za0.d, p6/m, p7/m, z4.d, z1.d
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmopa za8.d,p0/m,p1/m,z1.d,z8.d'
[^:]*:[0-9]+: Error: operand mismatch -- `fmopa za0.d,p2/m,p3/m,z2.s,z7.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmopa za0.s, p2/m, p3/m, z2.s, z7.s
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmopa za4.s,p0/m,p1/m,z1.h,z4.h'
[^:]*:[0-9]+: Error: operand mismatch -- `fmopa za1.s,p2/m,p3/m,z2.q,z3.q'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmopa za1.s, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmops za4.s,p0/m,p1/m,z1.s,z4.s'
[^:]*:[0-9]+: Error: operand mismatch -- `fmops za1.s,p2/m,p3/m,z2.q,z3.q'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmops za1.s, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmops za8.d,p0/m,p1/m,z1.d,z8.d'
[^:]*:[0-9]+: Error: operand mismatch -- `fmops za0.d,p2/m,p3/m,z2.s,z7.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmops za0.s, p2/m, p3/m, z2.s, z7.s
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `fmops za8.s,p0/m,p1/m,z1.h,z4.h'
[^:]*:[0-9]+: Error: operand mismatch -- `fmops za1.q,p2/m,p3/m,z2.h,z3.h'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	fmops za1.s, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `smopa za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `smopa za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	smopa za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `smopa za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `smopa za1.d,p2/m,p3/m,z2.h,z7.q'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	smopa za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `smops za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `smops za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	smops za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `smops za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `smops za1.d,p2/m,p3/m,z2.h,z7.q'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	smops za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `sumopa za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `sumopa za1.q,p2/m,p3/m,z2.s,z3.s'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	sumopa za1.d, p2/m, p3/m, z2.h, z3.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `sumopa za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `sumopa za1.d,p2/m,p3/m,z2.h,z7.q'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	sumopa za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `sumops za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `sumops za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	sumops za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `sumops za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `sumops za1.q,p2/m,p3/m,z2.h,z7.h'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	sumops za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `umopa za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `umopa za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	umopa za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `umopa za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `umopa za1.q,p2/m,p3/m,z2.h,z7.h'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	umopa za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `umops za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `umops za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	umops za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `umops za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `umops za1.d,p2/m,p3/m,z2.d,z7.d'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	umops za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `usmopa za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `usmopa za1.q,p2/m,p3/m,z2.b,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	usmopa za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `usmopa za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `usmopa za1.q,p2/m,p3/m,z2.h,z7.h'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	usmopa za1.d, p2/m, p3/m, z2.h, z7.h
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `usmops za4.s,p0/m,p1/m,z1.b,z4.b'
[^:]*:[0-9]+: Error: operand mismatch -- `usmops za1.s,p2/m,p3/m,z2.s,z3.b'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	usmops za1.s, p2/m, p3/m, z2.b, z3.b
[^:]*:[0-9]+: Error: ZA tile number out of range at operand 1 -- `usmops za8.d,p0/m,p1/m,z1.h,z8.h'
[^:]*:[0-9]+: Error: operand mismatch -- `usmops za1.d,p2/m,p3/m,z2.d,z7.d'
[^:]*:[0-9]+: Info:    did you mean this\?
[^:]*:[0-9]+: Info:    	usmops za1.d, p2/m, p3/m, z2.h, z7.h
