.*: Assembler messages:
.*: Warning: end of file in string; '"' inserted
.*2: Warning: .base64 string terminated early
.*3: Error: .base64 string terminated unexpectedly
.*4: Error: invalid character ' ' found inside .base64 string
.*5: Error: the equals character cannot start a block of four base64 encoded bytes
.*6: Error: the equals character cannot be the second character in a block of four base64 encoded bytes
.*7: Error: no base64 characters expected after '=' padding characters
.*8: Error: junk at end of line, first unrecognized character is `"'
.*9: Error: expected double quote enclosed string as argument to .base64 pseudo-op
.*10: Error: end of line encountered inside .base64 string
