[^ :]+: Assembler messages:
.*: Error: selected processor does not support `rcwcasp x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwcaspa x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwcaspal x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwcaspl x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwscasp x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwscaspa x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwscaspal x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwscaspl x0,x1,x4,x5,\[x16\]'
.*: Error: selected processor does not support `rcwclrp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwclrpa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwclrpal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwclrpl x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsclrp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsclrpa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsclrpal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsclrpl x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwswpp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwswppa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwswppal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwswppl x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsswpp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsswppa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsswppal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsswppl x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsetp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsetpa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsetpal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwsetpl x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwssetp x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwssetpa x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwssetpal x0,x5,\[x16\]'
.*: Error: selected processor does not support `rcwssetpl x0,x5,\[x16\]'
