[^:]+: Assembler messages:
[^:]+:9: Error: operand mismatch -- `bf1cvtl v0.16b,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:10: Error: operand mismatch -- `bf1cvtl v0.8b,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:11: Error: operand mismatch -- `bf1cvtl v0.4h,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:13: Error: operand mismatch -- `bf1cvtl v0.2s,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:14: Error: operand mismatch -- `bf1cvtl v0.4s,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:15: Error: operand mismatch -- `bf1cvtl v0.2d,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:16: Error: invalid use of vector register at operand 1 -- `bf1cvtl v0,v1.8b'
[^:]+:27:  Info: macro invoked from here
[^:]+:18: Error: operand mismatch -- `bf1cvtl v0.8h,v1.4h'
[^:]+:27:  Info: macro invoked from here
[^:]+:19: Error: operand mismatch -- `bf1cvtl v0.8h,v1.2s'
[^:]+:27:  Info: macro invoked from here
[^:]+:20: Error: operand mismatch -- `bf1cvtl v0.8h,v1.16b'
[^:]+:27:  Info: macro invoked from here
[^:]+:21: Error: operand mismatch -- `bf1cvtl v0.8h,v1.8h'
[^:]+:27:  Info: macro invoked from here
[^:]+:22: Error: operand mismatch -- `bf1cvtl v0.8h,v1.4s'
[^:]+:27:  Info: macro invoked from here
[^:]+:23: Error: operand mismatch -- `bf1cvtl v0.8h,v1.2d'
[^:]+:27:  Info: macro invoked from here
[^:]+:24: Error: invalid use of vector register at operand 2 -- `bf1cvtl v0.8h,v0'
[^:]+:27:  Info: macro invoked from here
[^:]+:9: Error: operand mismatch -- `bf2cvtl v0.16b,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:10: Error: operand mismatch -- `bf2cvtl v0.8b,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:11: Error: operand mismatch -- `bf2cvtl v0.4h,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:13: Error: operand mismatch -- `bf2cvtl v0.2s,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:14: Error: operand mismatch -- `bf2cvtl v0.4s,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:15: Error: operand mismatch -- `bf2cvtl v0.2d,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:16: Error: invalid use of vector register at operand 1 -- `bf2cvtl v0,v1.8b'
[^:]+:28:  Info: macro invoked from here
[^:]+:18: Error: operand mismatch -- `bf2cvtl v0.8h,v1.4h'
[^:]+:28:  Info: macro invoked from here
[^:]+:19: Error: operand mismatch -- `bf2cvtl v0.8h,v1.2s'
[^:]+:28:  Info: macro invoked from here
[^:]+:20: Error: operand mismatch -- `bf2cvtl v0.8h,v1.16b'
[^:]+:28:  Info: macro invoked from here
[^:]+:21: Error: operand mismatch -- `bf2cvtl v0.8h,v1.8h'
[^:]+:28:  Info: macro invoked from here
[^:]+:22: Error: operand mismatch -- `bf2cvtl v0.8h,v1.4s'
[^:]+:28:  Info: macro invoked from here
[^:]+:23: Error: operand mismatch -- `bf2cvtl v0.8h,v1.2d'
[^:]+:28:  Info: macro invoked from here
[^:]+:24: Error: invalid use of vector register at operand 2 -- `bf2cvtl v0.8h,v0'
[^:]+:28:  Info: macro invoked from here
[^:]+:9: Error: operand mismatch -- `f1cvtl v0.16b,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:10: Error: operand mismatch -- `f1cvtl v0.8b,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:11: Error: operand mismatch -- `f1cvtl v0.4h,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:13: Error: operand mismatch -- `f1cvtl v0.2s,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:14: Error: operand mismatch -- `f1cvtl v0.4s,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:15: Error: operand mismatch -- `f1cvtl v0.2d,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:16: Error: invalid use of vector register at operand 1 -- `f1cvtl v0,v1.8b'
[^:]+:29:  Info: macro invoked from here
[^:]+:18: Error: operand mismatch -- `f1cvtl v0.8h,v1.4h'
[^:]+:29:  Info: macro invoked from here
[^:]+:19: Error: operand mismatch -- `f1cvtl v0.8h,v1.2s'
[^:]+:29:  Info: macro invoked from here
[^:]+:20: Error: operand mismatch -- `f1cvtl v0.8h,v1.16b'
[^:]+:29:  Info: macro invoked from here
[^:]+:21: Error: operand mismatch -- `f1cvtl v0.8h,v1.8h'
[^:]+:29:  Info: macro invoked from here
[^:]+:22: Error: operand mismatch -- `f1cvtl v0.8h,v1.4s'
[^:]+:29:  Info: macro invoked from here
[^:]+:23: Error: operand mismatch -- `f1cvtl v0.8h,v1.2d'
[^:]+:29:  Info: macro invoked from here
[^:]+:24: Error: invalid use of vector register at operand 2 -- `f1cvtl v0.8h,v0'
[^:]+:29:  Info: macro invoked from here
[^:]+:9: Error: operand mismatch -- `f2cvtl v0.16b,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:10: Error: operand mismatch -- `f2cvtl v0.8b,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:11: Error: operand mismatch -- `f2cvtl v0.4h,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:13: Error: operand mismatch -- `f2cvtl v0.2s,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:14: Error: operand mismatch -- `f2cvtl v0.4s,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:15: Error: operand mismatch -- `f2cvtl v0.2d,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:16: Error: invalid use of vector register at operand 1 -- `f2cvtl v0,v1.8b'
[^:]+:30:  Info: macro invoked from here
[^:]+:18: Error: operand mismatch -- `f2cvtl v0.8h,v1.4h'
[^:]+:30:  Info: macro invoked from here
[^:]+:19: Error: operand mismatch -- `f2cvtl v0.8h,v1.2s'
[^:]+:30:  Info: macro invoked from here
[^:]+:20: Error: operand mismatch -- `f2cvtl v0.8h,v1.16b'
[^:]+:30:  Info: macro invoked from here
[^:]+:21: Error: operand mismatch -- `f2cvtl v0.8h,v1.8h'
[^:]+:30:  Info: macro invoked from here
[^:]+:22: Error: operand mismatch -- `f2cvtl v0.8h,v1.4s'
[^:]+:30:  Info: macro invoked from here
[^:]+:23: Error: operand mismatch -- `f2cvtl v0.8h,v1.2d'
[^:]+:30:  Info: macro invoked from here
[^:]+:24: Error: invalid use of vector register at operand 2 -- `f2cvtl v0.8h,v0'
[^:]+:30:  Info: macro invoked from here
[^:]+:37: Error: operand mismatch -- `bf1cvtl2 v0.16b,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:38: Error: operand mismatch -- `bf1cvtl2 v0.8b,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:39: Error: operand mismatch -- `bf1cvtl2 v0.4h,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:41: Error: operand mismatch -- `bf1cvtl2 v0.2s,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:42: Error: operand mismatch -- `bf1cvtl2 v0.4s,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:43: Error: operand mismatch -- `bf1cvtl2 v0.2d,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:44: Error: invalid use of vector register at operand 1 -- `bf1cvtl2 v0,v1.16b'
[^:]+:56:  Info: macro invoked from here
[^:]+:46: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.8b'
[^:]+:56:  Info: macro invoked from here
[^:]+:47: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.4h'
[^:]+:56:  Info: macro invoked from here
[^:]+:48: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.2s'
[^:]+:56:  Info: macro invoked from here
[^:]+:50: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.8h'
[^:]+:56:  Info: macro invoked from here
[^:]+:51: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.4s'
[^:]+:56:  Info: macro invoked from here
[^:]+:52: Error: operand mismatch -- `bf1cvtl2 v0.8h,v1.2d'
[^:]+:56:  Info: macro invoked from here
[^:]+:53: Error: invalid use of vector register at operand 2 -- `bf1cvtl2 v0.8h,v1'
[^:]+:56:  Info: macro invoked from here
[^:]+:37: Error: operand mismatch -- `bf2cvtl2 v0.16b,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:38: Error: operand mismatch -- `bf2cvtl2 v0.8b,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:39: Error: operand mismatch -- `bf2cvtl2 v0.4h,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:41: Error: operand mismatch -- `bf2cvtl2 v0.2s,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:42: Error: operand mismatch -- `bf2cvtl2 v0.4s,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:43: Error: operand mismatch -- `bf2cvtl2 v0.2d,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:44: Error: invalid use of vector register at operand 1 -- `bf2cvtl2 v0,v1.16b'
[^:]+:57:  Info: macro invoked from here
[^:]+:46: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.8b'
[^:]+:57:  Info: macro invoked from here
[^:]+:47: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.4h'
[^:]+:57:  Info: macro invoked from here
[^:]+:48: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.2s'
[^:]+:57:  Info: macro invoked from here
[^:]+:50: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.8h'
[^:]+:57:  Info: macro invoked from here
[^:]+:51: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.4s'
[^:]+:57:  Info: macro invoked from here
[^:]+:52: Error: operand mismatch -- `bf2cvtl2 v0.8h,v1.2d'
[^:]+:57:  Info: macro invoked from here
[^:]+:53: Error: invalid use of vector register at operand 2 -- `bf2cvtl2 v0.8h,v1'
[^:]+:57:  Info: macro invoked from here
[^:]+:37: Error: operand mismatch -- `f1cvtl2 v0.16b,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:38: Error: operand mismatch -- `f1cvtl2 v0.8b,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:39: Error: operand mismatch -- `f1cvtl2 v0.4h,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:41: Error: operand mismatch -- `f1cvtl2 v0.2s,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:42: Error: operand mismatch -- `f1cvtl2 v0.4s,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:43: Error: operand mismatch -- `f1cvtl2 v0.2d,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:44: Error: invalid use of vector register at operand 1 -- `f1cvtl2 v0,v1.16b'
[^:]+:58:  Info: macro invoked from here
[^:]+:46: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.8b'
[^:]+:58:  Info: macro invoked from here
[^:]+:47: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.4h'
[^:]+:58:  Info: macro invoked from here
[^:]+:48: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.2s'
[^:]+:58:  Info: macro invoked from here
[^:]+:50: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.8h'
[^:]+:58:  Info: macro invoked from here
[^:]+:51: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.4s'
[^:]+:58:  Info: macro invoked from here
[^:]+:52: Error: operand mismatch -- `f1cvtl2 v0.8h,v1.2d'
[^:]+:58:  Info: macro invoked from here
[^:]+:53: Error: invalid use of vector register at operand 2 -- `f1cvtl2 v0.8h,v1'
[^:]+:58:  Info: macro invoked from here
[^:]+:37: Error: operand mismatch -- `f2cvtl2 v0.16b,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:38: Error: operand mismatch -- `f2cvtl2 v0.8b,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:39: Error: operand mismatch -- `f2cvtl2 v0.4h,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:41: Error: operand mismatch -- `f2cvtl2 v0.2s,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:42: Error: operand mismatch -- `f2cvtl2 v0.4s,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:43: Error: operand mismatch -- `f2cvtl2 v0.2d,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:44: Error: invalid use of vector register at operand 1 -- `f2cvtl2 v0,v1.16b'
[^:]+:59:  Info: macro invoked from here
[^:]+:46: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.8b'
[^:]+:59:  Info: macro invoked from here
[^:]+:47: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.4h'
[^:]+:59:  Info: macro invoked from here
[^:]+:48: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.2s'
[^:]+:59:  Info: macro invoked from here
[^:]+:50: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.8h'
[^:]+:59:  Info: macro invoked from here
[^:]+:51: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.4s'
[^:]+:59:  Info: macro invoked from here
[^:]+:52: Error: operand mismatch -- `f2cvtl2 v0.8h,v1.2d'
[^:]+:59:  Info: macro invoked from here
[^:]+:53: Error: invalid use of vector register at operand 2 -- `f2cvtl2 v0.8h,v1'
[^:]+:59:  Info: macro invoked from here
[^:]+:64: Error: operand mismatch -- `fscale v0.8b,v0.8b,v0.8b'
[^:]+:65: Error: operand mismatch -- `fscale v0.16b,v0.16b,v0.16b'
[^:]+:72: Error: operand mismatch -- `fcvtn v0.4h,v1.4h,v2.4h'
[^:]+:73: Error: operand mismatch -- `fcvtn v0.2s,v1.4h,v2.4h'
[^:]+:74: Error: operand mismatch -- `fcvtn v0.16b,v1.4h,v2.4h'
[^:]+:75: Error: operand mismatch -- `fcvtn v0.8h,v1.4h,v2.4h'
[^:]+:76: Error: operand mismatch -- `fcvtn v0.4s,v1.4h,v2.4h'
[^:]+:77: Error: operand mismatch -- `fcvtn v0.2d,v1.4h,v2.4h'
[^:]+:79: Error: operand mismatch -- `fcvtn v0.8b,v1.8h,v2.8h'
[^:]+:80: Error: operand mismatch -- `fcvtn v0.4h,v1.8h,v2.8h'
[^:]+:81: Error: operand mismatch -- `fcvtn v0.2s,v1.8h,v2.8h'
[^:]+:83: Error: operand mismatch -- `fcvtn v0.8h,v1.8h,v2.8h'
[^:]+:84: Error: operand mismatch -- `fcvtn v0.4s,v1.8h,v2.8h'
[^:]+:85: Error: operand mismatch -- `fcvtn v0.2d,v1.8h,v2.8h'
[^:]+:88: Error: operand mismatch -- `fcvtn v0.8b,v1.8b,v2.8b'
[^:]+:90: Error: operand mismatch -- `fcvtn v0.8b,v1.2s,v2.2s'
[^:]+:91: Error: operand mismatch -- `fcvtn v0.8b,v1.16b,v2.16b'
[^:]+:92: Error: operand mismatch -- `fcvtn v0.8b,v1.8h,v2.8h'
[^:]+:94: Error: operand mismatch -- `fcvtn v0.8b,v1.2d,v2.2d'
[^:]+:96: Error: operand mismatch -- `fcvtn v0.16b,v1.8b,v2.8b'
[^:]+:97: Error: operand mismatch -- `fcvtn v0.16b,v1.4h,v2.4h'
[^:]+:98: Error: operand mismatch -- `fcvtn v0.16b,v1.2s,v2.2s'
[^:]+:99: Error: operand mismatch -- `fcvtn v0.16b,v1.16b,v2.16b'
[^:]+:101: Error: operand mismatch -- `fcvtn v0.16b,v1.4s,v2.4s'
[^:]+:102: Error: operand mismatch -- `fcvtn v0.16b,v1.2d,v2.2d'
[^:]+:107: Error: operand mismatch -- `fcvtn v0.4h,v1.4s,v2.4s'
[^:]+:108: Error: operand mismatch -- `fcvtn v0.2s,v1.4s,v2.4s'
[^:]+:109: Error: operand mismatch -- `fcvtn v0.16b,v1.4s,v2.4s'
[^:]+:110: Error: operand mismatch -- `fcvtn v0.8h,v1.4s,v2.4s'
[^:]+:111: Error: operand mismatch -- `fcvtn v0.4s,v1.4s,v2.4s'
[^:]+:112: Error: operand mismatch -- `fcvtn v0.2d,v1.4s,v2.4s'
[^:]+:115: Error: operand mismatch -- `fcvtn2 v0.16b,v1.8b,v2.8b'
[^:]+:116: Error: operand mismatch -- `fcvtn2 v0.16b,v1.4h,v2.4h'
[^:]+:117: Error: operand mismatch -- `fcvtn2 v0.16b,v1.2d,v2.2d'
[^:]+:118: Error: operand mismatch -- `fcvtn2 v0.16b,v1.16b,v2.16b'
[^:]+:119: Error: operand mismatch -- `fcvtn2 v0.16b,v1.8h,v2.8h'
[^:]+:121: Error: operand mismatch -- `fcvtn2 v0.16b,v1.2d,v2.2d'
