#as: -march=rv32ic
#source: dis-addr-topaddr.s
#objdump: -d

.*:     file format elf32-(little|big)riscv


Disassembly of section .text:

0+000 <target>:
[ 	]+[0-9a-f]+:[ 	]+fff00283[ 	]+lb[   	]+t0,-1\(zero\) # ffffffff <addr_top>
