	vclmul.vv v4, v8, v12
	vclmul.vv v4, v8, v12, v0.t
	vclmul.vx v4, v8, a1
	vclmul.vx v4, v8, a1, v0.t
	vclmulh.vv v4, v8, v12
	vclmulh.vv v4, v8, v12, v0.t
	vclmulh.vx v4, v8, a1
	vclmulh.vx v4, v8, a1, v0.t
