	.syntax unified
	.thumb
	.align 2
	.thumb_func
f1:
      add.n r4, #8
      add.n sp, #8
      add.w r4, #8
      sub.n r4, #8
      sub.n sp, #8
      sub.w r4, #8
      lsl.n r4, #8
      lsl.n sp, #8
      lsl.w r4, #8
