.*: Assembler messages:
.*: Error: selected processor does not support system register name 'scr2_el3'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'scr2_el3'
.*:  Info: macro invoked from here