fmopa za2.h, p0/m, p0/m, z0.b, z0.b
fmopa za0.h, p8/m, p0/m, z0.b, z0.b
fmopa za0.h, p0/m, p8/m, z0.b, z0.b

fmopa za4.s, p0/m, p0/m, z0.b, z0.b
fmopa za0.s, p8/m, p0/m, z0.b, z0.b
fmopa za0.s, p0/m, p8/m, z0.b, z0.b
