.*: Assembler messages:
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbidr0_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc0_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc1_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc2_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc3_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc4_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc5_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc6_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc7_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc8_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc9_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc10_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc11_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc12_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc13_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc14_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc15_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc16_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc17_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc18_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc19_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc20_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc21_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc22_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc23_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc24_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc25_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc26_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc27_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc28_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc29_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc30_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbsrc31_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt0_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt1_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt2_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt3_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt4_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt5_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt6_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt7_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt8_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt9_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt10_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt11_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt12_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt13_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt14_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt15_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt16_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt17_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt18_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt19_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt20_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt21_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt22_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt23_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt24_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt25_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt26_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt27_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt28_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt29_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt30_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbtgt31_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf0_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf1_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf2_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf3_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf4_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf5_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf6_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf7_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf8_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf9_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf10_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf11_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf12_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf13_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf14_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf15_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf16_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf17_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf18_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf19_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf20_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf21_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf22_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf23_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf24_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf25_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf26_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf27_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf28_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf29_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf30_el1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr brbinf31_el1,x0'
