.*Assembler messages:
.*Error: illegal opcode for zve32x `vle64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vle64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vle64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vse64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vse64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vse64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlse64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlse64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlse64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vsse64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vsse64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vsse64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vloxei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vle64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vle64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vle64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg2e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg2e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg2e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg2e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg2e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg2e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg3e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg3e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg3e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg3e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg3e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg3e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg4e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg4e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg4e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg4e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg4e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg4e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg5e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg5e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg5e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg5e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg5e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg5e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg6e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg6e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg6e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg6e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg6e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg6e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg7e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg7e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg7e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg7e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg7e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg7e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg8e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg8e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg8e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vsseg8e64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vsseg8e64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vsseg8e64.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlsseg2e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg2e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg2e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg2e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg2e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg2e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg3e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg3e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg3e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg3e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg3e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg3e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg4e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg4e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg4e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg4e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg4e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg4e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg5e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg5e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg5e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg5e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg5e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg5e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg6e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg6e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg6e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg6e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg6e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg6e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg7e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg7e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg7e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg7e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg7e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg7e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vlsseg8e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg8e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vlsseg8e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vssseg8e64.v v4,\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg8e64.v v4,0\(a0\),a1'
.*Error: illegal opcode for zve32x `vssseg8e64.v v4,\(a0\),a1,v0.t'
.*Error: illegal opcode for zve32x `vloxseg2ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg2ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg2ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg2ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg2ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg2ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg3ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg3ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg3ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg3ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg3ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg3ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg4ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg4ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg4ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg4ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg4ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg4ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg5ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg5ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg5ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg5ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg5ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg5ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg6ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg6ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg6ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg6ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg6ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg6ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg7ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg7ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg7ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg7ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg7ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg7ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vloxseg8ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg8ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vloxseg8ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsoxseg8ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg8ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsoxseg8ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg2ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg2ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg2ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg2ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg2ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg2ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg3ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg3ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg3ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg3ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg3ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg3ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg4ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg4ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg4ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg4ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg4ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg4ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg5ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg5ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg5ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg5ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg5ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg5ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg6ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg6ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg6ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg6ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg6ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg6ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg7ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg7ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg7ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg7ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg7ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg7ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vluxseg8ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg8ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vluxseg8ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vsuxseg8ei64.v v4,\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg8ei64.v v4,0\(a0\),v12'
.*Error: illegal opcode for zve32x `vsuxseg8ei64.v v4,\(a0\),v12,v0.t'
.*Error: illegal opcode for zve32x `vlseg2e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg2e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg2e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg3e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg3e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg3e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg4e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg4e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg4e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg5e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg5e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg5e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg6e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg6e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg6e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg7e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg7e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg7e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vlseg8e64ff.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vlseg8e64ff.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vlseg8e64ff.v v4,\(a0\),v0.t'
.*Error: illegal opcode for zve32x `vl1re64.v v3,\(a0\)'
.*Error: illegal opcode for zve32x `vl1re64.v v3,0\(a0\)'
.*Error: illegal opcode for zve32x `vl2re64.v v2,\(a0\)'
.*Error: illegal opcode for zve32x `vl2re64.v v2,0\(a0\)'
.*Error: illegal opcode for zve32x `vl4re64.v v4,\(a0\)'
.*Error: illegal opcode for zve32x `vl4re64.v v4,0\(a0\)'
.*Error: illegal opcode for zve32x `vl8re64.v v8,\(a0\)'
.*Error: illegal opcode for zve32x `vl8re64.v v8,0\(a0\)'
