	.data
	.db	".db text\n837480"
	DEFB	"DEFB text\nd8783"
	DEFM	"DEFM text\n37857"
	DB	"DB text\n3879837"
	.ascii	".ascii text\72\277\f\n\0"
	.asciz	".asciz text\n999"
	.string	".string text\n\t\0"
	.end
