	udiv	w0, w0, w0
	udiv	wzr, w0, w0
	udiv	w0, wzr, w0
	udiv	w0, w0, wzr
	udiv	x0, x0, x0
	udiv	xzr, x0, x0
	udiv	x0, xzr, x0
	udiv	x0, x0, xzr

	sdiv	w0, w0, w0
	sdiv	wzr, w0, w0
	sdiv	w0, wzr, w0
	sdiv	w0, w0, wzr
	sdiv	x0, x0, x0
	sdiv	xzr, x0, x0
	sdiv	x0, xzr, x0
	sdiv	x0, x0, xzr

	lslv	w0, w0, w0
	lslv	wzr, w0, w0
	lslv	w0, wzr, w0
	lslv	w0, w0, wzr
	lslv	x0, x0, x0
	lslv	xzr, x0, x0
	lslv	x0, xzr, x0
	lslv	x0, x0, xzr

	lsl	w0, w0, w0
	lsl	wzr, w0, w0
	lsl	w0, wzr, w0
	lsl	w0, w0, wzr
	lsl	x0, x0, x0
	lsl	xzr, x0, x0
	lsl	x0, xzr, x0
	lsl	x0, x0, xzr

	lsrv	w0, w0, w0
	lsrv	wzr, w0, w0
	lsrv	w0, wzr, w0
	lsrv	w0, w0, wzr
	lsrv	x0, x0, x0
	lsrv	xzr, x0, x0
	lsrv	x0, xzr, x0
	lsrv	x0, x0, xzr

	lsr	w0, w0, w0
	lsr	wzr, w0, w0
	lsr	w0, wzr, w0
	lsr	w0, w0, wzr
	lsr	x0, x0, x0
	lsr	xzr, x0, x0
	lsr	x0, xzr, x0
	lsr	x0, x0, xzr

	asrv	w0, w0, w0
	asrv	wzr, w0, w0
	asrv	w0, wzr, w0
	asrv	w0, w0, wzr
	asrv	x0, x0, x0
	asrv	xzr, x0, x0
	asrv	x0, xzr, x0
	asrv	x0, x0, xzr

	asr	w0, w0, w0
	asr	wzr, w0, w0
	asr	w0, wzr, w0
	asr	w0, w0, wzr
	asr	x0, x0, x0
	asr	xzr, x0, x0
	asr	x0, xzr, x0
	asr	x0, x0, xzr

	rorv	w0, w0, w0
	rorv	wzr, w0, w0
	rorv	w0, wzr, w0
	rorv	w0, w0, wzr
	rorv	x0, x0, x0
	rorv	xzr, x0, x0
	rorv	x0, xzr, x0
	rorv	x0, x0, xzr

	ror	w0, w0, w0
	ror	wzr, w0, w0
	ror	w0, wzr, w0
	ror	w0, w0, wzr
	ror	x0, x0, x0
	ror	xzr, x0, x0
	ror	x0, xzr, x0
	ror	x0, x0, xzr
