	abs	z0.b, p0/z, z0.b
	abs	z31.b, p0/z, z0.b
	abs	z0.b, p7/z, z0.b
	abs	z0.b, p0/z, z31.b
	abs	z0.h, p0/z, z0.h
	abs	z31.h, p0/z, z0.h
	abs	z0.h, p7/z, z0.h
	abs	z0.h, p0/z, z31.h
	abs	z0.s, p0/z, z0.s
	abs	z31.s, p0/z, z0.s
	abs	z0.s, p7/z, z0.s
	abs	z0.s, p0/z, z31.s
	abs	z0.d, p0/z, z0.d
	abs	z31.d, p0/z, z0.d
	abs	z0.d, p7/z, z0.d
	abs	z0.d, p0/z, z31.d

	bfcvt	z0.h, p0/z, z0.s
	bfcvt	z31.h, p0/z, z0.s
	bfcvt	z0.h, p7/z, z0.s
	bfcvt	z0.h, p0/z, z31.s

	bfcvtnt	z0.h, p0/z, z0.s
	bfcvtnt	z31.h, p0/z, z0.s
	bfcvtnt	z0.h, p7/z, z0.s
	bfcvtnt	z0.h, p0/z, z31.s

	cls	z0.b, p0/z, z0.b
	cls	z31.b, p0/z, z0.b
	cls	z0.b, p7/z, z0.b
	cls	z0.b, p0/z, z31.b
	cls	z0.h, p0/z, z0.h
	cls	z31.h, p0/z, z0.h
	cls	z0.h, p7/z, z0.h
	cls	z0.h, p0/z, z31.h
	cls	z0.s, p0/z, z0.s
	cls	z31.s, p0/z, z0.s
	cls	z0.s, p7/z, z0.s
	cls	z0.s, p0/z, z31.s
	cls	z0.d, p0/z, z0.d
	cls	z31.d, p0/z, z0.d
	cls	z0.d, p7/z, z0.d
	cls	z0.d, p0/z, z31.d

	clz	z0.b, p0/z, z0.b
	clz	z31.b, p0/z, z0.b
	clz	z0.b, p7/z, z0.b
	clz	z0.b, p0/z, z31.b
	clz	z0.h, p0/z, z0.h
	clz	z31.h, p0/z, z0.h
	clz	z0.h, p7/z, z0.h
	clz	z0.h, p0/z, z31.h
	clz	z0.s, p0/z, z0.s
	clz	z31.s, p0/z, z0.s
	clz	z0.s, p7/z, z0.s
	clz	z0.s, p0/z, z31.s
	clz	z0.d, p0/z, z0.d
	clz	z31.d, p0/z, z0.d
	clz	z0.d, p7/z, z0.d
	clz	z0.d, p0/z, z31.d

	cnot	z0.b, p0/z, z0.b
	cnot	z31.b, p0/z, z0.b
	cnot	z0.b, p7/z, z0.b
	cnot	z0.b, p0/z, z31.b
	cnot	z0.h, p0/z, z0.h
	cnot	z31.h, p0/z, z0.h
	cnot	z0.h, p7/z, z0.h
	cnot	z0.h, p0/z, z31.h
	cnot	z0.s, p0/z, z0.s
	cnot	z31.s, p0/z, z0.s
	cnot	z0.s, p7/z, z0.s
	cnot	z0.s, p0/z, z31.s
	cnot	z0.d, p0/z, z0.d
	cnot	z31.d, p0/z, z0.d
	cnot	z0.d, p7/z, z0.d
	cnot	z0.d, p0/z, z31.d

	cnt	z0.b, p0/z, z0.b
	cnt	z31.b, p0/z, z0.b
	cnt	z0.b, p7/z, z0.b
	cnt	z0.b, p0/z, z31.b
	cnt	z0.h, p0/z, z0.h
	cnt	z31.h, p0/z, z0.h
	cnt	z0.h, p7/z, z0.h
	cnt	z0.h, p0/z, z31.h
	cnt	z0.s, p0/z, z0.s
	cnt	z31.s, p0/z, z0.s
	cnt	z0.s, p7/z, z0.s
	cnt	z0.s, p0/z, z31.s
	cnt	z0.d, p0/z, z0.d
	cnt	z31.d, p0/z, z0.d
	cnt	z0.d, p7/z, z0.d
	cnt	z0.d, p0/z, z31.d

// Word and doubleword forms in nonstreaming mode are part of FEAT_SVE.
	compact	z0.b, p0, z0.b
	compact	z31.b, p0, z0.b
	compact	z0.b, p7, z0.b
	compact	z0.b, p0, z31.b
	compact	z0.h, p0, z0.h
	compact	z31.h, p0, z0.h
	compact	z0.h, p7, z0.h
	compact	z0.h, p0, z31.h
	compact	z0.s, p0, z0.s
	compact	z31.s, p0, z0.s
	compact	z0.s, p7, z0.s
	compact	z0.s, p0, z31.s
	compact	z0.d, p0, z0.d
	compact	z31.d, p0, z0.d
	compact	z0.d, p7, z0.d
	compact	z0.d, p0, z31.d

	expand	z0.b, p0, z0.b
	expand	z31.b, p0, z0.b
	expand	z0.b, p7, z0.b
	expand	z0.b, p0, z31.b
	expand	z0.h, p0, z0.h
	expand	z31.h, p0, z0.h
	expand	z0.h, p7, z0.h
	expand	z0.h, p0, z31.h
	expand	z0.s, p0, z0.s
	expand	z31.s, p0, z0.s
	expand	z0.s, p7, z0.s
	expand	z0.s, p0, z31.s
	expand	z0.d, p0, z0.d
	expand	z31.d, p0, z0.d
	expand	z0.d, p7, z0.d
	expand	z0.d, p0, z31.d

	fabs	z0.h, p0/z, z0.h
	fabs	z31.h, p0/z, z0.h
	fabs	z0.h, p7/z, z0.h
	fabs	z0.h, p0/z, z31.h
	fabs	z0.s, p0/z, z0.s
	fabs	z31.s, p0/z, z0.s
	fabs	z0.s, p7/z, z0.s
	fabs	z0.s, p0/z, z31.s
	fabs	z0.d, p0/z, z0.d
	fabs	z31.d, p0/z, z0.d
	fabs	z0.d, p7/z, z0.d
	fabs	z0.d, p0/z, z31.d

	fcvt	z0.s, p0/z, z0.h
	fcvt	z31.s, p0/z, z0.h
	fcvt	z0.s, p7/z, z0.h
	fcvt	z0.s, p0/z, z31.h
	fcvt	z0.d, p0/z, z0.h
	fcvt	z31.d, p0/z, z0.h
	fcvt	z0.d, p7/z, z0.h
	fcvt	z0.d, p0/z, z31.h
	fcvt	z0.h, p0/z, z0.s
	fcvt	z31.h, p0/z, z0.s
	fcvt	z0.h, p7/z, z0.s
	fcvt	z0.h, p0/z, z31.s
	fcvt	z0.d, p0/z, z0.s
	fcvt	z31.d, p0/z, z0.s
	fcvt	z0.d, p7/z, z0.s
	fcvt	z0.d, p0/z, z31.s
	fcvt	z0.h, p0/z, z0.d
	fcvt	z31.h, p0/z, z0.d
	fcvt	z0.h, p7/z, z0.d
	fcvt	z0.h, p0/z, z31.d
	fcvt	z0.s, p0/z, z0.d
	fcvt	z31.s, p0/z, z0.d
	fcvt	z0.s, p7/z, z0.d
	fcvt	z0.s, p0/z, z31.d

	fcvtlt	z0.s, p0/z, z0.h
	fcvtlt	z31.s, p0/z, z0.h
	fcvtlt	z0.s, p7/z, z0.h
	fcvtlt	z0.s, p0/z, z31.h
	fcvtlt	z0.d, p0/z, z0.s
	fcvtlt	z31.d, p0/z, z0.s
	fcvtlt	z0.d, p7/z, z0.s
	fcvtlt	z0.d, p0/z, z31.s

	fcvtnt	z0.h, p0/z, z0.s
	fcvtnt	z31.h, p0/z, z0.s
	fcvtnt	z0.h, p7/z, z0.s
	fcvtnt	z0.h, p0/z, z31.s
	fcvtnt	z0.s, p0/z, z0.d
	fcvtnt	z31.s, p0/z, z0.d
	fcvtnt	z0.s, p7/z, z0.d
	fcvtnt	z0.s, p0/z, z31.d

	fcvtx	z0.s, p0/z, z0.d
	fcvtx	z31.s, p0/z, z0.d
	fcvtx	z0.s, p7/z, z0.d
	fcvtx	z0.s, p0/z, z31.d

	fcvtxnt	z0.s, p0/z, z0.d
	fcvtxnt	z31.s, p0/z, z0.d
	fcvtxnt	z0.s, p7/z, z0.d
	fcvtxnt	z0.s, p0/z, z31.d

	fcvtzs	z0.h, p0/z, z0.h
	fcvtzs	z31.h, p0/z, z0.h
	fcvtzs	z0.h, p7/z, z0.h
	fcvtzs	z0.h, p0/z, z31.h
	fcvtzs	z0.s, p0/z, z0.h
	fcvtzs	z31.s, p0/z, z0.h
	fcvtzs	z0.s, p7/z, z0.h
	fcvtzs	z0.s, p0/z, z31.h
	fcvtzs	z0.d, p0/z, z0.h
	fcvtzs	z31.d, p0/z, z0.h
	fcvtzs	z0.d, p7/z, z0.h
	fcvtzs	z0.d, p0/z, z31.h
	fcvtzs	z0.s, p0/z, z0.s
	fcvtzs	z31.s, p0/z, z0.s
	fcvtzs	z0.s, p7/z, z0.s
	fcvtzs	z0.s, p0/z, z31.s
	fcvtzs	z0.d, p0/z, z0.s
	fcvtzs	z31.d, p0/z, z0.s
	fcvtzs	z0.d, p7/z, z0.s
	fcvtzs	z0.d, p0/z, z31.s
	fcvtzs	z0.s, p0/z, z0.d
	fcvtzs	z31.s, p0/z, z0.d
	fcvtzs	z0.s, p7/z, z0.d
	fcvtzs	z0.s, p0/z, z31.d
	fcvtzs	z0.d, p0/z, z0.d
	fcvtzs	z31.d, p0/z, z0.d
	fcvtzs	z0.d, p7/z, z0.d
	fcvtzs	z0.d, p0/z, z31.d

	fcvtzu	z0.h, p0/z, z0.h
	fcvtzu	z31.h, p0/z, z0.h
	fcvtzu	z0.h, p7/z, z0.h
	fcvtzu	z0.h, p0/z, z31.h
	fcvtzu	z0.s, p0/z, z0.h
	fcvtzu	z31.s, p0/z, z0.h
	fcvtzu	z0.s, p7/z, z0.h
	fcvtzu	z0.s, p0/z, z31.h
	fcvtzu	z0.d, p0/z, z0.h
	fcvtzu	z31.d, p0/z, z0.h
	fcvtzu	z0.d, p7/z, z0.h
	fcvtzu	z0.d, p0/z, z31.h
	fcvtzu	z0.s, p0/z, z0.s
	fcvtzu	z31.s, p0/z, z0.s
	fcvtzu	z0.s, p7/z, z0.s
	fcvtzu	z0.s, p0/z, z31.s
	fcvtzu	z0.d, p0/z, z0.s
	fcvtzu	z31.d, p0/z, z0.s
	fcvtzu	z0.d, p7/z, z0.s
	fcvtzu	z0.d, p0/z, z31.s
	fcvtzu	z0.s, p0/z, z0.d
	fcvtzu	z31.s, p0/z, z0.d
	fcvtzu	z0.s, p7/z, z0.d
	fcvtzu	z0.s, p0/z, z31.d
	fcvtzu	z0.d, p0/z, z0.d
	fcvtzu	z31.d, p0/z, z0.d
	fcvtzu	z0.d, p7/z, z0.d
	fcvtzu	z0.d, p0/z, z31.d

	firstp	x0, p0, p0.b
	firstp	xzr, p0, p0.b
	firstp	x0, p15, p0.b
	firstp	x0, p0, p15.b
	firstp	x0, p0, p0.h
	firstp	xzr, p0, p0.h
	firstp	x0, p15, p0.h
	firstp	x0, p0, p15.h
	firstp	x0, p0, p0.s
	firstp	xzr, p0, p0.s
	firstp	x0, p15, p0.s
	firstp	x0, p0, p15.s
	firstp	x0, p0, p0.d
	firstp	xzr, p0, p0.d
	firstp	x0, p15, p0.d
	firstp	x0, p0, p15.d

	flogb	z0.h, p0/z, z0.h
	flogb	z31.h, p0/z, z0.h
	flogb	z0.h, p7/z, z0.h
	flogb	z0.h, p0/z, z31.h
	flogb	z0.s, p0/z, z0.s
	flogb	z31.s, p0/z, z0.s
	flogb	z0.s, p7/z, z0.s
	flogb	z0.s, p0/z, z31.s
	flogb	z0.d, p0/z, z0.d
	flogb	z31.d, p0/z, z0.d
	flogb	z0.d, p7/z, z0.d
	flogb	z0.d, p0/z, z31.d

	fneg	z0.h, p0/z, z0.h
	fneg	z31.h, p0/z, z0.h
	fneg	z0.h, p7/z, z0.h
	fneg	z0.h, p0/z, z31.h
	fneg	z0.s, p0/z, z0.s
	fneg	z31.s, p0/z, z0.s
	fneg	z0.s, p7/z, z0.s
	fneg	z0.s, p0/z, z31.s
	fneg	z0.d, p0/z, z0.d
	fneg	z31.d, p0/z, z0.d
	fneg	z0.d, p7/z, z0.d
	fneg	z0.d, p0/z, z31.d

	frecpx	z0.h, p0/z, z0.h
	frecpx	z31.h, p0/z, z0.h
	frecpx	z0.h, p7/z, z0.h
	frecpx	z0.h, p0/z, z31.h
	frecpx	z0.s, p0/z, z0.s
	frecpx	z31.s, p0/z, z0.s
	frecpx	z0.s, p7/z, z0.s
	frecpx	z0.s, p0/z, z31.s
	frecpx	z0.d, p0/z, z0.d
	frecpx	z31.d, p0/z, z0.d
	frecpx	z0.d, p7/z, z0.d
	frecpx	z0.d, p0/z, z31.d

	frint32x z0.s, p0/m, z0.s
	frint32x z31.s, p0/m, z0.s
	frint32x z0.s, p7/m, z0.s
	frint32x z0.s, p0/m, z31.s
	frint32x z0.d, p0/m, z0.d
	frint32x z31.d, p0/m, z0.d
	frint32x z0.d, p7/m, z0.d
	frint32x z0.d, p0/m, z31.d
	frint32x z0.s, p0/z, z0.s
	frint32x z31.s, p0/z, z0.s
	frint32x z0.s, p7/z, z0.s
	frint32x z0.s, p0/z, z31.s
	frint32x z0.d, p0/z, z0.d
	frint32x z31.d, p0/z, z0.d
	frint32x z0.d, p7/z, z0.d
	frint32x z0.d, p0/z, z31.d

	frint32z z0.s, p0/m, z0.s
	frint32z z31.s, p0/m, z0.s
	frint32z z0.s, p7/m, z0.s
	frint32z z0.s, p0/m, z31.s
	frint32z z0.d, p0/m, z0.d
	frint32z z31.d, p0/m, z0.d
	frint32z z0.d, p7/m, z0.d
	frint32z z0.d, p0/m, z31.d
	frint32z z0.s, p0/z, z0.s
	frint32z z31.s, p0/z, z0.s
	frint32z z0.s, p7/z, z0.s
	frint32z z0.s, p0/z, z31.s
	frint32z z0.d, p0/z, z0.d
	frint32z z31.d, p0/z, z0.d
	frint32z z0.d, p7/z, z0.d
	frint32z z0.d, p0/z, z31.d

	frint64x z0.s, p0/m, z0.s
	frint64x z31.s, p0/m, z0.s
	frint64x z0.s, p7/m, z0.s
	frint64x z0.s, p0/m, z31.s
	frint64x z0.d, p0/m, z0.d
	frint64x z31.d, p0/m, z0.d
	frint64x z0.d, p7/m, z0.d
	frint64x z0.d, p0/m, z31.d
	frint64x z0.s, p0/z, z0.s
	frint64x z31.s, p0/z, z0.s
	frint64x z0.s, p7/z, z0.s
	frint64x z0.s, p0/z, z31.s
	frint64x z0.d, p0/z, z0.d
	frint64x z31.d, p0/z, z0.d
	frint64x z0.d, p7/z, z0.d
	frint64x z0.d, p0/z, z31.d

	frint64z z0.s, p0/m, z0.s
	frint64z z31.s, p0/m, z0.s
	frint64z z0.s, p7/m, z0.s
	frint64z z0.s, p0/m, z31.s
	frint64z z0.d, p0/m, z0.d
	frint64z z31.d, p0/m, z0.d
	frint64z z0.d, p7/m, z0.d
	frint64z z0.d, p0/m, z31.d
	frint64z z0.s, p0/z, z0.s
	frint64z z31.s, p0/z, z0.s
	frint64z z0.s, p7/z, z0.s
	frint64z z0.s, p0/z, z31.s
	frint64z z0.d, p0/z, z0.d
	frint64z z31.d, p0/z, z0.d
	frint64z z0.d, p7/z, z0.d
	frint64z z0.d, p0/z, z31.d

	frintx z0.h, p0/z, z0.h
	frintx z31.h, p0/z, z0.h
	frintx z0.h, p7/z, z0.h
	frintx z0.h, p0/z, z31.h
	frintx z0.s, p0/z, z0.s
	frintx z31.s, p0/z, z0.s
	frintx z0.s, p7/z, z0.s
	frintx z0.s, p0/z, z31.s
	frintx z0.d, p0/z, z0.d
	frintx z31.d, p0/z, z0.d
	frintx z0.d, p7/z, z0.d
	frintx z0.d, p0/z, z31.d

	frinti z0.h, p0/z, z0.h
	frinti z31.h, p0/z, z0.h
	frinti z0.h, p7/z, z0.h
	frinti z0.h, p0/z, z31.h
	frinti z0.s, p0/z, z0.s
	frinti z31.s, p0/z, z0.s
	frinti z0.s, p7/z, z0.s
	frinti z0.s, p0/z, z31.s
	frinti z0.d, p0/z, z0.d
	frinti z31.d, p0/z, z0.d
	frinti z0.d, p7/z, z0.d
	frinti z0.d, p0/z, z31.d

	frinta z0.h, p0/z, z0.h
	frinta z31.h, p0/z, z0.h
	frinta z0.h, p7/z, z0.h
	frinta z0.h, p0/z, z31.h
	frinta z0.s, p0/z, z0.s
	frinta z31.s, p0/z, z0.s
	frinta z0.s, p7/z, z0.s
	frinta z0.s, p0/z, z31.s
	frinta z0.d, p0/z, z0.d
	frinta z31.d, p0/z, z0.d
	frinta z0.d, p7/z, z0.d
	frinta z0.d, p0/z, z31.d

	frintn z0.h, p0/z, z0.h
	frintn z31.h, p0/z, z0.h
	frintn z0.h, p7/z, z0.h
	frintn z0.h, p0/z, z31.h
	frintn z0.s, p0/z, z0.s
	frintn z31.s, p0/z, z0.s
	frintn z0.s, p7/z, z0.s
	frintn z0.s, p0/z, z31.s
	frintn z0.d, p0/z, z0.d
	frintn z31.d, p0/z, z0.d
	frintn z0.d, p7/z, z0.d
	frintn z0.d, p0/z, z31.d

	frintz z0.h, p0/z, z0.h
	frintz z31.h, p0/z, z0.h
	frintz z0.h, p7/z, z0.h
	frintz z0.h, p0/z, z31.h
	frintz z0.s, p0/z, z0.s
	frintz z31.s, p0/z, z0.s
	frintz z0.s, p7/z, z0.s
	frintz z0.s, p0/z, z31.s
	frintz z0.d, p0/z, z0.d
	frintz z31.d, p0/z, z0.d
	frintz z0.d, p7/z, z0.d
	frintz z0.d, p0/z, z31.d

	frintm z0.h, p0/z, z0.h
	frintm z31.h, p0/z, z0.h
	frintm z0.h, p7/z, z0.h
	frintm z0.h, p0/z, z31.h
	frintm z0.s, p0/z, z0.s
	frintm z31.s, p0/z, z0.s
	frintm z0.s, p7/z, z0.s
	frintm z0.s, p0/z, z31.s
	frintm z0.d, p0/z, z0.d
	frintm z31.d, p0/z, z0.d
	frintm z0.d, p7/z, z0.d
	frintm z0.d, p0/z, z31.d

	frintp z0.h, p0/z, z0.h
	frintp z31.h, p0/z, z0.h
	frintp z0.h, p7/z, z0.h
	frintp z0.h, p0/z, z31.h
	frintp z0.s, p0/z, z0.s
	frintp z31.s, p0/z, z0.s
	frintp z0.s, p7/z, z0.s
	frintp z0.s, p0/z, z31.s
	frintp z0.d, p0/z, z0.d
	frintp z31.d, p0/z, z0.d
	frintp z0.d, p7/z, z0.d
	frintp z0.d, p0/z, z31.d

	fsqrt z0.h, p0/z, z0.h
	fsqrt z31.h, p0/z, z0.h
	fsqrt z0.h, p7/z, z0.h
	fsqrt z0.h, p0/z, z31.h
	fsqrt z0.s, p0/z, z0.s
	fsqrt z31.s, p0/z, z0.s
	fsqrt z0.s, p7/z, z0.s
	fsqrt z0.s, p0/z, z31.s
	fsqrt z0.d, p0/z, z0.d
	fsqrt z31.d, p0/z, z0.d
	fsqrt z0.d, p7/z, z0.d
	fsqrt z0.d, p0/z, z31.d

	lastp	x0, p0, p0.b
	lastp	xzr, p0, p0.b
	lastp	x0, p15, p0.b
	lastp	x0, p0, p15.b
	lastp	x0, p0, p0.h
	lastp	xzr, p0, p0.h
	lastp	x0, p15, p0.h
	lastp	x0, p0, p15.h
	lastp	x0, p0, p0.s
	lastp	xzr, p0, p0.s
	lastp	x0, p15, p0.s
	lastp	x0, p0, p15.s
	lastp	x0, p0, p0.d
	lastp	xzr, p0, p0.d
	lastp	x0, p15, p0.d
	lastp	x0, p0, p15.d

	neg	z0.b, p0/z, z0.b
	neg	z31.b, p0/z, z0.b
	neg	z0.b, p7/z, z0.b
	neg	z0.b, p0/z, z31.b
	neg	z0.h, p0/z, z0.h
	neg	z31.h, p0/z, z0.h
	neg	z0.h, p7/z, z0.h
	neg	z0.h, p0/z, z31.h
	neg	z0.s, p0/z, z0.s
	neg	z31.s, p0/z, z0.s
	neg	z0.s, p7/z, z0.s
	neg	z0.s, p0/z, z31.s
	neg	z0.d, p0/z, z0.d
	neg	z31.d, p0/z, z0.d
	neg	z0.d, p7/z, z0.d
	neg	z0.d, p0/z, z31.d

	not	z0.b, p0/z, z0.b
	not	z31.b, p0/z, z0.b
	not	z0.b, p7/z, z0.b
	not	z0.b, p0/z, z31.b
	not	z0.h, p0/z, z0.h
	not	z31.h, p0/z, z0.h
	not	z0.h, p7/z, z0.h
	not	z0.h, p0/z, z31.h
	not	z0.s, p0/z, z0.s
	not	z31.s, p0/z, z0.s
	not	z0.s, p7/z, z0.s
	not	z0.s, p0/z, z31.s
	not	z0.d, p0/z, z0.d
	not	z31.d, p0/z, z0.d
	not	z0.d, p7/z, z0.d
	not	z0.d, p0/z, z31.d

	rbit	z0.b, p0/z, z0.b
	rbit	z31.b, p0/z, z0.b
	rbit	z0.b, p7/z, z0.b
	rbit	z0.b, p0/z, z31.b
	rbit	z0.h, p0/z, z0.h
	rbit	z31.h, p0/z, z0.h
	rbit	z0.h, p7/z, z0.h
	rbit	z0.h, p0/z, z31.h
	rbit	z0.s, p0/z, z0.s
	rbit	z31.s, p0/z, z0.s
	rbit	z0.s, p7/z, z0.s
	rbit	z0.s, p0/z, z31.s
	rbit	z0.d, p0/z, z0.d
	rbit	z31.d, p0/z, z0.d
	rbit	z0.d, p7/z, z0.d
	rbit	z0.d, p0/z, z31.d

	revb	z0.h, p0/z, z0.h
	revb	z31.h, p0/z, z0.h
	revb	z0.h, p7/z, z0.h
	revb	z0.h, p0/z, z31.h
	revb	z0.s, p0/z, z0.s
	revb	z31.s, p0/z, z0.s
	revb	z0.s, p7/z, z0.s
	revb	z0.s, p0/z, z31.s
	revb	z0.d, p0/z, z0.d
	revb	z31.d, p0/z, z0.d
	revb	z0.d, p7/z, z0.d
	revb	z0.d, p0/z, z31.d

	revh	z0.s, p0/z, z0.s
	revh	z31.s, p0/z, z0.s
	revh	z0.s, p7/z, z0.s
	revh	z0.s, p0/z, z31.s
	revh	z0.d, p0/z, z0.d
	revh	z31.d, p0/z, z0.d
	revh	z0.d, p7/z, z0.d
	revh	z0.d, p0/z, z31.d

	revw	z0.d, p0/z, z0.d
	revw	z31.d, p0/z, z0.d
	revw	z0.d, p7/z, z0.d
	revw	z0.d, p0/z, z31.d

	revd	z0.q, p0/z, z0.q
	revd	z31.q, p0/z, z0.q
	revd	z0.q, p7/z, z0.q
	revd	z0.q, p0/z, z31.q

	scvtf z0.h, p0/z, z0.h
	scvtf z31.h, p0/z, z0.h
	scvtf z0.h, p7/z, z0.h
	scvtf z0.h, p0/z, z31.h
	scvtf z0.h, p0/z, z0.s
	scvtf z31.h, p0/z, z0.s
	scvtf z0.h, p7/z, z0.s
	scvtf z0.h, p0/z, z31.s
	scvtf z0.s, p0/z, z0.s
	scvtf z31.s, p0/z, z0.s
	scvtf z0.s, p7/z, z0.s
	scvtf z0.s, p0/z, z31.s
	scvtf z0.d, p0/z, z0.s
	scvtf z31.d, p0/z, z0.s
	scvtf z0.d, p7/z, z0.s
	scvtf z0.d, p0/z, z31.s
	scvtf z0.h, p0/z, z0.d
	scvtf z31.h, p0/z, z0.d
	scvtf z0.h, p7/z, z0.d
	scvtf z0.h, p0/z, z31.d
	scvtf z0.s, p0/z, z0.d
	scvtf z31.s, p0/z, z0.d
	scvtf z0.s, p7/z, z0.d
	scvtf z0.s, p0/z, z31.d
	scvtf z0.d, p0/z, z0.d
	scvtf z31.d, p0/z, z0.d
	scvtf z0.d, p7/z, z0.d
	scvtf z0.d, p0/z, z31.d

	sqabs	z0.b, p0/z, z0.b
	sqabs	z31.b, p0/z, z0.b
	sqabs	z0.b, p7/z, z0.b
	sqabs	z0.b, p0/z, z31.b
	sqabs	z0.h, p0/z, z0.h
	sqabs	z31.h, p0/z, z0.h
	sqabs	z0.h, p7/z, z0.h
	sqabs	z0.h, p0/z, z31.h
	sqabs	z0.s, p0/z, z0.s
	sqabs	z31.s, p0/z, z0.s
	sqabs	z0.s, p7/z, z0.s
	sqabs	z0.s, p0/z, z31.s
	sqabs	z0.d, p0/z, z0.d
	sqabs	z31.d, p0/z, z0.d
	sqabs	z0.d, p7/z, z0.d
	sqabs	z0.d, p0/z, z31.d

	sqneg	z0.b, p0/z, z0.b
	sqneg	z31.b, p0/z, z0.b
	sqneg	z0.b, p7/z, z0.b
	sqneg	z0.b, p0/z, z31.b
	sqneg	z0.h, p0/z, z0.h
	sqneg	z31.h, p0/z, z0.h
	sqneg	z0.h, p7/z, z0.h
	sqneg	z0.h, p0/z, z31.h
	sqneg	z0.s, p0/z, z0.s
	sqneg	z31.s, p0/z, z0.s
	sqneg	z0.s, p7/z, z0.s
	sqneg	z0.s, p0/z, z31.s
	sqneg	z0.d, p0/z, z0.d
	sqneg	z31.d, p0/z, z0.d
	sqneg	z0.d, p7/z, z0.d
	sqneg	z0.d, p0/z, z31.d

	sxtb	z0.h, p0/z, z0.h
	sxtb	z31.h, p0/z, z0.h
	sxtb	z0.h, p7/z, z0.h
	sxtb	z0.h, p0/z, z31.h
	sxtb	z0.s, p0/z, z0.s
	sxtb	z31.s, p0/z, z0.s
	sxtb	z0.s, p7/z, z0.s
	sxtb	z0.s, p0/z, z31.s
	sxtb	z0.d, p0/z, z0.d
	sxtb	z31.d, p0/z, z0.d
	sxtb	z0.d, p7/z, z0.d
	sxtb	z0.d, p0/z, z31.d

	sxth	z0.s, p0/z, z0.s
	sxth	z31.s, p0/z, z0.s
	sxth	z0.s, p7/z, z0.s
	sxth	z0.s, p0/z, z31.s
	sxth	z0.d, p0/z, z0.d
	sxth	z31.d, p0/z, z0.d
	sxth	z0.d, p7/z, z0.d
	sxth	z0.d, p0/z, z31.d

	sxtw	z0.d, p0/z, z0.d
	sxtw	z31.d, p0/z, z0.d
	sxtw	z0.d, p7/z, z0.d
	sxtw	z0.d, p0/z, z31.d

	ucvtf z0.h, p0/z, z0.h
	ucvtf z31.h, p0/z, z0.h
	ucvtf z0.h, p7/z, z0.h
	ucvtf z0.h, p0/z, z31.h
	ucvtf z0.h, p0/z, z0.s
	ucvtf z31.h, p0/z, z0.s
	ucvtf z0.h, p7/z, z0.s
	ucvtf z0.h, p0/z, z31.s
	ucvtf z0.s, p0/z, z0.s
	ucvtf z31.s, p0/z, z0.s
	ucvtf z0.s, p7/z, z0.s
	ucvtf z0.s, p0/z, z31.s
	ucvtf z0.d, p0/z, z0.s
	ucvtf z31.d, p0/z, z0.s
	ucvtf z0.d, p7/z, z0.s
	ucvtf z0.d, p0/z, z31.s
	ucvtf z0.h, p0/z, z0.d
	ucvtf z31.h, p0/z, z0.d
	ucvtf z0.h, p7/z, z0.d
	ucvtf z0.h, p0/z, z31.d
	ucvtf z0.s, p0/z, z0.d
	ucvtf z31.s, p0/z, z0.d
	ucvtf z0.s, p7/z, z0.d
	ucvtf z0.s, p0/z, z31.d
	ucvtf z0.d, p0/z, z0.d
	ucvtf z31.d, p0/z, z0.d
	ucvtf z0.d, p7/z, z0.d
	ucvtf z0.d, p0/z, z31.d

	urecpe z0.s, p0/z, z0.s
	urecpe z31.s, p0/z, z0.s
	urecpe z0.s, p7/z, z0.s
	urecpe z0.s, p0/z, z31.s

	ursqrte z0.s, p0/z, z0.s
	ursqrte z31.s, p0/z, z0.s
	ursqrte z0.s, p7/z, z0.s
	ursqrte z0.s, p0/z, z31.s

	uxtb	z0.h, p0/z, z0.h
	uxtb	z31.h, p0/z, z0.h
	uxtb	z0.h, p7/z, z0.h
	uxtb	z0.h, p0/z, z31.h
	uxtb	z0.s, p0/z, z0.s
	uxtb	z31.s, p0/z, z0.s
	uxtb	z0.s, p7/z, z0.s
	uxtb	z0.s, p0/z, z31.s
	uxtb	z0.d, p0/z, z0.d
	uxtb	z31.d, p0/z, z0.d
	uxtb	z0.d, p7/z, z0.d
	uxtb	z0.d, p0/z, z31.d

	uxth	z0.s, p0/z, z0.s
	uxth	z31.s, p0/z, z0.s
	uxth	z0.s, p7/z, z0.s
	uxth	z0.s, p0/z, z31.s
	uxth	z0.d, p0/z, z0.d
	uxth	z31.d, p0/z, z0.d
	uxth	z0.d, p7/z, z0.d
	uxth	z0.d, p0/z, z31.d

	uxtw	z0.d, p0/z, z0.d
	uxtw	z31.d, p0/z, z0.d
	uxtw	z0.d, p7/z, z0.d
	uxtw	z0.d, p0/z, z31.d

