mrs x0, mpam0_el1
msr mpam0_el1, x0
mrs x0, mpam1_el1
msr mpam1_el1, x0
mrs x0, mpam1_el12
msr mpam1_el12, x0
mrs x0, mpam2_el2
msr mpam2_el2, x0
mrs x0, mpam3_el3
msr mpam3_el3, x0
mrs x0, mpamhcr_el2
msr mpamhcr_el2, x0
mrs x0, mpamidr_el1
mrs x0, mpamvpm0_el2
msr mpamvpm0_el2, x0
mrs x0, mpamvpm1_el2
msr mpamvpm1_el2, x0
mrs x0, mpamvpm2_el2
msr mpamvpm2_el2, x0
mrs x0, mpamvpm3_el2
msr mpamvpm3_el2, x0
mrs x0, mpamvpm4_el2
msr mpamvpm4_el2, x0
mrs x0, mpamvpm5_el2
msr mpamvpm5_el2, x0
mrs x0, mpamvpm6_el2
msr mpamvpm6_el2, x0
mrs x0, mpamvpm7_el2
msr mpamvpm7_el2, x0
mrs x0, mpamvpmv_el2
msr mpamvpmv_el2, x0
