	whilege	pn8.b, x0, x0, vlx2
	whilege	pn8.b, x0, x0, vlx4
	WHILEGE	PN8.B, X0, X0, VLx2
	WHILEGE	PN8.B, X0, X0, VLx4
	whilege	pn15.b, x0, x0, vlx2
	whilege	pn8.b, x30, x0, vlx2
	whilege	pn8.b, xzr, x0, vlx2
	whilege	pn8.b, x0, x30, vlx2
	whilege	pn8.b, x0, xzr, vlx2
	whilege	pn11.b, x20, x1, vlx4

	whilege	pn8.h, x0, x0, vlx2
	whilege	pn8.h, x0, x0, vlx4
	WHILEGE	PN8.h, X0, X0, VLx2
	WHILEGE	PN8.h, X0, X0, VLx4
	whilege	pn15.h, x0, x0, vlx2
	whilege	pn8.h, x30, x0, vlx2
	whilege	pn8.h, xzr, x0, vlx2
	whilege	pn8.h, x0, x30, vlx2
	whilege	pn8.h, x0, xzr, vlx2
	whilege	pn14.h, x14, x25, vlx4

	whilege	pn8.s, x0, x0, vlx2
	whilege	pn8.s, x0, x0, vlx4
	WHILEGE	PN8.s, X0, X0, VLx2
	WHILEGE	PN8.s, X0, X0, VLx4
	whilege	pn15.s, x0, x0, vlx2
	whilege	pn8.s, x30, x0, vlx2
	whilege	pn8.s, xzr, x0, vlx2
	whilege	pn8.s, x0, x30, vlx2
	whilege	pn8.s, x0, xzr, vlx2
	whilege	pn9.s, x4, x27, vlx2

	whilege	pn8.d, x0, x0, vlx2
	whilege	pn8.d, x0, x0, vlx4
	WHILEGE	PN8.d, X0, X0, VLx2
	WHILEGE	PN8.d, X0, X0, VLx4
	whilege	pn15.d, x0, x0, vlx2
	whilege	pn8.d, x30, x0, vlx2
	whilege	pn8.d, xzr, x0, vlx2
	whilege	pn8.d, x0, x30, vlx2
	whilege	pn8.d, x0, xzr, vlx2
	whilege	pn13.d, x26, x9, vlx4

	whilegt	pn8.b, x0, x0, vlx2
	whilegt	pn8.b, x0, x0, vlx4
	WHILEGT	PN8.B, X0, X0, VLx2
	WHILEGT	PN8.B, X0, X0, VLx4
	whilegt	pn15.b, x0, x0, vlx2
	whilegt	pn8.b, x30, x0, vlx2
	whilegt	pn8.b, xzr, x0, vlx2
	whilegt	pn8.b, x0, x30, vlx2
	whilegt	pn8.b, x0, xzr, vlx2
	whilegt	pn11.b, x20, x1, vlx4

	whilegt	pn8.h, x0, x0, vlx2
	whilegt	pn8.h, x0, x0, vlx4
	WHILEGT	PN8.h, X0, X0, VLx2
	WHILEGT	PN8.h, X0, X0, VLx4
	whilegt	pn15.h, x0, x0, vlx2
	whilegt	pn8.h, x30, x0, vlx2
	whilegt	pn8.h, xzr, x0, vlx2
	whilegt	pn8.h, x0, x30, vlx2
	whilegt	pn8.h, x0, xzr, vlx2
	whilegt	pn14.h, x14, x25, vlx4

	whilegt	pn8.s, x0, x0, vlx2
	whilegt	pn8.s, x0, x0, vlx4
	WHILEGT	PN8.s, X0, X0, VLx2
	WHILEGT	PN8.s, X0, X0, VLx4
	whilegt	pn15.s, x0, x0, vlx2
	whilegt	pn8.s, x30, x0, vlx2
	whilegt	pn8.s, xzr, x0, vlx2
	whilegt	pn8.s, x0, x30, vlx2
	whilegt	pn8.s, x0, xzr, vlx2
	whilegt	pn9.s, x4, x27, vlx2

	whilegt	pn8.d, x0, x0, vlx2
	whilegt	pn8.d, x0, x0, vlx4
	WHILEGT	PN8.d, X0, X0, VLx2
	WHILEGT	PN8.d, X0, X0, VLx4
	whilegt	pn15.d, x0, x0, vlx2
	whilegt	pn8.d, x30, x0, vlx2
	whilegt	pn8.d, xzr, x0, vlx2
	whilegt	pn8.d, x0, x30, vlx2
	whilegt	pn8.d, x0, xzr, vlx2
	whilegt	pn13.d, x26, x9, vlx4

	whilehi	pn8.b, x0, x0, vlx2
	whilehi	pn8.b, x0, x0, vlx4
	WHILEHI	PN8.B, X0, X0, VLx2
	WHILEHI	PN8.B, X0, X0, VLx4
	whilehi	pn15.b, x0, x0, vlx2
	whilehi	pn8.b, x30, x0, vlx2
	whilehi	pn8.b, xzr, x0, vlx2
	whilehi	pn8.b, x0, x30, vlx2
	whilehi	pn8.b, x0, xzr, vlx2
	whilehi	pn11.b, x20, x1, vlx4

	whilehi	pn8.h, x0, x0, vlx2
	whilehi	pn8.h, x0, x0, vlx4
	WHILEHI	PN8.h, X0, X0, VLx2
	WHILEHI	PN8.h, X0, X0, VLx4
	whilehi	pn15.h, x0, x0, vlx2
	whilehi	pn8.h, x30, x0, vlx2
	whilehi	pn8.h, xzr, x0, vlx2
	whilehi	pn8.h, x0, x30, vlx2
	whilehi	pn8.h, x0, xzr, vlx2
	whilehi	pn14.h, x14, x25, vlx4

	whilehi	pn8.s, x0, x0, vlx2
	whilehi	pn8.s, x0, x0, vlx4
	WHILEHI	PN8.s, X0, X0, VLx2
	WHILEHI	PN8.s, X0, X0, VLx4
	whilehi	pn15.s, x0, x0, vlx2
	whilehi	pn8.s, x30, x0, vlx2
	whilehi	pn8.s, xzr, x0, vlx2
	whilehi	pn8.s, x0, x30, vlx2
	whilehi	pn8.s, x0, xzr, vlx2
	whilehi	pn9.s, x4, x27, vlx2

	whilehi	pn8.d, x0, x0, vlx2
	whilehi	pn8.d, x0, x0, vlx4
	WHILEHI	PN8.d, X0, X0, VLx2
	WHILEHI	PN8.d, X0, X0, VLx4
	whilehi	pn15.d, x0, x0, vlx2
	whilehi	pn8.d, x30, x0, vlx2
	whilehi	pn8.d, xzr, x0, vlx2
	whilehi	pn8.d, x0, x30, vlx2
	whilehi	pn8.d, x0, xzr, vlx2
	whilehi	pn13.d, x26, x9, vlx4

	whilehs	pn8.b, x0, x0, vlx2
	whilehs	pn8.b, x0, x0, vlx4
	WHILEHS	PN8.B, X0, X0, VLx2
	WHILEHS	PN8.B, X0, X0, VLx4
	whilehs	pn15.b, x0, x0, vlx2
	whilehs	pn8.b, x30, x0, vlx2
	whilehs	pn8.b, xzr, x0, vlx2
	whilehs	pn8.b, x0, x30, vlx2
	whilehs	pn8.b, x0, xzr, vlx2
	whilehs	pn11.b, x20, x1, vlx4

	whilehs	pn8.h, x0, x0, vlx2
	whilehs	pn8.h, x0, x0, vlx4
	WHILEHS	PN8.h, X0, X0, VLx2
	WHILEHS	PN8.h, X0, X0, VLx4
	whilehs	pn15.h, x0, x0, vlx2
	whilehs	pn8.h, x30, x0, vlx2
	whilehs	pn8.h, xzr, x0, vlx2
	whilehs	pn8.h, x0, x30, vlx2
	whilehs	pn8.h, x0, xzr, vlx2
	whilehs	pn14.h, x14, x25, vlx4

	whilehs	pn8.s, x0, x0, vlx2
	whilehs	pn8.s, x0, x0, vlx4
	WHILEHS	PN8.s, X0, X0, VLx2
	WHILEHS	PN8.s, X0, X0, VLx4
	whilehs	pn15.s, x0, x0, vlx2
	whilehs	pn8.s, x30, x0, vlx2
	whilehs	pn8.s, xzr, x0, vlx2
	whilehs	pn8.s, x0, x30, vlx2
	whilehs	pn8.s, x0, xzr, vlx2
	whilehs	pn9.s, x4, x27, vlx2

	whilehs	pn8.d, x0, x0, vlx2
	whilehs	pn8.d, x0, x0, vlx4
	WHILEHS	PN8.d, X0, X0, VLx2
	WHILEHS	PN8.d, X0, X0, VLx4
	whilehs	pn15.d, x0, x0, vlx2
	whilehs	pn8.d, x30, x0, vlx2
	whilehs	pn8.d, xzr, x0, vlx2
	whilehs	pn8.d, x0, x30, vlx2
	whilehs	pn8.d, x0, xzr, vlx2
	whilehs	pn13.d, x26, x9, vlx4

	whilele	pn8.b, x0, x0, vlx2
	whilele	pn8.b, x0, x0, vlx4
	WHILELE	PN8.B, X0, X0, VLx2
	WHILELE	PN8.B, X0, X0, VLx4
	whilele	pn15.b, x0, x0, vlx2
	whilele	pn8.b, x30, x0, vlx2
	whilele	pn8.b, xzr, x0, vlx2
	whilele	pn8.b, x0, x30, vlx2
	whilele	pn8.b, x0, xzr, vlx2
	whilele	pn11.b, x20, x1, vlx4

	whilele	pn8.h, x0, x0, vlx2
	whilele	pn8.h, x0, x0, vlx4
	WHILELE	PN8.h, X0, X0, VLx2
	WHILELE	PN8.h, X0, X0, VLx4
	whilele	pn15.h, x0, x0, vlx2
	whilele	pn8.h, x30, x0, vlx2
	whilele	pn8.h, xzr, x0, vlx2
	whilele	pn8.h, x0, x30, vlx2
	whilele	pn8.h, x0, xzr, vlx2
	whilele	pn14.h, x14, x25, vlx4

	whilele	pn8.s, x0, x0, vlx2
	whilele	pn8.s, x0, x0, vlx4
	WHILELE	PN8.s, X0, X0, VLx2
	WHILELE	PN8.s, X0, X0, VLx4
	whilele	pn15.s, x0, x0, vlx2
	whilele	pn8.s, x30, x0, vlx2
	whilele	pn8.s, xzr, x0, vlx2
	whilele	pn8.s, x0, x30, vlx2
	whilele	pn8.s, x0, xzr, vlx2
	whilele	pn9.s, x4, x27, vlx2

	whilele	pn8.d, x0, x0, vlx2
	whilele	pn8.d, x0, x0, vlx4
	WHILELE	PN8.d, X0, X0, VLx2
	WHILELE	PN8.d, X0, X0, VLx4
	whilele	pn15.d, x0, x0, vlx2
	whilele	pn8.d, x30, x0, vlx2
	whilele	pn8.d, xzr, x0, vlx2
	whilele	pn8.d, x0, x30, vlx2
	whilele	pn8.d, x0, xzr, vlx2
	whilele	pn13.d, x26, x9, vlx4

	whilelt	pn8.b, x0, x0, vlx2
	whilelt	pn8.b, x0, x0, vlx4
	WHILELT	PN8.B, X0, X0, VLx2
	WHILELT	PN8.B, X0, X0, VLx4
	whilelt	pn15.b, x0, x0, vlx2
	whilelt	pn8.b, x30, x0, vlx2
	whilelt	pn8.b, xzr, x0, vlx2
	whilelt	pn8.b, x0, x30, vlx2
	whilelt	pn8.b, x0, xzr, vlx2
	whilelt	pn11.b, x20, x1, vlx4

	whilelt	pn8.h, x0, x0, vlx2
	whilelt	pn8.h, x0, x0, vlx4
	WHILELT	PN8.h, X0, X0, VLx2
	WHILELT	PN8.h, X0, X0, VLx4
	whilelt	pn15.h, x0, x0, vlx2
	whilelt	pn8.h, x30, x0, vlx2
	whilelt	pn8.h, xzr, x0, vlx2
	whilelt	pn8.h, x0, x30, vlx2
	whilelt	pn8.h, x0, xzr, vlx2
	whilelt	pn14.h, x14, x25, vlx4

	whilelt	pn8.s, x0, x0, vlx2
	whilelt	pn8.s, x0, x0, vlx4
	WHILELT	PN8.s, X0, X0, VLx2
	WHILELT	PN8.s, X0, X0, VLx4
	whilelt	pn15.s, x0, x0, vlx2
	whilelt	pn8.s, x30, x0, vlx2
	whilelt	pn8.s, xzr, x0, vlx2
	whilelt	pn8.s, x0, x30, vlx2
	whilelt	pn8.s, x0, xzr, vlx2
	whilelt	pn9.s, x4, x27, vlx2

	whilelt	pn8.d, x0, x0, vlx2
	whilelt	pn8.d, x0, x0, vlx4
	WHILELT	PN8.d, X0, X0, VLx2
	WHILELT	PN8.d, X0, X0, VLx4
	whilelt	pn15.d, x0, x0, vlx2
	whilelt	pn8.d, x30, x0, vlx2
	whilelt	pn8.d, xzr, x0, vlx2
	whilelt	pn8.d, x0, x30, vlx2
	whilelt	pn8.d, x0, xzr, vlx2
	whilelt	pn13.d, x26, x9, vlx4

	whilelo	pn8.b, x0, x0, vlx2
	whilelo	pn8.b, x0, x0, vlx4
	WHILELO	PN8.B, X0, X0, VLx2
	WHILELO	PN8.B, X0, X0, VLx4
	whilelo	pn15.b, x0, x0, vlx2
	whilelo	pn8.b, x30, x0, vlx2
	whilelo	pn8.b, xzr, x0, vlx2
	whilelo	pn8.b, x0, x30, vlx2
	whilelo	pn8.b, x0, xzr, vlx2
	whilelo	pn11.b, x20, x1, vlx4

	whilelo	pn8.h, x0, x0, vlx2
	whilelo	pn8.h, x0, x0, vlx4
	WHILELO	PN8.h, X0, X0, VLx2
	WHILELO	PN8.h, X0, X0, VLx4
	whilelo	pn15.h, x0, x0, vlx2
	whilelo	pn8.h, x30, x0, vlx2
	whilelo	pn8.h, xzr, x0, vlx2
	whilelo	pn8.h, x0, x30, vlx2
	whilelo	pn8.h, x0, xzr, vlx2
	whilelo	pn14.h, x14, x25, vlx4

	whilelo	pn8.s, x0, x0, vlx2
	whilelo	pn8.s, x0, x0, vlx4
	WHILELO	PN8.s, X0, X0, VLx2
	WHILELO	PN8.s, X0, X0, VLx4
	whilelo	pn15.s, x0, x0, vlx2
	whilelo	pn8.s, x30, x0, vlx2
	whilelo	pn8.s, xzr, x0, vlx2
	whilelo	pn8.s, x0, x30, vlx2
	whilelo	pn8.s, x0, xzr, vlx2
	whilelo	pn9.s, x4, x27, vlx2

	whilelo	pn8.d, x0, x0, vlx2
	whilelo	pn8.d, x0, x0, vlx4
	WHILELO	PN8.d, X0, X0, VLx2
	WHILELO	PN8.d, X0, X0, VLx4
	whilelo	pn15.d, x0, x0, vlx2
	whilelo	pn8.d, x30, x0, vlx2
	whilelo	pn8.d, xzr, x0, vlx2
	whilelo	pn8.d, x0, x30, vlx2
	whilelo	pn8.d, x0, xzr, vlx2
	whilelo	pn13.d, x26, x9, vlx4

	whilels	pn8.b, x0, x0, vlx2
	whilels	pn8.b, x0, x0, vlx4
	WHILELS	PN8.B, X0, X0, VLx2
	WHILELS	PN8.B, X0, X0, VLx4
	whilels	pn15.b, x0, x0, vlx2
	whilels	pn8.b, x30, x0, vlx2
	whilels	pn8.b, xzr, x0, vlx2
	whilels	pn8.b, x0, x30, vlx2
	whilels	pn8.b, x0, xzr, vlx2
	whilels	pn11.b, x20, x1, vlx4

	whilels	pn8.h, x0, x0, vlx2
	whilels	pn8.h, x0, x0, vlx4
	WHILELS	PN8.h, X0, X0, VLx2
	WHILELS	PN8.h, X0, X0, VLx4
	whilels	pn15.h, x0, x0, vlx2
	whilels	pn8.h, x30, x0, vlx2
	whilels	pn8.h, xzr, x0, vlx2
	whilels	pn8.h, x0, x30, vlx2
	whilels	pn8.h, x0, xzr, vlx2
	whilels	pn14.h, x14, x25, vlx4

	whilels	pn8.s, x0, x0, vlx2
	whilels	pn8.s, x0, x0, vlx4
	WHILELS	PN8.s, X0, X0, VLx2
	WHILELS	PN8.s, X0, X0, VLx4
	whilels	pn15.s, x0, x0, vlx2
	whilels	pn8.s, x30, x0, vlx2
	whilels	pn8.s, xzr, x0, vlx2
	whilels	pn8.s, x0, x30, vlx2
	whilels	pn8.s, x0, xzr, vlx2
	whilels	pn9.s, x4, x27, vlx2

	whilels	pn8.d, x0, x0, vlx2
	whilels	pn8.d, x0, x0, vlx4
	WHILELS	PN8.d, X0, X0, VLx2
	WHILELS	PN8.d, X0, X0, VLx4
	whilels	pn15.d, x0, x0, vlx2
	whilels	pn8.d, x30, x0, vlx2
	whilels	pn8.d, xzr, x0, vlx2
	whilels	pn8.d, x0, x30, vlx2
	whilels	pn8.d, x0, xzr, vlx2
	whilels	pn13.d, x26, x9, vlx4
