.*: Assembler messages:
.*:1: Error: pc-relative offset out of range, shall fit in 16 bits
.*:2: Error: pc-relative offset out of range, shall fit in 16 bits
.*:3: Error: pc-relative offset out of range, shall fit in 16 bits
.*:4: Error: pc-relative offset out of range, shall fit in 16 bits
