.*: Assembler messages:
.*:[0-9]*: Warning: 'prefetchit0' only supports RIP-relative address
.*:[0-9]*: Warning: 'prefetchit1' only supports RIP-relative address
.*:[0-9]*: Warning: 'prefetchit0' only supports RIP-relative address
.*:[0-9]*: Warning: 'prefetchit1' only supports RIP-relative address
