fmlalb z0.h, z0.b, z0.b
fmlalb z23.h, z27.b, z29.b
movprfx z25, z31
fmlalb z25.h, z21.b, z19.b

fmlalb z0.h, z0.b, z0.b[0]
fmlalb z23.h, z27.b, z5.b[1]
movprfx z25, z31
fmlalb z25.h, z21.b, z7.b[6]
fmlalb z25.h, z21.b, z7.b[15]

fmlallbb z0.s, z0.b, z0.b
fmlallbb z23.s, z27.b, z29.b
movprfx z25, z31
fmlallbb z25.s, z21.b, z19.b

fmlallbb z0.s, z0.b, z0.b[0]
fmlallbb z23.s, z27.b, z5.b[1]
movprfx z25, z31
fmlallbb z25.s, z21.b, z7.b[6]
fmlallbb z25.s, z21.b, z7.b[15]

fmlallbt z0.s, z0.b, z0.b
fmlallbt z23.s, z27.b, z29.b
movprfx z25, z31
fmlallbt z25.s, z21.b, z19.b

fmlallbt z0.s, z0.b, z0.b[0]
fmlallbt z23.s, z27.b, z5.b[1]
movprfx z25, z31
fmlallbt z25.s, z21.b, z7.b[6]
fmlallbt z25.s, z21.b, z7.b[15]

fmlalltb z0.s, z0.b, z0.b
fmlalltb z23.s, z27.b, z29.b
movprfx z25, z31
fmlalltb z25.s, z21.b, z19.b

fmlalltb z0.s, z0.b, z0.b[0]
fmlalltb z23.s, z27.b, z5.b[1]
movprfx z25, z31
fmlalltb z25.s, z21.b, z7.b[6]
fmlalltb z25.s, z21.b, z7.b[15]

fmlalltt z0.s, z0.b, z0.b
fmlalltt z23.s, z27.b, z29.b
movprfx z25, z31
fmlalltt z25.s, z21.b, z19.b

fmlalltt z0.s, z0.b, z0.b[0]
fmlalltt z23.s, z27.b, z5.b[1]
movprfx z25, z31
fmlalltt z25.s, z21.b, z7.b[6]
fmlalltt z25.s, z21.b, z7.b[15]

fmlalt z0.h, z0.b, z0.b
fmlalt z23.h, z27.b, z29.b
movprfx z25, z31
fmlalt z25.h, z21.b, z19.b

fmlalt z0.h, z0.b, z0.b[0]
fmlalt z23.h, z27.b, z5.b[1]
movprfx z25, z31
fmlalt z25.h, z21.b, z7.b[6]
fmlalt z25.h, z21.b, z7.b[15]
