All available -march extensions for RISC-V:
	e                                       1.9
	i                                       2.1, 2.0
	m                                       2.0
	a                                       2.1, 2.0
	f                                       2.2, 2.0
	d                                       2.2, 2.0
	q                                       2.2, 2.0
	c                                       2.0
	b                                       1.0
	v                                       1.0
	h                                       1.0
	zic64b                                  1.0
	ziccamoa                                1.0
	ziccif                                  1.0
	zicclsm                                 1.0
	ziccrse                                 1.0
	zicbom                                  1.0
	zicbop                                  1.0
	zicboz                                  1.0
	zicond                                  1.0
	zicntr                                  2.0
	zicsr                                   2.0
	zifencei                                2.0
	zihintntl                               1.0
	zihintpause                             2.0
	zihpm                                   2.0
	zimop                                   1.0
	zicfiss                                 1.0
	zicfilp                                 1.0
	zilsd                                   1.0
	zmmul                                   1.0
	za64rs                                  1.0
	za128rs                                 1.0
	zaamo                                   1.0
	zabha                                   1.0
	zacas                                   1.0
	zalrsc                                  1.0
	zawrs                                   1.0
	zfbfmin                                 1.0
	zfa                                     1.0
	zfh                                     1.0
	zfhmin                                  1.0
	zfinx                                   1.0
	zdinx                                   1.0
	zqinx                                   1.0
	zhinx                                   1.0
	zhinxmin                                1.0
	zbb                                     1.0
	zba                                     1.0
	zbc                                     1.0
	zbs                                     1.0
	zbkb                                    1.0
	zbkc                                    1.0
	zbkx                                    1.0
	zk                                      1.0
	zkn                                     1.0
	zknd                                    1.0
	zkne                                    1.0
	zknh                                    1.0
	zkr                                     1.0
	zks                                     1.0
	zksed                                   1.0
	zksh                                    1.0
	zkt                                     1.0
	zve32x                                  1.0
	zve32f                                  1.0
	zve64x                                  1.0
	zve64f                                  1.0
	zve64d                                  1.0
	zvbb                                    1.0
	zvbc                                    1.0
	zvfbfmin                                1.0
	zvfbfwma                                1.0
	zvfh                                    1.0
	zvfhmin                                 1.0
	zvkb                                    1.0
	zvkg                                    1.0
	zvkn                                    1.0
	zvkng                                   1.0
	zvknc                                   1.0
	zvkned                                  1.0
	zvknha                                  1.0
	zvknhb                                  1.0
	zvksed                                  1.0
	zvksh                                   1.0
	zvks                                    1.0
	zvksg                                   1.0
	zvksc                                   1.0
	zvkt                                    1.0
	zvl32b                                  1.0
	zvl64b                                  1.0
	zvl128b                                 1.0
	zvl256b                                 1.0
	zvl512b                                 1.0
	zvl1024b                                1.0
	zvl2048b                                1.0
	zvl4096b                                1.0
	zvl8192b                                1.0
	zvl16384b                               1.0
	zvl32768b                               1.0
	zvl65536b                               1.0
	ztso                                    1.0
	zca                                     1.0
	zcb                                     1.0
	zce                                     1.0
	zcf                                     1.0
	zcd                                     1.0
	zcmop                                   1.0
	zcmp                                    1.0
	zcmt                                    1.0
	zclsd                                   1.0
	sdtrig                                  1.0
	sha                                     1.0
	shcounterenw                            1.0
	shgatpa                                 1.0
	shtvala                                 1.0
	shvsatpa                                1.0
	shvstvala                               1.0
	shvstvecd                               1.0
	smaia                                   1.0
	smcdeleg                                1.0
	smcsrind                                1.0
	smcntrpmf                               1.0
	smctr                                   1.0
	smepmp                                  1.0
	smrnmi                                  1.0
	smstateen                               1.0
	smdbltrp                                1.0
	ssaia                                   1.0
	ssccfg                                  1.0
	ssccptr                                 1.0
	sscsrind                                1.0
	sscofpmf                                1.0
	sscounterenw                            1.0
	ssctr                                   1.0
	ssstateen                               1.0
	ssstrict                                1.0
	sstc                                    1.0
	sstvala                                 1.0
	sstvecd                                 1.0
	ssu64xl                                 1.0
	ssdbltrp                                1.0
	svade                                   1.0
	svadu                                   1.0
	svbare                                  1.0
	svinval                                 1.0
	svnapot                                 1.0
	svpbmt                                  1.0
	svvptc                                  1.0
	ssqosid                                 1.0
	ssnpm                                   1.0
	smnpm                                   1.0
	smmpm                                   1.0
	sspm                                    1.0
	supm                                    1.0
	xcvalu                                  1.0
	xcvbi                                   1.0
	xcvbitmanip                             1.0
	xcvelw                                  1.0
	xcvmac                                  1.0
	xcvmem                                  1.0
	xcvsimd                                 1.0
	xtheadba                                1.0
	xtheadbb                                1.0
	xtheadbs                                1.0
	xtheadcmo                               1.0
	xtheadcondmov                           1.0
	xtheadfmemidx                           1.0
	xtheadfmv                               1.0
	xtheadint                               1.0
	xtheadmac                               1.0
	xtheadmemidx                            1.0
	xtheadmempair                           1.0
	xtheadsync                              1.0
	xtheadvector                            1.0
	xtheadvdot                              1.0
	xtheadzvamo                             1.0
	xventanacondops                         1.0
	xsfvcp                                  1.0
	xsfcease                                1.0
	xsfvqmaccqoq                            1.0
	xsfvqmaccdod                            1.0
	xsfvfnrclipxfqf                         1.0
	xmipscbop                               1.0
	xmipscmov                               1.0
	xmipsexectl                             1.0
	xmipslsp                                1.0
