.*: Assembler messages:
.*: Error: selected processor does not support `tenter #0'
.*: Error: selected processor does not support `tenter #1'
.*: Error: selected processor does not support `tenter #3'
.*: Error: selected processor does not support `tenter #7'
.*: Error: selected processor does not support `tenter #15'
.*: Error: selected processor does not support `tenter #31'
.*: Error: selected processor does not support `tenter #63'
.*: Error: selected processor does not support `tenter #127'
.*: Error: selected processor does not support `tenter #0,nb'
.*: Error: selected processor does not support `tenter #1,nb'
.*: Error: selected processor does not support `tenter #3,nb'
.*: Error: selected processor does not support `tenter #7,nb'
.*: Error: selected processor does not support `tenter #15,nb'
.*: Error: selected processor does not support `tenter #31,NB'
.*: Error: selected processor does not support `tenter #63,nb'
.*: Error: selected processor does not support `tenter #127,NB'
.*: Error: selected processor does not support `texit'
.*: Error: selected processor does not support `texit nb'
.*: Error: selected processor does not support `texit NB'
.*: Error: selected processor does not support `texit nB'
.*: Error: selected processor does not support `texit Nb'
