[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w10,2\],{ ?z14\.b ?- ?z15\.b ?},z13\.b\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w9,1\],{ ?z4\.b ?- ?z7\.b ?},z10\.b\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0,vgx2\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.s\[W8,0,VGx2\],{ ?Z0\.b ?- ?Z1\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.S\[W8,0,VGX2\],{ ?Z0\.B ?- ?Z1\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w11,0\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,7\],{ ?z0\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z30\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z31\.b,z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z31\.b ?- ?z0\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z1\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w9,3\],{ ?z21\.b ?- ?z22\.b ?},z9\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z30\.b,z31\.b,z0\.b,z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z30\.b ?- ?z1\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z31\.b,z0\.b,z1\.b,z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z31\.b ?- ?z2\.b ?},z0\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b'
[^ :]+:[0-9]+: Error: selected processor does not support `sudot za\.s\[w10,5\],{ ?z17\.b ?- ?z20\.b ?},z3\.b'
