[^:]*: Assembler messages:
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:7: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:12: Error: syntax error -- `vorreq q0,q1,q2'
[^:]*:13: Error: syntax error -- `vorreq q0,q1,q2'
[^:]*:15: Error: syntax error -- `vorreq q0,q1,q2'
[^:]*:17: Error: instruction missing MVE vector predication code -- `vorr q0,q1,q2'
[^:]*:18: Error: vector predicated instruction should be in VPT/VPST block -- `vorrt q0,q1,q2'
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:28: Error: syntax error -- `vorreq.i16 q0,#255'
[^:]*:29: Error: syntax error -- `vorreq.i16 q0,#255'
[^:]*:31: Error: syntax error -- `vorreq.i16 q0,#255'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vorr.i16 q0,#255'
[^:]*:34: Error: vector predicated instruction should be in VPT/VPST block -- `vorrt.i16 q0,#255'
[^:]*:35: Error: bad type in SIMD instruction -- `vorr.i8 q0,#255'
[^:]*:36: Error: bad type in SIMD instruction -- `vorr.i64 q0,#255'
[^:]*:37: Error: immediate value out of range -- `vorr.i16 q0,#257'
[^:]*:38: Error: immediate value out of range -- `vorr.i32 q0,#257'
