[^ :]+: Assembler messages:
.*: Error: selected processor does not support `gic cdaff,x0'
.*: Error: selected processor does not support `gic cdaff,xzr'
.*: Error: selected processor does not support `gic cddi,x0'
.*: Error: selected processor does not support `gic cddi,xzr'
.*: Error: selected processor does not support `gic cddis,x0'
.*: Error: selected processor does not support `gic cddis,xzr'
.*: Error: selected processor does not support `gic cden,x0'
.*: Error: selected processor does not support `gic cden,xzr'
.*: Error: selected processor does not support `gic cdeoi,x0'
.*: Error: selected processor does not support `gic cdeoi,xzr'
.*: Error: selected processor does not support `gic cdhm,x0'
.*: Error: selected processor does not support `gic cdhm,xzr'
.*: Error: selected processor does not support `gic cdpend,x0'
.*: Error: selected processor does not support `gic cdpend,xzr'
.*: Error: selected processor does not support `gic cdpri,x0'
.*: Error: selected processor does not support `gic cdpri,xzr'
.*: Error: selected processor does not support `gic cdrcfg,x0'
.*: Error: selected processor does not support `gic cdrcfg,xzr'
.*: Error: selected processor does not support `gicr x0,cdia'
.*: Error: selected processor does not support `gicr xzr,cdia'
.*: Error: selected processor does not support `gicr x0,cdnmia'
.*: Error: selected processor does not support `gicr xzr,cdnmia'
.*: Error: selected processor does not support `gic vdaff,x0'
.*: Error: selected processor does not support `gic vdaff,xzr'
.*: Error: selected processor does not support `gic vddi,x0'
.*: Error: selected processor does not support `gic vddi,xzr'
.*: Error: selected processor does not support `gic vddis,x0'
.*: Error: selected processor does not support `gic vddis,xzr'
.*: Error: selected processor does not support `gic vden,x0'
.*: Error: selected processor does not support `gic vden,xzr'
.*: Error: selected processor does not support `gic vdhm,x0'
.*: Error: selected processor does not support `gic vdhm,xzr'
.*: Error: selected processor does not support `gic vdpend,x0'
.*: Error: selected processor does not support `gic vdpend,xzr'
.*: Error: selected processor does not support `gic vdpri,x0'
.*: Error: selected processor does not support `gic vdpri,xzr'
.*: Error: selected processor does not support `gic vdrcfg,x0'
.*: Error: selected processor does not support `gic vdrcfg,xzr'
.*: Error: selected processor does not support `gic ldaff,x0'
.*: Error: selected processor does not support `gic ldaff,xzr'
.*: Error: selected processor does not support `gic lddi,x0'
.*: Error: selected processor does not support `gic lddi,xzr'
.*: Error: selected processor does not support `gic lddis,x0'
.*: Error: selected processor does not support `gic lddis,xzr'
.*: Error: selected processor does not support `gic lden,x0'
.*: Error: selected processor does not support `gic lden,xzr'
.*: Error: selected processor does not support `gic ldhm,x0'
.*: Error: selected processor does not support `gic ldhm,xzr'
.*: Error: selected processor does not support `gic ldpend,x0'
.*: Error: selected processor does not support `gic ldpend,xzr'
.*: Error: selected processor does not support `gic ldpri,x0'
.*: Error: selected processor does not support `gic ldpri,xzr'
.*: Error: selected processor does not support `gic ldrcfg,x0'
.*: Error: selected processor does not support `gic ldrcfg,xzr'
.*: Error: selected processor does not support `gsb sys'
.*: Error: selected processor does not support `gsb ack'
