/* fprcvt.s Test file for AArch64 floating-point<->fixed-point
   conversion and floating-point<->integer conversion instructions.  */

a:
	fcvtas s0, h0
	fcvtas s31, h0
	fcvtas s0, h31
	fcvtas d0, s0
	fcvtas d31, s0
	fcvtas d0, s31
	fcvtas d0, h0
	fcvtas d31, h0
	fcvtas d0, h31
	fcvtas s0, d0
	fcvtas s31, d0
	fcvtas s0, d31
b:
	fcvtau s0, h0
	fcvtau s31, h0
	fcvtau s0, h31
	fcvtau d0, s0
	fcvtau d31, s0
	fcvtau d0, s31
	fcvtau d0, h0
	fcvtau d31, h0
	fcvtau d0, h31
	fcvtau s0, d0
	fcvtau s31, d0
	fcvtau s0, d31
c:
	fcvtms s0, h0
	fcvtms s31, h0
	fcvtms s0, h31
	fcvtms d0, s0
	fcvtms d31, s0
	fcvtms d0, s31
	fcvtms d0, h0
	fcvtms d31, h0
	fcvtms d0, h31
	fcvtms s0, d0
	fcvtms s31, d0
	fcvtms s0, d31
d:
	fcvtmu s0, h0
	fcvtmu s31, h0
	fcvtmu s0, h31
	fcvtmu d0, s0
	fcvtmu d31, s0
	fcvtmu d0, s31
	fcvtmu d0, h0
	fcvtmu d31, h0
	fcvtmu d0, h31
	fcvtmu s0, d0
	fcvtmu s31, d0
	fcvtmu s0, d31
e:
	fcvtns s0, h0
	fcvtns s31, h0
	fcvtns s0, h31
	fcvtns d0, s0
	fcvtns d31, s0
	fcvtns d0, s31
	fcvtns d0, h0
	fcvtns d31, h0
	fcvtns d0, h31
	fcvtns s0, d0
	fcvtns s31, d0
	fcvtns s0, d31
f:
	fcvtnu s0, h0
	fcvtnu s31, h0
	fcvtnu s0, h31
	fcvtnu d0, s0
	fcvtnu d31, s0
	fcvtnu d0, s31
	fcvtnu d0, h0
	fcvtnu d31, h0
	fcvtnu d0, h31
	fcvtnu s0, d0
	fcvtnu s31, d0
	fcvtnu s0, d31
g:
	fcvtps s0, h0
	fcvtps s31, h0
	fcvtps s0, h31
	fcvtps d0, s0
	fcvtps d31, s0
	fcvtps d0, s31
	fcvtps d0, h0
	fcvtps d31, h0
	fcvtps d0, h31
	fcvtps s0, d0
	fcvtps s31, d0
	fcvtps s0, d31
h:
	fcvtpu s0, h0
	fcvtpu s31, h0
	fcvtpu s0, h31
	fcvtpu d0, s0
	fcvtpu d31, s0
	fcvtpu d0, s31
	fcvtpu d0, h0
	fcvtpu d31, h0
	fcvtpu d0, h31
	fcvtpu s0, d0
	fcvtpu s31, d0
	fcvtpu s0, d31
i:
	fcvtzs s0, h0
	fcvtzs s31, h0
	fcvtzs s0, h31
	fcvtzs d0, s0
	fcvtzs d31, s0
	fcvtzs d0, s31
	fcvtzs d0, h0
	fcvtzs d31, h0
	fcvtzs d0, h31
	fcvtzs s0, d0
	fcvtzs s31, d0
	fcvtzs s0, d31
j:
	fcvtzu s0, h0
	fcvtzu s31, h0
	fcvtzu s0, h31
	fcvtzu d0, s0
	fcvtzu d31, s0
	fcvtzu d0, s31
	fcvtzu d0, h0
	fcvtzu d31, h0
	fcvtzu d0, h31
	fcvtzu s0, d0
	fcvtzu s31, d0
	fcvtzu s0, d31
k:
	scvtf h0, s0
	scvtf h31, s0
	scvtf h0, s31
	scvtf d0, s0
	scvtf d31, s0
	scvtf d0, s31
	scvtf h0, d0
	scvtf h31, d0
	scvtf h0, d31
	scvtf s0, d0
	scvtf s31, d0
	scvtf s0, d31
l:
	ucvtf h0, s0
	ucvtf h31, s0
	ucvtf h0, s31
	ucvtf d0, s0
	ucvtf d31, s0
	ucvtf d0, s31
	ucvtf h0, d0
	ucvtf h31, d0
	ucvtf h0, d31
	ucvtf s0, d0
	ucvtf s31, d0
	ucvtf s0, d31
