[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w10,2\],{ ?z14\.h ?- ?z15\.h ?},z13\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.s\[w9,1\],{ ?z4\.b ?- ?z7\.b ?},z10\.b\[2\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0,vgx2\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.s\[W8,0,VGx2\],{ ?Z0\.h ?- ?Z1\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.S\[W8,0,VGX2\],{ ?Z0\.H ?- ?Z1\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w11,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,7\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z30\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.h ?- ?z1\.h ?},z0\.h\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w10,2\],{ ?z14\.h ?- ?z15\.h ?},z13\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0,vgx4\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.s\[W8,0,VGx4\],{ ?Z0\.b ?- ?Z3\.b ?},Z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.S\[W8,0,VGX4\],{ ?Z0\.B ?- ?Z3\.B ?},Z0\.B\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w11,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,7\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z28\.b ?- ?z31\.b ?},z0\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z15\.b\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w8,0\],{ ?z0\.b ?- ?z3\.b ?},z0\.b\[3\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.s\[w9,1\],{ ?z4\.b ?- ?z7\.b ?},z10\.b\[2\]'
