fmopa za0.s, p0/m, p0/m, z0.b, z0.b
fmopa za3.s, p0/m, p0/m, z0.b, z0.b
fmopa za0.s, p7/m, p0/m, z0.b, z0.b
fmopa za0.s, p0/m, p7/m, z0.b, z0.b
fmopa za0.s, p0/m, p0/m, z31.b, z0.b
fmopa za0.s, p0/m, p0/m, z0.b, z31.b
