/* FMOPA.  */
fmopa ZA0.h, p0/m, p0/m, z0.h, z0.h
fmopa ZA1.h, p0/m, p0/m, z0.h, z0.h
fmopa ZA0.h, p7/m, p0/m, z0.h, z0.h
fmopa ZA0.h, p0/m, p7/m, z0.h, z0.h
fmopa ZA0.h, p0/m, p0/m, z31.h, z0.h
fmopa ZA0.h, p0/m, p0/m, z0.h, z31.h
fmopa ZA1.h, p7/m, p7/m, z31.h, z31.h
fmopa ZA0.h, p3/m, p5/m, z10.h, z15.h
fmopa ZA1.h, p1/m, p3/m, z15.h, z25.h

/* FMOPS.  */
fmops ZA0.h, p0/m, p0/m, z0.h, z0.h
fmops ZA1.h, p0/m, p0/m, z0.h, z0.h
fmops ZA0.h, p7/m, p0/m, z0.h, z0.h
fmops ZA0.h, p0/m, p7/m, z0.h, z0.h
fmops ZA0.h, p0/m, p0/m, z31.h, z0.h
fmops ZA0.h, p0/m, p0/m, z0.h, z31.h
fmops ZA1.h, p7/m, p7/m, z31.h, z31.h
fmops ZA0.h, p3/m, p5/m, z10.h, z15.h
fmops ZA1.h, p1/m, p3/m, z15.h, z25.h
