.syntax unified
.text
itt le
vaddle.f32 s3, s5, s7
vaddle.f64 d7, d4, d6
itt lt
vaddlt.f32 s3, s5, s7
vaddlt.f64 d7, d4, d6
itt le
vsuble.f32 s3, s5, s7
vsuble.f64 d7, d4, d6
itt lt
vsublt.f32 s3, s5, s7
vsublt.f64 d7, d4, d6
itt le
vaddle.f32 s0, s12
vsuble.f64 d0, d1
