[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.d\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot ZA\.D\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `svdot za\.d\[w9,1\],{ ?z4\.h ?- ?z7\.h ?},z10\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,0,vgx4\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.d\[W8,0,VGx4\],{ ?Z0\.h ?- ?Z3\.h ?},Z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot ZA\.D\[W8,0,VGX4\],{ ?Z0\.H ?- ?Z3\.H ?},Z0\.H\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w11,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,7\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,0\],{ ?z28\.h ?- ?z31\.h ?},z0\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z15\.h\[0\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w8,0\],{ ?z0\.h ?- ?z3\.h ?},z0\.h\[1\]'
[^ :]+:[0-9]+: Error: selected processor does not support `uvdot za\.d\[w9,1\],{ ?z4\.h ?- ?z7\.h ?},z10\.h\[1\]'
