.*: Assembler messages:
.*: Error: operand mismatch -- `fcvt { ?z0.d-z1.d ?},z0.h'
.*: Info:    did you mean this\?
.*: Info:    	fcvt { ?z0.s-z1.s ?}, z0.h
.*: Error: start register out of range at operand 1 -- `fcvt { ?z29.s-z30.s ?},z0.h'
.*: Error: operand mismatch -- `fcvt { ?z0.s-z1.s ?},z31.d'
.*: Info:    did you mean this\?
.*: Info:    	fcvt { ?z0.s-z1.s ?}, z31.h
.*: Error: start register out of range at operand 1 -- `fcvt { ?z15.s-z16.s ?},z31.h'
.*: Error: operand mismatch -- `fcvt { ?z14.s-z15.s ?},z15.b'
.*: Info:    did you mean this\?
.*: Info:    	fcvt { ?z14.s-z15.s ?}, z15.h
.*: Error: type mismatch in vector register list at operand 1 -- `fcvt { ?z6.s,z7.b ?},z7.h'
.*: Error: missing type suffix at operand 1 -- `fcvt { ?z2-z3 ?},z3.h'
.*: Error: operand mismatch -- `fcvtl { ?z0.d-z1.d ?},z0.h'
.*: Info:    did you mean this\?
.*: Info:    	fcvtl { ?z0.s-z1.s ?}, z0.h
.*: Error: start register out of range at operand 1 -- `fcvtl { ?z29.s-z30.s ?},z0.h'
.*: Error: operand mismatch -- `fcvtl { ?z0.s-z1.s ?},z31.d'
.*: Info:    did you mean this\?
.*: Info:    	fcvtl { ?z0.s-z1.s ?}, z31.h
.*: Error: start register out of range at operand 1 -- `fcvtl { ?z15.s-z16.s ?},z31.h'
.*: Error: operand mismatch -- `fcvtl { ?z14.s-z15.s ?},z15.b'
.*: Info:    did you mean this\?
.*: Info:    	fcvtl { ?z14.s-z15.s ?}, z15.h
.*: Error: type mismatch in vector register list at operand 1 -- `fcvtl { ?z6.s,z7.b ?},z7.h'
.*: Error: missing type suffix at operand 1 -- `fcvtl { ?z2-z3 ?},z3.h'
