.*: Assembler messages:
.*:3: Warning: operand 1: expected general register name
.*:3: Warning: operand 2: expected general register name as index register
.*:3: Warning: operand 2: expected general register name as base register
.*:4: Warning: operand 1: expected floating-point register name
.*:4: Warning: operand 2: expected general register name as index register
.*:4: Warning: operand 2: expected general register name as base register
.*:5: Warning: operand 1: expected vector register name
.*:5: Warning: operand 2: expected general register name as index register
.*:5: Warning: operand 2: expected general register name as base register
.*:6: Warning: operand 1: expected vector register name
.*:6: Warning: operand 2: expected vector register name as index register
.*:6: Warning: operand 2: expected general register name as base register
.*:7: Warning: operand 1: expected access register name
.*:7: Warning: operand 2: expected general register name
