.*: Assembler messages:
.*:6: Warning: IT blocks containing 32-bit Thumb instructions are performance deprecated in ARMv8-A and ARMv8-R
.*:14: Warning: IT blocks containing more than one conditional instruction are performance deprecated in ARMv8-A and ARMv8-R
.*:19: Warning: IT blocks containing more than one conditional instruction are performance deprecated in ARMv8-A and ARMv8-R
.*:29: Warning: IT blocks containing 32-bit Thumb instructions are performance deprecated in ARMv8-A and ARMv8-R
.*:35: Warning: IT blocks containing more than one conditional instruction are performance deprecated in ARMv8-A and ARMv8-R
.*:39: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Short branches, Undefined, SVC, LDM/STM
.*:42: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Miscellaneous 16-bit instructions
.*:48: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Literal loads
.*:51: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Hi-register ADD, MOV, CMP, BX, BLX using pc
.*:54: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Short branches, Undefined, SVC, LDM/STM
.*:54: Error: r15 not allowed here -- `addeq r0,pc,pc'
.*:57: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: Short branches, Undefined, SVC, LDM/STM
.*:57: Error: r15 not allowed here -- `addeq pc,r0,r0'
.*:60: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: ADD/SUB sp, sp #imm
.*:64: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: ADD/SUB sp, sp #imm
.*:67: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: ADD/SUB sp, sp #imm
.*:71: Warning: IT blocks containing 16-bit Thumb instructions of the following class are performance deprecated in ARMv8-A and ARMv8-R: ADD/SUB sp, sp #imm
