	tlbip	ipas2e1os, x0, x1
	tlbip	ipas2le1os, x0, x1
	tlbip	ripas2e1os, x0, x1
	tlbip	ripas2le1os, x0, x1
	tlbip	rvaae1os, x0, x1
	tlbip	rvaale1os, x0, x1
	tlbip	rvae1os, x0, x1
	tlbip	rvae2os, x0, x1
	tlbip	rvale1os, x0, x1
	tlbip	rvale2os, x0, x1
	tlbip	vaae1os, x0, x1
	tlbip	vaale1os, x0, x1
	tlbip	vae1os, x0, x1
	tlbip	vae2os, x0, x1
	tlbip	vale1os, x0, x1
	tlbip	vale2os, x0, x1

	tlbip	ipas2e1osnxs, x0, x1
	tlbip	ipas2le1osnxs, x0, x1
	tlbip	ripas2e1osnxs, x0, x1
	tlbip	ripas2le1osnxs, x0, x1
	tlbip	rvaae1osnxs, x0, x1
	tlbip	rvaale1osnxs, x0, x1
	tlbip	rvae1osnxs, x0, x1
	tlbip	rvae2osnxs, x0, x1
	tlbip	rvale1osnxs, x0, x1
	tlbip	rvale2osnxs, x0, x1
	tlbip	vaae1osnxs, x0, x1
	tlbip	vaale1osnxs, x0, x1
	tlbip	vae1osnxs, x0, x1
	tlbip	vae2osnxs, x0, x1
	tlbip	vale1osnxs, x0, x1
	tlbip	vale2osnxs, x0, x1

	tlbip	ipas2e1is, x0, x1
	tlbip	ipas2le1is, x0, x1
	tlbip	ripas2e1is, x0, x1
	tlbip	ripas2le1is, x0, x1
	tlbip	rvaae1is, x0, x1
	tlbip	rvaale1is, x0, x1
	tlbip	rvae1is, x0, x1
	tlbip	rvae2is, x0, x1
	tlbip	rvale1is, x0, x1
	tlbip	rvale2is, x0, x1
	tlbip	vaae1is, x0, x1
	tlbip	vaale1is, x0, x1
	tlbip	vae1is, x0, x1
	tlbip	vae2is, x0, x1
	tlbip	vale1is, x0, x1
	tlbip	vale2is, x0, x1

	tlbip	ipas2e1isnxs, x0, x1
	tlbip	ipas2le1isnxs, x0, x1
	tlbip	ripas2e1isnxs, x0, x1
	tlbip	ripas2le1isnxs, x0, x1
	tlbip	rvaae1isnxs, x0, x1
	tlbip	rvaale1isnxs, x0, x1
	tlbip	rvae1isnxs, x0, x1
	tlbip	rvae2isnxs, x0, x1
	tlbip	rvale1isnxs, x0, x1
	tlbip	rvale2isnxs, x0, x1
	tlbip	vaae1isnxs, x0, x1
	tlbip	vaale1isnxs, x0, x1
	tlbip	vae1isnxs, x0, x1
	tlbip	vae2isnxs, x0, x1
	tlbip	vale1isnxs, x0, x1
	tlbip	vale2isnxs, x0, x1
