.*Assembler messages:
.*6: Warning: SCFI ignores most user-specified CFI directives
.*9: Error: SCFI: `jmp' insn with non-zero addend to sym not supported
.*9: Error: SCFI: unhandled op 0xeb may cause incorrect CFI
