[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtn z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `sqcvtun z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z31\.b,{ ?z0\.s ?- ?z3\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.b,{ ?z28\.s ?- ?z31\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z11\.b,{ ?z20\.s ?- ?z23\.s ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z31\.h,{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z0\.h,{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `uqcvtn z22\.h,{ ?z4\.d ?- ?z7\.d ?}'
