	.file	"A.c"
	.section	.ctf,"",%progbits
.Lctf0:
	.2byte	0xdff2
	.byte	0x4
	.byte	0
	.long	0
	.long	0
	.long	0x9
	.long	0
	.long	0
	.long	0x4
	.long	0x4
	.long	0x8
	.long	0x8
	.long	0x10
	.long	0x40
	.long	0x37
	.long	0x1
	.long	0x7
	.long	0x7
	.long	0x1
	.long	0xff00
	.long	0x1a000001
	.long	0x8
	.long	0x5
	.long	0
	.long	0x3
	.long	0x3
	.long	0x26000000
	.long	0x6
	.long	0
	.long	0xe000000
	.long	0x2
	.ascii "\0"
	.ascii "A\0"
	.ascii "B\0"
	.ascii "b\0"
	.ascii "a\0"
	.ascii "/usr/src/binutils-gdb/ld/testsuite/ld-ctf/A.c\0"
	.text
	.comm	a,8,8
	.ident	"GCC: (GNU) 8.3.1 20191121 (Red Hat 8.3.1-5.0.1)"
	.section	.note.GNU-stack,"",%progbits
