.*: Assembler messages:
.*:3: Error: .*vblendvpd.*
.*:4: Error: .*vblendvpd.*
.*:5: Error: .*vblendvps.*
.*:6: Error: .*vblendvps.*
.*:7: Error: .*vfmaddpd.*
.*:8: Error: .*vfmaddpd.*
.*:9: Error: .*vfmaddps.*
.*:10: Error: .*vfmaddps.*
.*:11: Error: .*vgatherdpd.*
.*:12: Error: .*vgatherdpd.*
.*:13: Error: .*vgatherdps.*
.*:14: Error: .*vgatherdps.*
.*:15: Error: .*vgatherqpd.*
.*:16: Error: .*vgatherqpd.*
.*:17: Error: .*vgatherqps.*
.*:18: Error: .*vgatherqps.*
.*:19: Error: .*vpblendvb.*
.*:20: Error: .*vpblendvb.*
.*:21: Error: .*vpcmov.*
.*:22: Error: .*vpcmov.*
.*:23: Error: .*vpermil2pd.*
.*:24: Error: .*vpermil2pd.*
.*:25: Error: .*vpermil2ps.*
.*:26: Error: .*vpermil2ps.*
.*:27: Error: .*vpgatherdd.*
.*:28: Error: .*vpgatherdd.*
.*:29: Error: .*vpgatherdq.*
.*:30: Error: .*vpgatherdq.*
.*:31: Error: .*vpgatherqd.*
.*:32: Error: .*vpgatherqd.*
.*:33: Error: .*vpgatherqq.*
.*:34: Error: .*vpgatherqq.*
.*:38: Error: .*vblendvpd.*
.*:39: Error: .*vblendvpd.*
.*:40: Error: .*vblendvps.*
.*:41: Error: .*vblendvps.*
.*:42: Error: .*vfmaddpd.*
.*:43: Error: .*vfmaddpd.*
.*:44: Error: .*vfmaddps.*
.*:45: Error: .*vfmaddps.*
.*:46: Error: .*vgatherdpd.*
.*:47: Error: .*vgatherdpd.*
.*:48: Error: .*vgatherdps.*
.*:49: Error: .*vgatherdps.*
.*:50: Error: .*vgatherqpd.*
.*:51: Error: .*vgatherqpd.*
.*:52: Error: .*vgatherqps.*
.*:53: Error: .*vgatherqps.*
.*:54: Error: .*vpblendvb.*
.*:55: Error: .*vpblendvb.*
.*:56: Error: .*vpcmov.*
.*:57: Error: .*vpcmov.*
.*:58: Error: .*vpermil2pd.*
.*:59: Error: .*vpermil2pd.*
.*:60: Error: .*vpermil2ps.*
.*:61: Error: .*vpermil2ps.*
.*:62: Error: .*vpgatherdd.*
.*:63: Error: .*vpgatherdd.*
.*:64: Error: .*vpgatherdq.*
.*:65: Error: .*vpgatherdq.*
.*:66: Error: .*vpgatherqd.*
.*:67: Error: .*vpgatherqd.*
.*:68: Error: .*vpgatherqq.*
.*:69: Error: .*vpgatherqq.*
