.*: Assembler messages:
.*: Error: selected processor does not support `tchangef x0,x1'
.*: Error: selected processor does not support `tchangef xzr,x0'
.*: Error: selected processor does not support `tchangef x1,xzr'
.*: Error: selected processor does not support `tchangef x0,x1,nb'
.*: Error: selected processor does not support `tchangef xzr,x0,Nb'
.*: Error: selected processor does not support `tchangef x0,xzr,nB'
.*: Error: selected processor does not support `tchangef x0,x15,NB'
.*: Error: selected processor does not support `tchangef x0,#0'
.*: Error: selected processor does not support `tchangef xzr,#1'
.*: Error: selected processor does not support `tchangef x10,#127'
.*: Error: selected processor does not support `tchangef x0,#0,nb'
.*: Error: selected processor does not support `tchangef xzr,#1,NB'
.*: Error: selected processor does not support `tchangef x30,#63,nB'
.*: Error: selected processor does not support `tchangef x10,#127,Nb'
.*: Error: selected processor does not support `tchangeb x0,x1'
.*: Error: selected processor does not support `tchangeb xzr,x0'
.*: Error: selected processor does not support `tchangeb x0,xzr'
.*: Error: selected processor does not support `tchangeb x0,x1,nb'
.*: Error: selected processor does not support `tchangeb xzr,x0,Nb'
.*: Error: selected processor does not support `tchangeb x0,xzr,nB'
.*: Error: selected processor does not support `tchangeb x0,x15,NB'
.*: Error: selected processor does not support `tchangeb x0,#0'
.*: Error: selected processor does not support `tchangeb xzr,#1'
.*: Error: selected processor does not support `tchangeb x10,#127'
.*: Error: selected processor does not support `tchangeb x0,#0,nb'
.*: Error: selected processor does not support `tchangeb xzr,#1,NB'
.*: Error: selected processor does not support `tchangeb x30,#63,nB'
.*: Error: selected processor does not support `tchangeb x15,#127,Nb'
