#objdump: -dr
[^:]+:     file format .*


[^:]+:

[^:]+:
.*:	d50c867f 	tlbi	vmallws2e1
.*:	d50c825f 	tlbi	vmallws2e1is
.*:	d50c855f 	tlbi	vmallws2e1os
.*:	d50c967f 	tlbi	vmallws2e1nxs
.*:	d50c925f 	tlbi	vmallws2e1isnxs
.*:	d50c955f 	tlbi	vmallws2e1osnxs
.*:	d50c8240 	tlbi	vmallws2e1is, x0
.*:	d50c8540 	tlbi	vmallws2e1os, x0
.*:	d50c9240 	tlbi	vmallws2e1isnxs, x0
.*:	d50c9540 	tlbi	vmallws2e1osnxs, x0
