.*: Assembler messages:
.*: Error: illegal operands `cv.bclr x32,x32,20,20'
.*: Error: illegal operands `cv.bclr x33,x33,20,20'
.*: Error: illegal operands `cv.bclr x6,x7,0,32'
.*: Error: illegal operands `cv.bclr x6,x7,32,0'
.*: Error: illegal operands `cv.bclr x6,x7,0,-1'
.*: Error: illegal operands `cv.bclr x6,x7,-1,0'
.*: Error: illegal operands `cv.bclrr x32,x32,x32'
.*: Error: illegal operands `cv.bclrr x33,x33,x33'
.*: Error: illegal operands `cv.bitrev x32,x32,2,20'
.*: Error: illegal operands `cv.bitrev x33,x33,2,20'
.*: Error: illegal operands `cv.bitrev x6,x7,-1,0'
.*: Error: illegal operands `cv.bitrev x6,x7,0,-1'
.*: Error: illegal operands `cv.bitrev x6,x7,0,32'
.*: Error: illegal operands `cv.bitrev x6,x7,4,0'
.*: Error: illegal operands `cv.bset x32,x32,20,20'
.*: Error: illegal operands `cv.bset x33,x33,20,20'
.*: Error: illegal operands `cv.bset x6,x7,0,32'
.*: Error: illegal operands `cv.bset x6,x7,32,0'
.*: Error: illegal operands `cv.bset x6,x7,0,-1'
.*: Error: illegal operands `cv.bset x6,x7,-1,0'
.*: Error: illegal operands `cv.bsetr x32,x32,x32'
.*: Error: illegal operands `cv.bsetr x33,x33,x33'
.*: Error: illegal operands `cv.clb x32,x32'
.*: Error: illegal operands `cv.clb x33,x33'
.*: Error: illegal operands `cv.cnt x32,x32'
.*: Error: illegal operands `cv.cnt x33,x33'
.*: Error: illegal operands `cv.extract x32,x32,20,20'
.*: Error: illegal operands `cv.extract x33,x33,20,20'
.*: Error: illegal operands `cv.extract x6,x7,0,32'
.*: Error: illegal operands `cv.extract x6,x7,32,0'
.*: Error: illegal operands `cv.extract x6,x7,0,-1'
.*: Error: illegal operands `cv.extract x6,x7,-1,0'
.*: Error: illegal operands `cv.extractr x32,x32,x32'
.*: Error: illegal operands `cv.extractr x33,x33,x33'
.*: Error: illegal operands `cv.extractu x32,x32,20,20'
.*: Error: illegal operands `cv.extractu x33,x33,20,20'
.*: Error: illegal operands `cv.extractu x6,x7,0,32'
.*: Error: illegal operands `cv.extractu x6,x7,32,0'
.*: Error: illegal operands `cv.extractu x6,x7,0,-1'
.*: Error: illegal operands `cv.extractu x6,x7,-1,0'
.*: Error: illegal operands `cv.extractur x32,x32,x32'
.*: Error: illegal operands `cv.extractur x33,x33,x33'
.*: Error: illegal operands `cv.ff1 x32,x32'
.*: Error: illegal operands `cv.ff1 x33,x33'
.*: Error: illegal operands `cv.fl1 x32,x32'
.*: Error: illegal operands `cv.fl1 x33,x33'
.*: Error: illegal operands `cv.insert x32,x32,20,20'
.*: Error: illegal operands `cv.insert x33,x33,20,20'
.*: Error: illegal operands `cv.insert x6,x7,0,32'
.*: Error: illegal operands `cv.insert x6,x7,32,0'
.*: Error: illegal operands `cv.insert x6,x7,0,-1'
.*: Error: illegal operands `cv.insert x6,x7,-1,0'
.*: Error: illegal operands `cv.insertr x32,x32,x32'
.*: Error: illegal operands `cv.insertr x33,x33,x33'
.*: Error: illegal operands `cv.ror x32,x32,x32'
.*: Error: illegal operands `cv.ror x33,x33,x33'
