xvfmadd.s	$xr0, $xr1, $xr2, $xr3
xvfmsub.s	$xr0, $xr1, $xr2, $xr3
xvfnmadd.s	$xr0, $xr1, $xr2, $xr3
xvfnmsub.s	$xr0, $xr1, $xr2, $xr3
xvfcmp.caf.s	$xr0, $xr1, $xr2
xvfcmp.saf.s	$xr0, $xr1, $xr2
xvfcmp.clt.s	$xr0, $xr1, $xr2
xvfcmp.slt.s	$xr0, $xr1, $xr2
xvfcmp.ceq.s	$xr0, $xr1, $xr2
xvfcmp.seq.s	$xr0, $xr1, $xr2
xvfcmp.cle.s	$xr0, $xr1, $xr2
xvfcmp.sle.s	$xr0, $xr1, $xr2
xvfcmp.cun.s	$xr0, $xr1, $xr2
xvfcmp.sun.s	$xr0, $xr1, $xr2
xvfcmp.cult.s	$xr0, $xr1, $xr2
xvfcmp.sult.s	$xr0, $xr1, $xr2
xvfcmp.cueq.s	$xr0, $xr1, $xr2
xvfcmp.sueq.s	$xr0, $xr1, $xr2
xvfcmp.cule.s	$xr0, $xr1, $xr2
xvfcmp.sule.s	$xr0, $xr1, $xr2
xvfcmp.cne.s	$xr0, $xr1, $xr2
xvfcmp.sne.s	$xr0, $xr1, $xr2
xvfcmp.cor.s	$xr0, $xr1, $xr2
xvfcmp.sor.s	$xr0, $xr1, $xr2
xvfcmp.cune.s	$xr0, $xr1, $xr2
xvfcmp.sune.s	$xr0, $xr1, $xr2
xvbitsel.v	$xr0, $xr1, $xr2, $xr3
xvshuf.b	$xr0, $xr1, $xr2, $xr3
xvfmadd.d	$xr0, $xr1, $xr2, $xr3
xvfmsub.d	$xr0, $xr1, $xr2, $xr3
xvfnmadd.d	$xr0, $xr1, $xr2, $xr3
xvfnmsub.d	$xr0, $xr1, $xr2, $xr3
xvfcmp.caf.d	$xr0, $xr1, $xr2
xvfcmp.saf.d	$xr0, $xr1, $xr2
xvfcmp.clt.d	$xr0, $xr1, $xr2
xvfcmp.slt.d	$xr0, $xr1, $xr2
xvfcmp.ceq.d	$xr0, $xr1, $xr2
xvfcmp.seq.d	$xr0, $xr1, $xr2
xvfcmp.cle.d	$xr0, $xr1, $xr2
xvfcmp.sle.d	$xr0, $xr1, $xr2
xvfcmp.cun.d	$xr0, $xr1, $xr2
xvfcmp.sun.d	$xr0, $xr1, $xr2
xvfcmp.cult.d	$xr0, $xr1, $xr2
xvfcmp.sult.d	$xr0, $xr1, $xr2
xvfcmp.cueq.d	$xr0, $xr1, $xr2
xvfcmp.sueq.d	$xr0, $xr1, $xr2
xvfcmp.cule.d	$xr0, $xr1, $xr2
xvfcmp.sule.d	$xr0, $xr1, $xr2
xvfcmp.cne.d	$xr0, $xr1, $xr2
xvfcmp.sne.d	$xr0, $xr1, $xr2
xvfcmp.cor.d	$xr0, $xr1, $xr2
xvfcmp.sor.d	$xr0, $xr1, $xr2
xvfcmp.cune.d	$xr0, $xr1, $xr2
xvfcmp.sune.d	$xr0, $xr1, $xr2
xvld	$xr0, $r1, 1
xvst	$xr0, $r1, 1
xvldx	$xr0, $r1, $r2
xvstx	$xr0, $r1, $r2
xvldrepl.d	$xr0, $r1, 1000
xvldrepl.w	$xr0, $r1, 100
xvldrepl.h	$xr0, $r1, 10
xvldrepl.b	$xr0, $r1, 1
xvstelm.d	$xr0, $r1, 1000, 1
xvstelm.w	$xr0, $r1, 100, 1
xvstelm.h	$xr0, $r1, 10, 1
xvstelm.b	$xr0, $r1, 1, 1
xvseq.b	$xr0, $xr1, $xr2
xvseq.h	$xr0, $xr1, $xr2
xvseq.w	$xr0, $xr1, $xr2
xvseq.d	$xr0, $xr1, $xr2
xvsle.b	$xr0, $xr1, $xr2
xvsle.h	$xr0, $xr1, $xr2
xvsle.w	$xr0, $xr1, $xr2
xvsle.d	$xr0, $xr1, $xr2
xvsle.bu	$xr0, $xr1, $xr2
xvsle.hu	$xr0, $xr1, $xr2
xvsle.wu	$xr0, $xr1, $xr2
xvsle.du	$xr0, $xr1, $xr2
xvslt.b	$xr0, $xr1, $xr2
xvslt.h	$xr0, $xr1, $xr2
xvslt.w	$xr0, $xr1, $xr2
xvslt.d	$xr0, $xr1, $xr2
xvslt.bu	$xr0, $xr1, $xr2
xvslt.hu	$xr0, $xr1, $xr2
xvslt.wu	$xr0, $xr1, $xr2
xvslt.du	$xr0, $xr1, $xr2
xvadd.b	$xr0, $xr1, $xr2
xvadd.h	$xr0, $xr1, $xr2
xvadd.w	$xr0, $xr1, $xr2
xvadd.d	$xr0, $xr1, $xr2
xvsub.b	$xr0, $xr1, $xr2
xvsub.h	$xr0, $xr1, $xr2
xvsub.w	$xr0, $xr1, $xr2
xvsub.d	$xr0, $xr1, $xr2
xvsadd.b	$xr0, $xr1, $xr2
xvsadd.h	$xr0, $xr1, $xr2
xvsadd.w	$xr0, $xr1, $xr2
xvsadd.d	$xr0, $xr1, $xr2
xvssub.b	$xr0, $xr1, $xr2
xvssub.h	$xr0, $xr1, $xr2
xvssub.w	$xr0, $xr1, $xr2
xvssub.d	$xr0, $xr1, $xr2
xvsadd.bu	$xr0, $xr1, $xr2
xvsadd.hu	$xr0, $xr1, $xr2
xvsadd.wu	$xr0, $xr1, $xr2
xvsadd.du	$xr0, $xr1, $xr2
xvssub.bu	$xr0, $xr1, $xr2
xvssub.hu	$xr0, $xr1, $xr2
xvssub.wu	$xr0, $xr1, $xr2
xvssub.du	$xr0, $xr1, $xr2
xvhaddw.h.b	$xr0, $xr1, $xr2
xvhaddw.w.h	$xr0, $xr1, $xr2
xvhaddw.d.w	$xr0, $xr1, $xr2
xvhaddw.q.d	$xr0, $xr1, $xr2
xvhsubw.h.b	$xr0, $xr1, $xr2
xvhsubw.w.h	$xr0, $xr1, $xr2
xvhsubw.d.w	$xr0, $xr1, $xr2
xvhsubw.q.d	$xr0, $xr1, $xr2
xvhaddw.hu.bu	$xr0, $xr1, $xr2
xvhaddw.wu.hu	$xr0, $xr1, $xr2
xvhaddw.du.wu	$xr0, $xr1, $xr2
xvhaddw.qu.du	$xr0, $xr1, $xr2
xvhsubw.hu.bu	$xr0, $xr1, $xr2
xvhsubw.wu.hu	$xr0, $xr1, $xr2
xvhsubw.du.wu	$xr0, $xr1, $xr2
xvhsubw.qu.du	$xr0, $xr1, $xr2
xvaddwev.h.b	$xr0, $xr1, $xr2
xvaddwev.w.h	$xr0, $xr1, $xr2
xvaddwev.d.w	$xr0, $xr1, $xr2
xvaddwev.q.d	$xr0, $xr1, $xr2
xvaddwev.h.bu	$xr0, $xr1, $xr2
xvaddwev.w.hu	$xr0, $xr1, $xr2
xvaddwev.d.wu	$xr0, $xr1, $xr2
xvaddwev.q.du	$xr0, $xr1, $xr2
xvaddwev.h.bu.b	$xr0, $xr1, $xr2
xvaddwev.w.hu.h	$xr0, $xr1, $xr2
xvaddwev.d.wu.w	$xr0, $xr1, $xr2
xvaddwev.q.du.d	$xr0, $xr1, $xr2
xvaddwod.h.b	$xr0, $xr1, $xr2
xvaddwod.w.h	$xr0, $xr1, $xr2
xvaddwod.d.w	$xr0, $xr1, $xr2
xvaddwod.q.d	$xr0, $xr1, $xr2
xvaddwod.h.bu	$xr0, $xr1, $xr2
xvaddwod.w.hu	$xr0, $xr1, $xr2
xvaddwod.d.wu	$xr0, $xr1, $xr2
xvaddwod.q.du	$xr0, $xr1, $xr2
xvaddwod.h.bu.b	$xr0, $xr1, $xr2
xvaddwod.w.hu.h	$xr0, $xr1, $xr2
xvaddwod.d.wu.w	$xr0, $xr1, $xr2
xvaddwod.q.du.d	$xr0, $xr1, $xr2
xvmaddwev.h.b	$xr0, $xr1, $xr2
xvmaddwev.w.h	$xr0, $xr1, $xr2
xvmaddwev.d.w	$xr0, $xr1, $xr2
xvmaddwev.q.d	$xr0, $xr1, $xr2
xvmaddwev.h.bu.b	$xr0, $xr1, $xr2
xvmaddwev.w.hu.h	$xr0, $xr1, $xr2
xvmaddwev.d.wu.w	$xr0, $xr1, $xr2
xvmaddwev.q.du.d	$xr0, $xr1, $xr2
xvmaddwev.h.bu	$xr0, $xr1, $xr2
xvmaddwev.w.hu	$xr0, $xr1, $xr2
xvmaddwev.d.wu	$xr0, $xr1, $xr2
xvmaddwev.q.du	$xr0, $xr1, $xr2
xvmaddwod.h.b	$xr0, $xr1, $xr2
xvmaddwod.w.h	$xr0, $xr1, $xr2
xvmaddwod.d.w	$xr0, $xr1, $xr2
xvmaddwod.q.d	$xr0, $xr1, $xr2
xvmaddwod.h.bu	$xr0, $xr1, $xr2
xvmaddwod.w.hu	$xr0, $xr1, $xr2
xvmaddwod.d.wu	$xr0, $xr1, $xr2
xvmaddwod.q.du	$xr0, $xr1, $xr2
xvmaddwod.h.bu.b	$xr0, $xr1, $xr2
xvmaddwod.w.hu.h	$xr0, $xr1, $xr2
xvmaddwod.d.wu.w	$xr0, $xr1, $xr2
xvmaddwod.q.du.d	$xr0, $xr1, $xr2
xvmulwev.h.b	$xr0, $xr1, $xr2
xvmulwev.w.h	$xr0, $xr1, $xr2
xvmulwev.d.w	$xr0, $xr1, $xr2
xvmulwev.q.d	$xr0, $xr1, $xr2
xvmulwev.h.bu	$xr0, $xr1, $xr2
xvmulwev.w.hu	$xr0, $xr1, $xr2
xvmulwev.d.wu	$xr0, $xr1, $xr2
xvmulwev.q.du	$xr0, $xr1, $xr2
xvmulwev.h.bu.b	$xr0, $xr1, $xr2
xvmulwev.w.hu.h	$xr0, $xr1, $xr2
xvmulwev.d.wu.w	$xr0, $xr1, $xr2
xvmulwev.q.du.d	$xr0, $xr1, $xr2
xvmulwod.h.b	$xr0, $xr1, $xr2
xvmulwod.w.h	$xr0, $xr1, $xr2
xvmulwod.d.w	$xr0, $xr1, $xr2
xvmulwod.q.d	$xr0, $xr1, $xr2
xvmulwod.h.bu	$xr0, $xr1, $xr2
xvmulwod.w.hu	$xr0, $xr1, $xr2
xvmulwod.d.wu	$xr0, $xr1, $xr2
xvmulwod.q.du	$xr0, $xr1, $xr2
xvmulwod.h.bu.b	$xr0, $xr1, $xr2
xvmulwod.w.hu.h	$xr0, $xr1, $xr2
xvmulwod.d.wu.w	$xr0, $xr1, $xr2
xvmulwod.q.du.d	$xr0, $xr1, $xr2
xvsubwev.h.b	$xr0, $xr1, $xr2
xvsubwev.w.h	$xr0, $xr1, $xr2
xvsubwev.d.w	$xr0, $xr1, $xr2
xvsubwev.q.d	$xr0, $xr1, $xr2
xvsubwev.h.bu	$xr0, $xr1, $xr2
xvsubwev.w.hu	$xr0, $xr1, $xr2
xvsubwev.d.wu	$xr0, $xr1, $xr2
xvsubwev.q.du	$xr0, $xr1, $xr2
xvsubwod.h.b	$xr0, $xr1, $xr2
xvsubwod.w.h	$xr0, $xr1, $xr2
xvsubwod.d.w	$xr0, $xr1, $xr2
xvsubwod.q.d	$xr0, $xr1, $xr2
xvsubwod.h.bu	$xr0, $xr1, $xr2
xvsubwod.w.hu	$xr0, $xr1, $xr2
xvsubwod.d.wu	$xr0, $xr1, $xr2
xvsubwod.q.du	$xr0, $xr1, $xr2
xvadda.b	$xr0, $xr1, $xr2
xvadda.h	$xr0, $xr1, $xr2
xvadda.w	$xr0, $xr1, $xr2
xvadda.d	$xr0, $xr1, $xr2
xvabsd.b	$xr0, $xr1, $xr2
xvabsd.h	$xr0, $xr1, $xr2
xvabsd.w	$xr0, $xr1, $xr2
xvabsd.d	$xr0, $xr1, $xr2
xvabsd.bu	$xr0, $xr1, $xr2
xvabsd.hu	$xr0, $xr1, $xr2
xvabsd.wu	$xr0, $xr1, $xr2
xvabsd.du	$xr0, $xr1, $xr2
xvavg.b	$xr0, $xr1, $xr2
xvavg.h	$xr0, $xr1, $xr2
xvavg.w	$xr0, $xr1, $xr2
xvavg.d	$xr0, $xr1, $xr2
xvavg.bu	$xr0, $xr1, $xr2
xvavg.hu	$xr0, $xr1, $xr2
xvavg.wu	$xr0, $xr1, $xr2
xvavg.du	$xr0, $xr1, $xr2
xvavgr.b	$xr0, $xr1, $xr2
xvavgr.h	$xr0, $xr1, $xr2
xvavgr.w	$xr0, $xr1, $xr2
xvavgr.d	$xr0, $xr1, $xr2
xvavgr.bu	$xr0, $xr1, $xr2
xvavgr.hu	$xr0, $xr1, $xr2
xvavgr.wu	$xr0, $xr1, $xr2
xvavgr.du	$xr0, $xr1, $xr2
xvmax.b	$xr0, $xr1, $xr2
xvmax.h	$xr0, $xr1, $xr2
xvmax.w	$xr0, $xr1, $xr2
xvmax.d	$xr0, $xr1, $xr2
xvmin.b	$xr0, $xr1, $xr2
xvmin.h	$xr0, $xr1, $xr2
xvmin.w	$xr0, $xr1, $xr2
xvmin.d	$xr0, $xr1, $xr2
xvmax.bu	$xr0, $xr1, $xr2
xvmax.hu	$xr0, $xr1, $xr2
xvmax.wu	$xr0, $xr1, $xr2
xvmax.du	$xr0, $xr1, $xr2
xvmin.bu	$xr0, $xr1, $xr2
xvmin.hu	$xr0, $xr1, $xr2
xvmin.wu	$xr0, $xr1, $xr2
xvmin.du	$xr0, $xr1, $xr2
xvmul.b	$xr0, $xr1, $xr2
xvmul.h	$xr0, $xr1, $xr2
xvmul.w	$xr0, $xr1, $xr2
xvmul.d	$xr0, $xr1, $xr2
xvmuh.b	$xr0, $xr1, $xr2
xvmuh.h	$xr0, $xr1, $xr2
xvmuh.w	$xr0, $xr1, $xr2
xvmuh.d	$xr0, $xr1, $xr2
xvmuh.bu	$xr0, $xr1, $xr2
xvmuh.hu	$xr0, $xr1, $xr2
xvmuh.wu	$xr0, $xr1, $xr2
xvmuh.du	$xr0, $xr1, $xr2
xvmadd.b	$xr0, $xr1, $xr2
xvmadd.h	$xr0, $xr1, $xr2
xvmadd.w	$xr0, $xr1, $xr2
xvmadd.d	$xr0, $xr1, $xr2
xvmsub.b	$xr0, $xr1, $xr2
xvmsub.h	$xr0, $xr1, $xr2
xvmsub.w	$xr0, $xr1, $xr2
xvmsub.d	$xr0, $xr1, $xr2
xvdiv.b	$xr0, $xr1, $xr2
xvdiv.h	$xr0, $xr1, $xr2
xvdiv.w	$xr0, $xr1, $xr2
xvdiv.d	$xr0, $xr1, $xr2
xvmod.b	$xr0, $xr1, $xr2
xvmod.h	$xr0, $xr1, $xr2
xvmod.w	$xr0, $xr1, $xr2
xvmod.d	$xr0, $xr1, $xr2
xvdiv.bu	$xr0, $xr1, $xr2
xvdiv.hu	$xr0, $xr1, $xr2
xvdiv.wu	$xr0, $xr1, $xr2
xvdiv.du	$xr0, $xr1, $xr2
xvmod.bu	$xr0, $xr1, $xr2
xvmod.hu	$xr0, $xr1, $xr2
xvmod.wu	$xr0, $xr1, $xr2
xvmod.du	$xr0, $xr1, $xr2
xvsll.b	$xr0, $xr1, $xr2
xvsll.h	$xr0, $xr1, $xr2
xvsll.w	$xr0, $xr1, $xr2
xvsll.d	$xr0, $xr1, $xr2
xvsrl.b	$xr0, $xr1, $xr2
xvsrl.h	$xr0, $xr1, $xr2
xvsrl.w	$xr0, $xr1, $xr2
xvsrl.d	$xr0, $xr1, $xr2
xvsra.b	$xr0, $xr1, $xr2
xvsra.h	$xr0, $xr1, $xr2
xvsra.w	$xr0, $xr1, $xr2
xvsra.d	$xr0, $xr1, $xr2
xvrotr.b	$xr0, $xr1, $xr2
xvrotr.h	$xr0, $xr1, $xr2
xvrotr.w	$xr0, $xr1, $xr2
xvrotr.d	$xr0, $xr1, $xr2
xvsrlr.b	$xr0, $xr1, $xr2
xvsrlr.h	$xr0, $xr1, $xr2
xvsrlr.w	$xr0, $xr1, $xr2
xvsrlr.d	$xr0, $xr1, $xr2
xvsrar.b	$xr0, $xr1, $xr2
xvsrar.h	$xr0, $xr1, $xr2
xvsrar.w	$xr0, $xr1, $xr2
xvsrar.d	$xr0, $xr1, $xr2
xvsrln.b.h	$xr0, $xr1, $xr2
xvsrln.h.w	$xr0, $xr1, $xr2
xvsrln.w.d	$xr0, $xr1, $xr2
xvsran.b.h	$xr0, $xr1, $xr2
xvsran.h.w	$xr0, $xr1, $xr2
xvsran.w.d	$xr0, $xr1, $xr2
xvsrlrn.b.h	$xr0, $xr1, $xr2
xvsrlrn.h.w	$xr0, $xr1, $xr2
xvsrlrn.w.d	$xr0, $xr1, $xr2
xvsrarn.b.h	$xr0, $xr1, $xr2
xvsrarn.h.w	$xr0, $xr1, $xr2
xvsrarn.w.d	$xr0, $xr1, $xr2
xvssrln.b.h	$xr0, $xr1, $xr2
xvssrln.h.w	$xr0, $xr1, $xr2
xvssrln.w.d	$xr0, $xr1, $xr2
xvssran.b.h	$xr0, $xr1, $xr2
xvssran.h.w	$xr0, $xr1, $xr2
xvssran.w.d	$xr0, $xr1, $xr2
xvssrlrn.b.h	$xr0, $xr1, $xr2
xvssrlrn.h.w	$xr0, $xr1, $xr2
xvssrlrn.w.d	$xr0, $xr1, $xr2
xvssrarn.b.h	$xr0, $xr1, $xr2
xvssrarn.h.w	$xr0, $xr1, $xr2
xvssrarn.w.d	$xr0, $xr1, $xr2
xvssrln.bu.h	$xr0, $xr1, $xr2
xvssrln.hu.w	$xr0, $xr1, $xr2
xvssrln.wu.d	$xr0, $xr1, $xr2
xvssran.bu.h	$xr0, $xr1, $xr2
xvssran.hu.w	$xr0, $xr1, $xr2
xvssran.wu.d	$xr0, $xr1, $xr2
xvssrlrn.bu.h	$xr0, $xr1, $xr2
xvssrlrn.hu.w	$xr0, $xr1, $xr2
xvssrlrn.wu.d	$xr0, $xr1, $xr2
xvssrarn.bu.h	$xr0, $xr1, $xr2
xvssrarn.hu.w	$xr0, $xr1, $xr2
xvssrarn.wu.d	$xr0, $xr1, $xr2
xvbitclr.b	$xr0, $xr1, $xr2
xvbitclr.h	$xr0, $xr1, $xr2
xvbitclr.w	$xr0, $xr1, $xr2
xvbitclr.d	$xr0, $xr1, $xr2
xvbitset.b	$xr0, $xr1, $xr2
xvbitset.h	$xr0, $xr1, $xr2
xvbitset.w	$xr0, $xr1, $xr2
xvbitset.d	$xr0, $xr1, $xr2
xvbitrev.b	$xr0, $xr1, $xr2
xvbitrev.h	$xr0, $xr1, $xr2
xvbitrev.w	$xr0, $xr1, $xr2
xvbitrev.d	$xr0, $xr1, $xr2
xvpackev.b	$xr0, $xr1, $xr2
xvpackev.h	$xr0, $xr1, $xr2
xvpackev.w	$xr0, $xr1, $xr2
xvpackev.d	$xr0, $xr1, $xr2
xvpackod.b	$xr0, $xr1, $xr2
xvpackod.h	$xr0, $xr1, $xr2
xvpackod.w	$xr0, $xr1, $xr2
xvpackod.d	$xr0, $xr1, $xr2
xvilvl.b	$xr0, $xr1, $xr2
xvilvl.h	$xr0, $xr1, $xr2
xvilvl.w	$xr0, $xr1, $xr2
xvilvl.d	$xr0, $xr1, $xr2
xvilvh.b	$xr0, $xr1, $xr2
xvilvh.h	$xr0, $xr1, $xr2
xvilvh.w	$xr0, $xr1, $xr2
xvilvh.d	$xr0, $xr1, $xr2
xvpickev.b	$xr0, $xr1, $xr2
xvpickev.h	$xr0, $xr1, $xr2
xvpickev.w	$xr0, $xr1, $xr2
xvpickev.d	$xr0, $xr1, $xr2
xvpickod.b	$xr0, $xr1, $xr2
xvpickod.h	$xr0, $xr1, $xr2
xvpickod.w	$xr0, $xr1, $xr2
xvpickod.d	$xr0, $xr1, $xr2
xvreplve.b	$xr0, $xr1, $r2
xvreplve.h	$xr0, $xr1, $r2
xvreplve.w	$xr0, $xr1, $r2
xvreplve.d	$xr0, $xr1, $r2
xvand.v	$xr0, $xr1, $xr2
xvor.v	$xr0, $xr1, $xr2
xvxor.v	$xr0, $xr1, $xr2
xvnor.v	$xr0, $xr1, $xr2
xvandn.v	$xr0, $xr1, $xr2
xvorn.v	$xr0, $xr1, $xr2
xvfrstp.b	$xr0, $xr1, $xr2
xvfrstp.h	$xr0, $xr1, $xr2
xvadd.q	$xr0, $xr1, $xr2
xvsub.q	$xr0, $xr1, $xr2
xvsigncov.b	$xr0, $xr1, $xr2
xvsigncov.h	$xr0, $xr1, $xr2
xvsigncov.w	$xr0, $xr1, $xr2
xvsigncov.d	$xr0, $xr1, $xr2
xvfadd.s	$xr0, $xr1, $xr2
xvfadd.d	$xr0, $xr1, $xr2
xvfsub.s	$xr0, $xr1, $xr2
xvfsub.d	$xr0, $xr1, $xr2
xvfmul.s	$xr0, $xr1, $xr2
xvfmul.d	$xr0, $xr1, $xr2
xvfdiv.s	$xr0, $xr1, $xr2
xvfdiv.d	$xr0, $xr1, $xr2
xvfmax.s	$xr0, $xr1, $xr2
xvfmax.d	$xr0, $xr1, $xr2
xvfmin.s	$xr0, $xr1, $xr2
xvfmin.d	$xr0, $xr1, $xr2
xvfmaxa.s	$xr0, $xr1, $xr2
xvfmaxa.d	$xr0, $xr1, $xr2
xvfmina.s	$xr0, $xr1, $xr2
xvfmina.d	$xr0, $xr1, $xr2
xvfcvt.h.s	$xr0, $xr1, $xr2
xvfcvt.s.d	$xr0, $xr1, $xr2
xvffint.s.l	$xr0, $xr1, $xr2
xvftint.w.d	$xr0, $xr1, $xr2
xvftintrm.w.d	$xr0, $xr1, $xr2
xvftintrp.w.d	$xr0, $xr1, $xr2
xvftintrz.w.d	$xr0, $xr1, $xr2
xvftintrne.w.d	$xr0, $xr1, $xr2
xvshuf.h	$xr0, $xr1, $xr2
xvshuf.w	$xr0, $xr1, $xr2
xvshuf.d	$xr0, $xr1, $xr2
xvperm.w	$xr0, $xr1, $xr2
xvseqi.b	$xr0, $xr1, 1
xvseqi.h	$xr0, $xr1, 1
xvseqi.w	$xr0, $xr1, 1
xvseqi.d	$xr0, $xr1, 1
xvslei.b	$xr0, $xr1, 1
xvslei.h	$xr0, $xr1, 1
xvslei.w	$xr0, $xr1, 1
xvslei.d	$xr0, $xr1, 1
xvslei.bu	$xr0, $xr1, 1
xvslei.hu	$xr0, $xr1, 1
xvslei.wu	$xr0, $xr1, 1
xvslei.du	$xr0, $xr1, 1
xvslti.b	$xr0, $xr1, 1
xvslti.h	$xr0, $xr1, 1
xvslti.w	$xr0, $xr1, 1
xvslti.d	$xr0, $xr1, 1
xvslti.bu	$xr0, $xr1, 1
xvslti.hu	$xr0, $xr1, 1
xvslti.wu	$xr0, $xr1, 1
xvslti.du	$xr0, $xr1, 1
xvaddi.bu	$xr0, $xr1, 1
xvaddi.hu	$xr0, $xr1, 1
xvaddi.wu	$xr0, $xr1, 1
xvaddi.du	$xr0, $xr1, 1
xvsubi.bu	$xr0, $xr1, 1
xvsubi.hu	$xr0, $xr1, 1
xvsubi.wu	$xr0, $xr1, 1
xvsubi.du	$xr0, $xr1, 1
xvbsll.v	$xr0, $xr1, 1
xvbsrl.v	$xr0, $xr1, 1
xvmaxi.b	$xr0, $xr1, 1
xvmaxi.h	$xr0, $xr1, 1
xvmaxi.w	$xr0, $xr1, 1
xvmaxi.d	$xr0, $xr1, 1
xvmini.b	$xr0, $xr1, 1
xvmini.h	$xr0, $xr1, 1
xvmini.w	$xr0, $xr1, 1
xvmini.d	$xr0, $xr1, 1
xvmaxi.bu	$xr0, $xr1, 1
xvmaxi.hu	$xr0, $xr1, 1
xvmaxi.wu	$xr0, $xr1, 1
xvmaxi.du	$xr0, $xr1, 1
xvmini.bu	$xr0, $xr1, 1
xvmini.hu	$xr0, $xr1, 1
xvmini.wu	$xr0, $xr1, 1
xvmini.du	$xr0, $xr1, 1
xvfrstpi.b	$xr0, $xr1, 1
xvfrstpi.h	$xr0, $xr1, 1
xvclo.b	$xr0, $xr1
xvclo.h	$xr0, $xr1
xvclo.w	$xr0, $xr1
xvclo.d	$xr0, $xr1
xvclz.b	$xr0, $xr1
xvclz.h	$xr0, $xr1
xvclz.w	$xr0, $xr1
xvclz.d	$xr0, $xr1
xvpcnt.b	$xr0, $xr1
xvpcnt.h	$xr0, $xr1
xvpcnt.w	$xr0, $xr1
xvpcnt.d	$xr0, $xr1
xvneg.b	$xr0, $xr1
xvneg.h	$xr0, $xr1
xvneg.w	$xr0, $xr1
xvneg.d	$xr0, $xr1
xvmskltz.b	$xr0, $xr1
xvmskltz.h	$xr0, $xr1
xvmskltz.w	$xr0, $xr1
xvmskltz.d	$xr0, $xr1
xvmskgez.b	$xr0, $xr1
xvmsknz.b	$xr0, $xr1
xvseteqz.v	$fcc0, $xr1
xvsetnez.v	$fcc0, $xr1
xvsetanyeqz.b	$fcc0, $xr1
xvsetanyeqz.h	$fcc0, $xr1
xvsetanyeqz.w	$fcc0, $xr1
xvsetanyeqz.d	$fcc0, $xr1
xvsetallnez.b	$fcc0, $xr1
xvsetallnez.h	$fcc0, $xr1
xvsetallnez.w	$fcc0, $xr1
xvsetallnez.d	$fcc0, $xr1
xvflogb.s	$xr0, $xr1
xvflogb.d	$xr0, $xr1
xvfclass.s	$xr0, $xr1
xvfclass.d	$xr0, $xr1
xvfsqrt.s	$xr0, $xr1
xvfsqrt.d	$xr0, $xr1
xvfrecip.s	$xr0, $xr1
xvfrecip.d	$xr0, $xr1
xvfrsqrt.s	$xr0, $xr1
xvfrsqrt.d	$xr0, $xr1
xvfrint.s	$xr0, $xr1
xvfrint.d	$xr0, $xr1
xvfrintrm.s	$xr0, $xr1
xvfrintrm.d	$xr0, $xr1
xvfrintrp.s	$xr0, $xr1
xvfrintrp.d	$xr0, $xr1
xvfrintrz.s	$xr0, $xr1
xvfrintrz.d	$xr0, $xr1
xvfrintrne.s	$xr0, $xr1
xvfrintrne.d	$xr0, $xr1
xvfcvtl.s.h	$xr0, $xr1
xvfcvth.s.h	$xr0, $xr1
xvfcvtl.d.s	$xr0, $xr1
xvfcvth.d.s	$xr0, $xr1
xvffint.s.w	$xr0, $xr1
xvffint.s.wu	$xr0, $xr1
xvffint.d.l	$xr0, $xr1
xvffint.d.lu	$xr0, $xr1
xvffintl.d.w	$xr0, $xr1
xvffinth.d.w	$xr0, $xr1
xvftint.w.s	$xr0, $xr1
xvftint.l.d	$xr0, $xr1
xvftintrm.w.s	$xr0, $xr1
xvftintrm.l.d	$xr0, $xr1
xvftintrp.w.s	$xr0, $xr1
xvftintrp.l.d	$xr0, $xr1
xvftintrz.w.s	$xr0, $xr1
xvftintrz.l.d	$xr0, $xr1
xvftintrne.w.s	$xr0, $xr1
xvftintrne.l.d	$xr0, $xr1
xvftint.wu.s	$xr0, $xr1
xvftint.lu.d	$xr0, $xr1
xvftintrz.wu.s	$xr0, $xr1
xvftintrz.lu.d	$xr0, $xr1
xvftintl.l.s	$xr0, $xr1
xvftinth.l.s	$xr0, $xr1
xvftintrml.l.s	$xr0, $xr1
xvftintrmh.l.s	$xr0, $xr1
xvftintrpl.l.s	$xr0, $xr1
xvftintrph.l.s	$xr0, $xr1
xvftintrzl.l.s	$xr0, $xr1
xvftintrzh.l.s	$xr0, $xr1
xvftintrnel.l.s	$xr0, $xr1
xvftintrneh.l.s	$xr0, $xr1
xvexth.h.b	$xr0, $xr1
xvexth.w.h	$xr0, $xr1
xvexth.d.w	$xr0, $xr1
xvexth.q.d	$xr0, $xr1
xvexth.hu.bu	$xr0, $xr1
xvexth.wu.hu	$xr0, $xr1
xvexth.du.wu	$xr0, $xr1
xvexth.qu.du	$xr0, $xr1
xvreplgr2vr.b	$xr0, $r1
xvreplgr2vr.h	$xr0, $r1
xvreplgr2vr.w	$xr0, $r1
xvreplgr2vr.d	$xr0, $r1
xvhseli.d	$xr0, $xr1, 1
xvrotri.b	$xr0, $xr1, 1
xvrotri.h	$xr0, $xr1, 1
xvrotri.w	$xr0, $xr1, 1
xvrotri.d	$xr0, $xr1, 1
xvsrlri.b	$xr0, $xr1, 1
xvsrlri.h	$xr0, $xr1, 1
xvsrlri.w	$xr0, $xr1, 1
xvsrlri.d	$xr0, $xr1, 1
xvsrari.b	$xr0, $xr1, 1
xvsrari.h	$xr0, $xr1, 1
xvsrari.w	$xr0, $xr1, 1
xvsrari.d	$xr0, $xr1, 1
xvinsgr2vr.w	$xr0, $r1, 1
xvinsgr2vr.d	$xr0, $r1, 1
xvpickve2gr.w	$r0, $xr1, 1
xvpickve2gr.d	$r0, $xr1, 1
xvpickve2gr.wu	$r0, $xr1, 1
xvpickve2gr.du	$r0, $xr1, 1
xvrepl128vei.b	$xr0, $xr1, 1
xvrepl128vei.h	$xr0, $xr1, 1
xvrepl128vei.w	$xr0, $xr1, 1
xvrepl128vei.d	$xr0, $xr1, 1
xvinsve0.w	$xr0, $xr1, 1
xvinsve0.d	$xr0, $xr1, 1
xvpickve.w	$xr0, $xr1, 1
xvpickve.d	$xr0, $xr1, 1
xvreplve0.b	$xr0, $xr1
xvreplve0.h	$xr0, $xr1
xvreplve0.w	$xr0, $xr1
xvreplve0.d	$xr0, $xr1
xvreplve0.q	$xr0, $xr1
xvsllwil.h.b	$xr0, $xr1, 1
xvsllwil.w.h	$xr0, $xr1, 1
xvsllwil.d.w	$xr0, $xr1, 1
xvextl.q.d	$xr0, $xr1
xvsllwil.hu.bu	$xr0, $xr1, 1
xvsllwil.wu.hu	$xr0, $xr1, 1
xvsllwil.du.wu	$xr0, $xr1, 1
xvextl.qu.du	$xr0, $xr1
xvbitclri.b	$xr0, $xr1, 1
xvbitclri.h	$xr0, $xr1, 1
xvbitclri.w	$xr0, $xr1, 1
xvbitclri.d	$xr0, $xr1, 1
xvbitseti.b	$xr0, $xr1, 1
xvbitseti.h	$xr0, $xr1, 1
xvbitseti.w	$xr0, $xr1, 1
xvbitseti.d	$xr0, $xr1, 1
xvbitrevi.b	$xr0, $xr1, 1
xvbitrevi.h	$xr0, $xr1, 1
xvbitrevi.w	$xr0, $xr1, 1
xvbitrevi.d	$xr0, $xr1, 1
xvsat.b	$xr0, $xr1, 1
xvsat.h	$xr0, $xr1, 1
xvsat.w	$xr0, $xr1, 1
xvsat.d	$xr0, $xr1, 1
xvsat.bu	$xr0, $xr1, 1
xvsat.hu	$xr0, $xr1, 1
xvsat.wu	$xr0, $xr1, 1
xvsat.du	$xr0, $xr1, 1
xvslli.b	$xr0, $xr1, 1
xvslli.h	$xr0, $xr1, 1
xvslli.w	$xr0, $xr1, 1
xvslli.d	$xr0, $xr1, 1
xvsrli.b	$xr0, $xr1, 1
xvsrli.h	$xr0, $xr1, 1
xvsrli.w	$xr0, $xr1, 1
xvsrli.d	$xr0, $xr1, 1
xvsrai.b	$xr0, $xr1, 1
xvsrai.h	$xr0, $xr1, 1
xvsrai.w	$xr0, $xr1, 1
xvsrai.d	$xr0, $xr1, 1
xvsrlni.b.h	$xr0, $xr1, 1
xvsrlni.h.w	$xr0, $xr1, 1
xvsrlni.w.d	$xr0, $xr1, 1
xvsrlni.d.q	$xr0, $xr1, 1
xvsrlrni.b.h	$xr0, $xr1, 1
xvsrlrni.h.w	$xr0, $xr1, 1
xvsrlrni.w.d	$xr0, $xr1, 1
xvsrlrni.d.q	$xr0, $xr1, 1
xvssrlni.b.h	$xr0, $xr1, 1
xvssrlni.h.w	$xr0, $xr1, 1
xvssrlni.w.d	$xr0, $xr1, 1
xvssrlni.d.q	$xr0, $xr1, 1
xvssrlni.bu.h	$xr0, $xr1, 1
xvssrlni.hu.w	$xr0, $xr1, 1
xvssrlni.wu.d	$xr0, $xr1, 1
xvssrlni.du.q	$xr0, $xr1, 1
xvssrlrni.b.h	$xr0, $xr1, 1
xvssrlrni.h.w	$xr0, $xr1, 1
xvssrlrni.w.d	$xr0, $xr1, 1
xvssrlrni.d.q	$xr0, $xr1, 1
xvssrlrni.bu.h	$xr0, $xr1, 1
xvssrlrni.hu.w	$xr0, $xr1, 1
xvssrlrni.wu.d	$xr0, $xr1, 1
xvssrlrni.du.q	$xr0, $xr1, 1
xvsrani.b.h	$xr0, $xr1, 1
xvsrani.h.w	$xr0, $xr1, 1
xvsrani.w.d	$xr0, $xr1, 1
xvsrani.d.q	$xr0, $xr1, 1
xvsrarni.b.h	$xr0, $xr1, 1
xvsrarni.h.w	$xr0, $xr1, 1
xvsrarni.w.d	$xr0, $xr1, 1
xvsrarni.d.q	$xr0, $xr1, 1
xvssrani.b.h	$xr0, $xr1, 1
xvssrani.h.w	$xr0, $xr1, 1
xvssrani.w.d	$xr0, $xr1, 1
xvssrani.d.q	$xr0, $xr1, 1
xvssrani.bu.h	$xr0, $xr1, 1
xvssrani.hu.w	$xr0, $xr1, 1
xvssrani.wu.d	$xr0, $xr1, 1
xvssrani.du.q	$xr0, $xr1, 1
xvssrarni.b.h	$xr0, $xr1, 1
xvssrarni.h.w	$xr0, $xr1, 1
xvssrarni.w.d	$xr0, $xr1, 1
xvssrarni.d.q	$xr0, $xr1, 1
xvssrarni.bu.h	$xr0, $xr1, 1
xvssrarni.hu.w	$xr0, $xr1, 1
xvssrarni.wu.d	$xr0, $xr1, 1
xvssrarni.du.q	$xr0, $xr1, 1
xvextrins.d	$xr0, $xr1, 1
xvextrins.w	$xr0, $xr1, 1
xvextrins.h	$xr0, $xr1, 1
xvextrins.b	$xr0, $xr1, 1
xvshuf4i.b	$xr0, $xr1, 1
xvshuf4i.h	$xr0, $xr1, 1
xvshuf4i.w	$xr0, $xr1, 1
xvshuf4i.d	$xr0, $xr1, 1
xvbitseli.b	$xr0, $xr1, 1
xvandi.b	$xr0, $xr1, 1
xvori.b	$xr0, $xr1, 1
xvxori.b	$xr0, $xr1, 1
xvnori.b	$xr0, $xr1, 1
xvrepli.b	$xr0, 1
xvrepli.d	$xr0, 1
xvrepli.h	$xr0, 1
xvrepli.w	$xr0, 1
xvldi	$xr0, 1
xvpermi.w	$xr0, $xr1, 1
xvpermi.d	$xr0, $xr1, 1
xvpermi.q	$xr0, $xr1, 1
xvfrecipe.s	$xr0, $xr1
xvfrecipe.d	$xr0, $xr1
xvfrsqrte.s	$xr0, $xr1
xvfrsqrte.d	$xr0, $xr1
