.*: Assembler messages:
.*:5: Error: destination and source registers must be distinct for `vfcmaddcph'
.*:6: Error: destination and source registers must be distinct for `vfcmaddcph'
.*:7: Error: destination and source registers must be distinct for `vfcmaddcph'
.*:8: Error: destination and source registers must be distinct for `vfcmaddcsh'
.*:9: Error: destination and source registers must be distinct for `vfmaddcph'
.*:10: Error: destination and source registers must be distinct for `vfmaddcsh'
.*:11: Error: destination and source registers must be distinct for `vfcmulcph'
.*:12: Error: destination and source registers must be distinct for `vfcmulcsh'
.*:13: Error: destination and source registers must be distinct for `vfmulcph'
.*:14: Error: destination and source registers must be distinct for `vfmulcsh'
