.*: Assembler messages:
.*: Error: missing register at operand 2 -- `mlbi vpide1'
.*: Error: missing register at operand 2 -- `mlbi vpmge1'
.*: Error: extraneous register at operand 2 -- `mlbi vmalle1,x0'
.*: Error: extraneous register at operand 2 -- `mlbi vmalle1,xzr'
.*: Error: extraneous register at operand 2 -- `mlbi alle1,x0'
.*: Error: extraneous register at operand 2 -- `mlbi alle1,xzr'