[^:]*: Assembler messages:
[^:]+:3: Error: selected processor does not support `fneg s0,s1'
[^:]+:4: Error: selected processor does not support `fneg h0,h1'
[^:]+:5: Error: selected processor does not support `fneg v0\.4s,v1\.4s'
[^:]+:6: Error: selected processor does not support `fneg v0\.8h,v1\.8h'
[^:]+:7: Error: selected processor does not support `neg v0\.16b,v1\.16b'
