[^:]*: Assembler messages:
[^:]*:5: Error: register list must contain at least 1 and at most 16 registers -- `vpush {d0-d31}'
[^:]*:6: Error: register list must contain at least 1 and at most 16 registers -- `vpush {d1-d17}'
[^:]*:7: Error: register list must contain at least 1 and at most 16 registers -- `vpop {d1-d17}'
[^:]*:8: Error: register list must contain at least 1 and at most 16 registers -- `vpop {d0-d31}'
[^:]*:10: Error: register list must contain at least 1 and at most 16 registers -- `vpush {q0-q15}'
[^:]*:11: Error: register list must contain at least 1 and at most 16 registers -- `vpush {q1-q9}'
[^:]*:12: Error: register list must contain at least 1 and at most 16 registers -- `vpop {q1-q9}'
[^:]*:13: Error: register list must contain at least 1 and at most 16 registers -- `vpop {q0-q15}'
#pass

