[^ :]+: Assembler messages:
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0,vgx2\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.d\[W8,0,VGx2\],{ ?Z0\.d ?- ?Z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.D\[W8,0,VGX2\],{ ?Z0\.D ?- ?Z1\.D ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w11,0\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,7\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0\],{ ?z30\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w10,3\],{ ?z10\.d ?- ?z11\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0,vgx4\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.d\[W8,0,VGx4\],{ ?Z0\.d ?- ?Z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd ZA\.D\[W8,0,VGX4\],{ ?Z0\.D ?- ?Z3\.D ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w11,0\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,7\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w8,0\],{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fadd za\.d\[w11,1\],{ ?z12\.d ?- ?z15\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0,vgx2\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.d\[W8,0,VGx2\],{ ?Z0\.d ?- ?Z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.D\[W8,0,VGX2\],{ ?Z0\.D ?- ?Z1\.D ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w11,0\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,7\],{ ?z0\.d ?- ?z1\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0\],{ ?z30\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w10,3\],{ ?z10\.d ?- ?z11\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0,vgx4\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.d\[W8,0,VGx4\],{ ?Z0\.d ?- ?Z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub ZA\.D\[W8,0,VGX4\],{ ?Z0\.D ?- ?Z3\.D ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w11,0\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,7\],{ ?z0\.d ?- ?z3\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w8,0\],{ ?z28\.d ?- ?z31\.d ?}'
[^ :]+:[0-9]+: Error: selected processor does not support `fsub za\.d\[w11,1\],{ ?z12\.d ?- ?z15\.d ?}'
