.* Assembler messages:
.*:5: Error: `cmpbexadd' is only supported in 64-bit mode
.*:6: Error: `cmpbxadd' is only supported in 64-bit mode
.*:7: Error: `cmplexadd' is only supported in 64-bit mode
.*:8: Error: `cmplxadd' is only supported in 64-bit mode
