[^:]+: Assembler messages:
[^:]+:[0-9]+: Error: selected processor does not support `setgop .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgom .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgoe .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgopt .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgomt .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgoet .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgopn .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgomn .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgoen .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgoptn .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgomtn .*'
[^:]+:[0-9]+: Error: selected processor does not support `setgoetn .*'
[^:]+:[0-9]+: Warning: the preceding `setgop' should be followed by `setgom` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgopt' should be followed by `setgomt` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgopn' should be followed by `setgomn` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgoptn' should be followed by `setgomtn` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgom' should be followed by `setgoe` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgomt' should be followed by `setgoet` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgomn' should be followed by `setgoen` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: the preceding `setgomtn' should be followed by `setgoetn` rather than `ret` -- `ret'
[^:]+:[0-9]+: Warning: instruction opens new dependency sequence without ending previous one .*
[^:]+:[0-9]+: Warning: instruction opens new dependency sequence without ending previous one .*
[^:]+:[0-9]+: Warning: instruction opens new dependency sequence without ending previous one .*
[^:]+:[0-9]+: Warning: instruction opens new dependency sequence without ending previous one .*
