.*: Assembler messages:
.*: Error: selected processor does not support system register name 'lorc_el1'
.*: Error: selected processor does not support system register name 'lorea_el1'
.*: Error: selected processor does not support system register name 'lorn_el1'
.*: Error: selected processor does not support system register name 'lorsa_el1'
.*: Warning: specified register cannot be written to at operand 1 -- `msr ich_vtr_el2,x0'
