#source: ./rorc.s
#objdump: -dr

.*:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7e 40                         	rorc	r0
   2:	7e 4f                         	rorc	r15
