	whilege	0, x0, x0, vlx2
	whilege	pn8.b, 0, x0, vlx2
	whilege	pn8.b, x0, 0, vlx2
	whilege	pn8.b, x0, x0, 0

	whilege	pn0.b, x0, x0, vlx2
	whilege	p8.b, x0, x0, vlx2
	whilege	z8.b, x0, x0, vlx2
	whilege	pn8.b, x0, x0
	whilege	pn8.b, w0, w0, vlx2
	whilege	pn8.b, sp, x0, vlx2
	whilege	pn8.b, x0, sp, vlx2
	whilege	pn8.b, x0, x0, #0
	whilege	pn8.b, x0, x0, 1
