cbgt_0:
	cbgt	w0, #0, cbgt_0
	cbgt	w0, #0, cbgt_0
cbgt_1:
	cbgt	w0, #63, cbgt_1
	cbgt	w0, #63, cbgt_1
cbgt_2:
	cbgt	wzr, #0, cbgt_2
	cbgt	wzr, #0, cbgt_2
cbgt_3:
	cbgt	wzr, #63, cbgt_3
	cbgt	wzr, #63, cbgt_3
cbgt_4:
	cbgt	x0, #0, cbgt_4
	cbgt	x0, #0, cbgt_4
cbgt_5:
	cbgt	x0, #63, cbgt_5
	cbgt	x0, #63, cbgt_5
cbgt_6:
	cbgt	xzr, #0, cbgt_6
	cbgt	xzr, #0, cbgt_6
cbgt_7:
	cbgt	xzr, #63, cbgt_7
	cbgt	xzr, #63, cbgt_7
cblt_0:
	cblt	w0, #0, cblt_0
	cblt	w0, #0, cblt_0
cblt_1:
	cblt	w0, #63, cblt_1
	cblt	w0, #63, cblt_1
cblt_2:
	cblt	wzr, #0, cblt_2
	cblt	wzr, #0, cblt_2
cblt_3:
	cblt	wzr, #63, cblt_3
	cblt	wzr, #63, cblt_3
cblt_4:
	cblt	x0, #0, cblt_4
	cblt	x0, #0, cblt_4
cblt_5:
	cblt	x0, #63, cblt_5
	cblt	x0, #63, cblt_5
cblt_6:
	cblt	xzr, #0, cblt_6
	cblt	xzr, #0, cblt_6
cblt_7:
	cblt	xzr, #63, cblt_7
	cblt	xzr, #63, cblt_7
cbhi_0:
	cbhi	w0, #0, cbhi_0
	cbhi	w0, #0, cbhi_0
cbhi_1:
	cbhi	w0, #63, cbhi_1
	cbhi	w0, #63, cbhi_1
cbhi_2:
	cbhi	wzr, #0, cbhi_2
	cbhi	wzr, #0, cbhi_2
cbhi_3:
	cbhi	wzr, #63, cbhi_3
	cbhi	wzr, #63, cbhi_3
cbhi_4:
	cbhi	x0, #0, cbhi_4
	cbhi	x0, #0, cbhi_4
cbhi_5:
	cbhi	x0, #63, cbhi_5
	cbhi	x0, #63, cbhi_5
cbhi_6:
	cbhi	xzr, #0, cbhi_6
	cbhi	xzr, #0, cbhi_6
cbhi_7:
	cbhi	xzr, #63, cbhi_7
	cbhi	xzr, #63, cbhi_7
cblo_0:
	cblo	w0, #0, cblo_0
	cblo	w0, #0, cblo_0
cblo_1:
	cblo	w0, #63, cblo_1
	cblo	w0, #63, cblo_1
cblo_2:
	cblo	wzr, #0, cblo_2
	cblo	wzr, #0, cblo_2
cblo_3:
	cblo	wzr, #63, cblo_3
	cblo	wzr, #63, cblo_3
cblo_4:
	cblo	x0, #0, cblo_4
	cblo	x0, #0, cblo_4
cblo_5:
	cblo	x0, #63, cblo_5
	cblo	x0, #63, cblo_5
cblo_6:
	cblo	xzr, #0, cblo_6
	cblo	xzr, #0, cblo_6
cblo_7:
	cblo	xzr, #63, cblo_7
	cblo	xzr, #63, cblo_7
cbeq_0:
	cbeq	w0, #0, cbeq_0
	cbeq	w0, #0, cbeq_0
cbeq_1:
	cbeq	w0, #63, cbeq_1
	cbeq	w0, #63, cbeq_1
cbeq_2:
	cbeq	wzr, #0, cbeq_2
	cbeq	wzr, #0, cbeq_2
cbeq_3:
	cbeq	wzr, #63, cbeq_3
	cbeq	wzr, #63, cbeq_3
cbeq_4:
	cbeq	x0, #0, cbeq_4
	cbeq	x0, #0, cbeq_4
cbeq_5:
	cbeq	x0, #63, cbeq_5
	cbeq	x0, #63, cbeq_5
cbeq_6:
	cbeq	xzr, #0, cbeq_6
	cbeq	xzr, #0, cbeq_6
cbeq_7:
	cbeq	xzr, #63, cbeq_7
	cbeq	xzr, #63, cbeq_7
cbne_0:
	cbne	w0, #0, cbne_0
	cbne	w0, #0, cbne_0
cbne_1:
	cbne	w0, #63, cbne_1
	cbne	w0, #63, cbne_1
cbne_2:
	cbne	wzr, #0, cbne_2
	cbne	wzr, #0, cbne_2
cbne_3:
	cbne	wzr, #63, cbne_3
	cbne	wzr, #63, cbne_3
cbne_4:
	cbne	x0, #0, cbne_4
	cbne	x0, #0, cbne_4
cbne_5:
	cbne	x0, #63, cbne_5
	cbne	x0, #63, cbne_5
cbne_6:
	cbne	xzr, #0, cbne_6
	cbne	xzr, #0, cbne_6
cbne_7:
	cbne	xzr, #63, cbne_7
	cbne	xzr, #63, cbne_7

cbgt_8:
	cbgt	w0, w0, cbgt_8
	cbgt	w0, w0, cbgt_8
cbgt_9:
	cbgt	w0, wzr, cbgt_9
	cbgt	w0, wzr, cbgt_9
cbgt_10:
	cbgt	wzr, w0, cbgt_10
	cbgt	wzr, w0, cbgt_10
cbgt_11:
	cbgt	wzr, wzr, cbgt_11
	cbgt	wzr, wzr, cbgt_11
cbgt_12:
	cbgt	x0, x0, cbgt_12
	cbgt	x0, x0, cbgt_12
cbgt_13:
	cbgt	x0, xzr, cbgt_13
	cbgt	x0, xzr, cbgt_13
cbgt_14:
	cbgt	xzr, x0, cbgt_14
	cbgt	xzr, x0, cbgt_14
cbgt_15:
	cbgt	xzr, xzr, cbgt_15
	cbgt	xzr, xzr, cbgt_15
cbge_8:
	cbge	w0, w0, cbge_8
	cbge	w0, w0, cbge_8
cbge_9:
	cbge	w0, wzr, cbge_9
	cbge	w0, wzr, cbge_9
cbge_10:
	cbge	wzr, w0, cbge_10
	cbge	wzr, w0, cbge_10
cbge_11:
	cbge	wzr, wzr, cbge_11
	cbge	wzr, wzr, cbge_11
cbge_12:
	cbge	x0, x0, cbge_12
	cbge	x0, x0, cbge_12
cbge_13:
	cbge	x0, xzr, cbge_13
	cbge	x0, xzr, cbge_13
cbge_14:
	cbge	xzr, x0, cbge_14
	cbge	xzr, x0, cbge_14
cbge_15:
	cbge	xzr, xzr, cbge_15
	cbge	xzr, xzr, cbge_15
cbhi_8:
	cbhi	w0, w0, cbhi_8
	cbhi	w0, w0, cbhi_8
cbhi_9:
	cbhi	w0, wzr, cbhi_9
	cbhi	w0, wzr, cbhi_9
cbhi_10:
	cbhi	wzr, w0, cbhi_10
	cbhi	wzr, w0, cbhi_10
cbhi_11:
	cbhi	wzr, wzr, cbhi_11
	cbhi	wzr, wzr, cbhi_11
cbhi_12:
	cbhi	x0, x0, cbhi_12
	cbhi	x0, x0, cbhi_12
cbhi_13:
	cbhi	x0, xzr, cbhi_13
	cbhi	x0, xzr, cbhi_13
cbhi_14:
	cbhi	xzr, x0, cbhi_14
	cbhi	xzr, x0, cbhi_14
cbhi_15:
	cbhi	xzr, xzr, cbhi_15
	cbhi	xzr, xzr, cbhi_15
cbhs_8:
	cbhs	w0, w0, cbhs_8
	cbhs	w0, w0, cbhs_8
cbhs_9:
	cbhs	w0, wzr, cbhs_9
	cbhs	w0, wzr, cbhs_9
cbhs_10:
	cbhs	wzr, w0, cbhs_10
	cbhs	wzr, w0, cbhs_10
cbhs_11:
	cbhs	wzr, wzr, cbhs_11
	cbhs	wzr, wzr, cbhs_11
cbhs_12:
	cbhs	x0, x0, cbhs_12
	cbhs	x0, x0, cbhs_12
cbhs_13:
	cbhs	x0, xzr, cbhs_13
	cbhs	x0, xzr, cbhs_13
cbhs_14:
	cbhs	xzr, x0, cbhs_14
	cbhs	xzr, x0, cbhs_14
cbhs_15:
	cbhs	xzr, xzr, cbhs_15
	cbhs	xzr, xzr, cbhs_15
cbeq_8:
	cbeq	w0, w0, cbeq_8
	cbeq	w0, w0, cbeq_8
cbeq_9:
	cbeq	w0, wzr, cbeq_9
	cbeq	w0, wzr, cbeq_9
cbeq_10:
	cbeq	wzr, w0, cbeq_10
	cbeq	wzr, w0, cbeq_10
cbeq_11:
	cbeq	wzr, wzr, cbeq_11
	cbeq	wzr, wzr, cbeq_11
cbeq_12:
	cbeq	x0, x0, cbeq_12
	cbeq	x0, x0, cbeq_12
cbeq_13:
	cbeq	x0, xzr, cbeq_13
	cbeq	x0, xzr, cbeq_13
cbeq_14:
	cbeq	xzr, x0, cbeq_14
	cbeq	xzr, x0, cbeq_14
cbeq_15:
	cbeq	xzr, xzr, cbeq_15
	cbeq	xzr, xzr, cbeq_15
cbne_8:
	cbne	w0, w0, cbne_8
	cbne	w0, w0, cbne_8
cbne_9:
	cbne	w0, wzr, cbne_9
	cbne	w0, wzr, cbne_9
cbne_10:
	cbne	wzr, w0, cbne_10
	cbne	wzr, w0, cbne_10
cbne_11:
	cbne	wzr, wzr, cbne_11
	cbne	wzr, wzr, cbne_11
cbne_12:
	cbne	x0, x0, cbne_12
	cbne	x0, x0, cbne_12
cbne_13:
	cbne	x0, xzr, cbne_13
	cbne	x0, xzr, cbne_13
cbne_14:
	cbne	xzr, x0, cbne_14
	cbne	xzr, x0, cbne_14
cbne_15:
	cbne	xzr, xzr, cbne_15
	cbne	xzr, xzr, cbne_15

cbbgt_0:
	cbbgt	w0, w0, cbbgt_0
	cbbgt	w0, w0, cbbgt_0
cbbgt_1:
	cbbgt	w0, wzr, cbbgt_1
	cbbgt	w0, wzr, cbbgt_1
cbbgt_2:
	cbbgt	wzr, w0, cbbgt_2
	cbbgt	wzr, w0, cbbgt_2
cbbgt_3:
	cbbgt	wzr, wzr, cbbgt_3
	cbbgt	wzr, wzr, cbbgt_3
cbbge_0:
	cbbge	w0, w0, cbbge_0
	cbbge	w0, w0, cbbge_0
cbbge_1:
	cbbge	w0, wzr, cbbge_1
	cbbge	w0, wzr, cbbge_1
cbbge_2:
	cbbge	wzr, w0, cbbge_2
	cbbge	wzr, w0, cbbge_2
cbbge_3:
	cbbge	wzr, wzr, cbbge_3
	cbbge	wzr, wzr, cbbge_3
cbbhi_0:
	cbbhi	w0, w0, cbbhi_0
	cbbhi	w0, w0, cbbhi_0
cbbhi_1:
	cbbhi	w0, wzr, cbbhi_1
	cbbhi	w0, wzr, cbbhi_1
cbbhi_2:
	cbbhi	wzr, w0, cbbhi_2
	cbbhi	wzr, w0, cbbhi_2
cbbhi_3:
	cbbhi	wzr, wzr, cbbhi_3
	cbbhi	wzr, wzr, cbbhi_3
cbbhs_0:
	cbbhs	w0, w0, cbbhs_0
	cbbhs	w0, w0, cbbhs_0
cbbhs_1:
	cbbhs	w0, wzr, cbbhs_1
	cbbhs	w0, wzr, cbbhs_1
cbbhs_2:
	cbbhs	wzr, w0, cbbhs_2
	cbbhs	wzr, w0, cbbhs_2
cbbhs_3:
	cbbhs	wzr, wzr, cbbhs_3
	cbbhs	wzr, wzr, cbbhs_3
cbbeq_0:
	cbbeq	w0, w0, cbbeq_0
	cbbeq	w0, w0, cbbeq_0
cbbeq_1:
	cbbeq	w0, wzr, cbbeq_1
	cbbeq	w0, wzr, cbbeq_1
cbbeq_2:
	cbbeq	wzr, w0, cbbeq_2
	cbbeq	wzr, w0, cbbeq_2
cbbeq_3:
	cbbeq	wzr, wzr, cbbeq_3
	cbbeq	wzr, wzr, cbbeq_3
cbbne_0:
	cbbne	w0, w0, cbbne_0
	cbbne	w0, w0, cbbne_0
cbbne_1:
	cbbne	w0, wzr, cbbne_1
	cbbne	w0, wzr, cbbne_1
cbbne_2:
	cbbne	wzr, w0, cbbne_2
	cbbne	wzr, w0, cbbne_2
cbbne_3:
	cbbne	wzr, wzr, cbbne_3
	cbbne	wzr, wzr, cbbne_3

cbhgt_0:
	cbhgt	w0, w0, cbhgt_0
	cbhgt	w0, w0, cbhgt_0
cbhgt_1:
	cbhgt	w0, wzr, cbhgt_1
	cbhgt	w0, wzr, cbhgt_1
cbhgt_2:
	cbhgt	wzr, w0, cbhgt_2
	cbhgt	wzr, w0, cbhgt_2
cbhgt_3:
	cbhgt	wzr, wzr, cbhgt_3
	cbhgt	wzr, wzr, cbhgt_3
cbhge_0:
	cbhge	w0, w0, cbhge_0
	cbhge	w0, w0, cbhge_0
cbhge_1:
	cbhge	w0, wzr, cbhge_1
	cbhge	w0, wzr, cbhge_1
cbhge_2:
	cbhge	wzr, w0, cbhge_2
	cbhge	wzr, w0, cbhge_2
cbhge_3:
	cbhge	wzr, wzr, cbhge_3
	cbhge	wzr, wzr, cbhge_3
cbhhi_0:
	cbhhi	w0, w0, cbhhi_0
	cbhhi	w0, w0, cbhhi_0
cbhhi_1:
	cbhhi	w0, wzr, cbhhi_1
	cbhhi	w0, wzr, cbhhi_1
cbhhi_2:
	cbhhi	wzr, w0, cbhhi_2
	cbhhi	wzr, w0, cbhhi_2
cbhhi_3:
	cbhhi	wzr, wzr, cbhhi_3
	cbhhi	wzr, wzr, cbhhi_3
cbhhs_0:
	cbhhs	w0, w0, cbhhs_0
	cbhhs	w0, w0, cbhhs_0
cbhhs_1:
	cbhhs	w0, wzr, cbhhs_1
	cbhhs	w0, wzr, cbhhs_1
cbhhs_2:
	cbhhs	wzr, w0, cbhhs_2
	cbhhs	wzr, w0, cbhhs_2
cbhhs_3:
	cbhhs	wzr, wzr, cbhhs_3
	cbhhs	wzr, wzr, cbhhs_3
cbheq_0:
	cbheq	w0, w0, cbheq_0
	cbheq	w0, w0, cbheq_0
cbheq_1:
	cbheq	w0, wzr, cbheq_1
	cbheq	w0, wzr, cbheq_1
cbheq_2:
	cbheq	wzr, w0, cbheq_2
	cbheq	wzr, w0, cbheq_2
cbheq_3:
	cbheq	wzr, wzr, cbheq_3
	cbheq	wzr, wzr, cbheq_3
cbhne_0:
	cbhne	w0, w0, cbhne_0
	cbhne	w0, w0, cbhne_0
cbhne_1:
	cbhne	w0, wzr, cbhne_1
	cbhne	w0, wzr, cbhne_1
cbhne_2:
	cbhne	wzr, w0, cbhne_2
	cbhne	wzr, w0, cbhne_2
cbhne_3:
	cbhne	wzr, wzr, cbhne_3
	cbhne	wzr, wzr, cbhne_3

cbge_0:
	cbge	w0, #1, cbge_0
	cbge	w0, #1, cbge_0
cbge_1:
	cbge	w0, #64, cbge_1
	cbge	w0, #64, cbge_1
cbge_2:
	cbge	wzr, #1, cbge_2
	cbge	wzr, #1, cbge_2
cbge_3:
	cbge	wzr, #64, cbge_3
	cbge	wzr, #64, cbge_3
cbge_4:
	cbge	x0, #1, cbge_4
	cbge	x0, #1, cbge_4
cbge_5:
	cbge	x0, #64, cbge_5
	cbge	x0, #64, cbge_5
cbge_6:
	cbge	xzr, #1, cbge_6
	cbge	xzr, #1, cbge_6
cbge_7:
	cbge	xzr, #64, cbge_7
	cbge	xzr, #64, cbge_7
cble_0:
	cble	w0, #-1, cble_0
	cble	w0, #-1, cble_0
cble_1:
	cble	w0, #62, cble_1
	cble	w0, #62, cble_1
cble_2:
	cble	wzr, #-1, cble_2
	cble	wzr, #-1, cble_2
cble_3:
	cble	wzr, #62, cble_3
	cble	wzr, #62, cble_3
cble_4:
	cble	x0, #-1, cble_4
	cble	x0, #-1, cble_4
cble_5:
	cble	x0, #62, cble_5
	cble	x0, #62, cble_5
cble_6:
	cble	xzr, #-1, cble_6
	cble	xzr, #-1, cble_6
cble_7:
	cble	xzr, #62, cble_7
	cble	xzr, #62, cble_7
cbhs_0:
	cbhs	w0, #1, cbhs_0
	cbhs	w0, #1, cbhs_0
cbhs_1:
	cbhs	w0, #64, cbhs_1
	cbhs	w0, #64, cbhs_1
cbhs_2:
	cbhs	wzr, #1, cbhs_2
	cbhs	wzr, #1, cbhs_2
cbhs_3:
	cbhs	wzr, #64, cbhs_3
	cbhs	wzr, #64, cbhs_3
cbhs_4:
	cbhs	x0, #1, cbhs_4
	cbhs	x0, #1, cbhs_4
cbhs_5:
	cbhs	x0, #64, cbhs_5
	cbhs	x0, #64, cbhs_5
cbhs_6:
	cbhs	xzr, #1, cbhs_6
	cbhs	xzr, #1, cbhs_6
cbhs_7:
	cbhs	xzr, #64, cbhs_7
	cbhs	xzr, #64, cbhs_7
cbls_0:
	cbls	w0, #-1, cbls_0
	cbls	w0, #-1, cbls_0
cbls_1:
	cbls	w0, #62, cbls_1
	cbls	w0, #62, cbls_1
cbls_2:
	cbls	wzr, #-1, cbls_2
	cbls	wzr, #-1, cbls_2
cbls_3:
	cbls	wzr, #62, cbls_3
	cbls	wzr, #62, cbls_3
cbls_4:
	cbls	x0, #-1, cbls_4
	cbls	x0, #-1, cbls_4
cbls_5:
	cbls	x0, #62, cbls_5
	cbls	x0, #62, cbls_5
cbls_6:
	cbls	xzr, #-1, cbls_6
	cbls	xzr, #-1, cbls_6
cbls_7:
	cbls	xzr, #62, cbls_7
	cbls	xzr, #62, cbls_7

cblt_8:
	cblt	w0, w0, cblt_8
	cblt	w0, w0, cblt_8
cblt_9:
	cblt	w0, wzr, cblt_9
	cblt	w0, wzr, cblt_9
cblt_10:
	cblt	wzr, w0, cblt_10
	cblt	wzr, w0, cblt_10
cblt_11:
	cblt	wzr, wzr, cblt_11
	cblt	wzr, wzr, cblt_11
cblt_12:
	cblt	x0, x0, cblt_12
	cblt	x0, x0, cblt_12
cblt_13:
	cblt	x0, xzr, cblt_13
	cblt	x0, xzr, cblt_13
cblt_14:
	cblt	xzr, x0, cblt_14
	cblt	xzr, x0, cblt_14
cblt_15:
	cblt	xzr, xzr, cblt_15
	cblt	xzr, xzr, cblt_15
cble_8:
	cble	w0, w0, cble_8
	cble	w0, w0, cble_8
cble_9:
	cble	w0, wzr, cble_9
	cble	w0, wzr, cble_9
cble_10:
	cble	wzr, w0, cble_10
	cble	wzr, w0, cble_10
cble_11:
	cble	wzr, wzr, cble_11
	cble	wzr, wzr, cble_11
cble_12:
	cble	x0, x0, cble_12
	cble	x0, x0, cble_12
cble_13:
	cble	x0, xzr, cble_13
	cble	x0, xzr, cble_13
cble_14:
	cble	xzr, x0, cble_14
	cble	xzr, x0, cble_14
cble_15:
	cble	xzr, xzr, cble_15
	cble	xzr, xzr, cble_15
cblo_8:
	cblo	w0, w0, cblo_8
	cblo	w0, w0, cblo_8
cblo_9:
	cblo	w0, wzr, cblo_9
	cblo	w0, wzr, cblo_9
cblo_10:
	cblo	wzr, w0, cblo_10
	cblo	wzr, w0, cblo_10
cblo_11:
	cblo	wzr, wzr, cblo_11
	cblo	wzr, wzr, cblo_11
cblo_12:
	cblo	x0, x0, cblo_12
	cblo	x0, x0, cblo_12
cblo_13:
	cblo	x0, xzr, cblo_13
	cblo	x0, xzr, cblo_13
cblo_14:
	cblo	xzr, x0, cblo_14
	cblo	xzr, x0, cblo_14
cblo_15:
	cblo	xzr, xzr, cblo_15
	cblo	xzr, xzr, cblo_15
cbls_8:
	cbls	w0, w0, cbls_8
	cbls	w0, w0, cbls_8
cbls_9:
	cbls	w0, wzr, cbls_9
	cbls	w0, wzr, cbls_9
cbls_10:
	cbls	wzr, w0, cbls_10
	cbls	wzr, w0, cbls_10
cbls_11:
	cbls	wzr, wzr, cbls_11
	cbls	wzr, wzr, cbls_11
cbls_12:
	cbls	x0, x0, cbls_12
	cbls	x0, x0, cbls_12
cbls_13:
	cbls	x0, xzr, cbls_13
	cbls	x0, xzr, cbls_13
cbls_14:
	cbls	xzr, x0, cbls_14
	cbls	xzr, x0, cbls_14
cbls_15:
	cbls	xzr, xzr, cbls_15
	cbls	xzr, xzr, cbls_15

cbblt_0:
	cbblt	w0, w0, cbblt_0
	cbblt	w0, w0, cbblt_0
cbblt_1:
	cbblt	w0, wzr, cbblt_1
	cbblt	w0, wzr, cbblt_1
cbblt_2:
	cbblt	wzr, w0, cbblt_2
	cbblt	wzr, w0, cbblt_2
cbblt_3:
	cbblt	wzr, wzr, cbblt_3
	cbblt	wzr, wzr, cbblt_3
cbble_0:
	cbble	w0, w0, cbble_0
	cbble	w0, w0, cbble_0
cbble_1:
	cbble	w0, wzr, cbble_1
	cbble	w0, wzr, cbble_1
cbble_2:
	cbble	wzr, w0, cbble_2
	cbble	wzr, w0, cbble_2
cbble_3:
	cbble	wzr, wzr, cbble_3
	cbble	wzr, wzr, cbble_3
cbblo_0:
	cbblo	w0, w0, cbblo_0
	cbblo	w0, w0, cbblo_0
cbblo_1:
	cbblo	w0, wzr, cbblo_1
	cbblo	w0, wzr, cbblo_1
cbblo_2:
	cbblo	wzr, w0, cbblo_2
	cbblo	wzr, w0, cbblo_2
cbblo_3:
	cbblo	wzr, wzr, cbblo_3
	cbblo	wzr, wzr, cbblo_3
cbbls_0:
	cbbls	w0, w0, cbbls_0
	cbbls	w0, w0, cbbls_0
cbbls_1:
	cbbls	w0, wzr, cbbls_1
	cbbls	w0, wzr, cbbls_1
cbbls_2:
	cbbls	wzr, w0, cbbls_2
	cbbls	wzr, w0, cbbls_2
cbbls_3:
	cbbls	wzr, wzr, cbbls_3
	cbbls	wzr, wzr, cbbls_3

cbhlt_0:
	cbhlt	w0, w0, cbhlt_0
	cbhlt	w0, w0, cbhlt_0
cbhlt_1:
	cbhlt	w0, wzr, cbhlt_1
	cbhlt	w0, wzr, cbhlt_1
cbhlt_2:
	cbhlt	wzr, w0, cbhlt_2
	cbhlt	wzr, w0, cbhlt_2
cbhlt_3:
	cbhlt	wzr, wzr, cbhlt_3
	cbhlt	wzr, wzr, cbhlt_3
cbhle_0:
	cbhle	w0, w0, cbhle_0
	cbhle	w0, w0, cbhle_0
cbhle_1:
	cbhle	w0, wzr, cbhle_1
	cbhle	w0, wzr, cbhle_1
cbhle_2:
	cbhle	wzr, w0, cbhle_2
	cbhle	wzr, w0, cbhle_2
cbhle_3:
	cbhle	wzr, wzr, cbhle_3
	cbhle	wzr, wzr, cbhle_3
cbhlo_0:
	cbhlo	w0, w0, cbhlo_0
	cbhlo	w0, w0, cbhlo_0
cbhlo_1:
	cbhlo	w0, wzr, cbhlo_1
	cbhlo	w0, wzr, cbhlo_1
cbhlo_2:
	cbhlo	wzr, w0, cbhlo_2
	cbhlo	wzr, w0, cbhlo_2
cbhlo_3:
	cbhlo	wzr, wzr, cbhlo_3
	cbhlo	wzr, wzr, cbhlo_3
cbhls_0:
	cbhls	w0, w0, cbhls_0
	cbhls	w0, w0, cbhls_0
cbhls_1:
	cbhls	w0, wzr, cbhls_1
	cbhls	w0, wzr, cbhls_1
cbhls_2:
	cbhls	wzr, w0, cbhls_2
	cbhls	wzr, w0, cbhls_2
cbhls_3:
	cbhls	wzr, wzr, cbhls_3
	cbhls	wzr, wzr, cbhls_3
