.*: Assembler messages:
.*:1: Error: unexpected register name `w3' in instruction `goto w3'
.*:2: Error: unexpected register name `r3' in instruction `r2 =r3'
.*:2: Error: unexpected register name `r3' in instruction `r2 =r3'
.*:3: Error: unexpected register name `r3' in instruction `r2 =r3'
.*:3: Error: unexpected register name `r3' in instruction `r2 =r3'
.*:4: Error: unexpected register name `r3' in instruction `r2 =1\+r3'
.*:4: Error: unexpected register name `r3' in instruction `r2 =1\+r3'
