.attribute arch, "rv64ic"
.option push
.option arch, m2p0
.option arch, -i
.option arch, +e
.option arch, -g
.option arch, -c
.option arch, +zsubset2p0
.option arch, +f2p0_d2p0
.option arch, +
.option arch, +xvendor2p
.option pop
.option pop
