[^:]*: Assembler messages:
.*:29: Error: operand out of range \(32 is not between 0 and 31\)
.*:30: Error: operand out of range \(32 is not between 0 and 31\)
.*:31: Error: operand out of range \(32 is not between 0 and 31\)
.*:32: Error: operand out of range \(32 is not between 0 and 31\)
.*:33: Error: operand out of range \(8 is not between 0 and 7\)
.*:34: Error: operand out of range \(8 is not between 0 and 7\)
.*:35: Error: operand out of range \(4 is not between 0 and 3\)
.*:36: Error: operand out of range \(8 is not between 0 and 7\)
.*:37: Error: operand out of range \(4 is not between 0 and 3\)
.*:38: Error: operand out of range \(16 is not between 0 and 15\)
.*:39: Error: operand out of range \(16 is not between 0 and 15\)
.*:40: Error: operand out of range \(16 is not between 0 and 15\)
.*:41: Error: operand out of range \(4 is not between 0 and 3\)
.*:42: Error: operand out of range \(4 is not between 0 and 3\)
.*:43: Error: invalid offset
.*:44: Error: operand out of range \(8 is not between 0 and 7\)
.*:44: Error: invalid offset
.*:45: Error: UIMM values >7 are illegal
.*:46: Error: UIMM values >7 are illegal
.*:47: Error: UIMM values >7 are illegal
.*:48: Error: UIMM values >7 are illegal
.*:49: Error: UIMM values >15 are illegal
.*:50: Error: UIMM values >15 are illegal
.*:51: Error: UIMM values >15 are illegal
.*:52: Error: UIMM values >15 are illegal
.*:53: Error: operand out of range \(8 is not between 0 and 7\)
.*:54: Error: operand out of range \(8 is not between 0 and 7\)
.*:55: Error: operand out of range \(8 is not between 0 and 7\)
.*:56: Error: operand out of domain \(7 is not a multiple of 8\)
.*:57: Error: operand out of domain \(1 is not a multiple of 2\)
.*:58: Error: operand out of domain \(3 is not a multiple of 4\)
.*:59: Error: operand out of domain \(3 is not a multiple of 4\)
.*:60: Error: operand out of range \(32 is not between 0 and 31\)
.*:61: Error: operand out of domain \(7 is not a multiple of 8\)
.*:62: Error: operand out of domain \(3 is not a multiple of 4\)
.*:63: Error: operand out of domain \(3 is not a multiple of 4\)
.*:64: Error: operand out of domain \(3 is not a multiple of 4\)
.*:65: Error: operand out of domain \(3 is not a multiple of 4\)
.*:66: Error: operand out of domain \(3 is not a multiple of 4\)
.*:67: Error: operand out of domain \(3 is not a multiple of 4\)
.*:68: Error: operand out of domain \(1 is not a multiple of 2\)
.*:69: Error: operand out of domain \(7 is not a multiple of 8\)
.*:70: Error: operand out of domain \(7 is not a multiple of 8\)
.*:71: Error: operand out of domain \(7 is not a multiple of 8\)
.*:72: Error: operand out of domain \(7 is not a multiple of 8\)
.*:73: Error: operand out of domain \(1 is not a multiple of 2\)
.*:74: Error: operand out of domain \(1 is not a multiple of 2\)
.*:75: Error: operand out of domain \(1 is not a multiple of 2\)
.*:76: Error: operand out of domain \(1 is not a multiple of 2\)
.*:77: Error: operand out of domain \(3 is not a multiple of 4\)
.*:78: Error: operand out of domain \(3 is not a multiple of 4\)
.*:79: Error: operand out of domain \(3 is not a multiple of 4\)
.*:80: Error: operand out of domain \(3 is not a multiple of 4\)
.*:81: Error: operand out of domain \(3 is not a multiple of 4\)
.*:82: Error: operand out of domain \(3 is not a multiple of 4\)
.*:83: Error: operand out of domain \(3 is not a multiple of 4\)
.*:84: Error: UIMM = 00000 is illegal
.*:85: Error: operand out of domain \(7 is not a multiple of 8\)
.*:86: Error: operand out of domain \(7 is not a multiple of 8\)
.*:87: Error: operand out of domain \(7 is not a multiple of 8\)
.*:88: Error: operand out of domain \(7 is not a multiple of 8\)
.*:89: Error: operand out of domain \(3 is not a multiple of 4\)
.*:90: Error: operand out of domain \(3 is not a multiple of 4\)
.*:91: Error: operand out of domain \(3 is not a multiple of 4\)
.*:92: Error: operand out of domain \(3 is not a multiple of 4\)
.*:93: Error: operand out of domain \(3 is not a multiple of 4\)
.*:94: Error: operand out of domain \(3 is not a multiple of 4\)
.*:95: Error: operand out of domain \(3 is not a multiple of 4\)
.*:96: Error: operand out of domain \(3 is not a multiple of 4\)
.*:97: Error: operand out of domain \(3 is not a multiple of 4\)
.*:98: Error: operand out of domain \(3 is not a multiple of 4\)
.*:99: Error: operand out of domain \(1 is not a multiple of 2\)
