/* Branch Record Buffer Extension system registers.  */

/* Read from BRBE system registers.  */
mrs x0, brbcr_el1
mrs x0, brbcr_el12
mrs x0, brbfcr_el1
mrs x0, brbts_el1
mrs x0, brbinfinj_el1
mrs x0, brbsrcinj_el1
mrs x0, brbtgtinj_el1
mrs x0, brbidr0_el1
mrs x0, brbcr_el2
mrs x0, brbsrc0_el1
mrs x0, brbsrc10_el1
mrs x0, brbsrc11_el1
mrs x0, brbsrc12_el1
mrs x0, brbsrc13_el1
mrs x0, brbsrc14_el1
mrs x0, brbsrc15_el1
mrs x0, brbsrc16_el1
mrs x0, brbsrc17_el1
mrs x0, brbsrc18_el1
mrs x0, brbsrc19_el1
mrs x0, brbsrc20_el1
mrs x0, brbsrc21_el1
mrs x0, brbsrc22_el1
mrs x0, brbsrc23_el1
mrs x0, brbsrc24_el1
mrs x0, brbsrc25_el1
mrs x0, brbsrc26_el1
mrs x0, brbsrc27_el1
mrs x0, brbsrc28_el1
mrs x0, brbsrc29_el1
mrs x0, brbsrc30_el1
mrs x0, brbsrc31_el1
mrs x0, brbtgt0_el1
mrs x0, brbtgt1_el1
mrs x0, brbtgt2_el1
mrs x0, brbtgt3_el1
mrs x0, brbtgt4_el1
mrs x0, brbtgt5_el1
mrs x0, brbtgt6_el1
mrs x0, brbtgt7_el1
mrs x0, brbtgt8_el1
mrs x0, brbtgt9_el1
mrs x0, brbtgt10_el1
mrs x0, brbtgt11_el1
mrs x0, brbtgt12_el1
mrs x0, brbtgt13_el1
mrs x0, brbtgt14_el1
mrs x0, brbtgt15_el1
mrs x0, brbtgt16_el1
mrs x0, brbtgt17_el1
mrs x0, brbtgt18_el1
mrs x0, brbtgt19_el1
mrs x0, brbtgt20_el1
mrs x0, brbtgt21_el1
mrs x0, brbtgt22_el1
mrs x0, brbtgt23_el1
mrs x0, brbtgt24_el1
mrs x0, brbtgt25_el1
mrs x0, brbtgt26_el1
mrs x0, brbtgt27_el1
mrs x0, brbtgt28_el1
mrs x0, brbtgt29_el1
mrs x0, brbtgt30_el1
mrs x0, brbtgt31_el1
mrs x0, brbinf0_el1
mrs x0, brbinf1_el1
mrs x0, brbinf2_el1
mrs x0, brbinf3_el1
mrs x0, brbinf4_el1
mrs x0, brbinf5_el1
mrs x0, brbinf6_el1
mrs x0, brbinf7_el1
mrs x0, brbinf8_el1
mrs x0, brbinf9_el1
mrs x0, brbinf10_el1
mrs x0, brbinf11_el1
mrs x0, brbinf12_el1
mrs x0, brbinf13_el1
mrs x0, brbinf14_el1
mrs x0, brbinf15_el1
mrs x0, brbinf16_el1
mrs x0, brbinf17_el1
mrs x0, brbinf18_el1
mrs x0, brbinf19_el1
mrs x0, brbinf20_el1
mrs x0, brbinf21_el1
mrs x0, brbinf22_el1
mrs x0, brbinf23_el1
mrs x0, brbinf24_el1
mrs x0, brbinf25_el1
mrs x0, brbinf26_el1
mrs x0, brbinf27_el1
mrs x0, brbinf28_el1
mrs x0, brbinf29_el1
mrs x0, brbinf30_el1
mrs x0, brbinf31_el1

/* Write to BRBE system registers.  */
msr brbcr_el1, x0
msr brbcr_el12, x0
msr brbfcr_el1, x0
msr brbts_el1, x0
msr brbinfinj_el1, x0
msr brbsrcinj_el1, x0
msr brbtgtinj_el1, x0
msr brbcr_el2, x0
