[^:]*: Assembler messages:
[^:]*:3: Error: bad type in SIMD instruction -- `vqabs.u8 q0,q1'
[^:]*:4: Error: bad type in SIMD instruction -- `vqneg.u16 q0,q1'
[^:]*:5: Error: bad type in SIMD instruction -- `vqabs.s64 q0,q1'
[^:]*:6: Error: bad instruction `vqnegs.s64 q0,q1'
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:11: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Error: syntax error -- `vqabseq.s32 q0,q1'
[^:]*:18: Error: syntax error -- `vqabseq.s32 q0,q1'
[^:]*:19: Error: syntax error -- `vqabseq.s32 q0,q1'
[^:]*:20: Error: vector predicated instruction should be in VPT/VPST block -- `vqabst.s32 q0,q1'
[^:]*:22: Error: instruction missing MVE vector predication code -- `vqabs.s32 q0,q1'
[^:]*:24: Error: syntax error -- `vqnegeq.s32 q0,q1'
[^:]*:25: Error: syntax error -- `vqnegeq.s32 q0,q1'
[^:]*:26: Error: syntax error -- `vqnegeq.s32 q0,q1'
[^:]*:27: Error: vector predicated instruction should be in VPT/VPST block -- `vqnegt.s32 q0,q1'
[^:]*:29: Error: instruction missing MVE vector predication code -- `vqneg.s32 q0,q1'
