[^:]*: Assembler messages:
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*: Warning: multibyte character \(.*\) encountered in .*
[^:]*:[0-9]+: Warning: end of input
