.*: Assembler messages:
.*: Error: selected processor does not support system register name 'rvae1'
.*: Error: selected processor does not support system register name 'rvaae1'
.*: Error: selected processor does not support system register name 'rvale1'
.*: Error: selected processor does not support system register name 'rvaale1'
.*: Error: selected processor does not support system register name 'vae1'
.*: Error: selected processor does not support system register name 'vaae1'
.*: Error: selected processor does not support system register name 'vale1'
.*: Error: selected processor does not support system register name 'vaale1'
.*: Error: selected processor does not support system register name 'rvae1nxs'
.*: Error: selected processor does not support system register name 'rvaae1nxs'
.*: Error: selected processor does not support system register name 'rvale1nxs'
.*: Error: selected processor does not support system register name 'rvaale1nxs'
.*: Error: selected processor does not support system register name 'vae1nxs'
.*: Error: selected processor does not support system register name 'vaae1nxs'
.*: Error: selected processor does not support system register name 'vale1nxs'
.*: Error: selected processor does not support system register name 'vaale1nxs'
.*: Error: selected processor does not support system register name 'ipas2e1'
.*: Error: selected processor does not support system register name 'ripas2e1'
.*: Error: selected processor does not support system register name 'ipas2le1'
.*: Error: selected processor does not support system register name 'ripas2le1'
.*: Error: selected processor does not support system register name 'rvae2'
.*: Error: selected processor does not support system register name 'rvale2'
.*: Error: selected processor does not support system register name 'vae2'
.*: Error: selected processor does not support system register name 'vale2'
.*: Error: selected processor does not support system register name 'ipas2e1nxs'
.*: Error: selected processor does not support system register name 'ripas2e1nxs'
.*: Error: selected processor does not support system register name 'ipas2le1nxs'
.*: Error: selected processor does not support system register name 'ripas2le1nxs'
.*: Error: selected processor does not support system register name 'rvae2nxs'
.*: Error: selected processor does not support system register name 'rvale2nxs'
.*: Error: selected processor does not support system register name 'vae2nxs'
.*: Error: selected processor does not support system register name 'vale2nxs'
.*: Error: selected processor does not support system register name 'vae3os'
.*: Error: selected processor does not support system register name 'vale3os'
.*: Error: selected processor does not support system register name 'rvae3is'
.*: Error: selected processor does not support system register name 'rvale3is'
.*: Error: selected processor does not support system register name 'vae3is'
.*: Error: selected processor does not support system register name 'vale3is'
.*: Error: selected processor does not support system register name 'rvae3os'
.*: Error: selected processor does not support system register name 'rvale3os'
.*: Error: selected processor does not support system register name 'rvae3'
.*: Error: selected processor does not support system register name 'rvale3'
.*: Error: selected processor does not support system register name 'vae3'
.*: Error: selected processor does not support system register name 'vale3'
.*: Error: selected processor does not support system register name 'vae3osnxs'
.*: Error: selected processor does not support system register name 'vale3osnxs'
.*: Error: selected processor does not support system register name 'rvae3isnxs'
.*: Error: selected processor does not support system register name 'rvale3isnxs'
.*: Error: selected processor does not support system register name 'vae3isnxs'
.*: Error: selected processor does not support system register name 'vale3isnxs'
.*: Error: selected processor does not support system register name 'rvae3osnxs'
.*: Error: selected processor does not support system register name 'rvale3osnxs'
.*: Error: selected processor does not support system register name 'rvae3nxs'
.*: Error: selected processor does not support system register name 'rvale3nxs'
.*: Error: selected processor does not support system register name 'vae3nxs'
.*: Error: selected processor does not support system register name 'vale3nxs'
