.*: Assembler messages:
.*:10: Warning: the `dsp' extension requires MIPS64 revision 2 or greater
.*:10: Warning: the `eva' extension requires MIPS64 revision 2 or greater
.*:10: Warning: the `mt' extension requires MIPS64 revision 2 or greater
.*:10: Warning: the `mips16e2' extension requires MIPS64 revision 2 or greater
