# name: MVE vmlsldav instructions
# as: -march=armv8.1-m.main+mve.fp
# objdump: -dr --prefix-addresses --show-raw-insn -marmv8.1-m.main

.*: +file format .*arm.*

Disassembly of section .text:
[^>]*> ee80 0e01 	vmlsldav.s16	r0, r1, q0, q0
[^>]*> ee80 0e21 	vmlsldava.s16	r0, r1, q0, q0
[^>]*> ee80 1e01 	vmlsldavx.s16	r0, r1, q0, q0
[^>]*> ee80 1e21 	vmlsldavax.s16	r0, r1, q0, q0
[^>]*> ee80 0e03 	vmlsldav.s16	r0, r1, q0, q1
[^>]*> ee80 0e23 	vmlsldava.s16	r0, r1, q0, q1
[^>]*> ee80 1e03 	vmlsldavx.s16	r0, r1, q0, q1
[^>]*> ee80 1e23 	vmlsldavax.s16	r0, r1, q0, q1
[^>]*> ee80 0e05 	vmlsldav.s16	r0, r1, q0, q2
[^>]*> ee80 0e25 	vmlsldava.s16	r0, r1, q0, q2
[^>]*> ee80 1e05 	vmlsldavx.s16	r0, r1, q0, q2
[^>]*> ee80 1e25 	vmlsldavax.s16	r0, r1, q0, q2
[^>]*> ee80 0e09 	vmlsldav.s16	r0, r1, q0, q4
[^>]*> ee80 0e29 	vmlsldava.s16	r0, r1, q0, q4
[^>]*> ee80 1e09 	vmlsldavx.s16	r0, r1, q0, q4
[^>]*> ee80 1e29 	vmlsldavax.s16	r0, r1, q0, q4
[^>]*> ee80 0e0f 	vmlsldav.s16	r0, r1, q0, q7
[^>]*> ee80 0e2f 	vmlsldava.s16	r0, r1, q0, q7
[^>]*> ee80 1e0f 	vmlsldavx.s16	r0, r1, q0, q7
[^>]*> ee80 1e2f 	vmlsldavax.s16	r0, r1, q0, q7
[^>]*> ee82 0e01 	vmlsldav.s16	r0, r1, q1, q0
[^>]*> ee82 0e21 	vmlsldava.s16	r0, r1, q1, q0
[^>]*> ee82 1e01 	vmlsldavx.s16	r0, r1, q1, q0
[^>]*> ee82 1e21 	vmlsldavax.s16	r0, r1, q1, q0
[^>]*> ee82 0e03 	vmlsldav.s16	r0, r1, q1, q1
[^>]*> ee82 0e23 	vmlsldava.s16	r0, r1, q1, q1
[^>]*> ee82 1e03 	vmlsldavx.s16	r0, r1, q1, q1
[^>]*> ee82 1e23 	vmlsldavax.s16	r0, r1, q1, q1
[^>]*> ee82 0e05 	vmlsldav.s16	r0, r1, q1, q2
[^>]*> ee82 0e25 	vmlsldava.s16	r0, r1, q1, q2
[^>]*> ee82 1e05 	vmlsldavx.s16	r0, r1, q1, q2
[^>]*> ee82 1e25 	vmlsldavax.s16	r0, r1, q1, q2
[^>]*> ee82 0e09 	vmlsldav.s16	r0, r1, q1, q4
[^>]*> ee82 0e29 	vmlsldava.s16	r0, r1, q1, q4
[^>]*> ee82 1e09 	vmlsldavx.s16	r0, r1, q1, q4
[^>]*> ee82 1e29 	vmlsldavax.s16	r0, r1, q1, q4
[^>]*> ee82 0e0f 	vmlsldav.s16	r0, r1, q1, q7
[^>]*> ee82 0e2f 	vmlsldava.s16	r0, r1, q1, q7
[^>]*> ee82 1e0f 	vmlsldavx.s16	r0, r1, q1, q7
[^>]*> ee82 1e2f 	vmlsldavax.s16	r0, r1, q1, q7
[^>]*> ee84 0e01 	vmlsldav.s16	r0, r1, q2, q0
[^>]*> ee84 0e21 	vmlsldava.s16	r0, r1, q2, q0
[^>]*> ee84 1e01 	vmlsldavx.s16	r0, r1, q2, q0
[^>]*> ee84 1e21 	vmlsldavax.s16	r0, r1, q2, q0
[^>]*> ee84 0e03 	vmlsldav.s16	r0, r1, q2, q1
[^>]*> ee84 0e23 	vmlsldava.s16	r0, r1, q2, q1
[^>]*> ee84 1e03 	vmlsldavx.s16	r0, r1, q2, q1
[^>]*> ee84 1e23 	vmlsldavax.s16	r0, r1, q2, q1
[^>]*> ee84 0e05 	vmlsldav.s16	r0, r1, q2, q2
[^>]*> ee84 0e25 	vmlsldava.s16	r0, r1, q2, q2
[^>]*> ee84 1e05 	vmlsldavx.s16	r0, r1, q2, q2
[^>]*> ee84 1e25 	vmlsldavax.s16	r0, r1, q2, q2
[^>]*> ee84 0e09 	vmlsldav.s16	r0, r1, q2, q4
[^>]*> ee84 0e29 	vmlsldava.s16	r0, r1, q2, q4
[^>]*> ee84 1e09 	vmlsldavx.s16	r0, r1, q2, q4
[^>]*> ee84 1e29 	vmlsldavax.s16	r0, r1, q2, q4
[^>]*> ee84 0e0f 	vmlsldav.s16	r0, r1, q2, q7
[^>]*> ee84 0e2f 	vmlsldava.s16	r0, r1, q2, q7
[^>]*> ee84 1e0f 	vmlsldavx.s16	r0, r1, q2, q7
[^>]*> ee84 1e2f 	vmlsldavax.s16	r0, r1, q2, q7
[^>]*> ee88 0e01 	vmlsldav.s16	r0, r1, q4, q0
[^>]*> ee88 0e21 	vmlsldava.s16	r0, r1, q4, q0
[^>]*> ee88 1e01 	vmlsldavx.s16	r0, r1, q4, q0
[^>]*> ee88 1e21 	vmlsldavax.s16	r0, r1, q4, q0
[^>]*> ee88 0e03 	vmlsldav.s16	r0, r1, q4, q1
[^>]*> ee88 0e23 	vmlsldava.s16	r0, r1, q4, q1
[^>]*> ee88 1e03 	vmlsldavx.s16	r0, r1, q4, q1
[^>]*> ee88 1e23 	vmlsldavax.s16	r0, r1, q4, q1
[^>]*> ee88 0e05 	vmlsldav.s16	r0, r1, q4, q2
[^>]*> ee88 0e25 	vmlsldava.s16	r0, r1, q4, q2
[^>]*> ee88 1e05 	vmlsldavx.s16	r0, r1, q4, q2
[^>]*> ee88 1e25 	vmlsldavax.s16	r0, r1, q4, q2
[^>]*> ee88 0e09 	vmlsldav.s16	r0, r1, q4, q4
[^>]*> ee88 0e29 	vmlsldava.s16	r0, r1, q4, q4
[^>]*> ee88 1e09 	vmlsldavx.s16	r0, r1, q4, q4
[^>]*> ee88 1e29 	vmlsldavax.s16	r0, r1, q4, q4
[^>]*> ee88 0e0f 	vmlsldav.s16	r0, r1, q4, q7
[^>]*> ee88 0e2f 	vmlsldava.s16	r0, r1, q4, q7
[^>]*> ee88 1e0f 	vmlsldavx.s16	r0, r1, q4, q7
[^>]*> ee88 1e2f 	vmlsldavax.s16	r0, r1, q4, q7
[^>]*> ee8e 0e01 	vmlsldav.s16	r0, r1, q7, q0
[^>]*> ee8e 0e21 	vmlsldava.s16	r0, r1, q7, q0
[^>]*> ee8e 1e01 	vmlsldavx.s16	r0, r1, q7, q0
[^>]*> ee8e 1e21 	vmlsldavax.s16	r0, r1, q7, q0
[^>]*> ee8e 0e03 	vmlsldav.s16	r0, r1, q7, q1
[^>]*> ee8e 0e23 	vmlsldava.s16	r0, r1, q7, q1
[^>]*> ee8e 1e03 	vmlsldavx.s16	r0, r1, q7, q1
[^>]*> ee8e 1e23 	vmlsldavax.s16	r0, r1, q7, q1
[^>]*> ee8e 0e05 	vmlsldav.s16	r0, r1, q7, q2
[^>]*> ee8e 0e25 	vmlsldava.s16	r0, r1, q7, q2
[^>]*> ee8e 1e05 	vmlsldavx.s16	r0, r1, q7, q2
[^>]*> ee8e 1e25 	vmlsldavax.s16	r0, r1, q7, q2
[^>]*> ee8e 0e09 	vmlsldav.s16	r0, r1, q7, q4
[^>]*> ee8e 0e29 	vmlsldava.s16	r0, r1, q7, q4
[^>]*> ee8e 1e09 	vmlsldavx.s16	r0, r1, q7, q4
[^>]*> ee8e 1e29 	vmlsldavax.s16	r0, r1, q7, q4
[^>]*> ee8e 0e0f 	vmlsldav.s16	r0, r1, q7, q7
[^>]*> ee8e 0e2f 	vmlsldava.s16	r0, r1, q7, q7
[^>]*> ee8e 1e0f 	vmlsldavx.s16	r0, r1, q7, q7
[^>]*> ee8e 1e2f 	vmlsldavax.s16	r0, r1, q7, q7
[^>]*> ee90 0e01 	vmlsldav.s16	r0, r3, q0, q0
[^>]*> ee90 0e21 	vmlsldava.s16	r0, r3, q0, q0
[^>]*> ee90 1e01 	vmlsldavx.s16	r0, r3, q0, q0
[^>]*> ee90 1e21 	vmlsldavax.s16	r0, r3, q0, q0
[^>]*> ee90 0e03 	vmlsldav.s16	r0, r3, q0, q1
[^>]*> ee90 0e23 	vmlsldava.s16	r0, r3, q0, q1
[^>]*> ee90 1e03 	vmlsldavx.s16	r0, r3, q0, q1
[^>]*> ee90 1e23 	vmlsldavax.s16	r0, r3, q0, q1
[^>]*> ee90 0e05 	vmlsldav.s16	r0, r3, q0, q2
[^>]*> ee90 0e25 	vmlsldava.s16	r0, r3, q0, q2
[^>]*> ee90 1e05 	vmlsldavx.s16	r0, r3, q0, q2
[^>]*> ee90 1e25 	vmlsldavax.s16	r0, r3, q0, q2
[^>]*> ee90 0e09 	vmlsldav.s16	r0, r3, q0, q4
[^>]*> ee90 0e29 	vmlsldava.s16	r0, r3, q0, q4
[^>]*> ee90 1e09 	vmlsldavx.s16	r0, r3, q0, q4
[^>]*> ee90 1e29 	vmlsldavax.s16	r0, r3, q0, q4
[^>]*> ee90 0e0f 	vmlsldav.s16	r0, r3, q0, q7
[^>]*> ee90 0e2f 	vmlsldava.s16	r0, r3, q0, q7
[^>]*> ee90 1e0f 	vmlsldavx.s16	r0, r3, q0, q7
[^>]*> ee90 1e2f 	vmlsldavax.s16	r0, r3, q0, q7
[^>]*> ee92 0e01 	vmlsldav.s16	r0, r3, q1, q0
[^>]*> ee92 0e21 	vmlsldava.s16	r0, r3, q1, q0
[^>]*> ee92 1e01 	vmlsldavx.s16	r0, r3, q1, q0
[^>]*> ee92 1e21 	vmlsldavax.s16	r0, r3, q1, q0
[^>]*> ee92 0e03 	vmlsldav.s16	r0, r3, q1, q1
[^>]*> ee92 0e23 	vmlsldava.s16	r0, r3, q1, q1
[^>]*> ee92 1e03 	vmlsldavx.s16	r0, r3, q1, q1
[^>]*> ee92 1e23 	vmlsldavax.s16	r0, r3, q1, q1
[^>]*> ee92 0e05 	vmlsldav.s16	r0, r3, q1, q2
[^>]*> ee92 0e25 	vmlsldava.s16	r0, r3, q1, q2
[^>]*> ee92 1e05 	vmlsldavx.s16	r0, r3, q1, q2
[^>]*> ee92 1e25 	vmlsldavax.s16	r0, r3, q1, q2
[^>]*> ee92 0e09 	vmlsldav.s16	r0, r3, q1, q4
[^>]*> ee92 0e29 	vmlsldava.s16	r0, r3, q1, q4
[^>]*> ee92 1e09 	vmlsldavx.s16	r0, r3, q1, q4
[^>]*> ee92 1e29 	vmlsldavax.s16	r0, r3, q1, q4
[^>]*> ee92 0e0f 	vmlsldav.s16	r0, r3, q1, q7
[^>]*> ee92 0e2f 	vmlsldava.s16	r0, r3, q1, q7
[^>]*> ee92 1e0f 	vmlsldavx.s16	r0, r3, q1, q7
[^>]*> ee92 1e2f 	vmlsldavax.s16	r0, r3, q1, q7
[^>]*> ee94 0e01 	vmlsldav.s16	r0, r3, q2, q0
[^>]*> ee94 0e21 	vmlsldava.s16	r0, r3, q2, q0
[^>]*> ee94 1e01 	vmlsldavx.s16	r0, r3, q2, q0
[^>]*> ee94 1e21 	vmlsldavax.s16	r0, r3, q2, q0
[^>]*> ee94 0e03 	vmlsldav.s16	r0, r3, q2, q1
[^>]*> ee94 0e23 	vmlsldava.s16	r0, r3, q2, q1
[^>]*> ee94 1e03 	vmlsldavx.s16	r0, r3, q2, q1
[^>]*> ee94 1e23 	vmlsldavax.s16	r0, r3, q2, q1
[^>]*> ee94 0e05 	vmlsldav.s16	r0, r3, q2, q2
[^>]*> ee94 0e25 	vmlsldava.s16	r0, r3, q2, q2
[^>]*> ee94 1e05 	vmlsldavx.s16	r0, r3, q2, q2
[^>]*> ee94 1e25 	vmlsldavax.s16	r0, r3, q2, q2
[^>]*> ee94 0e09 	vmlsldav.s16	r0, r3, q2, q4
[^>]*> ee94 0e29 	vmlsldava.s16	r0, r3, q2, q4
[^>]*> ee94 1e09 	vmlsldavx.s16	r0, r3, q2, q4
[^>]*> ee94 1e29 	vmlsldavax.s16	r0, r3, q2, q4
[^>]*> ee94 0e0f 	vmlsldav.s16	r0, r3, q2, q7
[^>]*> ee94 0e2f 	vmlsldava.s16	r0, r3, q2, q7
[^>]*> ee94 1e0f 	vmlsldavx.s16	r0, r3, q2, q7
[^>]*> ee94 1e2f 	vmlsldavax.s16	r0, r3, q2, q7
[^>]*> ee98 0e01 	vmlsldav.s16	r0, r3, q4, q0
[^>]*> ee98 0e21 	vmlsldava.s16	r0, r3, q4, q0
[^>]*> ee98 1e01 	vmlsldavx.s16	r0, r3, q4, q0
[^>]*> ee98 1e21 	vmlsldavax.s16	r0, r3, q4, q0
[^>]*> ee98 0e03 	vmlsldav.s16	r0, r3, q4, q1
[^>]*> ee98 0e23 	vmlsldava.s16	r0, r3, q4, q1
[^>]*> ee98 1e03 	vmlsldavx.s16	r0, r3, q4, q1
[^>]*> ee98 1e23 	vmlsldavax.s16	r0, r3, q4, q1
[^>]*> ee98 0e05 	vmlsldav.s16	r0, r3, q4, q2
[^>]*> ee98 0e25 	vmlsldava.s16	r0, r3, q4, q2
[^>]*> ee98 1e05 	vmlsldavx.s16	r0, r3, q4, q2
[^>]*> ee98 1e25 	vmlsldavax.s16	r0, r3, q4, q2
[^>]*> ee98 0e09 	vmlsldav.s16	r0, r3, q4, q4
[^>]*> ee98 0e29 	vmlsldava.s16	r0, r3, q4, q4
[^>]*> ee98 1e09 	vmlsldavx.s16	r0, r3, q4, q4
[^>]*> ee98 1e29 	vmlsldavax.s16	r0, r3, q4, q4
[^>]*> ee98 0e0f 	vmlsldav.s16	r0, r3, q4, q7
[^>]*> ee98 0e2f 	vmlsldava.s16	r0, r3, q4, q7
[^>]*> ee98 1e0f 	vmlsldavx.s16	r0, r3, q4, q7
[^>]*> ee98 1e2f 	vmlsldavax.s16	r0, r3, q4, q7
[^>]*> ee9e 0e01 	vmlsldav.s16	r0, r3, q7, q0
[^>]*> ee9e 0e21 	vmlsldava.s16	r0, r3, q7, q0
[^>]*> ee9e 1e01 	vmlsldavx.s16	r0, r3, q7, q0
[^>]*> ee9e 1e21 	vmlsldavax.s16	r0, r3, q7, q0
[^>]*> ee9e 0e03 	vmlsldav.s16	r0, r3, q7, q1
[^>]*> ee9e 0e23 	vmlsldava.s16	r0, r3, q7, q1
[^>]*> ee9e 1e03 	vmlsldavx.s16	r0, r3, q7, q1
[^>]*> ee9e 1e23 	vmlsldavax.s16	r0, r3, q7, q1
[^>]*> ee9e 0e05 	vmlsldav.s16	r0, r3, q7, q2
[^>]*> ee9e 0e25 	vmlsldava.s16	r0, r3, q7, q2
[^>]*> ee9e 1e05 	vmlsldavx.s16	r0, r3, q7, q2
[^>]*> ee9e 1e25 	vmlsldavax.s16	r0, r3, q7, q2
[^>]*> ee9e 0e09 	vmlsldav.s16	r0, r3, q7, q4
[^>]*> ee9e 0e29 	vmlsldava.s16	r0, r3, q7, q4
[^>]*> ee9e 1e09 	vmlsldavx.s16	r0, r3, q7, q4
[^>]*> ee9e 1e29 	vmlsldavax.s16	r0, r3, q7, q4
[^>]*> ee9e 0e0f 	vmlsldav.s16	r0, r3, q7, q7
[^>]*> ee9e 0e2f 	vmlsldava.s16	r0, r3, q7, q7
[^>]*> ee9e 1e0f 	vmlsldavx.s16	r0, r3, q7, q7
[^>]*> ee9e 1e2f 	vmlsldavax.s16	r0, r3, q7, q7
[^>]*> eea0 0e01 	vmlsldav.s16	r0, r5, q0, q0
[^>]*> eea0 0e21 	vmlsldava.s16	r0, r5, q0, q0
[^>]*> eea0 1e01 	vmlsldavx.s16	r0, r5, q0, q0
[^>]*> eea0 1e21 	vmlsldavax.s16	r0, r5, q0, q0
[^>]*> eea0 0e03 	vmlsldav.s16	r0, r5, q0, q1
[^>]*> eea0 0e23 	vmlsldava.s16	r0, r5, q0, q1
[^>]*> eea0 1e03 	vmlsldavx.s16	r0, r5, q0, q1
[^>]*> eea0 1e23 	vmlsldavax.s16	r0, r5, q0, q1
[^>]*> eea0 0e05 	vmlsldav.s16	r0, r5, q0, q2
[^>]*> eea0 0e25 	vmlsldava.s16	r0, r5, q0, q2
[^>]*> eea0 1e05 	vmlsldavx.s16	r0, r5, q0, q2
[^>]*> eea0 1e25 	vmlsldavax.s16	r0, r5, q0, q2
[^>]*> eea0 0e09 	vmlsldav.s16	r0, r5, q0, q4
[^>]*> eea0 0e29 	vmlsldava.s16	r0, r5, q0, q4
[^>]*> eea0 1e09 	vmlsldavx.s16	r0, r5, q0, q4
[^>]*> eea0 1e29 	vmlsldavax.s16	r0, r5, q0, q4
[^>]*> eea0 0e0f 	vmlsldav.s16	r0, r5, q0, q7
[^>]*> eea0 0e2f 	vmlsldava.s16	r0, r5, q0, q7
[^>]*> eea0 1e0f 	vmlsldavx.s16	r0, r5, q0, q7
[^>]*> eea0 1e2f 	vmlsldavax.s16	r0, r5, q0, q7
[^>]*> eea2 0e01 	vmlsldav.s16	r0, r5, q1, q0
[^>]*> eea2 0e21 	vmlsldava.s16	r0, r5, q1, q0
[^>]*> eea2 1e01 	vmlsldavx.s16	r0, r5, q1, q0
[^>]*> eea2 1e21 	vmlsldavax.s16	r0, r5, q1, q0
[^>]*> eea2 0e03 	vmlsldav.s16	r0, r5, q1, q1
[^>]*> eea2 0e23 	vmlsldava.s16	r0, r5, q1, q1
[^>]*> eea2 1e03 	vmlsldavx.s16	r0, r5, q1, q1
[^>]*> eea2 1e23 	vmlsldavax.s16	r0, r5, q1, q1
[^>]*> eea2 0e05 	vmlsldav.s16	r0, r5, q1, q2
[^>]*> eea2 0e25 	vmlsldava.s16	r0, r5, q1, q2
[^>]*> eea2 1e05 	vmlsldavx.s16	r0, r5, q1, q2
[^>]*> eea2 1e25 	vmlsldavax.s16	r0, r5, q1, q2
[^>]*> eea2 0e09 	vmlsldav.s16	r0, r5, q1, q4
[^>]*> eea2 0e29 	vmlsldava.s16	r0, r5, q1, q4
[^>]*> eea2 1e09 	vmlsldavx.s16	r0, r5, q1, q4
[^>]*> eea2 1e29 	vmlsldavax.s16	r0, r5, q1, q4
[^>]*> eea2 0e0f 	vmlsldav.s16	r0, r5, q1, q7
[^>]*> eea2 0e2f 	vmlsldava.s16	r0, r5, q1, q7
[^>]*> eea2 1e0f 	vmlsldavx.s16	r0, r5, q1, q7
[^>]*> eea2 1e2f 	vmlsldavax.s16	r0, r5, q1, q7
[^>]*> eea4 0e01 	vmlsldav.s16	r0, r5, q2, q0
[^>]*> eea4 0e21 	vmlsldava.s16	r0, r5, q2, q0
[^>]*> eea4 1e01 	vmlsldavx.s16	r0, r5, q2, q0
[^>]*> eea4 1e21 	vmlsldavax.s16	r0, r5, q2, q0
[^>]*> eea4 0e03 	vmlsldav.s16	r0, r5, q2, q1
[^>]*> eea4 0e23 	vmlsldava.s16	r0, r5, q2, q1
[^>]*> eea4 1e03 	vmlsldavx.s16	r0, r5, q2, q1
[^>]*> eea4 1e23 	vmlsldavax.s16	r0, r5, q2, q1
[^>]*> eea4 0e05 	vmlsldav.s16	r0, r5, q2, q2
[^>]*> eea4 0e25 	vmlsldava.s16	r0, r5, q2, q2
[^>]*> eea4 1e05 	vmlsldavx.s16	r0, r5, q2, q2
[^>]*> eea4 1e25 	vmlsldavax.s16	r0, r5, q2, q2
[^>]*> eea4 0e09 	vmlsldav.s16	r0, r5, q2, q4
[^>]*> eea4 0e29 	vmlsldava.s16	r0, r5, q2, q4
[^>]*> eea4 1e09 	vmlsldavx.s16	r0, r5, q2, q4
[^>]*> eea4 1e29 	vmlsldavax.s16	r0, r5, q2, q4
[^>]*> eea4 0e0f 	vmlsldav.s16	r0, r5, q2, q7
[^>]*> eea4 0e2f 	vmlsldava.s16	r0, r5, q2, q7
[^>]*> eea4 1e0f 	vmlsldavx.s16	r0, r5, q2, q7
[^>]*> eea4 1e2f 	vmlsldavax.s16	r0, r5, q2, q7
[^>]*> eea8 0e01 	vmlsldav.s16	r0, r5, q4, q0
[^>]*> eea8 0e21 	vmlsldava.s16	r0, r5, q4, q0
[^>]*> eea8 1e01 	vmlsldavx.s16	r0, r5, q4, q0
[^>]*> eea8 1e21 	vmlsldavax.s16	r0, r5, q4, q0
[^>]*> eea8 0e03 	vmlsldav.s16	r0, r5, q4, q1
[^>]*> eea8 0e23 	vmlsldava.s16	r0, r5, q4, q1
[^>]*> eea8 1e03 	vmlsldavx.s16	r0, r5, q4, q1
[^>]*> eea8 1e23 	vmlsldavax.s16	r0, r5, q4, q1
[^>]*> eea8 0e05 	vmlsldav.s16	r0, r5, q4, q2
[^>]*> eea8 0e25 	vmlsldava.s16	r0, r5, q4, q2
[^>]*> eea8 1e05 	vmlsldavx.s16	r0, r5, q4, q2
[^>]*> eea8 1e25 	vmlsldavax.s16	r0, r5, q4, q2
[^>]*> eea8 0e09 	vmlsldav.s16	r0, r5, q4, q4
[^>]*> eea8 0e29 	vmlsldava.s16	r0, r5, q4, q4
[^>]*> eea8 1e09 	vmlsldavx.s16	r0, r5, q4, q4
[^>]*> eea8 1e29 	vmlsldavax.s16	r0, r5, q4, q4
[^>]*> eea8 0e0f 	vmlsldav.s16	r0, r5, q4, q7
[^>]*> eea8 0e2f 	vmlsldava.s16	r0, r5, q4, q7
[^>]*> eea8 1e0f 	vmlsldavx.s16	r0, r5, q4, q7
[^>]*> eea8 1e2f 	vmlsldavax.s16	r0, r5, q4, q7
[^>]*> eeae 0e01 	vmlsldav.s16	r0, r5, q7, q0
[^>]*> eeae 0e21 	vmlsldava.s16	r0, r5, q7, q0
[^>]*> eeae 1e01 	vmlsldavx.s16	r0, r5, q7, q0
[^>]*> eeae 1e21 	vmlsldavax.s16	r0, r5, q7, q0
[^>]*> eeae 0e03 	vmlsldav.s16	r0, r5, q7, q1
[^>]*> eeae 0e23 	vmlsldava.s16	r0, r5, q7, q1
[^>]*> eeae 1e03 	vmlsldavx.s16	r0, r5, q7, q1
[^>]*> eeae 1e23 	vmlsldavax.s16	r0, r5, q7, q1
[^>]*> eeae 0e05 	vmlsldav.s16	r0, r5, q7, q2
[^>]*> eeae 0e25 	vmlsldava.s16	r0, r5, q7, q2
[^>]*> eeae 1e05 	vmlsldavx.s16	r0, r5, q7, q2
[^>]*> eeae 1e25 	vmlsldavax.s16	r0, r5, q7, q2
[^>]*> eeae 0e09 	vmlsldav.s16	r0, r5, q7, q4
[^>]*> eeae 0e29 	vmlsldava.s16	r0, r5, q7, q4
[^>]*> eeae 1e09 	vmlsldavx.s16	r0, r5, q7, q4
[^>]*> eeae 1e29 	vmlsldavax.s16	r0, r5, q7, q4
[^>]*> eeae 0e0f 	vmlsldav.s16	r0, r5, q7, q7
[^>]*> eeae 0e2f 	vmlsldava.s16	r0, r5, q7, q7
[^>]*> eeae 1e0f 	vmlsldavx.s16	r0, r5, q7, q7
[^>]*> eeae 1e2f 	vmlsldavax.s16	r0, r5, q7, q7
[^>]*> eeb0 0e01 	vmlsldav.s16	r0, r7, q0, q0
[^>]*> eeb0 0e21 	vmlsldava.s16	r0, r7, q0, q0
[^>]*> eeb0 1e01 	vmlsldavx.s16	r0, r7, q0, q0
[^>]*> eeb0 1e21 	vmlsldavax.s16	r0, r7, q0, q0
[^>]*> eeb0 0e03 	vmlsldav.s16	r0, r7, q0, q1
[^>]*> eeb0 0e23 	vmlsldava.s16	r0, r7, q0, q1
[^>]*> eeb0 1e03 	vmlsldavx.s16	r0, r7, q0, q1
[^>]*> eeb0 1e23 	vmlsldavax.s16	r0, r7, q0, q1
[^>]*> eeb0 0e05 	vmlsldav.s16	r0, r7, q0, q2
[^>]*> eeb0 0e25 	vmlsldava.s16	r0, r7, q0, q2
[^>]*> eeb0 1e05 	vmlsldavx.s16	r0, r7, q0, q2
[^>]*> eeb0 1e25 	vmlsldavax.s16	r0, r7, q0, q2
[^>]*> eeb0 0e09 	vmlsldav.s16	r0, r7, q0, q4
[^>]*> eeb0 0e29 	vmlsldava.s16	r0, r7, q0, q4
[^>]*> eeb0 1e09 	vmlsldavx.s16	r0, r7, q0, q4
[^>]*> eeb0 1e29 	vmlsldavax.s16	r0, r7, q0, q4
[^>]*> eeb0 0e0f 	vmlsldav.s16	r0, r7, q0, q7
[^>]*> eeb0 0e2f 	vmlsldava.s16	r0, r7, q0, q7
[^>]*> eeb0 1e0f 	vmlsldavx.s16	r0, r7, q0, q7
[^>]*> eeb0 1e2f 	vmlsldavax.s16	r0, r7, q0, q7
[^>]*> eeb2 0e01 	vmlsldav.s16	r0, r7, q1, q0
[^>]*> eeb2 0e21 	vmlsldava.s16	r0, r7, q1, q0
[^>]*> eeb2 1e01 	vmlsldavx.s16	r0, r7, q1, q0
[^>]*> eeb2 1e21 	vmlsldavax.s16	r0, r7, q1, q0
[^>]*> eeb2 0e03 	vmlsldav.s16	r0, r7, q1, q1
[^>]*> eeb2 0e23 	vmlsldava.s16	r0, r7, q1, q1
[^>]*> eeb2 1e03 	vmlsldavx.s16	r0, r7, q1, q1
[^>]*> eeb2 1e23 	vmlsldavax.s16	r0, r7, q1, q1
[^>]*> eeb2 0e05 	vmlsldav.s16	r0, r7, q1, q2
[^>]*> eeb2 0e25 	vmlsldava.s16	r0, r7, q1, q2
[^>]*> eeb2 1e05 	vmlsldavx.s16	r0, r7, q1, q2
[^>]*> eeb2 1e25 	vmlsldavax.s16	r0, r7, q1, q2
[^>]*> eeb2 0e09 	vmlsldav.s16	r0, r7, q1, q4
[^>]*> eeb2 0e29 	vmlsldava.s16	r0, r7, q1, q4
[^>]*> eeb2 1e09 	vmlsldavx.s16	r0, r7, q1, q4
[^>]*> eeb2 1e29 	vmlsldavax.s16	r0, r7, q1, q4
[^>]*> eeb2 0e0f 	vmlsldav.s16	r0, r7, q1, q7
[^>]*> eeb2 0e2f 	vmlsldava.s16	r0, r7, q1, q7
[^>]*> eeb2 1e0f 	vmlsldavx.s16	r0, r7, q1, q7
[^>]*> eeb2 1e2f 	vmlsldavax.s16	r0, r7, q1, q7
[^>]*> eeb4 0e01 	vmlsldav.s16	r0, r7, q2, q0
[^>]*> eeb4 0e21 	vmlsldava.s16	r0, r7, q2, q0
[^>]*> eeb4 1e01 	vmlsldavx.s16	r0, r7, q2, q0
[^>]*> eeb4 1e21 	vmlsldavax.s16	r0, r7, q2, q0
[^>]*> eeb4 0e03 	vmlsldav.s16	r0, r7, q2, q1
[^>]*> eeb4 0e23 	vmlsldava.s16	r0, r7, q2, q1
[^>]*> eeb4 1e03 	vmlsldavx.s16	r0, r7, q2, q1
[^>]*> eeb4 1e23 	vmlsldavax.s16	r0, r7, q2, q1
[^>]*> eeb4 0e05 	vmlsldav.s16	r0, r7, q2, q2
[^>]*> eeb4 0e25 	vmlsldava.s16	r0, r7, q2, q2
[^>]*> eeb4 1e05 	vmlsldavx.s16	r0, r7, q2, q2
[^>]*> eeb4 1e25 	vmlsldavax.s16	r0, r7, q2, q2
[^>]*> eeb4 0e09 	vmlsldav.s16	r0, r7, q2, q4
[^>]*> eeb4 0e29 	vmlsldava.s16	r0, r7, q2, q4
[^>]*> eeb4 1e09 	vmlsldavx.s16	r0, r7, q2, q4
[^>]*> eeb4 1e29 	vmlsldavax.s16	r0, r7, q2, q4
[^>]*> eeb4 0e0f 	vmlsldav.s16	r0, r7, q2, q7
[^>]*> eeb4 0e2f 	vmlsldava.s16	r0, r7, q2, q7
[^>]*> eeb4 1e0f 	vmlsldavx.s16	r0, r7, q2, q7
[^>]*> eeb4 1e2f 	vmlsldavax.s16	r0, r7, q2, q7
[^>]*> eeb8 0e01 	vmlsldav.s16	r0, r7, q4, q0
[^>]*> eeb8 0e21 	vmlsldava.s16	r0, r7, q4, q0
[^>]*> eeb8 1e01 	vmlsldavx.s16	r0, r7, q4, q0
[^>]*> eeb8 1e21 	vmlsldavax.s16	r0, r7, q4, q0
[^>]*> eeb8 0e03 	vmlsldav.s16	r0, r7, q4, q1
[^>]*> eeb8 0e23 	vmlsldava.s16	r0, r7, q4, q1
[^>]*> eeb8 1e03 	vmlsldavx.s16	r0, r7, q4, q1
[^>]*> eeb8 1e23 	vmlsldavax.s16	r0, r7, q4, q1
[^>]*> eeb8 0e05 	vmlsldav.s16	r0, r7, q4, q2
[^>]*> eeb8 0e25 	vmlsldava.s16	r0, r7, q4, q2
[^>]*> eeb8 1e05 	vmlsldavx.s16	r0, r7, q4, q2
[^>]*> eeb8 1e25 	vmlsldavax.s16	r0, r7, q4, q2
[^>]*> eeb8 0e09 	vmlsldav.s16	r0, r7, q4, q4
[^>]*> eeb8 0e29 	vmlsldava.s16	r0, r7, q4, q4
[^>]*> eeb8 1e09 	vmlsldavx.s16	r0, r7, q4, q4
[^>]*> eeb8 1e29 	vmlsldavax.s16	r0, r7, q4, q4
[^>]*> eeb8 0e0f 	vmlsldav.s16	r0, r7, q4, q7
[^>]*> eeb8 0e2f 	vmlsldava.s16	r0, r7, q4, q7
[^>]*> eeb8 1e0f 	vmlsldavx.s16	r0, r7, q4, q7
[^>]*> eeb8 1e2f 	vmlsldavax.s16	r0, r7, q4, q7
[^>]*> eebe 0e01 	vmlsldav.s16	r0, r7, q7, q0
[^>]*> eebe 0e21 	vmlsldava.s16	r0, r7, q7, q0
[^>]*> eebe 1e01 	vmlsldavx.s16	r0, r7, q7, q0
[^>]*> eebe 1e21 	vmlsldavax.s16	r0, r7, q7, q0
[^>]*> eebe 0e03 	vmlsldav.s16	r0, r7, q7, q1
[^>]*> eebe 0e23 	vmlsldava.s16	r0, r7, q7, q1
[^>]*> eebe 1e03 	vmlsldavx.s16	r0, r7, q7, q1
[^>]*> eebe 1e23 	vmlsldavax.s16	r0, r7, q7, q1
[^>]*> eebe 0e05 	vmlsldav.s16	r0, r7, q7, q2
[^>]*> eebe 0e25 	vmlsldava.s16	r0, r7, q7, q2
[^>]*> eebe 1e05 	vmlsldavx.s16	r0, r7, q7, q2
[^>]*> eebe 1e25 	vmlsldavax.s16	r0, r7, q7, q2
[^>]*> eebe 0e09 	vmlsldav.s16	r0, r7, q7, q4
[^>]*> eebe 0e29 	vmlsldava.s16	r0, r7, q7, q4
[^>]*> eebe 1e09 	vmlsldavx.s16	r0, r7, q7, q4
[^>]*> eebe 1e29 	vmlsldavax.s16	r0, r7, q7, q4
[^>]*> eebe 0e0f 	vmlsldav.s16	r0, r7, q7, q7
[^>]*> eebe 0e2f 	vmlsldava.s16	r0, r7, q7, q7
[^>]*> eebe 1e0f 	vmlsldavx.s16	r0, r7, q7, q7
[^>]*> eebe 1e2f 	vmlsldavax.s16	r0, r7, q7, q7
[^>]*> eec0 0e01 	vmlsldav.s16	r0, r9, q0, q0
[^>]*> eec0 0e21 	vmlsldava.s16	r0, r9, q0, q0
[^>]*> eec0 1e01 	vmlsldavx.s16	r0, r9, q0, q0
[^>]*> eec0 1e21 	vmlsldavax.s16	r0, r9, q0, q0
[^>]*> eec0 0e03 	vmlsldav.s16	r0, r9, q0, q1
[^>]*> eec0 0e23 	vmlsldava.s16	r0, r9, q0, q1
[^>]*> eec0 1e03 	vmlsldavx.s16	r0, r9, q0, q1
[^>]*> eec0 1e23 	vmlsldavax.s16	r0, r9, q0, q1
[^>]*> eec0 0e05 	vmlsldav.s16	r0, r9, q0, q2
[^>]*> eec0 0e25 	vmlsldava.s16	r0, r9, q0, q2
[^>]*> eec0 1e05 	vmlsldavx.s16	r0, r9, q0, q2
[^>]*> eec0 1e25 	vmlsldavax.s16	r0, r9, q0, q2
[^>]*> eec0 0e09 	vmlsldav.s16	r0, r9, q0, q4
[^>]*> eec0 0e29 	vmlsldava.s16	r0, r9, q0, q4
[^>]*> eec0 1e09 	vmlsldavx.s16	r0, r9, q0, q4
[^>]*> eec0 1e29 	vmlsldavax.s16	r0, r9, q0, q4
[^>]*> eec0 0e0f 	vmlsldav.s16	r0, r9, q0, q7
[^>]*> eec0 0e2f 	vmlsldava.s16	r0, r9, q0, q7
[^>]*> eec0 1e0f 	vmlsldavx.s16	r0, r9, q0, q7
[^>]*> eec0 1e2f 	vmlsldavax.s16	r0, r9, q0, q7
[^>]*> eec2 0e01 	vmlsldav.s16	r0, r9, q1, q0
[^>]*> eec2 0e21 	vmlsldava.s16	r0, r9, q1, q0
[^>]*> eec2 1e01 	vmlsldavx.s16	r0, r9, q1, q0
[^>]*> eec2 1e21 	vmlsldavax.s16	r0, r9, q1, q0
[^>]*> eec2 0e03 	vmlsldav.s16	r0, r9, q1, q1
[^>]*> eec2 0e23 	vmlsldava.s16	r0, r9, q1, q1
[^>]*> eec2 1e03 	vmlsldavx.s16	r0, r9, q1, q1
[^>]*> eec2 1e23 	vmlsldavax.s16	r0, r9, q1, q1
[^>]*> eec2 0e05 	vmlsldav.s16	r0, r9, q1, q2
[^>]*> eec2 0e25 	vmlsldava.s16	r0, r9, q1, q2
[^>]*> eec2 1e05 	vmlsldavx.s16	r0, r9, q1, q2
[^>]*> eec2 1e25 	vmlsldavax.s16	r0, r9, q1, q2
[^>]*> eec2 0e09 	vmlsldav.s16	r0, r9, q1, q4
[^>]*> eec2 0e29 	vmlsldava.s16	r0, r9, q1, q4
[^>]*> eec2 1e09 	vmlsldavx.s16	r0, r9, q1, q4
[^>]*> eec2 1e29 	vmlsldavax.s16	r0, r9, q1, q4
[^>]*> eec2 0e0f 	vmlsldav.s16	r0, r9, q1, q7
[^>]*> eec2 0e2f 	vmlsldava.s16	r0, r9, q1, q7
[^>]*> eec2 1e0f 	vmlsldavx.s16	r0, r9, q1, q7
[^>]*> eec2 1e2f 	vmlsldavax.s16	r0, r9, q1, q7
[^>]*> eec4 0e01 	vmlsldav.s16	r0, r9, q2, q0
[^>]*> eec4 0e21 	vmlsldava.s16	r0, r9, q2, q0
[^>]*> eec4 1e01 	vmlsldavx.s16	r0, r9, q2, q0
[^>]*> eec4 1e21 	vmlsldavax.s16	r0, r9, q2, q0
[^>]*> eec4 0e03 	vmlsldav.s16	r0, r9, q2, q1
[^>]*> eec4 0e23 	vmlsldava.s16	r0, r9, q2, q1
[^>]*> eec4 1e03 	vmlsldavx.s16	r0, r9, q2, q1
[^>]*> eec4 1e23 	vmlsldavax.s16	r0, r9, q2, q1
[^>]*> eec4 0e05 	vmlsldav.s16	r0, r9, q2, q2
[^>]*> eec4 0e25 	vmlsldava.s16	r0, r9, q2, q2
[^>]*> eec4 1e05 	vmlsldavx.s16	r0, r9, q2, q2
[^>]*> eec4 1e25 	vmlsldavax.s16	r0, r9, q2, q2
[^>]*> eec4 0e09 	vmlsldav.s16	r0, r9, q2, q4
[^>]*> eec4 0e29 	vmlsldava.s16	r0, r9, q2, q4
[^>]*> eec4 1e09 	vmlsldavx.s16	r0, r9, q2, q4
[^>]*> eec4 1e29 	vmlsldavax.s16	r0, r9, q2, q4
[^>]*> eec4 0e0f 	vmlsldav.s16	r0, r9, q2, q7
[^>]*> eec4 0e2f 	vmlsldava.s16	r0, r9, q2, q7
[^>]*> eec4 1e0f 	vmlsldavx.s16	r0, r9, q2, q7
[^>]*> eec4 1e2f 	vmlsldavax.s16	r0, r9, q2, q7
[^>]*> eec8 0e01 	vmlsldav.s16	r0, r9, q4, q0
[^>]*> eec8 0e21 	vmlsldava.s16	r0, r9, q4, q0
[^>]*> eec8 1e01 	vmlsldavx.s16	r0, r9, q4, q0
[^>]*> eec8 1e21 	vmlsldavax.s16	r0, r9, q4, q0
[^>]*> eec8 0e03 	vmlsldav.s16	r0, r9, q4, q1
[^>]*> eec8 0e23 	vmlsldava.s16	r0, r9, q4, q1
[^>]*> eec8 1e03 	vmlsldavx.s16	r0, r9, q4, q1
[^>]*> eec8 1e23 	vmlsldavax.s16	r0, r9, q4, q1
[^>]*> eec8 0e05 	vmlsldav.s16	r0, r9, q4, q2
[^>]*> eec8 0e25 	vmlsldava.s16	r0, r9, q4, q2
[^>]*> eec8 1e05 	vmlsldavx.s16	r0, r9, q4, q2
[^>]*> eec8 1e25 	vmlsldavax.s16	r0, r9, q4, q2
[^>]*> eec8 0e09 	vmlsldav.s16	r0, r9, q4, q4
[^>]*> eec8 0e29 	vmlsldava.s16	r0, r9, q4, q4
[^>]*> eec8 1e09 	vmlsldavx.s16	r0, r9, q4, q4
[^>]*> eec8 1e29 	vmlsldavax.s16	r0, r9, q4, q4
[^>]*> eec8 0e0f 	vmlsldav.s16	r0, r9, q4, q7
[^>]*> eec8 0e2f 	vmlsldava.s16	r0, r9, q4, q7
[^>]*> eec8 1e0f 	vmlsldavx.s16	r0, r9, q4, q7
[^>]*> eec8 1e2f 	vmlsldavax.s16	r0, r9, q4, q7
[^>]*> eece 0e01 	vmlsldav.s16	r0, r9, q7, q0
[^>]*> eece 0e21 	vmlsldava.s16	r0, r9, q7, q0
[^>]*> eece 1e01 	vmlsldavx.s16	r0, r9, q7, q0
[^>]*> eece 1e21 	vmlsldavax.s16	r0, r9, q7, q0
[^>]*> eece 0e03 	vmlsldav.s16	r0, r9, q7, q1
[^>]*> eece 0e23 	vmlsldava.s16	r0, r9, q7, q1
[^>]*> eece 1e03 	vmlsldavx.s16	r0, r9, q7, q1
[^>]*> eece 1e23 	vmlsldavax.s16	r0, r9, q7, q1
[^>]*> eece 0e05 	vmlsldav.s16	r0, r9, q7, q2
[^>]*> eece 0e25 	vmlsldava.s16	r0, r9, q7, q2
[^>]*> eece 1e05 	vmlsldavx.s16	r0, r9, q7, q2
[^>]*> eece 1e25 	vmlsldavax.s16	r0, r9, q7, q2
[^>]*> eece 0e09 	vmlsldav.s16	r0, r9, q7, q4
[^>]*> eece 0e29 	vmlsldava.s16	r0, r9, q7, q4
[^>]*> eece 1e09 	vmlsldavx.s16	r0, r9, q7, q4
[^>]*> eece 1e29 	vmlsldavax.s16	r0, r9, q7, q4
[^>]*> eece 0e0f 	vmlsldav.s16	r0, r9, q7, q7
[^>]*> eece 0e2f 	vmlsldava.s16	r0, r9, q7, q7
[^>]*> eece 1e0f 	vmlsldavx.s16	r0, r9, q7, q7
[^>]*> eece 1e2f 	vmlsldavax.s16	r0, r9, q7, q7
[^>]*> eed0 0e01 	vmlsldav.s16	r0, fp, q0, q0
[^>]*> eed0 0e21 	vmlsldava.s16	r0, fp, q0, q0
[^>]*> eed0 1e01 	vmlsldavx.s16	r0, fp, q0, q0
[^>]*> eed0 1e21 	vmlsldavax.s16	r0, fp, q0, q0
[^>]*> eed0 0e03 	vmlsldav.s16	r0, fp, q0, q1
[^>]*> eed0 0e23 	vmlsldava.s16	r0, fp, q0, q1
[^>]*> eed0 1e03 	vmlsldavx.s16	r0, fp, q0, q1
[^>]*> eed0 1e23 	vmlsldavax.s16	r0, fp, q0, q1
[^>]*> eed0 0e05 	vmlsldav.s16	r0, fp, q0, q2
[^>]*> eed0 0e25 	vmlsldava.s16	r0, fp, q0, q2
[^>]*> eed0 1e05 	vmlsldavx.s16	r0, fp, q0, q2
[^>]*> eed0 1e25 	vmlsldavax.s16	r0, fp, q0, q2
[^>]*> eed0 0e09 	vmlsldav.s16	r0, fp, q0, q4
[^>]*> eed0 0e29 	vmlsldava.s16	r0, fp, q0, q4
[^>]*> eed0 1e09 	vmlsldavx.s16	r0, fp, q0, q4
[^>]*> eed0 1e29 	vmlsldavax.s16	r0, fp, q0, q4
[^>]*> eed0 0e0f 	vmlsldav.s16	r0, fp, q0, q7
[^>]*> eed0 0e2f 	vmlsldava.s16	r0, fp, q0, q7
[^>]*> eed0 1e0f 	vmlsldavx.s16	r0, fp, q0, q7
[^>]*> eed0 1e2f 	vmlsldavax.s16	r0, fp, q0, q7
[^>]*> eed2 0e01 	vmlsldav.s16	r0, fp, q1, q0
[^>]*> eed2 0e21 	vmlsldava.s16	r0, fp, q1, q0
[^>]*> eed2 1e01 	vmlsldavx.s16	r0, fp, q1, q0
[^>]*> eed2 1e21 	vmlsldavax.s16	r0, fp, q1, q0
[^>]*> eed2 0e03 	vmlsldav.s16	r0, fp, q1, q1
[^>]*> eed2 0e23 	vmlsldava.s16	r0, fp, q1, q1
[^>]*> eed2 1e03 	vmlsldavx.s16	r0, fp, q1, q1
[^>]*> eed2 1e23 	vmlsldavax.s16	r0, fp, q1, q1
[^>]*> eed2 0e05 	vmlsldav.s16	r0, fp, q1, q2
[^>]*> eed2 0e25 	vmlsldava.s16	r0, fp, q1, q2
[^>]*> eed2 1e05 	vmlsldavx.s16	r0, fp, q1, q2
[^>]*> eed2 1e25 	vmlsldavax.s16	r0, fp, q1, q2
[^>]*> eed2 0e09 	vmlsldav.s16	r0, fp, q1, q4
[^>]*> eed2 0e29 	vmlsldava.s16	r0, fp, q1, q4
[^>]*> eed2 1e09 	vmlsldavx.s16	r0, fp, q1, q4
[^>]*> eed2 1e29 	vmlsldavax.s16	r0, fp, q1, q4
[^>]*> eed2 0e0f 	vmlsldav.s16	r0, fp, q1, q7
[^>]*> eed2 0e2f 	vmlsldava.s16	r0, fp, q1, q7
[^>]*> eed2 1e0f 	vmlsldavx.s16	r0, fp, q1, q7
[^>]*> eed2 1e2f 	vmlsldavax.s16	r0, fp, q1, q7
[^>]*> eed4 0e01 	vmlsldav.s16	r0, fp, q2, q0
[^>]*> eed4 0e21 	vmlsldava.s16	r0, fp, q2, q0
[^>]*> eed4 1e01 	vmlsldavx.s16	r0, fp, q2, q0
[^>]*> eed4 1e21 	vmlsldavax.s16	r0, fp, q2, q0
[^>]*> eed4 0e03 	vmlsldav.s16	r0, fp, q2, q1
[^>]*> eed4 0e23 	vmlsldava.s16	r0, fp, q2, q1
[^>]*> eed4 1e03 	vmlsldavx.s16	r0, fp, q2, q1
[^>]*> eed4 1e23 	vmlsldavax.s16	r0, fp, q2, q1
[^>]*> eed4 0e05 	vmlsldav.s16	r0, fp, q2, q2
[^>]*> eed4 0e25 	vmlsldava.s16	r0, fp, q2, q2
[^>]*> eed4 1e05 	vmlsldavx.s16	r0, fp, q2, q2
[^>]*> eed4 1e25 	vmlsldavax.s16	r0, fp, q2, q2
[^>]*> eed4 0e09 	vmlsldav.s16	r0, fp, q2, q4
[^>]*> eed4 0e29 	vmlsldava.s16	r0, fp, q2, q4
[^>]*> eed4 1e09 	vmlsldavx.s16	r0, fp, q2, q4
[^>]*> eed4 1e29 	vmlsldavax.s16	r0, fp, q2, q4
[^>]*> eed4 0e0f 	vmlsldav.s16	r0, fp, q2, q7
[^>]*> eed4 0e2f 	vmlsldava.s16	r0, fp, q2, q7
[^>]*> eed4 1e0f 	vmlsldavx.s16	r0, fp, q2, q7
[^>]*> eed4 1e2f 	vmlsldavax.s16	r0, fp, q2, q7
[^>]*> eed8 0e01 	vmlsldav.s16	r0, fp, q4, q0
[^>]*> eed8 0e21 	vmlsldava.s16	r0, fp, q4, q0
[^>]*> eed8 1e01 	vmlsldavx.s16	r0, fp, q4, q0
[^>]*> eed8 1e21 	vmlsldavax.s16	r0, fp, q4, q0
[^>]*> eed8 0e03 	vmlsldav.s16	r0, fp, q4, q1
[^>]*> eed8 0e23 	vmlsldava.s16	r0, fp, q4, q1
[^>]*> eed8 1e03 	vmlsldavx.s16	r0, fp, q4, q1
[^>]*> eed8 1e23 	vmlsldavax.s16	r0, fp, q4, q1
[^>]*> eed8 0e05 	vmlsldav.s16	r0, fp, q4, q2
[^>]*> eed8 0e25 	vmlsldava.s16	r0, fp, q4, q2
[^>]*> eed8 1e05 	vmlsldavx.s16	r0, fp, q4, q2
[^>]*> eed8 1e25 	vmlsldavax.s16	r0, fp, q4, q2
[^>]*> eed8 0e09 	vmlsldav.s16	r0, fp, q4, q4
[^>]*> eed8 0e29 	vmlsldava.s16	r0, fp, q4, q4
[^>]*> eed8 1e09 	vmlsldavx.s16	r0, fp, q4, q4
[^>]*> eed8 1e29 	vmlsldavax.s16	r0, fp, q4, q4
[^>]*> eed8 0e0f 	vmlsldav.s16	r0, fp, q4, q7
[^>]*> eed8 0e2f 	vmlsldava.s16	r0, fp, q4, q7
[^>]*> eed8 1e0f 	vmlsldavx.s16	r0, fp, q4, q7
[^>]*> eed8 1e2f 	vmlsldavax.s16	r0, fp, q4, q7
[^>]*> eede 0e01 	vmlsldav.s16	r0, fp, q7, q0
[^>]*> eede 0e21 	vmlsldava.s16	r0, fp, q7, q0
[^>]*> eede 1e01 	vmlsldavx.s16	r0, fp, q7, q0
[^>]*> eede 1e21 	vmlsldavax.s16	r0, fp, q7, q0
[^>]*> eede 0e03 	vmlsldav.s16	r0, fp, q7, q1
[^>]*> eede 0e23 	vmlsldava.s16	r0, fp, q7, q1
[^>]*> eede 1e03 	vmlsldavx.s16	r0, fp, q7, q1
[^>]*> eede 1e23 	vmlsldavax.s16	r0, fp, q7, q1
[^>]*> eede 0e05 	vmlsldav.s16	r0, fp, q7, q2
[^>]*> eede 0e25 	vmlsldava.s16	r0, fp, q7, q2
[^>]*> eede 1e05 	vmlsldavx.s16	r0, fp, q7, q2
[^>]*> eede 1e25 	vmlsldavax.s16	r0, fp, q7, q2
[^>]*> eede 0e09 	vmlsldav.s16	r0, fp, q7, q4
[^>]*> eede 0e29 	vmlsldava.s16	r0, fp, q7, q4
[^>]*> eede 1e09 	vmlsldavx.s16	r0, fp, q7, q4
[^>]*> eede 1e29 	vmlsldavax.s16	r0, fp, q7, q4
[^>]*> eede 0e0f 	vmlsldav.s16	r0, fp, q7, q7
[^>]*> eede 0e2f 	vmlsldava.s16	r0, fp, q7, q7
[^>]*> eede 1e0f 	vmlsldavx.s16	r0, fp, q7, q7
[^>]*> eede 1e2f 	vmlsldavax.s16	r0, fp, q7, q7
[^>]*> ee80 2e01 	vmlsldav.s16	r2, r1, q0, q0
[^>]*> ee80 2e21 	vmlsldava.s16	r2, r1, q0, q0
[^>]*> ee80 3e01 	vmlsldavx.s16	r2, r1, q0, q0
[^>]*> ee80 3e21 	vmlsldavax.s16	r2, r1, q0, q0
[^>]*> ee80 2e03 	vmlsldav.s16	r2, r1, q0, q1
[^>]*> ee80 2e23 	vmlsldava.s16	r2, r1, q0, q1
[^>]*> ee80 3e03 	vmlsldavx.s16	r2, r1, q0, q1
[^>]*> ee80 3e23 	vmlsldavax.s16	r2, r1, q0, q1
[^>]*> ee80 2e05 	vmlsldav.s16	r2, r1, q0, q2
[^>]*> ee80 2e25 	vmlsldava.s16	r2, r1, q0, q2
[^>]*> ee80 3e05 	vmlsldavx.s16	r2, r1, q0, q2
[^>]*> ee80 3e25 	vmlsldavax.s16	r2, r1, q0, q2
[^>]*> ee80 2e09 	vmlsldav.s16	r2, r1, q0, q4
[^>]*> ee80 2e29 	vmlsldava.s16	r2, r1, q0, q4
[^>]*> ee80 3e09 	vmlsldavx.s16	r2, r1, q0, q4
[^>]*> ee80 3e29 	vmlsldavax.s16	r2, r1, q0, q4
[^>]*> ee80 2e0f 	vmlsldav.s16	r2, r1, q0, q7
[^>]*> ee80 2e2f 	vmlsldava.s16	r2, r1, q0, q7
[^>]*> ee80 3e0f 	vmlsldavx.s16	r2, r1, q0, q7
[^>]*> ee80 3e2f 	vmlsldavax.s16	r2, r1, q0, q7
[^>]*> ee82 2e01 	vmlsldav.s16	r2, r1, q1, q0
[^>]*> ee82 2e21 	vmlsldava.s16	r2, r1, q1, q0
[^>]*> ee82 3e01 	vmlsldavx.s16	r2, r1, q1, q0
[^>]*> ee82 3e21 	vmlsldavax.s16	r2, r1, q1, q0
[^>]*> ee82 2e03 	vmlsldav.s16	r2, r1, q1, q1
[^>]*> ee82 2e23 	vmlsldava.s16	r2, r1, q1, q1
[^>]*> ee82 3e03 	vmlsldavx.s16	r2, r1, q1, q1
[^>]*> ee82 3e23 	vmlsldavax.s16	r2, r1, q1, q1
[^>]*> ee82 2e05 	vmlsldav.s16	r2, r1, q1, q2
[^>]*> ee82 2e25 	vmlsldava.s16	r2, r1, q1, q2
[^>]*> ee82 3e05 	vmlsldavx.s16	r2, r1, q1, q2
[^>]*> ee82 3e25 	vmlsldavax.s16	r2, r1, q1, q2
[^>]*> ee82 2e09 	vmlsldav.s16	r2, r1, q1, q4
[^>]*> ee82 2e29 	vmlsldava.s16	r2, r1, q1, q4
[^>]*> ee82 3e09 	vmlsldavx.s16	r2, r1, q1, q4
[^>]*> ee82 3e29 	vmlsldavax.s16	r2, r1, q1, q4
[^>]*> ee82 2e0f 	vmlsldav.s16	r2, r1, q1, q7
[^>]*> ee82 2e2f 	vmlsldava.s16	r2, r1, q1, q7
[^>]*> ee82 3e0f 	vmlsldavx.s16	r2, r1, q1, q7
[^>]*> ee82 3e2f 	vmlsldavax.s16	r2, r1, q1, q7
[^>]*> ee84 2e01 	vmlsldav.s16	r2, r1, q2, q0
[^>]*> ee84 2e21 	vmlsldava.s16	r2, r1, q2, q0
[^>]*> ee84 3e01 	vmlsldavx.s16	r2, r1, q2, q0
[^>]*> ee84 3e21 	vmlsldavax.s16	r2, r1, q2, q0
[^>]*> ee84 2e03 	vmlsldav.s16	r2, r1, q2, q1
[^>]*> ee84 2e23 	vmlsldava.s16	r2, r1, q2, q1
[^>]*> ee84 3e03 	vmlsldavx.s16	r2, r1, q2, q1
[^>]*> ee84 3e23 	vmlsldavax.s16	r2, r1, q2, q1
[^>]*> ee84 2e05 	vmlsldav.s16	r2, r1, q2, q2
[^>]*> ee84 2e25 	vmlsldava.s16	r2, r1, q2, q2
[^>]*> ee84 3e05 	vmlsldavx.s16	r2, r1, q2, q2
[^>]*> ee84 3e25 	vmlsldavax.s16	r2, r1, q2, q2
[^>]*> ee84 2e09 	vmlsldav.s16	r2, r1, q2, q4
[^>]*> ee84 2e29 	vmlsldava.s16	r2, r1, q2, q4
[^>]*> ee84 3e09 	vmlsldavx.s16	r2, r1, q2, q4
[^>]*> ee84 3e29 	vmlsldavax.s16	r2, r1, q2, q4
[^>]*> ee84 2e0f 	vmlsldav.s16	r2, r1, q2, q7
[^>]*> ee84 2e2f 	vmlsldava.s16	r2, r1, q2, q7
[^>]*> ee84 3e0f 	vmlsldavx.s16	r2, r1, q2, q7
[^>]*> ee84 3e2f 	vmlsldavax.s16	r2, r1, q2, q7
[^>]*> ee88 2e01 	vmlsldav.s16	r2, r1, q4, q0
[^>]*> ee88 2e21 	vmlsldava.s16	r2, r1, q4, q0
[^>]*> ee88 3e01 	vmlsldavx.s16	r2, r1, q4, q0
[^>]*> ee88 3e21 	vmlsldavax.s16	r2, r1, q4, q0
[^>]*> ee88 2e03 	vmlsldav.s16	r2, r1, q4, q1
[^>]*> ee88 2e23 	vmlsldava.s16	r2, r1, q4, q1
[^>]*> ee88 3e03 	vmlsldavx.s16	r2, r1, q4, q1
[^>]*> ee88 3e23 	vmlsldavax.s16	r2, r1, q4, q1
[^>]*> ee88 2e05 	vmlsldav.s16	r2, r1, q4, q2
[^>]*> ee88 2e25 	vmlsldava.s16	r2, r1, q4, q2
[^>]*> ee88 3e05 	vmlsldavx.s16	r2, r1, q4, q2
[^>]*> ee88 3e25 	vmlsldavax.s16	r2, r1, q4, q2
[^>]*> ee88 2e09 	vmlsldav.s16	r2, r1, q4, q4
[^>]*> ee88 2e29 	vmlsldava.s16	r2, r1, q4, q4
[^>]*> ee88 3e09 	vmlsldavx.s16	r2, r1, q4, q4
[^>]*> ee88 3e29 	vmlsldavax.s16	r2, r1, q4, q4
[^>]*> ee88 2e0f 	vmlsldav.s16	r2, r1, q4, q7
[^>]*> ee88 2e2f 	vmlsldava.s16	r2, r1, q4, q7
[^>]*> ee88 3e0f 	vmlsldavx.s16	r2, r1, q4, q7
[^>]*> ee88 3e2f 	vmlsldavax.s16	r2, r1, q4, q7
[^>]*> ee8e 2e01 	vmlsldav.s16	r2, r1, q7, q0
[^>]*> ee8e 2e21 	vmlsldava.s16	r2, r1, q7, q0
[^>]*> ee8e 3e01 	vmlsldavx.s16	r2, r1, q7, q0
[^>]*> ee8e 3e21 	vmlsldavax.s16	r2, r1, q7, q0
[^>]*> ee8e 2e03 	vmlsldav.s16	r2, r1, q7, q1
[^>]*> ee8e 2e23 	vmlsldava.s16	r2, r1, q7, q1
[^>]*> ee8e 3e03 	vmlsldavx.s16	r2, r1, q7, q1
[^>]*> ee8e 3e23 	vmlsldavax.s16	r2, r1, q7, q1
[^>]*> ee8e 2e05 	vmlsldav.s16	r2, r1, q7, q2
[^>]*> ee8e 2e25 	vmlsldava.s16	r2, r1, q7, q2
[^>]*> ee8e 3e05 	vmlsldavx.s16	r2, r1, q7, q2
[^>]*> ee8e 3e25 	vmlsldavax.s16	r2, r1, q7, q2
[^>]*> ee8e 2e09 	vmlsldav.s16	r2, r1, q7, q4
[^>]*> ee8e 2e29 	vmlsldava.s16	r2, r1, q7, q4
[^>]*> ee8e 3e09 	vmlsldavx.s16	r2, r1, q7, q4
[^>]*> ee8e 3e29 	vmlsldavax.s16	r2, r1, q7, q4
[^>]*> ee8e 2e0f 	vmlsldav.s16	r2, r1, q7, q7
[^>]*> ee8e 2e2f 	vmlsldava.s16	r2, r1, q7, q7
[^>]*> ee8e 3e0f 	vmlsldavx.s16	r2, r1, q7, q7
[^>]*> ee8e 3e2f 	vmlsldavax.s16	r2, r1, q7, q7
[^>]*> ee90 2e01 	vmlsldav.s16	r2, r3, q0, q0
[^>]*> ee90 2e21 	vmlsldava.s16	r2, r3, q0, q0
[^>]*> ee90 3e01 	vmlsldavx.s16	r2, r3, q0, q0
[^>]*> ee90 3e21 	vmlsldavax.s16	r2, r3, q0, q0
[^>]*> ee90 2e03 	vmlsldav.s16	r2, r3, q0, q1
[^>]*> ee90 2e23 	vmlsldava.s16	r2, r3, q0, q1
[^>]*> ee90 3e03 	vmlsldavx.s16	r2, r3, q0, q1
[^>]*> ee90 3e23 	vmlsldavax.s16	r2, r3, q0, q1
[^>]*> ee90 2e05 	vmlsldav.s16	r2, r3, q0, q2
[^>]*> ee90 2e25 	vmlsldava.s16	r2, r3, q0, q2
[^>]*> ee90 3e05 	vmlsldavx.s16	r2, r3, q0, q2
[^>]*> ee90 3e25 	vmlsldavax.s16	r2, r3, q0, q2
[^>]*> ee90 2e09 	vmlsldav.s16	r2, r3, q0, q4
[^>]*> ee90 2e29 	vmlsldava.s16	r2, r3, q0, q4
[^>]*> ee90 3e09 	vmlsldavx.s16	r2, r3, q0, q4
[^>]*> ee90 3e29 	vmlsldavax.s16	r2, r3, q0, q4
[^>]*> ee90 2e0f 	vmlsldav.s16	r2, r3, q0, q7
[^>]*> ee90 2e2f 	vmlsldava.s16	r2, r3, q0, q7
[^>]*> ee90 3e0f 	vmlsldavx.s16	r2, r3, q0, q7
[^>]*> ee90 3e2f 	vmlsldavax.s16	r2, r3, q0, q7
[^>]*> ee92 2e01 	vmlsldav.s16	r2, r3, q1, q0
[^>]*> ee92 2e21 	vmlsldava.s16	r2, r3, q1, q0
[^>]*> ee92 3e01 	vmlsldavx.s16	r2, r3, q1, q0
[^>]*> ee92 3e21 	vmlsldavax.s16	r2, r3, q1, q0
[^>]*> ee92 2e03 	vmlsldav.s16	r2, r3, q1, q1
[^>]*> ee92 2e23 	vmlsldava.s16	r2, r3, q1, q1
[^>]*> ee92 3e03 	vmlsldavx.s16	r2, r3, q1, q1
[^>]*> ee92 3e23 	vmlsldavax.s16	r2, r3, q1, q1
[^>]*> ee92 2e05 	vmlsldav.s16	r2, r3, q1, q2
[^>]*> ee92 2e25 	vmlsldava.s16	r2, r3, q1, q2
[^>]*> ee92 3e05 	vmlsldavx.s16	r2, r3, q1, q2
[^>]*> ee92 3e25 	vmlsldavax.s16	r2, r3, q1, q2
[^>]*> ee92 2e09 	vmlsldav.s16	r2, r3, q1, q4
[^>]*> ee92 2e29 	vmlsldava.s16	r2, r3, q1, q4
[^>]*> ee92 3e09 	vmlsldavx.s16	r2, r3, q1, q4
[^>]*> ee92 3e29 	vmlsldavax.s16	r2, r3, q1, q4
[^>]*> ee92 2e0f 	vmlsldav.s16	r2, r3, q1, q7
[^>]*> ee92 2e2f 	vmlsldava.s16	r2, r3, q1, q7
[^>]*> ee92 3e0f 	vmlsldavx.s16	r2, r3, q1, q7
[^>]*> ee92 3e2f 	vmlsldavax.s16	r2, r3, q1, q7
[^>]*> ee94 2e01 	vmlsldav.s16	r2, r3, q2, q0
[^>]*> ee94 2e21 	vmlsldava.s16	r2, r3, q2, q0
[^>]*> ee94 3e01 	vmlsldavx.s16	r2, r3, q2, q0
[^>]*> ee94 3e21 	vmlsldavax.s16	r2, r3, q2, q0
[^>]*> ee94 2e03 	vmlsldav.s16	r2, r3, q2, q1
[^>]*> ee94 2e23 	vmlsldava.s16	r2, r3, q2, q1
[^>]*> ee94 3e03 	vmlsldavx.s16	r2, r3, q2, q1
[^>]*> ee94 3e23 	vmlsldavax.s16	r2, r3, q2, q1
[^>]*> ee94 2e05 	vmlsldav.s16	r2, r3, q2, q2
[^>]*> ee94 2e25 	vmlsldava.s16	r2, r3, q2, q2
[^>]*> ee94 3e05 	vmlsldavx.s16	r2, r3, q2, q2
[^>]*> ee94 3e25 	vmlsldavax.s16	r2, r3, q2, q2
[^>]*> ee94 2e09 	vmlsldav.s16	r2, r3, q2, q4
[^>]*> ee94 2e29 	vmlsldava.s16	r2, r3, q2, q4
[^>]*> ee94 3e09 	vmlsldavx.s16	r2, r3, q2, q4
[^>]*> ee94 3e29 	vmlsldavax.s16	r2, r3, q2, q4
[^>]*> ee94 2e0f 	vmlsldav.s16	r2, r3, q2, q7
[^>]*> ee94 2e2f 	vmlsldava.s16	r2, r3, q2, q7
[^>]*> ee94 3e0f 	vmlsldavx.s16	r2, r3, q2, q7
[^>]*> ee94 3e2f 	vmlsldavax.s16	r2, r3, q2, q7
[^>]*> ee98 2e01 	vmlsldav.s16	r2, r3, q4, q0
[^>]*> ee98 2e21 	vmlsldava.s16	r2, r3, q4, q0
[^>]*> ee98 3e01 	vmlsldavx.s16	r2, r3, q4, q0
[^>]*> ee98 3e21 	vmlsldavax.s16	r2, r3, q4, q0
[^>]*> ee98 2e03 	vmlsldav.s16	r2, r3, q4, q1
[^>]*> ee98 2e23 	vmlsldava.s16	r2, r3, q4, q1
[^>]*> ee98 3e03 	vmlsldavx.s16	r2, r3, q4, q1
[^>]*> ee98 3e23 	vmlsldavax.s16	r2, r3, q4, q1
[^>]*> ee98 2e05 	vmlsldav.s16	r2, r3, q4, q2
[^>]*> ee98 2e25 	vmlsldava.s16	r2, r3, q4, q2
[^>]*> ee98 3e05 	vmlsldavx.s16	r2, r3, q4, q2
[^>]*> ee98 3e25 	vmlsldavax.s16	r2, r3, q4, q2
[^>]*> ee98 2e09 	vmlsldav.s16	r2, r3, q4, q4
[^>]*> ee98 2e29 	vmlsldava.s16	r2, r3, q4, q4
[^>]*> ee98 3e09 	vmlsldavx.s16	r2, r3, q4, q4
[^>]*> ee98 3e29 	vmlsldavax.s16	r2, r3, q4, q4
[^>]*> ee98 2e0f 	vmlsldav.s16	r2, r3, q4, q7
[^>]*> ee98 2e2f 	vmlsldava.s16	r2, r3, q4, q7
[^>]*> ee98 3e0f 	vmlsldavx.s16	r2, r3, q4, q7
[^>]*> ee98 3e2f 	vmlsldavax.s16	r2, r3, q4, q7
[^>]*> ee9e 2e01 	vmlsldav.s16	r2, r3, q7, q0
[^>]*> ee9e 2e21 	vmlsldava.s16	r2, r3, q7, q0
[^>]*> ee9e 3e01 	vmlsldavx.s16	r2, r3, q7, q0
[^>]*> ee9e 3e21 	vmlsldavax.s16	r2, r3, q7, q0
[^>]*> ee9e 2e03 	vmlsldav.s16	r2, r3, q7, q1
[^>]*> ee9e 2e23 	vmlsldava.s16	r2, r3, q7, q1
[^>]*> ee9e 3e03 	vmlsldavx.s16	r2, r3, q7, q1
[^>]*> ee9e 3e23 	vmlsldavax.s16	r2, r3, q7, q1
[^>]*> ee9e 2e05 	vmlsldav.s16	r2, r3, q7, q2
[^>]*> ee9e 2e25 	vmlsldava.s16	r2, r3, q7, q2
[^>]*> ee9e 3e05 	vmlsldavx.s16	r2, r3, q7, q2
[^>]*> ee9e 3e25 	vmlsldavax.s16	r2, r3, q7, q2
[^>]*> ee9e 2e09 	vmlsldav.s16	r2, r3, q7, q4
[^>]*> ee9e 2e29 	vmlsldava.s16	r2, r3, q7, q4
[^>]*> ee9e 3e09 	vmlsldavx.s16	r2, r3, q7, q4
[^>]*> ee9e 3e29 	vmlsldavax.s16	r2, r3, q7, q4
[^>]*> ee9e 2e0f 	vmlsldav.s16	r2, r3, q7, q7
[^>]*> ee9e 2e2f 	vmlsldava.s16	r2, r3, q7, q7
[^>]*> ee9e 3e0f 	vmlsldavx.s16	r2, r3, q7, q7
[^>]*> ee9e 3e2f 	vmlsldavax.s16	r2, r3, q7, q7
[^>]*> eea0 2e01 	vmlsldav.s16	r2, r5, q0, q0
[^>]*> eea0 2e21 	vmlsldava.s16	r2, r5, q0, q0
[^>]*> eea0 3e01 	vmlsldavx.s16	r2, r5, q0, q0
[^>]*> eea0 3e21 	vmlsldavax.s16	r2, r5, q0, q0
[^>]*> eea0 2e03 	vmlsldav.s16	r2, r5, q0, q1
[^>]*> eea0 2e23 	vmlsldava.s16	r2, r5, q0, q1
[^>]*> eea0 3e03 	vmlsldavx.s16	r2, r5, q0, q1
[^>]*> eea0 3e23 	vmlsldavax.s16	r2, r5, q0, q1
[^>]*> eea0 2e05 	vmlsldav.s16	r2, r5, q0, q2
[^>]*> eea0 2e25 	vmlsldava.s16	r2, r5, q0, q2
[^>]*> eea0 3e05 	vmlsldavx.s16	r2, r5, q0, q2
[^>]*> eea0 3e25 	vmlsldavax.s16	r2, r5, q0, q2
[^>]*> eea0 2e09 	vmlsldav.s16	r2, r5, q0, q4
[^>]*> eea0 2e29 	vmlsldava.s16	r2, r5, q0, q4
[^>]*> eea0 3e09 	vmlsldavx.s16	r2, r5, q0, q4
[^>]*> eea0 3e29 	vmlsldavax.s16	r2, r5, q0, q4
[^>]*> eea0 2e0f 	vmlsldav.s16	r2, r5, q0, q7
[^>]*> eea0 2e2f 	vmlsldava.s16	r2, r5, q0, q7
[^>]*> eea0 3e0f 	vmlsldavx.s16	r2, r5, q0, q7
[^>]*> eea0 3e2f 	vmlsldavax.s16	r2, r5, q0, q7
[^>]*> eea2 2e01 	vmlsldav.s16	r2, r5, q1, q0
[^>]*> eea2 2e21 	vmlsldava.s16	r2, r5, q1, q0
[^>]*> eea2 3e01 	vmlsldavx.s16	r2, r5, q1, q0
[^>]*> eea2 3e21 	vmlsldavax.s16	r2, r5, q1, q0
[^>]*> eea2 2e03 	vmlsldav.s16	r2, r5, q1, q1
[^>]*> eea2 2e23 	vmlsldava.s16	r2, r5, q1, q1
[^>]*> eea2 3e03 	vmlsldavx.s16	r2, r5, q1, q1
[^>]*> eea2 3e23 	vmlsldavax.s16	r2, r5, q1, q1
[^>]*> eea2 2e05 	vmlsldav.s16	r2, r5, q1, q2
[^>]*> eea2 2e25 	vmlsldava.s16	r2, r5, q1, q2
[^>]*> eea2 3e05 	vmlsldavx.s16	r2, r5, q1, q2
[^>]*> eea2 3e25 	vmlsldavax.s16	r2, r5, q1, q2
[^>]*> eea2 2e09 	vmlsldav.s16	r2, r5, q1, q4
[^>]*> eea2 2e29 	vmlsldava.s16	r2, r5, q1, q4
[^>]*> eea2 3e09 	vmlsldavx.s16	r2, r5, q1, q4
[^>]*> eea2 3e29 	vmlsldavax.s16	r2, r5, q1, q4
[^>]*> eea2 2e0f 	vmlsldav.s16	r2, r5, q1, q7
[^>]*> eea2 2e2f 	vmlsldava.s16	r2, r5, q1, q7
[^>]*> eea2 3e0f 	vmlsldavx.s16	r2, r5, q1, q7
[^>]*> eea2 3e2f 	vmlsldavax.s16	r2, r5, q1, q7
[^>]*> eea4 2e01 	vmlsldav.s16	r2, r5, q2, q0
[^>]*> eea4 2e21 	vmlsldava.s16	r2, r5, q2, q0
[^>]*> eea4 3e01 	vmlsldavx.s16	r2, r5, q2, q0
[^>]*> eea4 3e21 	vmlsldavax.s16	r2, r5, q2, q0
[^>]*> eea4 2e03 	vmlsldav.s16	r2, r5, q2, q1
[^>]*> eea4 2e23 	vmlsldava.s16	r2, r5, q2, q1
[^>]*> eea4 3e03 	vmlsldavx.s16	r2, r5, q2, q1
[^>]*> eea4 3e23 	vmlsldavax.s16	r2, r5, q2, q1
[^>]*> eea4 2e05 	vmlsldav.s16	r2, r5, q2, q2
[^>]*> eea4 2e25 	vmlsldava.s16	r2, r5, q2, q2
[^>]*> eea4 3e05 	vmlsldavx.s16	r2, r5, q2, q2
[^>]*> eea4 3e25 	vmlsldavax.s16	r2, r5, q2, q2
[^>]*> eea4 2e09 	vmlsldav.s16	r2, r5, q2, q4
[^>]*> eea4 2e29 	vmlsldava.s16	r2, r5, q2, q4
[^>]*> eea4 3e09 	vmlsldavx.s16	r2, r5, q2, q4
[^>]*> eea4 3e29 	vmlsldavax.s16	r2, r5, q2, q4
[^>]*> eea4 2e0f 	vmlsldav.s16	r2, r5, q2, q7
[^>]*> eea4 2e2f 	vmlsldava.s16	r2, r5, q2, q7
[^>]*> eea4 3e0f 	vmlsldavx.s16	r2, r5, q2, q7
[^>]*> eea4 3e2f 	vmlsldavax.s16	r2, r5, q2, q7
[^>]*> eea8 2e01 	vmlsldav.s16	r2, r5, q4, q0
[^>]*> eea8 2e21 	vmlsldava.s16	r2, r5, q4, q0
[^>]*> eea8 3e01 	vmlsldavx.s16	r2, r5, q4, q0
[^>]*> eea8 3e21 	vmlsldavax.s16	r2, r5, q4, q0
[^>]*> eea8 2e03 	vmlsldav.s16	r2, r5, q4, q1
[^>]*> eea8 2e23 	vmlsldava.s16	r2, r5, q4, q1
[^>]*> eea8 3e03 	vmlsldavx.s16	r2, r5, q4, q1
[^>]*> eea8 3e23 	vmlsldavax.s16	r2, r5, q4, q1
[^>]*> eea8 2e05 	vmlsldav.s16	r2, r5, q4, q2
[^>]*> eea8 2e25 	vmlsldava.s16	r2, r5, q4, q2
[^>]*> eea8 3e05 	vmlsldavx.s16	r2, r5, q4, q2
[^>]*> eea8 3e25 	vmlsldavax.s16	r2, r5, q4, q2
[^>]*> eea8 2e09 	vmlsldav.s16	r2, r5, q4, q4
[^>]*> eea8 2e29 	vmlsldava.s16	r2, r5, q4, q4
[^>]*> eea8 3e09 	vmlsldavx.s16	r2, r5, q4, q4
[^>]*> eea8 3e29 	vmlsldavax.s16	r2, r5, q4, q4
[^>]*> eea8 2e0f 	vmlsldav.s16	r2, r5, q4, q7
[^>]*> eea8 2e2f 	vmlsldava.s16	r2, r5, q4, q7
[^>]*> eea8 3e0f 	vmlsldavx.s16	r2, r5, q4, q7
[^>]*> eea8 3e2f 	vmlsldavax.s16	r2, r5, q4, q7
[^>]*> eeae 2e01 	vmlsldav.s16	r2, r5, q7, q0
[^>]*> eeae 2e21 	vmlsldava.s16	r2, r5, q7, q0
[^>]*> eeae 3e01 	vmlsldavx.s16	r2, r5, q7, q0
[^>]*> eeae 3e21 	vmlsldavax.s16	r2, r5, q7, q0
[^>]*> eeae 2e03 	vmlsldav.s16	r2, r5, q7, q1
[^>]*> eeae 2e23 	vmlsldava.s16	r2, r5, q7, q1
[^>]*> eeae 3e03 	vmlsldavx.s16	r2, r5, q7, q1
[^>]*> eeae 3e23 	vmlsldavax.s16	r2, r5, q7, q1
[^>]*> eeae 2e05 	vmlsldav.s16	r2, r5, q7, q2
[^>]*> eeae 2e25 	vmlsldava.s16	r2, r5, q7, q2
[^>]*> eeae 3e05 	vmlsldavx.s16	r2, r5, q7, q2
[^>]*> eeae 3e25 	vmlsldavax.s16	r2, r5, q7, q2
[^>]*> eeae 2e09 	vmlsldav.s16	r2, r5, q7, q4
[^>]*> eeae 2e29 	vmlsldava.s16	r2, r5, q7, q4
[^>]*> eeae 3e09 	vmlsldavx.s16	r2, r5, q7, q4
[^>]*> eeae 3e29 	vmlsldavax.s16	r2, r5, q7, q4
[^>]*> eeae 2e0f 	vmlsldav.s16	r2, r5, q7, q7
[^>]*> eeae 2e2f 	vmlsldava.s16	r2, r5, q7, q7
[^>]*> eeae 3e0f 	vmlsldavx.s16	r2, r5, q7, q7
[^>]*> eeae 3e2f 	vmlsldavax.s16	r2, r5, q7, q7
[^>]*> eeb0 2e01 	vmlsldav.s16	r2, r7, q0, q0
[^>]*> eeb0 2e21 	vmlsldava.s16	r2, r7, q0, q0
[^>]*> eeb0 3e01 	vmlsldavx.s16	r2, r7, q0, q0
[^>]*> eeb0 3e21 	vmlsldavax.s16	r2, r7, q0, q0
[^>]*> eeb0 2e03 	vmlsldav.s16	r2, r7, q0, q1
[^>]*> eeb0 2e23 	vmlsldava.s16	r2, r7, q0, q1
[^>]*> eeb0 3e03 	vmlsldavx.s16	r2, r7, q0, q1
[^>]*> eeb0 3e23 	vmlsldavax.s16	r2, r7, q0, q1
[^>]*> eeb0 2e05 	vmlsldav.s16	r2, r7, q0, q2
[^>]*> eeb0 2e25 	vmlsldava.s16	r2, r7, q0, q2
[^>]*> eeb0 3e05 	vmlsldavx.s16	r2, r7, q0, q2
[^>]*> eeb0 3e25 	vmlsldavax.s16	r2, r7, q0, q2
[^>]*> eeb0 2e09 	vmlsldav.s16	r2, r7, q0, q4
[^>]*> eeb0 2e29 	vmlsldava.s16	r2, r7, q0, q4
[^>]*> eeb0 3e09 	vmlsldavx.s16	r2, r7, q0, q4
[^>]*> eeb0 3e29 	vmlsldavax.s16	r2, r7, q0, q4
[^>]*> eeb0 2e0f 	vmlsldav.s16	r2, r7, q0, q7
[^>]*> eeb0 2e2f 	vmlsldava.s16	r2, r7, q0, q7
[^>]*> eeb0 3e0f 	vmlsldavx.s16	r2, r7, q0, q7
[^>]*> eeb0 3e2f 	vmlsldavax.s16	r2, r7, q0, q7
[^>]*> eeb2 2e01 	vmlsldav.s16	r2, r7, q1, q0
[^>]*> eeb2 2e21 	vmlsldava.s16	r2, r7, q1, q0
[^>]*> eeb2 3e01 	vmlsldavx.s16	r2, r7, q1, q0
[^>]*> eeb2 3e21 	vmlsldavax.s16	r2, r7, q1, q0
[^>]*> eeb2 2e03 	vmlsldav.s16	r2, r7, q1, q1
[^>]*> eeb2 2e23 	vmlsldava.s16	r2, r7, q1, q1
[^>]*> eeb2 3e03 	vmlsldavx.s16	r2, r7, q1, q1
[^>]*> eeb2 3e23 	vmlsldavax.s16	r2, r7, q1, q1
[^>]*> eeb2 2e05 	vmlsldav.s16	r2, r7, q1, q2
[^>]*> eeb2 2e25 	vmlsldava.s16	r2, r7, q1, q2
[^>]*> eeb2 3e05 	vmlsldavx.s16	r2, r7, q1, q2
[^>]*> eeb2 3e25 	vmlsldavax.s16	r2, r7, q1, q2
[^>]*> eeb2 2e09 	vmlsldav.s16	r2, r7, q1, q4
[^>]*> eeb2 2e29 	vmlsldava.s16	r2, r7, q1, q4
[^>]*> eeb2 3e09 	vmlsldavx.s16	r2, r7, q1, q4
[^>]*> eeb2 3e29 	vmlsldavax.s16	r2, r7, q1, q4
[^>]*> eeb2 2e0f 	vmlsldav.s16	r2, r7, q1, q7
[^>]*> eeb2 2e2f 	vmlsldava.s16	r2, r7, q1, q7
[^>]*> eeb2 3e0f 	vmlsldavx.s16	r2, r7, q1, q7
[^>]*> eeb2 3e2f 	vmlsldavax.s16	r2, r7, q1, q7
[^>]*> eeb4 2e01 	vmlsldav.s16	r2, r7, q2, q0
[^>]*> eeb4 2e21 	vmlsldava.s16	r2, r7, q2, q0
[^>]*> eeb4 3e01 	vmlsldavx.s16	r2, r7, q2, q0
[^>]*> eeb4 3e21 	vmlsldavax.s16	r2, r7, q2, q0
[^>]*> eeb4 2e03 	vmlsldav.s16	r2, r7, q2, q1
[^>]*> eeb4 2e23 	vmlsldava.s16	r2, r7, q2, q1
[^>]*> eeb4 3e03 	vmlsldavx.s16	r2, r7, q2, q1
[^>]*> eeb4 3e23 	vmlsldavax.s16	r2, r7, q2, q1
[^>]*> eeb4 2e05 	vmlsldav.s16	r2, r7, q2, q2
[^>]*> eeb4 2e25 	vmlsldava.s16	r2, r7, q2, q2
[^>]*> eeb4 3e05 	vmlsldavx.s16	r2, r7, q2, q2
[^>]*> eeb4 3e25 	vmlsldavax.s16	r2, r7, q2, q2
[^>]*> eeb4 2e09 	vmlsldav.s16	r2, r7, q2, q4
[^>]*> eeb4 2e29 	vmlsldava.s16	r2, r7, q2, q4
[^>]*> eeb4 3e09 	vmlsldavx.s16	r2, r7, q2, q4
[^>]*> eeb4 3e29 	vmlsldavax.s16	r2, r7, q2, q4
[^>]*> eeb4 2e0f 	vmlsldav.s16	r2, r7, q2, q7
[^>]*> eeb4 2e2f 	vmlsldava.s16	r2, r7, q2, q7
[^>]*> eeb4 3e0f 	vmlsldavx.s16	r2, r7, q2, q7
[^>]*> eeb4 3e2f 	vmlsldavax.s16	r2, r7, q2, q7
[^>]*> eeb8 2e01 	vmlsldav.s16	r2, r7, q4, q0
[^>]*> eeb8 2e21 	vmlsldava.s16	r2, r7, q4, q0
[^>]*> eeb8 3e01 	vmlsldavx.s16	r2, r7, q4, q0
[^>]*> eeb8 3e21 	vmlsldavax.s16	r2, r7, q4, q0
[^>]*> eeb8 2e03 	vmlsldav.s16	r2, r7, q4, q1
[^>]*> eeb8 2e23 	vmlsldava.s16	r2, r7, q4, q1
[^>]*> eeb8 3e03 	vmlsldavx.s16	r2, r7, q4, q1
[^>]*> eeb8 3e23 	vmlsldavax.s16	r2, r7, q4, q1
[^>]*> eeb8 2e05 	vmlsldav.s16	r2, r7, q4, q2
[^>]*> eeb8 2e25 	vmlsldava.s16	r2, r7, q4, q2
[^>]*> eeb8 3e05 	vmlsldavx.s16	r2, r7, q4, q2
[^>]*> eeb8 3e25 	vmlsldavax.s16	r2, r7, q4, q2
[^>]*> eeb8 2e09 	vmlsldav.s16	r2, r7, q4, q4
[^>]*> eeb8 2e29 	vmlsldava.s16	r2, r7, q4, q4
[^>]*> eeb8 3e09 	vmlsldavx.s16	r2, r7, q4, q4
[^>]*> eeb8 3e29 	vmlsldavax.s16	r2, r7, q4, q4
[^>]*> eeb8 2e0f 	vmlsldav.s16	r2, r7, q4, q7
[^>]*> eeb8 2e2f 	vmlsldava.s16	r2, r7, q4, q7
[^>]*> eeb8 3e0f 	vmlsldavx.s16	r2, r7, q4, q7
[^>]*> eeb8 3e2f 	vmlsldavax.s16	r2, r7, q4, q7
[^>]*> eebe 2e01 	vmlsldav.s16	r2, r7, q7, q0
[^>]*> eebe 2e21 	vmlsldava.s16	r2, r7, q7, q0
[^>]*> eebe 3e01 	vmlsldavx.s16	r2, r7, q7, q0
[^>]*> eebe 3e21 	vmlsldavax.s16	r2, r7, q7, q0
[^>]*> eebe 2e03 	vmlsldav.s16	r2, r7, q7, q1
[^>]*> eebe 2e23 	vmlsldava.s16	r2, r7, q7, q1
[^>]*> eebe 3e03 	vmlsldavx.s16	r2, r7, q7, q1
[^>]*> eebe 3e23 	vmlsldavax.s16	r2, r7, q7, q1
[^>]*> eebe 2e05 	vmlsldav.s16	r2, r7, q7, q2
[^>]*> eebe 2e25 	vmlsldava.s16	r2, r7, q7, q2
[^>]*> eebe 3e05 	vmlsldavx.s16	r2, r7, q7, q2
[^>]*> eebe 3e25 	vmlsldavax.s16	r2, r7, q7, q2
[^>]*> eebe 2e09 	vmlsldav.s16	r2, r7, q7, q4
[^>]*> eebe 2e29 	vmlsldava.s16	r2, r7, q7, q4
[^>]*> eebe 3e09 	vmlsldavx.s16	r2, r7, q7, q4
[^>]*> eebe 3e29 	vmlsldavax.s16	r2, r7, q7, q4
[^>]*> eebe 2e0f 	vmlsldav.s16	r2, r7, q7, q7
[^>]*> eebe 2e2f 	vmlsldava.s16	r2, r7, q7, q7
[^>]*> eebe 3e0f 	vmlsldavx.s16	r2, r7, q7, q7
[^>]*> eebe 3e2f 	vmlsldavax.s16	r2, r7, q7, q7
[^>]*> eec0 2e01 	vmlsldav.s16	r2, r9, q0, q0
[^>]*> eec0 2e21 	vmlsldava.s16	r2, r9, q0, q0
[^>]*> eec0 3e01 	vmlsldavx.s16	r2, r9, q0, q0
[^>]*> eec0 3e21 	vmlsldavax.s16	r2, r9, q0, q0
[^>]*> eec0 2e03 	vmlsldav.s16	r2, r9, q0, q1
[^>]*> eec0 2e23 	vmlsldava.s16	r2, r9, q0, q1
[^>]*> eec0 3e03 	vmlsldavx.s16	r2, r9, q0, q1
[^>]*> eec0 3e23 	vmlsldavax.s16	r2, r9, q0, q1
[^>]*> eec0 2e05 	vmlsldav.s16	r2, r9, q0, q2
[^>]*> eec0 2e25 	vmlsldava.s16	r2, r9, q0, q2
[^>]*> eec0 3e05 	vmlsldavx.s16	r2, r9, q0, q2
[^>]*> eec0 3e25 	vmlsldavax.s16	r2, r9, q0, q2
[^>]*> eec0 2e09 	vmlsldav.s16	r2, r9, q0, q4
[^>]*> eec0 2e29 	vmlsldava.s16	r2, r9, q0, q4
[^>]*> eec0 3e09 	vmlsldavx.s16	r2, r9, q0, q4
[^>]*> eec0 3e29 	vmlsldavax.s16	r2, r9, q0, q4
[^>]*> eec0 2e0f 	vmlsldav.s16	r2, r9, q0, q7
[^>]*> eec0 2e2f 	vmlsldava.s16	r2, r9, q0, q7
[^>]*> eec0 3e0f 	vmlsldavx.s16	r2, r9, q0, q7
[^>]*> eec0 3e2f 	vmlsldavax.s16	r2, r9, q0, q7
[^>]*> eec2 2e01 	vmlsldav.s16	r2, r9, q1, q0
[^>]*> eec2 2e21 	vmlsldava.s16	r2, r9, q1, q0
[^>]*> eec2 3e01 	vmlsldavx.s16	r2, r9, q1, q0
[^>]*> eec2 3e21 	vmlsldavax.s16	r2, r9, q1, q0
[^>]*> eec2 2e03 	vmlsldav.s16	r2, r9, q1, q1
[^>]*> eec2 2e23 	vmlsldava.s16	r2, r9, q1, q1
[^>]*> eec2 3e03 	vmlsldavx.s16	r2, r9, q1, q1
[^>]*> eec2 3e23 	vmlsldavax.s16	r2, r9, q1, q1
[^>]*> eec2 2e05 	vmlsldav.s16	r2, r9, q1, q2
[^>]*> eec2 2e25 	vmlsldava.s16	r2, r9, q1, q2
[^>]*> eec2 3e05 	vmlsldavx.s16	r2, r9, q1, q2
[^>]*> eec2 3e25 	vmlsldavax.s16	r2, r9, q1, q2
[^>]*> eec2 2e09 	vmlsldav.s16	r2, r9, q1, q4
[^>]*> eec2 2e29 	vmlsldava.s16	r2, r9, q1, q4
[^>]*> eec2 3e09 	vmlsldavx.s16	r2, r9, q1, q4
[^>]*> eec2 3e29 	vmlsldavax.s16	r2, r9, q1, q4
[^>]*> eec2 2e0f 	vmlsldav.s16	r2, r9, q1, q7
[^>]*> eec2 2e2f 	vmlsldava.s16	r2, r9, q1, q7
[^>]*> eec2 3e0f 	vmlsldavx.s16	r2, r9, q1, q7
[^>]*> eec2 3e2f 	vmlsldavax.s16	r2, r9, q1, q7
[^>]*> eec4 2e01 	vmlsldav.s16	r2, r9, q2, q0
[^>]*> eec4 2e21 	vmlsldava.s16	r2, r9, q2, q0
[^>]*> eec4 3e01 	vmlsldavx.s16	r2, r9, q2, q0
[^>]*> eec4 3e21 	vmlsldavax.s16	r2, r9, q2, q0
[^>]*> eec4 2e03 	vmlsldav.s16	r2, r9, q2, q1
[^>]*> eec4 2e23 	vmlsldava.s16	r2, r9, q2, q1
[^>]*> eec4 3e03 	vmlsldavx.s16	r2, r9, q2, q1
[^>]*> eec4 3e23 	vmlsldavax.s16	r2, r9, q2, q1
[^>]*> eec4 2e05 	vmlsldav.s16	r2, r9, q2, q2
[^>]*> eec4 2e25 	vmlsldava.s16	r2, r9, q2, q2
[^>]*> eec4 3e05 	vmlsldavx.s16	r2, r9, q2, q2
[^>]*> eec4 3e25 	vmlsldavax.s16	r2, r9, q2, q2
[^>]*> eec4 2e09 	vmlsldav.s16	r2, r9, q2, q4
[^>]*> eec4 2e29 	vmlsldava.s16	r2, r9, q2, q4
[^>]*> eec4 3e09 	vmlsldavx.s16	r2, r9, q2, q4
[^>]*> eec4 3e29 	vmlsldavax.s16	r2, r9, q2, q4
[^>]*> eec4 2e0f 	vmlsldav.s16	r2, r9, q2, q7
[^>]*> eec4 2e2f 	vmlsldava.s16	r2, r9, q2, q7
[^>]*> eec4 3e0f 	vmlsldavx.s16	r2, r9, q2, q7
[^>]*> eec4 3e2f 	vmlsldavax.s16	r2, r9, q2, q7
[^>]*> eec8 2e01 	vmlsldav.s16	r2, r9, q4, q0
[^>]*> eec8 2e21 	vmlsldava.s16	r2, r9, q4, q0
[^>]*> eec8 3e01 	vmlsldavx.s16	r2, r9, q4, q0
[^>]*> eec8 3e21 	vmlsldavax.s16	r2, r9, q4, q0
[^>]*> eec8 2e03 	vmlsldav.s16	r2, r9, q4, q1
[^>]*> eec8 2e23 	vmlsldava.s16	r2, r9, q4, q1
[^>]*> eec8 3e03 	vmlsldavx.s16	r2, r9, q4, q1
[^>]*> eec8 3e23 	vmlsldavax.s16	r2, r9, q4, q1
[^>]*> eec8 2e05 	vmlsldav.s16	r2, r9, q4, q2
[^>]*> eec8 2e25 	vmlsldava.s16	r2, r9, q4, q2
[^>]*> eec8 3e05 	vmlsldavx.s16	r2, r9, q4, q2
[^>]*> eec8 3e25 	vmlsldavax.s16	r2, r9, q4, q2
[^>]*> eec8 2e09 	vmlsldav.s16	r2, r9, q4, q4
[^>]*> eec8 2e29 	vmlsldava.s16	r2, r9, q4, q4
[^>]*> eec8 3e09 	vmlsldavx.s16	r2, r9, q4, q4
[^>]*> eec8 3e29 	vmlsldavax.s16	r2, r9, q4, q4
[^>]*> eec8 2e0f 	vmlsldav.s16	r2, r9, q4, q7
[^>]*> eec8 2e2f 	vmlsldava.s16	r2, r9, q4, q7
[^>]*> eec8 3e0f 	vmlsldavx.s16	r2, r9, q4, q7
[^>]*> eec8 3e2f 	vmlsldavax.s16	r2, r9, q4, q7
[^>]*> eece 2e01 	vmlsldav.s16	r2, r9, q7, q0
[^>]*> eece 2e21 	vmlsldava.s16	r2, r9, q7, q0
[^>]*> eece 3e01 	vmlsldavx.s16	r2, r9, q7, q0
[^>]*> eece 3e21 	vmlsldavax.s16	r2, r9, q7, q0
[^>]*> eece 2e03 	vmlsldav.s16	r2, r9, q7, q1
[^>]*> eece 2e23 	vmlsldava.s16	r2, r9, q7, q1
[^>]*> eece 3e03 	vmlsldavx.s16	r2, r9, q7, q1
[^>]*> eece 3e23 	vmlsldavax.s16	r2, r9, q7, q1
[^>]*> eece 2e05 	vmlsldav.s16	r2, r9, q7, q2
[^>]*> eece 2e25 	vmlsldava.s16	r2, r9, q7, q2
[^>]*> eece 3e05 	vmlsldavx.s16	r2, r9, q7, q2
[^>]*> eece 3e25 	vmlsldavax.s16	r2, r9, q7, q2
[^>]*> eece 2e09 	vmlsldav.s16	r2, r9, q7, q4
[^>]*> eece 2e29 	vmlsldava.s16	r2, r9, q7, q4
[^>]*> eece 3e09 	vmlsldavx.s16	r2, r9, q7, q4
[^>]*> eece 3e29 	vmlsldavax.s16	r2, r9, q7, q4
[^>]*> eece 2e0f 	vmlsldav.s16	r2, r9, q7, q7
[^>]*> eece 2e2f 	vmlsldava.s16	r2, r9, q7, q7
[^>]*> eece 3e0f 	vmlsldavx.s16	r2, r9, q7, q7
[^>]*> eece 3e2f 	vmlsldavax.s16	r2, r9, q7, q7
[^>]*> eed0 2e01 	vmlsldav.s16	r2, fp, q0, q0
[^>]*> eed0 2e21 	vmlsldava.s16	r2, fp, q0, q0
[^>]*> eed0 3e01 	vmlsldavx.s16	r2, fp, q0, q0
[^>]*> eed0 3e21 	vmlsldavax.s16	r2, fp, q0, q0
[^>]*> eed0 2e03 	vmlsldav.s16	r2, fp, q0, q1
[^>]*> eed0 2e23 	vmlsldava.s16	r2, fp, q0, q1
[^>]*> eed0 3e03 	vmlsldavx.s16	r2, fp, q0, q1
[^>]*> eed0 3e23 	vmlsldavax.s16	r2, fp, q0, q1
[^>]*> eed0 2e05 	vmlsldav.s16	r2, fp, q0, q2
[^>]*> eed0 2e25 	vmlsldava.s16	r2, fp, q0, q2
[^>]*> eed0 3e05 	vmlsldavx.s16	r2, fp, q0, q2
[^>]*> eed0 3e25 	vmlsldavax.s16	r2, fp, q0, q2
[^>]*> eed0 2e09 	vmlsldav.s16	r2, fp, q0, q4
[^>]*> eed0 2e29 	vmlsldava.s16	r2, fp, q0, q4
[^>]*> eed0 3e09 	vmlsldavx.s16	r2, fp, q0, q4
[^>]*> eed0 3e29 	vmlsldavax.s16	r2, fp, q0, q4
[^>]*> eed0 2e0f 	vmlsldav.s16	r2, fp, q0, q7
[^>]*> eed0 2e2f 	vmlsldava.s16	r2, fp, q0, q7
[^>]*> eed0 3e0f 	vmlsldavx.s16	r2, fp, q0, q7
[^>]*> eed0 3e2f 	vmlsldavax.s16	r2, fp, q0, q7
[^>]*> eed2 2e01 	vmlsldav.s16	r2, fp, q1, q0
[^>]*> eed2 2e21 	vmlsldava.s16	r2, fp, q1, q0
[^>]*> eed2 3e01 	vmlsldavx.s16	r2, fp, q1, q0
[^>]*> eed2 3e21 	vmlsldavax.s16	r2, fp, q1, q0
[^>]*> eed2 2e03 	vmlsldav.s16	r2, fp, q1, q1
[^>]*> eed2 2e23 	vmlsldava.s16	r2, fp, q1, q1
[^>]*> eed2 3e03 	vmlsldavx.s16	r2, fp, q1, q1
[^>]*> eed2 3e23 	vmlsldavax.s16	r2, fp, q1, q1
[^>]*> eed2 2e05 	vmlsldav.s16	r2, fp, q1, q2
[^>]*> eed2 2e25 	vmlsldava.s16	r2, fp, q1, q2
[^>]*> eed2 3e05 	vmlsldavx.s16	r2, fp, q1, q2
[^>]*> eed2 3e25 	vmlsldavax.s16	r2, fp, q1, q2
[^>]*> eed2 2e09 	vmlsldav.s16	r2, fp, q1, q4
[^>]*> eed2 2e29 	vmlsldava.s16	r2, fp, q1, q4
[^>]*> eed2 3e09 	vmlsldavx.s16	r2, fp, q1, q4
[^>]*> eed2 3e29 	vmlsldavax.s16	r2, fp, q1, q4
[^>]*> eed2 2e0f 	vmlsldav.s16	r2, fp, q1, q7
[^>]*> eed2 2e2f 	vmlsldava.s16	r2, fp, q1, q7
[^>]*> eed2 3e0f 	vmlsldavx.s16	r2, fp, q1, q7
[^>]*> eed2 3e2f 	vmlsldavax.s16	r2, fp, q1, q7
[^>]*> eed4 2e01 	vmlsldav.s16	r2, fp, q2, q0
[^>]*> eed4 2e21 	vmlsldava.s16	r2, fp, q2, q0
[^>]*> eed4 3e01 	vmlsldavx.s16	r2, fp, q2, q0
[^>]*> eed4 3e21 	vmlsldavax.s16	r2, fp, q2, q0
[^>]*> eed4 2e03 	vmlsldav.s16	r2, fp, q2, q1
[^>]*> eed4 2e23 	vmlsldava.s16	r2, fp, q2, q1
[^>]*> eed4 3e03 	vmlsldavx.s16	r2, fp, q2, q1
[^>]*> eed4 3e23 	vmlsldavax.s16	r2, fp, q2, q1
[^>]*> eed4 2e05 	vmlsldav.s16	r2, fp, q2, q2
[^>]*> eed4 2e25 	vmlsldava.s16	r2, fp, q2, q2
[^>]*> eed4 3e05 	vmlsldavx.s16	r2, fp, q2, q2
[^>]*> eed4 3e25 	vmlsldavax.s16	r2, fp, q2, q2
[^>]*> eed4 2e09 	vmlsldav.s16	r2, fp, q2, q4
[^>]*> eed4 2e29 	vmlsldava.s16	r2, fp, q2, q4
[^>]*> eed4 3e09 	vmlsldavx.s16	r2, fp, q2, q4
[^>]*> eed4 3e29 	vmlsldavax.s16	r2, fp, q2, q4
[^>]*> eed4 2e0f 	vmlsldav.s16	r2, fp, q2, q7
[^>]*> eed4 2e2f 	vmlsldava.s16	r2, fp, q2, q7
[^>]*> eed4 3e0f 	vmlsldavx.s16	r2, fp, q2, q7
[^>]*> eed4 3e2f 	vmlsldavax.s16	r2, fp, q2, q7
[^>]*> eed8 2e01 	vmlsldav.s16	r2, fp, q4, q0
[^>]*> eed8 2e21 	vmlsldava.s16	r2, fp, q4, q0
[^>]*> eed8 3e01 	vmlsldavx.s16	r2, fp, q4, q0
[^>]*> eed8 3e21 	vmlsldavax.s16	r2, fp, q4, q0
[^>]*> eed8 2e03 	vmlsldav.s16	r2, fp, q4, q1
[^>]*> eed8 2e23 	vmlsldava.s16	r2, fp, q4, q1
[^>]*> eed8 3e03 	vmlsldavx.s16	r2, fp, q4, q1
[^>]*> eed8 3e23 	vmlsldavax.s16	r2, fp, q4, q1
[^>]*> eed8 2e05 	vmlsldav.s16	r2, fp, q4, q2
[^>]*> eed8 2e25 	vmlsldava.s16	r2, fp, q4, q2
[^>]*> eed8 3e05 	vmlsldavx.s16	r2, fp, q4, q2
[^>]*> eed8 3e25 	vmlsldavax.s16	r2, fp, q4, q2
[^>]*> eed8 2e09 	vmlsldav.s16	r2, fp, q4, q4
[^>]*> eed8 2e29 	vmlsldava.s16	r2, fp, q4, q4
[^>]*> eed8 3e09 	vmlsldavx.s16	r2, fp, q4, q4
[^>]*> eed8 3e29 	vmlsldavax.s16	r2, fp, q4, q4
[^>]*> eed8 2e0f 	vmlsldav.s16	r2, fp, q4, q7
[^>]*> eed8 2e2f 	vmlsldava.s16	r2, fp, q4, q7
[^>]*> eed8 3e0f 	vmlsldavx.s16	r2, fp, q4, q7
[^>]*> eed8 3e2f 	vmlsldavax.s16	r2, fp, q4, q7
[^>]*> eede 2e01 	vmlsldav.s16	r2, fp, q7, q0
[^>]*> eede 2e21 	vmlsldava.s16	r2, fp, q7, q0
[^>]*> eede 3e01 	vmlsldavx.s16	r2, fp, q7, q0
[^>]*> eede 3e21 	vmlsldavax.s16	r2, fp, q7, q0
[^>]*> eede 2e03 	vmlsldav.s16	r2, fp, q7, q1
[^>]*> eede 2e23 	vmlsldava.s16	r2, fp, q7, q1
[^>]*> eede 3e03 	vmlsldavx.s16	r2, fp, q7, q1
[^>]*> eede 3e23 	vmlsldavax.s16	r2, fp, q7, q1
[^>]*> eede 2e05 	vmlsldav.s16	r2, fp, q7, q2
[^>]*> eede 2e25 	vmlsldava.s16	r2, fp, q7, q2
[^>]*> eede 3e05 	vmlsldavx.s16	r2, fp, q7, q2
[^>]*> eede 3e25 	vmlsldavax.s16	r2, fp, q7, q2
[^>]*> eede 2e09 	vmlsldav.s16	r2, fp, q7, q4
[^>]*> eede 2e29 	vmlsldava.s16	r2, fp, q7, q4
[^>]*> eede 3e09 	vmlsldavx.s16	r2, fp, q7, q4
[^>]*> eede 3e29 	vmlsldavax.s16	r2, fp, q7, q4
[^>]*> eede 2e0f 	vmlsldav.s16	r2, fp, q7, q7
[^>]*> eede 2e2f 	vmlsldava.s16	r2, fp, q7, q7
[^>]*> eede 3e0f 	vmlsldavx.s16	r2, fp, q7, q7
[^>]*> eede 3e2f 	vmlsldavax.s16	r2, fp, q7, q7
[^>]*> ee80 4e01 	vmlsldav.s16	r4, r1, q0, q0
[^>]*> ee80 4e21 	vmlsldava.s16	r4, r1, q0, q0
[^>]*> ee80 5e01 	vmlsldavx.s16	r4, r1, q0, q0
[^>]*> ee80 5e21 	vmlsldavax.s16	r4, r1, q0, q0
[^>]*> ee80 4e03 	vmlsldav.s16	r4, r1, q0, q1
[^>]*> ee80 4e23 	vmlsldava.s16	r4, r1, q0, q1
[^>]*> ee80 5e03 	vmlsldavx.s16	r4, r1, q0, q1
[^>]*> ee80 5e23 	vmlsldavax.s16	r4, r1, q0, q1
[^>]*> ee80 4e05 	vmlsldav.s16	r4, r1, q0, q2
[^>]*> ee80 4e25 	vmlsldava.s16	r4, r1, q0, q2
[^>]*> ee80 5e05 	vmlsldavx.s16	r4, r1, q0, q2
[^>]*> ee80 5e25 	vmlsldavax.s16	r4, r1, q0, q2
[^>]*> ee80 4e09 	vmlsldav.s16	r4, r1, q0, q4
[^>]*> ee80 4e29 	vmlsldava.s16	r4, r1, q0, q4
[^>]*> ee80 5e09 	vmlsldavx.s16	r4, r1, q0, q4
[^>]*> ee80 5e29 	vmlsldavax.s16	r4, r1, q0, q4
[^>]*> ee80 4e0f 	vmlsldav.s16	r4, r1, q0, q7
[^>]*> ee80 4e2f 	vmlsldava.s16	r4, r1, q0, q7
[^>]*> ee80 5e0f 	vmlsldavx.s16	r4, r1, q0, q7
[^>]*> ee80 5e2f 	vmlsldavax.s16	r4, r1, q0, q7
[^>]*> ee82 4e01 	vmlsldav.s16	r4, r1, q1, q0
[^>]*> ee82 4e21 	vmlsldava.s16	r4, r1, q1, q0
[^>]*> ee82 5e01 	vmlsldavx.s16	r4, r1, q1, q0
[^>]*> ee82 5e21 	vmlsldavax.s16	r4, r1, q1, q0
[^>]*> ee82 4e03 	vmlsldav.s16	r4, r1, q1, q1
[^>]*> ee82 4e23 	vmlsldava.s16	r4, r1, q1, q1
[^>]*> ee82 5e03 	vmlsldavx.s16	r4, r1, q1, q1
[^>]*> ee82 5e23 	vmlsldavax.s16	r4, r1, q1, q1
[^>]*> ee82 4e05 	vmlsldav.s16	r4, r1, q1, q2
[^>]*> ee82 4e25 	vmlsldava.s16	r4, r1, q1, q2
[^>]*> ee82 5e05 	vmlsldavx.s16	r4, r1, q1, q2
[^>]*> ee82 5e25 	vmlsldavax.s16	r4, r1, q1, q2
[^>]*> ee82 4e09 	vmlsldav.s16	r4, r1, q1, q4
[^>]*> ee82 4e29 	vmlsldava.s16	r4, r1, q1, q4
[^>]*> ee82 5e09 	vmlsldavx.s16	r4, r1, q1, q4
[^>]*> ee82 5e29 	vmlsldavax.s16	r4, r1, q1, q4
[^>]*> ee82 4e0f 	vmlsldav.s16	r4, r1, q1, q7
[^>]*> ee82 4e2f 	vmlsldava.s16	r4, r1, q1, q7
[^>]*> ee82 5e0f 	vmlsldavx.s16	r4, r1, q1, q7
[^>]*> ee82 5e2f 	vmlsldavax.s16	r4, r1, q1, q7
[^>]*> ee84 4e01 	vmlsldav.s16	r4, r1, q2, q0
[^>]*> ee84 4e21 	vmlsldava.s16	r4, r1, q2, q0
[^>]*> ee84 5e01 	vmlsldavx.s16	r4, r1, q2, q0
[^>]*> ee84 5e21 	vmlsldavax.s16	r4, r1, q2, q0
[^>]*> ee84 4e03 	vmlsldav.s16	r4, r1, q2, q1
[^>]*> ee84 4e23 	vmlsldava.s16	r4, r1, q2, q1
[^>]*> ee84 5e03 	vmlsldavx.s16	r4, r1, q2, q1
[^>]*> ee84 5e23 	vmlsldavax.s16	r4, r1, q2, q1
[^>]*> ee84 4e05 	vmlsldav.s16	r4, r1, q2, q2
[^>]*> ee84 4e25 	vmlsldava.s16	r4, r1, q2, q2
[^>]*> ee84 5e05 	vmlsldavx.s16	r4, r1, q2, q2
[^>]*> ee84 5e25 	vmlsldavax.s16	r4, r1, q2, q2
[^>]*> ee84 4e09 	vmlsldav.s16	r4, r1, q2, q4
[^>]*> ee84 4e29 	vmlsldava.s16	r4, r1, q2, q4
[^>]*> ee84 5e09 	vmlsldavx.s16	r4, r1, q2, q4
[^>]*> ee84 5e29 	vmlsldavax.s16	r4, r1, q2, q4
[^>]*> ee84 4e0f 	vmlsldav.s16	r4, r1, q2, q7
[^>]*> ee84 4e2f 	vmlsldava.s16	r4, r1, q2, q7
[^>]*> ee84 5e0f 	vmlsldavx.s16	r4, r1, q2, q7
[^>]*> ee84 5e2f 	vmlsldavax.s16	r4, r1, q2, q7
[^>]*> ee88 4e01 	vmlsldav.s16	r4, r1, q4, q0
[^>]*> ee88 4e21 	vmlsldava.s16	r4, r1, q4, q0
[^>]*> ee88 5e01 	vmlsldavx.s16	r4, r1, q4, q0
[^>]*> ee88 5e21 	vmlsldavax.s16	r4, r1, q4, q0
[^>]*> ee88 4e03 	vmlsldav.s16	r4, r1, q4, q1
[^>]*> ee88 4e23 	vmlsldava.s16	r4, r1, q4, q1
[^>]*> ee88 5e03 	vmlsldavx.s16	r4, r1, q4, q1
[^>]*> ee88 5e23 	vmlsldavax.s16	r4, r1, q4, q1
[^>]*> ee88 4e05 	vmlsldav.s16	r4, r1, q4, q2
[^>]*> ee88 4e25 	vmlsldava.s16	r4, r1, q4, q2
[^>]*> ee88 5e05 	vmlsldavx.s16	r4, r1, q4, q2
[^>]*> ee88 5e25 	vmlsldavax.s16	r4, r1, q4, q2
[^>]*> ee88 4e09 	vmlsldav.s16	r4, r1, q4, q4
[^>]*> ee88 4e29 	vmlsldava.s16	r4, r1, q4, q4
[^>]*> ee88 5e09 	vmlsldavx.s16	r4, r1, q4, q4
[^>]*> ee88 5e29 	vmlsldavax.s16	r4, r1, q4, q4
[^>]*> ee88 4e0f 	vmlsldav.s16	r4, r1, q4, q7
[^>]*> ee88 4e2f 	vmlsldava.s16	r4, r1, q4, q7
[^>]*> ee88 5e0f 	vmlsldavx.s16	r4, r1, q4, q7
[^>]*> ee88 5e2f 	vmlsldavax.s16	r4, r1, q4, q7
[^>]*> ee8e 4e01 	vmlsldav.s16	r4, r1, q7, q0
[^>]*> ee8e 4e21 	vmlsldava.s16	r4, r1, q7, q0
[^>]*> ee8e 5e01 	vmlsldavx.s16	r4, r1, q7, q0
[^>]*> ee8e 5e21 	vmlsldavax.s16	r4, r1, q7, q0
[^>]*> ee8e 4e03 	vmlsldav.s16	r4, r1, q7, q1
[^>]*> ee8e 4e23 	vmlsldava.s16	r4, r1, q7, q1
[^>]*> ee8e 5e03 	vmlsldavx.s16	r4, r1, q7, q1
[^>]*> ee8e 5e23 	vmlsldavax.s16	r4, r1, q7, q1
[^>]*> ee8e 4e05 	vmlsldav.s16	r4, r1, q7, q2
[^>]*> ee8e 4e25 	vmlsldava.s16	r4, r1, q7, q2
[^>]*> ee8e 5e05 	vmlsldavx.s16	r4, r1, q7, q2
[^>]*> ee8e 5e25 	vmlsldavax.s16	r4, r1, q7, q2
[^>]*> ee8e 4e09 	vmlsldav.s16	r4, r1, q7, q4
[^>]*> ee8e 4e29 	vmlsldava.s16	r4, r1, q7, q4
[^>]*> ee8e 5e09 	vmlsldavx.s16	r4, r1, q7, q4
[^>]*> ee8e 5e29 	vmlsldavax.s16	r4, r1, q7, q4
[^>]*> ee8e 4e0f 	vmlsldav.s16	r4, r1, q7, q7
[^>]*> ee8e 4e2f 	vmlsldava.s16	r4, r1, q7, q7
[^>]*> ee8e 5e0f 	vmlsldavx.s16	r4, r1, q7, q7
[^>]*> ee8e 5e2f 	vmlsldavax.s16	r4, r1, q7, q7
[^>]*> ee90 4e01 	vmlsldav.s16	r4, r3, q0, q0
[^>]*> ee90 4e21 	vmlsldava.s16	r4, r3, q0, q0
[^>]*> ee90 5e01 	vmlsldavx.s16	r4, r3, q0, q0
[^>]*> ee90 5e21 	vmlsldavax.s16	r4, r3, q0, q0
[^>]*> ee90 4e03 	vmlsldav.s16	r4, r3, q0, q1
[^>]*> ee90 4e23 	vmlsldava.s16	r4, r3, q0, q1
[^>]*> ee90 5e03 	vmlsldavx.s16	r4, r3, q0, q1
[^>]*> ee90 5e23 	vmlsldavax.s16	r4, r3, q0, q1
[^>]*> ee90 4e05 	vmlsldav.s16	r4, r3, q0, q2
[^>]*> ee90 4e25 	vmlsldava.s16	r4, r3, q0, q2
[^>]*> ee90 5e05 	vmlsldavx.s16	r4, r3, q0, q2
[^>]*> ee90 5e25 	vmlsldavax.s16	r4, r3, q0, q2
[^>]*> ee90 4e09 	vmlsldav.s16	r4, r3, q0, q4
[^>]*> ee90 4e29 	vmlsldava.s16	r4, r3, q0, q4
[^>]*> ee90 5e09 	vmlsldavx.s16	r4, r3, q0, q4
[^>]*> ee90 5e29 	vmlsldavax.s16	r4, r3, q0, q4
[^>]*> ee90 4e0f 	vmlsldav.s16	r4, r3, q0, q7
[^>]*> ee90 4e2f 	vmlsldava.s16	r4, r3, q0, q7
[^>]*> ee90 5e0f 	vmlsldavx.s16	r4, r3, q0, q7
[^>]*> ee90 5e2f 	vmlsldavax.s16	r4, r3, q0, q7
[^>]*> ee92 4e01 	vmlsldav.s16	r4, r3, q1, q0
[^>]*> ee92 4e21 	vmlsldava.s16	r4, r3, q1, q0
[^>]*> ee92 5e01 	vmlsldavx.s16	r4, r3, q1, q0
[^>]*> ee92 5e21 	vmlsldavax.s16	r4, r3, q1, q0
[^>]*> ee92 4e03 	vmlsldav.s16	r4, r3, q1, q1
[^>]*> ee92 4e23 	vmlsldava.s16	r4, r3, q1, q1
[^>]*> ee92 5e03 	vmlsldavx.s16	r4, r3, q1, q1
[^>]*> ee92 5e23 	vmlsldavax.s16	r4, r3, q1, q1
[^>]*> ee92 4e05 	vmlsldav.s16	r4, r3, q1, q2
[^>]*> ee92 4e25 	vmlsldava.s16	r4, r3, q1, q2
[^>]*> ee92 5e05 	vmlsldavx.s16	r4, r3, q1, q2
[^>]*> ee92 5e25 	vmlsldavax.s16	r4, r3, q1, q2
[^>]*> ee92 4e09 	vmlsldav.s16	r4, r3, q1, q4
[^>]*> ee92 4e29 	vmlsldava.s16	r4, r3, q1, q4
[^>]*> ee92 5e09 	vmlsldavx.s16	r4, r3, q1, q4
[^>]*> ee92 5e29 	vmlsldavax.s16	r4, r3, q1, q4
[^>]*> ee92 4e0f 	vmlsldav.s16	r4, r3, q1, q7
[^>]*> ee92 4e2f 	vmlsldava.s16	r4, r3, q1, q7
[^>]*> ee92 5e0f 	vmlsldavx.s16	r4, r3, q1, q7
[^>]*> ee92 5e2f 	vmlsldavax.s16	r4, r3, q1, q7
[^>]*> ee94 4e01 	vmlsldav.s16	r4, r3, q2, q0
[^>]*> ee94 4e21 	vmlsldava.s16	r4, r3, q2, q0
[^>]*> ee94 5e01 	vmlsldavx.s16	r4, r3, q2, q0
[^>]*> ee94 5e21 	vmlsldavax.s16	r4, r3, q2, q0
[^>]*> ee94 4e03 	vmlsldav.s16	r4, r3, q2, q1
[^>]*> ee94 4e23 	vmlsldava.s16	r4, r3, q2, q1
[^>]*> ee94 5e03 	vmlsldavx.s16	r4, r3, q2, q1
[^>]*> ee94 5e23 	vmlsldavax.s16	r4, r3, q2, q1
[^>]*> ee94 4e05 	vmlsldav.s16	r4, r3, q2, q2
[^>]*> ee94 4e25 	vmlsldava.s16	r4, r3, q2, q2
[^>]*> ee94 5e05 	vmlsldavx.s16	r4, r3, q2, q2
[^>]*> ee94 5e25 	vmlsldavax.s16	r4, r3, q2, q2
[^>]*> ee94 4e09 	vmlsldav.s16	r4, r3, q2, q4
[^>]*> ee94 4e29 	vmlsldava.s16	r4, r3, q2, q4
[^>]*> ee94 5e09 	vmlsldavx.s16	r4, r3, q2, q4
[^>]*> ee94 5e29 	vmlsldavax.s16	r4, r3, q2, q4
[^>]*> ee94 4e0f 	vmlsldav.s16	r4, r3, q2, q7
[^>]*> ee94 4e2f 	vmlsldava.s16	r4, r3, q2, q7
[^>]*> ee94 5e0f 	vmlsldavx.s16	r4, r3, q2, q7
[^>]*> ee94 5e2f 	vmlsldavax.s16	r4, r3, q2, q7
[^>]*> ee98 4e01 	vmlsldav.s16	r4, r3, q4, q0
[^>]*> ee98 4e21 	vmlsldava.s16	r4, r3, q4, q0
[^>]*> ee98 5e01 	vmlsldavx.s16	r4, r3, q4, q0
[^>]*> ee98 5e21 	vmlsldavax.s16	r4, r3, q4, q0
[^>]*> ee98 4e03 	vmlsldav.s16	r4, r3, q4, q1
[^>]*> ee98 4e23 	vmlsldava.s16	r4, r3, q4, q1
[^>]*> ee98 5e03 	vmlsldavx.s16	r4, r3, q4, q1
[^>]*> ee98 5e23 	vmlsldavax.s16	r4, r3, q4, q1
[^>]*> ee98 4e05 	vmlsldav.s16	r4, r3, q4, q2
[^>]*> ee98 4e25 	vmlsldava.s16	r4, r3, q4, q2
[^>]*> ee98 5e05 	vmlsldavx.s16	r4, r3, q4, q2
[^>]*> ee98 5e25 	vmlsldavax.s16	r4, r3, q4, q2
[^>]*> ee98 4e09 	vmlsldav.s16	r4, r3, q4, q4
[^>]*> ee98 4e29 	vmlsldava.s16	r4, r3, q4, q4
[^>]*> ee98 5e09 	vmlsldavx.s16	r4, r3, q4, q4
[^>]*> ee98 5e29 	vmlsldavax.s16	r4, r3, q4, q4
[^>]*> ee98 4e0f 	vmlsldav.s16	r4, r3, q4, q7
[^>]*> ee98 4e2f 	vmlsldava.s16	r4, r3, q4, q7
[^>]*> ee98 5e0f 	vmlsldavx.s16	r4, r3, q4, q7
[^>]*> ee98 5e2f 	vmlsldavax.s16	r4, r3, q4, q7
[^>]*> ee9e 4e01 	vmlsldav.s16	r4, r3, q7, q0
[^>]*> ee9e 4e21 	vmlsldava.s16	r4, r3, q7, q0
[^>]*> ee9e 5e01 	vmlsldavx.s16	r4, r3, q7, q0
[^>]*> ee9e 5e21 	vmlsldavax.s16	r4, r3, q7, q0
[^>]*> ee9e 4e03 	vmlsldav.s16	r4, r3, q7, q1
[^>]*> ee9e 4e23 	vmlsldava.s16	r4, r3, q7, q1
[^>]*> ee9e 5e03 	vmlsldavx.s16	r4, r3, q7, q1
[^>]*> ee9e 5e23 	vmlsldavax.s16	r4, r3, q7, q1
[^>]*> ee9e 4e05 	vmlsldav.s16	r4, r3, q7, q2
[^>]*> ee9e 4e25 	vmlsldava.s16	r4, r3, q7, q2
[^>]*> ee9e 5e05 	vmlsldavx.s16	r4, r3, q7, q2
[^>]*> ee9e 5e25 	vmlsldavax.s16	r4, r3, q7, q2
[^>]*> ee9e 4e09 	vmlsldav.s16	r4, r3, q7, q4
[^>]*> ee9e 4e29 	vmlsldava.s16	r4, r3, q7, q4
[^>]*> ee9e 5e09 	vmlsldavx.s16	r4, r3, q7, q4
[^>]*> ee9e 5e29 	vmlsldavax.s16	r4, r3, q7, q4
[^>]*> ee9e 4e0f 	vmlsldav.s16	r4, r3, q7, q7
[^>]*> ee9e 4e2f 	vmlsldava.s16	r4, r3, q7, q7
[^>]*> ee9e 5e0f 	vmlsldavx.s16	r4, r3, q7, q7
[^>]*> ee9e 5e2f 	vmlsldavax.s16	r4, r3, q7, q7
[^>]*> eea0 4e01 	vmlsldav.s16	r4, r5, q0, q0
[^>]*> eea0 4e21 	vmlsldava.s16	r4, r5, q0, q0
[^>]*> eea0 5e01 	vmlsldavx.s16	r4, r5, q0, q0
[^>]*> eea0 5e21 	vmlsldavax.s16	r4, r5, q0, q0
[^>]*> eea0 4e03 	vmlsldav.s16	r4, r5, q0, q1
[^>]*> eea0 4e23 	vmlsldava.s16	r4, r5, q0, q1
[^>]*> eea0 5e03 	vmlsldavx.s16	r4, r5, q0, q1
[^>]*> eea0 5e23 	vmlsldavax.s16	r4, r5, q0, q1
[^>]*> eea0 4e05 	vmlsldav.s16	r4, r5, q0, q2
[^>]*> eea0 4e25 	vmlsldava.s16	r4, r5, q0, q2
[^>]*> eea0 5e05 	vmlsldavx.s16	r4, r5, q0, q2
[^>]*> eea0 5e25 	vmlsldavax.s16	r4, r5, q0, q2
[^>]*> eea0 4e09 	vmlsldav.s16	r4, r5, q0, q4
[^>]*> eea0 4e29 	vmlsldava.s16	r4, r5, q0, q4
[^>]*> eea0 5e09 	vmlsldavx.s16	r4, r5, q0, q4
[^>]*> eea0 5e29 	vmlsldavax.s16	r4, r5, q0, q4
[^>]*> eea0 4e0f 	vmlsldav.s16	r4, r5, q0, q7
[^>]*> eea0 4e2f 	vmlsldava.s16	r4, r5, q0, q7
[^>]*> eea0 5e0f 	vmlsldavx.s16	r4, r5, q0, q7
[^>]*> eea0 5e2f 	vmlsldavax.s16	r4, r5, q0, q7
[^>]*> eea2 4e01 	vmlsldav.s16	r4, r5, q1, q0
[^>]*> eea2 4e21 	vmlsldava.s16	r4, r5, q1, q0
[^>]*> eea2 5e01 	vmlsldavx.s16	r4, r5, q1, q0
[^>]*> eea2 5e21 	vmlsldavax.s16	r4, r5, q1, q0
[^>]*> eea2 4e03 	vmlsldav.s16	r4, r5, q1, q1
[^>]*> eea2 4e23 	vmlsldava.s16	r4, r5, q1, q1
[^>]*> eea2 5e03 	vmlsldavx.s16	r4, r5, q1, q1
[^>]*> eea2 5e23 	vmlsldavax.s16	r4, r5, q1, q1
[^>]*> eea2 4e05 	vmlsldav.s16	r4, r5, q1, q2
[^>]*> eea2 4e25 	vmlsldava.s16	r4, r5, q1, q2
[^>]*> eea2 5e05 	vmlsldavx.s16	r4, r5, q1, q2
[^>]*> eea2 5e25 	vmlsldavax.s16	r4, r5, q1, q2
[^>]*> eea2 4e09 	vmlsldav.s16	r4, r5, q1, q4
[^>]*> eea2 4e29 	vmlsldava.s16	r4, r5, q1, q4
[^>]*> eea2 5e09 	vmlsldavx.s16	r4, r5, q1, q4
[^>]*> eea2 5e29 	vmlsldavax.s16	r4, r5, q1, q4
[^>]*> eea2 4e0f 	vmlsldav.s16	r4, r5, q1, q7
[^>]*> eea2 4e2f 	vmlsldava.s16	r4, r5, q1, q7
[^>]*> eea2 5e0f 	vmlsldavx.s16	r4, r5, q1, q7
[^>]*> eea2 5e2f 	vmlsldavax.s16	r4, r5, q1, q7
[^>]*> eea4 4e01 	vmlsldav.s16	r4, r5, q2, q0
[^>]*> eea4 4e21 	vmlsldava.s16	r4, r5, q2, q0
[^>]*> eea4 5e01 	vmlsldavx.s16	r4, r5, q2, q0
[^>]*> eea4 5e21 	vmlsldavax.s16	r4, r5, q2, q0
[^>]*> eea4 4e03 	vmlsldav.s16	r4, r5, q2, q1
[^>]*> eea4 4e23 	vmlsldava.s16	r4, r5, q2, q1
[^>]*> eea4 5e03 	vmlsldavx.s16	r4, r5, q2, q1
[^>]*> eea4 5e23 	vmlsldavax.s16	r4, r5, q2, q1
[^>]*> eea4 4e05 	vmlsldav.s16	r4, r5, q2, q2
[^>]*> eea4 4e25 	vmlsldava.s16	r4, r5, q2, q2
[^>]*> eea4 5e05 	vmlsldavx.s16	r4, r5, q2, q2
[^>]*> eea4 5e25 	vmlsldavax.s16	r4, r5, q2, q2
[^>]*> eea4 4e09 	vmlsldav.s16	r4, r5, q2, q4
[^>]*> eea4 4e29 	vmlsldava.s16	r4, r5, q2, q4
[^>]*> eea4 5e09 	vmlsldavx.s16	r4, r5, q2, q4
[^>]*> eea4 5e29 	vmlsldavax.s16	r4, r5, q2, q4
[^>]*> eea4 4e0f 	vmlsldav.s16	r4, r5, q2, q7
[^>]*> eea4 4e2f 	vmlsldava.s16	r4, r5, q2, q7
[^>]*> eea4 5e0f 	vmlsldavx.s16	r4, r5, q2, q7
[^>]*> eea4 5e2f 	vmlsldavax.s16	r4, r5, q2, q7
[^>]*> eea8 4e01 	vmlsldav.s16	r4, r5, q4, q0
[^>]*> eea8 4e21 	vmlsldava.s16	r4, r5, q4, q0
[^>]*> eea8 5e01 	vmlsldavx.s16	r4, r5, q4, q0
[^>]*> eea8 5e21 	vmlsldavax.s16	r4, r5, q4, q0
[^>]*> eea8 4e03 	vmlsldav.s16	r4, r5, q4, q1
[^>]*> eea8 4e23 	vmlsldava.s16	r4, r5, q4, q1
[^>]*> eea8 5e03 	vmlsldavx.s16	r4, r5, q4, q1
[^>]*> eea8 5e23 	vmlsldavax.s16	r4, r5, q4, q1
[^>]*> eea8 4e05 	vmlsldav.s16	r4, r5, q4, q2
[^>]*> eea8 4e25 	vmlsldava.s16	r4, r5, q4, q2
[^>]*> eea8 5e05 	vmlsldavx.s16	r4, r5, q4, q2
[^>]*> eea8 5e25 	vmlsldavax.s16	r4, r5, q4, q2
[^>]*> eea8 4e09 	vmlsldav.s16	r4, r5, q4, q4
[^>]*> eea8 4e29 	vmlsldava.s16	r4, r5, q4, q4
[^>]*> eea8 5e09 	vmlsldavx.s16	r4, r5, q4, q4
[^>]*> eea8 5e29 	vmlsldavax.s16	r4, r5, q4, q4
[^>]*> eea8 4e0f 	vmlsldav.s16	r4, r5, q4, q7
[^>]*> eea8 4e2f 	vmlsldava.s16	r4, r5, q4, q7
[^>]*> eea8 5e0f 	vmlsldavx.s16	r4, r5, q4, q7
[^>]*> eea8 5e2f 	vmlsldavax.s16	r4, r5, q4, q7
[^>]*> eeae 4e01 	vmlsldav.s16	r4, r5, q7, q0
[^>]*> eeae 4e21 	vmlsldava.s16	r4, r5, q7, q0
[^>]*> eeae 5e01 	vmlsldavx.s16	r4, r5, q7, q0
[^>]*> eeae 5e21 	vmlsldavax.s16	r4, r5, q7, q0
[^>]*> eeae 4e03 	vmlsldav.s16	r4, r5, q7, q1
[^>]*> eeae 4e23 	vmlsldava.s16	r4, r5, q7, q1
[^>]*> eeae 5e03 	vmlsldavx.s16	r4, r5, q7, q1
[^>]*> eeae 5e23 	vmlsldavax.s16	r4, r5, q7, q1
[^>]*> eeae 4e05 	vmlsldav.s16	r4, r5, q7, q2
[^>]*> eeae 4e25 	vmlsldava.s16	r4, r5, q7, q2
[^>]*> eeae 5e05 	vmlsldavx.s16	r4, r5, q7, q2
[^>]*> eeae 5e25 	vmlsldavax.s16	r4, r5, q7, q2
[^>]*> eeae 4e09 	vmlsldav.s16	r4, r5, q7, q4
[^>]*> eeae 4e29 	vmlsldava.s16	r4, r5, q7, q4
[^>]*> eeae 5e09 	vmlsldavx.s16	r4, r5, q7, q4
[^>]*> eeae 5e29 	vmlsldavax.s16	r4, r5, q7, q4
[^>]*> eeae 4e0f 	vmlsldav.s16	r4, r5, q7, q7
[^>]*> eeae 4e2f 	vmlsldava.s16	r4, r5, q7, q7
[^>]*> eeae 5e0f 	vmlsldavx.s16	r4, r5, q7, q7
[^>]*> eeae 5e2f 	vmlsldavax.s16	r4, r5, q7, q7
[^>]*> eeb0 4e01 	vmlsldav.s16	r4, r7, q0, q0
[^>]*> eeb0 4e21 	vmlsldava.s16	r4, r7, q0, q0
[^>]*> eeb0 5e01 	vmlsldavx.s16	r4, r7, q0, q0
[^>]*> eeb0 5e21 	vmlsldavax.s16	r4, r7, q0, q0
[^>]*> eeb0 4e03 	vmlsldav.s16	r4, r7, q0, q1
[^>]*> eeb0 4e23 	vmlsldava.s16	r4, r7, q0, q1
[^>]*> eeb0 5e03 	vmlsldavx.s16	r4, r7, q0, q1
[^>]*> eeb0 5e23 	vmlsldavax.s16	r4, r7, q0, q1
[^>]*> eeb0 4e05 	vmlsldav.s16	r4, r7, q0, q2
[^>]*> eeb0 4e25 	vmlsldava.s16	r4, r7, q0, q2
[^>]*> eeb0 5e05 	vmlsldavx.s16	r4, r7, q0, q2
[^>]*> eeb0 5e25 	vmlsldavax.s16	r4, r7, q0, q2
[^>]*> eeb0 4e09 	vmlsldav.s16	r4, r7, q0, q4
[^>]*> eeb0 4e29 	vmlsldava.s16	r4, r7, q0, q4
[^>]*> eeb0 5e09 	vmlsldavx.s16	r4, r7, q0, q4
[^>]*> eeb0 5e29 	vmlsldavax.s16	r4, r7, q0, q4
[^>]*> eeb0 4e0f 	vmlsldav.s16	r4, r7, q0, q7
[^>]*> eeb0 4e2f 	vmlsldava.s16	r4, r7, q0, q7
[^>]*> eeb0 5e0f 	vmlsldavx.s16	r4, r7, q0, q7
[^>]*> eeb0 5e2f 	vmlsldavax.s16	r4, r7, q0, q7
[^>]*> eeb2 4e01 	vmlsldav.s16	r4, r7, q1, q0
[^>]*> eeb2 4e21 	vmlsldava.s16	r4, r7, q1, q0
[^>]*> eeb2 5e01 	vmlsldavx.s16	r4, r7, q1, q0
[^>]*> eeb2 5e21 	vmlsldavax.s16	r4, r7, q1, q0
[^>]*> eeb2 4e03 	vmlsldav.s16	r4, r7, q1, q1
[^>]*> eeb2 4e23 	vmlsldava.s16	r4, r7, q1, q1
[^>]*> eeb2 5e03 	vmlsldavx.s16	r4, r7, q1, q1
[^>]*> eeb2 5e23 	vmlsldavax.s16	r4, r7, q1, q1
[^>]*> eeb2 4e05 	vmlsldav.s16	r4, r7, q1, q2
[^>]*> eeb2 4e25 	vmlsldava.s16	r4, r7, q1, q2
[^>]*> eeb2 5e05 	vmlsldavx.s16	r4, r7, q1, q2
[^>]*> eeb2 5e25 	vmlsldavax.s16	r4, r7, q1, q2
[^>]*> eeb2 4e09 	vmlsldav.s16	r4, r7, q1, q4
[^>]*> eeb2 4e29 	vmlsldava.s16	r4, r7, q1, q4
[^>]*> eeb2 5e09 	vmlsldavx.s16	r4, r7, q1, q4
[^>]*> eeb2 5e29 	vmlsldavax.s16	r4, r7, q1, q4
[^>]*> eeb2 4e0f 	vmlsldav.s16	r4, r7, q1, q7
[^>]*> eeb2 4e2f 	vmlsldava.s16	r4, r7, q1, q7
[^>]*> eeb2 5e0f 	vmlsldavx.s16	r4, r7, q1, q7
[^>]*> eeb2 5e2f 	vmlsldavax.s16	r4, r7, q1, q7
[^>]*> eeb4 4e01 	vmlsldav.s16	r4, r7, q2, q0
[^>]*> eeb4 4e21 	vmlsldava.s16	r4, r7, q2, q0
[^>]*> eeb4 5e01 	vmlsldavx.s16	r4, r7, q2, q0
[^>]*> eeb4 5e21 	vmlsldavax.s16	r4, r7, q2, q0
[^>]*> eeb4 4e03 	vmlsldav.s16	r4, r7, q2, q1
[^>]*> eeb4 4e23 	vmlsldava.s16	r4, r7, q2, q1
[^>]*> eeb4 5e03 	vmlsldavx.s16	r4, r7, q2, q1
[^>]*> eeb4 5e23 	vmlsldavax.s16	r4, r7, q2, q1
[^>]*> eeb4 4e05 	vmlsldav.s16	r4, r7, q2, q2
[^>]*> eeb4 4e25 	vmlsldava.s16	r4, r7, q2, q2
[^>]*> eeb4 5e05 	vmlsldavx.s16	r4, r7, q2, q2
[^>]*> eeb4 5e25 	vmlsldavax.s16	r4, r7, q2, q2
[^>]*> eeb4 4e09 	vmlsldav.s16	r4, r7, q2, q4
[^>]*> eeb4 4e29 	vmlsldava.s16	r4, r7, q2, q4
[^>]*> eeb4 5e09 	vmlsldavx.s16	r4, r7, q2, q4
[^>]*> eeb4 5e29 	vmlsldavax.s16	r4, r7, q2, q4
[^>]*> eeb4 4e0f 	vmlsldav.s16	r4, r7, q2, q7
[^>]*> eeb4 4e2f 	vmlsldava.s16	r4, r7, q2, q7
[^>]*> eeb4 5e0f 	vmlsldavx.s16	r4, r7, q2, q7
[^>]*> eeb4 5e2f 	vmlsldavax.s16	r4, r7, q2, q7
[^>]*> eeb8 4e01 	vmlsldav.s16	r4, r7, q4, q0
[^>]*> eeb8 4e21 	vmlsldava.s16	r4, r7, q4, q0
[^>]*> eeb8 5e01 	vmlsldavx.s16	r4, r7, q4, q0
[^>]*> eeb8 5e21 	vmlsldavax.s16	r4, r7, q4, q0
[^>]*> eeb8 4e03 	vmlsldav.s16	r4, r7, q4, q1
[^>]*> eeb8 4e23 	vmlsldava.s16	r4, r7, q4, q1
[^>]*> eeb8 5e03 	vmlsldavx.s16	r4, r7, q4, q1
[^>]*> eeb8 5e23 	vmlsldavax.s16	r4, r7, q4, q1
[^>]*> eeb8 4e05 	vmlsldav.s16	r4, r7, q4, q2
[^>]*> eeb8 4e25 	vmlsldava.s16	r4, r7, q4, q2
[^>]*> eeb8 5e05 	vmlsldavx.s16	r4, r7, q4, q2
[^>]*> eeb8 5e25 	vmlsldavax.s16	r4, r7, q4, q2
[^>]*> eeb8 4e09 	vmlsldav.s16	r4, r7, q4, q4
[^>]*> eeb8 4e29 	vmlsldava.s16	r4, r7, q4, q4
[^>]*> eeb8 5e09 	vmlsldavx.s16	r4, r7, q4, q4
[^>]*> eeb8 5e29 	vmlsldavax.s16	r4, r7, q4, q4
[^>]*> eeb8 4e0f 	vmlsldav.s16	r4, r7, q4, q7
[^>]*> eeb8 4e2f 	vmlsldava.s16	r4, r7, q4, q7
[^>]*> eeb8 5e0f 	vmlsldavx.s16	r4, r7, q4, q7
[^>]*> eeb8 5e2f 	vmlsldavax.s16	r4, r7, q4, q7
[^>]*> eebe 4e01 	vmlsldav.s16	r4, r7, q7, q0
[^>]*> eebe 4e21 	vmlsldava.s16	r4, r7, q7, q0
[^>]*> eebe 5e01 	vmlsldavx.s16	r4, r7, q7, q0
[^>]*> eebe 5e21 	vmlsldavax.s16	r4, r7, q7, q0
[^>]*> eebe 4e03 	vmlsldav.s16	r4, r7, q7, q1
[^>]*> eebe 4e23 	vmlsldava.s16	r4, r7, q7, q1
[^>]*> eebe 5e03 	vmlsldavx.s16	r4, r7, q7, q1
[^>]*> eebe 5e23 	vmlsldavax.s16	r4, r7, q7, q1
[^>]*> eebe 4e05 	vmlsldav.s16	r4, r7, q7, q2
[^>]*> eebe 4e25 	vmlsldava.s16	r4, r7, q7, q2
[^>]*> eebe 5e05 	vmlsldavx.s16	r4, r7, q7, q2
[^>]*> eebe 5e25 	vmlsldavax.s16	r4, r7, q7, q2
[^>]*> eebe 4e09 	vmlsldav.s16	r4, r7, q7, q4
[^>]*> eebe 4e29 	vmlsldava.s16	r4, r7, q7, q4
[^>]*> eebe 5e09 	vmlsldavx.s16	r4, r7, q7, q4
[^>]*> eebe 5e29 	vmlsldavax.s16	r4, r7, q7, q4
[^>]*> eebe 4e0f 	vmlsldav.s16	r4, r7, q7, q7
[^>]*> eebe 4e2f 	vmlsldava.s16	r4, r7, q7, q7
[^>]*> eebe 5e0f 	vmlsldavx.s16	r4, r7, q7, q7
[^>]*> eebe 5e2f 	vmlsldavax.s16	r4, r7, q7, q7
[^>]*> eec0 4e01 	vmlsldav.s16	r4, r9, q0, q0
[^>]*> eec0 4e21 	vmlsldava.s16	r4, r9, q0, q0
[^>]*> eec0 5e01 	vmlsldavx.s16	r4, r9, q0, q0
[^>]*> eec0 5e21 	vmlsldavax.s16	r4, r9, q0, q0
[^>]*> eec0 4e03 	vmlsldav.s16	r4, r9, q0, q1
[^>]*> eec0 4e23 	vmlsldava.s16	r4, r9, q0, q1
[^>]*> eec0 5e03 	vmlsldavx.s16	r4, r9, q0, q1
[^>]*> eec0 5e23 	vmlsldavax.s16	r4, r9, q0, q1
[^>]*> eec0 4e05 	vmlsldav.s16	r4, r9, q0, q2
[^>]*> eec0 4e25 	vmlsldava.s16	r4, r9, q0, q2
[^>]*> eec0 5e05 	vmlsldavx.s16	r4, r9, q0, q2
[^>]*> eec0 5e25 	vmlsldavax.s16	r4, r9, q0, q2
[^>]*> eec0 4e09 	vmlsldav.s16	r4, r9, q0, q4
[^>]*> eec0 4e29 	vmlsldava.s16	r4, r9, q0, q4
[^>]*> eec0 5e09 	vmlsldavx.s16	r4, r9, q0, q4
[^>]*> eec0 5e29 	vmlsldavax.s16	r4, r9, q0, q4
[^>]*> eec0 4e0f 	vmlsldav.s16	r4, r9, q0, q7
[^>]*> eec0 4e2f 	vmlsldava.s16	r4, r9, q0, q7
[^>]*> eec0 5e0f 	vmlsldavx.s16	r4, r9, q0, q7
[^>]*> eec0 5e2f 	vmlsldavax.s16	r4, r9, q0, q7
[^>]*> eec2 4e01 	vmlsldav.s16	r4, r9, q1, q0
[^>]*> eec2 4e21 	vmlsldava.s16	r4, r9, q1, q0
[^>]*> eec2 5e01 	vmlsldavx.s16	r4, r9, q1, q0
[^>]*> eec2 5e21 	vmlsldavax.s16	r4, r9, q1, q0
[^>]*> eec2 4e03 	vmlsldav.s16	r4, r9, q1, q1
[^>]*> eec2 4e23 	vmlsldava.s16	r4, r9, q1, q1
[^>]*> eec2 5e03 	vmlsldavx.s16	r4, r9, q1, q1
[^>]*> eec2 5e23 	vmlsldavax.s16	r4, r9, q1, q1
[^>]*> eec2 4e05 	vmlsldav.s16	r4, r9, q1, q2
[^>]*> eec2 4e25 	vmlsldava.s16	r4, r9, q1, q2
[^>]*> eec2 5e05 	vmlsldavx.s16	r4, r9, q1, q2
[^>]*> eec2 5e25 	vmlsldavax.s16	r4, r9, q1, q2
[^>]*> eec2 4e09 	vmlsldav.s16	r4, r9, q1, q4
[^>]*> eec2 4e29 	vmlsldava.s16	r4, r9, q1, q4
[^>]*> eec2 5e09 	vmlsldavx.s16	r4, r9, q1, q4
[^>]*> eec2 5e29 	vmlsldavax.s16	r4, r9, q1, q4
[^>]*> eec2 4e0f 	vmlsldav.s16	r4, r9, q1, q7
[^>]*> eec2 4e2f 	vmlsldava.s16	r4, r9, q1, q7
[^>]*> eec2 5e0f 	vmlsldavx.s16	r4, r9, q1, q7
[^>]*> eec2 5e2f 	vmlsldavax.s16	r4, r9, q1, q7
[^>]*> eec4 4e01 	vmlsldav.s16	r4, r9, q2, q0
[^>]*> eec4 4e21 	vmlsldava.s16	r4, r9, q2, q0
[^>]*> eec4 5e01 	vmlsldavx.s16	r4, r9, q2, q0
[^>]*> eec4 5e21 	vmlsldavax.s16	r4, r9, q2, q0
[^>]*> eec4 4e03 	vmlsldav.s16	r4, r9, q2, q1
[^>]*> eec4 4e23 	vmlsldava.s16	r4, r9, q2, q1
[^>]*> eec4 5e03 	vmlsldavx.s16	r4, r9, q2, q1
[^>]*> eec4 5e23 	vmlsldavax.s16	r4, r9, q2, q1
[^>]*> eec4 4e05 	vmlsldav.s16	r4, r9, q2, q2
[^>]*> eec4 4e25 	vmlsldava.s16	r4, r9, q2, q2
[^>]*> eec4 5e05 	vmlsldavx.s16	r4, r9, q2, q2
[^>]*> eec4 5e25 	vmlsldavax.s16	r4, r9, q2, q2
[^>]*> eec4 4e09 	vmlsldav.s16	r4, r9, q2, q4
[^>]*> eec4 4e29 	vmlsldava.s16	r4, r9, q2, q4
[^>]*> eec4 5e09 	vmlsldavx.s16	r4, r9, q2, q4
[^>]*> eec4 5e29 	vmlsldavax.s16	r4, r9, q2, q4
[^>]*> eec4 4e0f 	vmlsldav.s16	r4, r9, q2, q7
[^>]*> eec4 4e2f 	vmlsldava.s16	r4, r9, q2, q7
[^>]*> eec4 5e0f 	vmlsldavx.s16	r4, r9, q2, q7
[^>]*> eec4 5e2f 	vmlsldavax.s16	r4, r9, q2, q7
[^>]*> eec8 4e01 	vmlsldav.s16	r4, r9, q4, q0
[^>]*> eec8 4e21 	vmlsldava.s16	r4, r9, q4, q0
[^>]*> eec8 5e01 	vmlsldavx.s16	r4, r9, q4, q0
[^>]*> eec8 5e21 	vmlsldavax.s16	r4, r9, q4, q0
[^>]*> eec8 4e03 	vmlsldav.s16	r4, r9, q4, q1
[^>]*> eec8 4e23 	vmlsldava.s16	r4, r9, q4, q1
[^>]*> eec8 5e03 	vmlsldavx.s16	r4, r9, q4, q1
[^>]*> eec8 5e23 	vmlsldavax.s16	r4, r9, q4, q1
[^>]*> eec8 4e05 	vmlsldav.s16	r4, r9, q4, q2
[^>]*> eec8 4e25 	vmlsldava.s16	r4, r9, q4, q2
[^>]*> eec8 5e05 	vmlsldavx.s16	r4, r9, q4, q2
[^>]*> eec8 5e25 	vmlsldavax.s16	r4, r9, q4, q2
[^>]*> eec8 4e09 	vmlsldav.s16	r4, r9, q4, q4
[^>]*> eec8 4e29 	vmlsldava.s16	r4, r9, q4, q4
[^>]*> eec8 5e09 	vmlsldavx.s16	r4, r9, q4, q4
[^>]*> eec8 5e29 	vmlsldavax.s16	r4, r9, q4, q4
[^>]*> eec8 4e0f 	vmlsldav.s16	r4, r9, q4, q7
[^>]*> eec8 4e2f 	vmlsldava.s16	r4, r9, q4, q7
[^>]*> eec8 5e0f 	vmlsldavx.s16	r4, r9, q4, q7
[^>]*> eec8 5e2f 	vmlsldavax.s16	r4, r9, q4, q7
[^>]*> eece 4e01 	vmlsldav.s16	r4, r9, q7, q0
[^>]*> eece 4e21 	vmlsldava.s16	r4, r9, q7, q0
[^>]*> eece 5e01 	vmlsldavx.s16	r4, r9, q7, q0
[^>]*> eece 5e21 	vmlsldavax.s16	r4, r9, q7, q0
[^>]*> eece 4e03 	vmlsldav.s16	r4, r9, q7, q1
[^>]*> eece 4e23 	vmlsldava.s16	r4, r9, q7, q1
[^>]*> eece 5e03 	vmlsldavx.s16	r4, r9, q7, q1
[^>]*> eece 5e23 	vmlsldavax.s16	r4, r9, q7, q1
[^>]*> eece 4e05 	vmlsldav.s16	r4, r9, q7, q2
[^>]*> eece 4e25 	vmlsldava.s16	r4, r9, q7, q2
[^>]*> eece 5e05 	vmlsldavx.s16	r4, r9, q7, q2
[^>]*> eece 5e25 	vmlsldavax.s16	r4, r9, q7, q2
[^>]*> eece 4e09 	vmlsldav.s16	r4, r9, q7, q4
[^>]*> eece 4e29 	vmlsldava.s16	r4, r9, q7, q4
[^>]*> eece 5e09 	vmlsldavx.s16	r4, r9, q7, q4
[^>]*> eece 5e29 	vmlsldavax.s16	r4, r9, q7, q4
[^>]*> eece 4e0f 	vmlsldav.s16	r4, r9, q7, q7
[^>]*> eece 4e2f 	vmlsldava.s16	r4, r9, q7, q7
[^>]*> eece 5e0f 	vmlsldavx.s16	r4, r9, q7, q7
[^>]*> eece 5e2f 	vmlsldavax.s16	r4, r9, q7, q7
[^>]*> eed0 4e01 	vmlsldav.s16	r4, fp, q0, q0
[^>]*> eed0 4e21 	vmlsldava.s16	r4, fp, q0, q0
[^>]*> eed0 5e01 	vmlsldavx.s16	r4, fp, q0, q0
[^>]*> eed0 5e21 	vmlsldavax.s16	r4, fp, q0, q0
[^>]*> eed0 4e03 	vmlsldav.s16	r4, fp, q0, q1
[^>]*> eed0 4e23 	vmlsldava.s16	r4, fp, q0, q1
[^>]*> eed0 5e03 	vmlsldavx.s16	r4, fp, q0, q1
[^>]*> eed0 5e23 	vmlsldavax.s16	r4, fp, q0, q1
[^>]*> eed0 4e05 	vmlsldav.s16	r4, fp, q0, q2
[^>]*> eed0 4e25 	vmlsldava.s16	r4, fp, q0, q2
[^>]*> eed0 5e05 	vmlsldavx.s16	r4, fp, q0, q2
[^>]*> eed0 5e25 	vmlsldavax.s16	r4, fp, q0, q2
[^>]*> eed0 4e09 	vmlsldav.s16	r4, fp, q0, q4
[^>]*> eed0 4e29 	vmlsldava.s16	r4, fp, q0, q4
[^>]*> eed0 5e09 	vmlsldavx.s16	r4, fp, q0, q4
[^>]*> eed0 5e29 	vmlsldavax.s16	r4, fp, q0, q4
[^>]*> eed0 4e0f 	vmlsldav.s16	r4, fp, q0, q7
[^>]*> eed0 4e2f 	vmlsldava.s16	r4, fp, q0, q7
[^>]*> eed0 5e0f 	vmlsldavx.s16	r4, fp, q0, q7
[^>]*> eed0 5e2f 	vmlsldavax.s16	r4, fp, q0, q7
[^>]*> eed2 4e01 	vmlsldav.s16	r4, fp, q1, q0
[^>]*> eed2 4e21 	vmlsldava.s16	r4, fp, q1, q0
[^>]*> eed2 5e01 	vmlsldavx.s16	r4, fp, q1, q0
[^>]*> eed2 5e21 	vmlsldavax.s16	r4, fp, q1, q0
[^>]*> eed2 4e03 	vmlsldav.s16	r4, fp, q1, q1
[^>]*> eed2 4e23 	vmlsldava.s16	r4, fp, q1, q1
[^>]*> eed2 5e03 	vmlsldavx.s16	r4, fp, q1, q1
[^>]*> eed2 5e23 	vmlsldavax.s16	r4, fp, q1, q1
[^>]*> eed2 4e05 	vmlsldav.s16	r4, fp, q1, q2
[^>]*> eed2 4e25 	vmlsldava.s16	r4, fp, q1, q2
[^>]*> eed2 5e05 	vmlsldavx.s16	r4, fp, q1, q2
[^>]*> eed2 5e25 	vmlsldavax.s16	r4, fp, q1, q2
[^>]*> eed2 4e09 	vmlsldav.s16	r4, fp, q1, q4
[^>]*> eed2 4e29 	vmlsldava.s16	r4, fp, q1, q4
[^>]*> eed2 5e09 	vmlsldavx.s16	r4, fp, q1, q4
[^>]*> eed2 5e29 	vmlsldavax.s16	r4, fp, q1, q4
[^>]*> eed2 4e0f 	vmlsldav.s16	r4, fp, q1, q7
[^>]*> eed2 4e2f 	vmlsldava.s16	r4, fp, q1, q7
[^>]*> eed2 5e0f 	vmlsldavx.s16	r4, fp, q1, q7
[^>]*> eed2 5e2f 	vmlsldavax.s16	r4, fp, q1, q7
[^>]*> eed4 4e01 	vmlsldav.s16	r4, fp, q2, q0
[^>]*> eed4 4e21 	vmlsldava.s16	r4, fp, q2, q0
[^>]*> eed4 5e01 	vmlsldavx.s16	r4, fp, q2, q0
[^>]*> eed4 5e21 	vmlsldavax.s16	r4, fp, q2, q0
[^>]*> eed4 4e03 	vmlsldav.s16	r4, fp, q2, q1
[^>]*> eed4 4e23 	vmlsldava.s16	r4, fp, q2, q1
[^>]*> eed4 5e03 	vmlsldavx.s16	r4, fp, q2, q1
[^>]*> eed4 5e23 	vmlsldavax.s16	r4, fp, q2, q1
[^>]*> eed4 4e05 	vmlsldav.s16	r4, fp, q2, q2
[^>]*> eed4 4e25 	vmlsldava.s16	r4, fp, q2, q2
[^>]*> eed4 5e05 	vmlsldavx.s16	r4, fp, q2, q2
[^>]*> eed4 5e25 	vmlsldavax.s16	r4, fp, q2, q2
[^>]*> eed4 4e09 	vmlsldav.s16	r4, fp, q2, q4
[^>]*> eed4 4e29 	vmlsldava.s16	r4, fp, q2, q4
[^>]*> eed4 5e09 	vmlsldavx.s16	r4, fp, q2, q4
[^>]*> eed4 5e29 	vmlsldavax.s16	r4, fp, q2, q4
[^>]*> eed4 4e0f 	vmlsldav.s16	r4, fp, q2, q7
[^>]*> eed4 4e2f 	vmlsldava.s16	r4, fp, q2, q7
[^>]*> eed4 5e0f 	vmlsldavx.s16	r4, fp, q2, q7
[^>]*> eed4 5e2f 	vmlsldavax.s16	r4, fp, q2, q7
[^>]*> eed8 4e01 	vmlsldav.s16	r4, fp, q4, q0
[^>]*> eed8 4e21 	vmlsldava.s16	r4, fp, q4, q0
[^>]*> eed8 5e01 	vmlsldavx.s16	r4, fp, q4, q0
[^>]*> eed8 5e21 	vmlsldavax.s16	r4, fp, q4, q0
[^>]*> eed8 4e03 	vmlsldav.s16	r4, fp, q4, q1
[^>]*> eed8 4e23 	vmlsldava.s16	r4, fp, q4, q1
[^>]*> eed8 5e03 	vmlsldavx.s16	r4, fp, q4, q1
[^>]*> eed8 5e23 	vmlsldavax.s16	r4, fp, q4, q1
[^>]*> eed8 4e05 	vmlsldav.s16	r4, fp, q4, q2
[^>]*> eed8 4e25 	vmlsldava.s16	r4, fp, q4, q2
[^>]*> eed8 5e05 	vmlsldavx.s16	r4, fp, q4, q2
[^>]*> eed8 5e25 	vmlsldavax.s16	r4, fp, q4, q2
[^>]*> eed8 4e09 	vmlsldav.s16	r4, fp, q4, q4
[^>]*> eed8 4e29 	vmlsldava.s16	r4, fp, q4, q4
[^>]*> eed8 5e09 	vmlsldavx.s16	r4, fp, q4, q4
[^>]*> eed8 5e29 	vmlsldavax.s16	r4, fp, q4, q4
[^>]*> eed8 4e0f 	vmlsldav.s16	r4, fp, q4, q7
[^>]*> eed8 4e2f 	vmlsldava.s16	r4, fp, q4, q7
[^>]*> eed8 5e0f 	vmlsldavx.s16	r4, fp, q4, q7
[^>]*> eed8 5e2f 	vmlsldavax.s16	r4, fp, q4, q7
[^>]*> eede 4e01 	vmlsldav.s16	r4, fp, q7, q0
[^>]*> eede 4e21 	vmlsldava.s16	r4, fp, q7, q0
[^>]*> eede 5e01 	vmlsldavx.s16	r4, fp, q7, q0
[^>]*> eede 5e21 	vmlsldavax.s16	r4, fp, q7, q0
[^>]*> eede 4e03 	vmlsldav.s16	r4, fp, q7, q1
[^>]*> eede 4e23 	vmlsldava.s16	r4, fp, q7, q1
[^>]*> eede 5e03 	vmlsldavx.s16	r4, fp, q7, q1
[^>]*> eede 5e23 	vmlsldavax.s16	r4, fp, q7, q1
[^>]*> eede 4e05 	vmlsldav.s16	r4, fp, q7, q2
[^>]*> eede 4e25 	vmlsldava.s16	r4, fp, q7, q2
[^>]*> eede 5e05 	vmlsldavx.s16	r4, fp, q7, q2
[^>]*> eede 5e25 	vmlsldavax.s16	r4, fp, q7, q2
[^>]*> eede 4e09 	vmlsldav.s16	r4, fp, q7, q4
[^>]*> eede 4e29 	vmlsldava.s16	r4, fp, q7, q4
[^>]*> eede 5e09 	vmlsldavx.s16	r4, fp, q7, q4
[^>]*> eede 5e29 	vmlsldavax.s16	r4, fp, q7, q4
[^>]*> eede 4e0f 	vmlsldav.s16	r4, fp, q7, q7
[^>]*> eede 4e2f 	vmlsldava.s16	r4, fp, q7, q7
[^>]*> eede 5e0f 	vmlsldavx.s16	r4, fp, q7, q7
[^>]*> eede 5e2f 	vmlsldavax.s16	r4, fp, q7, q7
[^>]*> ee80 8e01 	vmlsldav.s16	r8, r1, q0, q0
[^>]*> ee80 8e21 	vmlsldava.s16	r8, r1, q0, q0
[^>]*> ee80 9e01 	vmlsldavx.s16	r8, r1, q0, q0
[^>]*> ee80 9e21 	vmlsldavax.s16	r8, r1, q0, q0
[^>]*> ee80 8e03 	vmlsldav.s16	r8, r1, q0, q1
[^>]*> ee80 8e23 	vmlsldava.s16	r8, r1, q0, q1
[^>]*> ee80 9e03 	vmlsldavx.s16	r8, r1, q0, q1
[^>]*> ee80 9e23 	vmlsldavax.s16	r8, r1, q0, q1
[^>]*> ee80 8e05 	vmlsldav.s16	r8, r1, q0, q2
[^>]*> ee80 8e25 	vmlsldava.s16	r8, r1, q0, q2
[^>]*> ee80 9e05 	vmlsldavx.s16	r8, r1, q0, q2
[^>]*> ee80 9e25 	vmlsldavax.s16	r8, r1, q0, q2
[^>]*> ee80 8e09 	vmlsldav.s16	r8, r1, q0, q4
[^>]*> ee80 8e29 	vmlsldava.s16	r8, r1, q0, q4
[^>]*> ee80 9e09 	vmlsldavx.s16	r8, r1, q0, q4
[^>]*> ee80 9e29 	vmlsldavax.s16	r8, r1, q0, q4
[^>]*> ee80 8e0f 	vmlsldav.s16	r8, r1, q0, q7
[^>]*> ee80 8e2f 	vmlsldava.s16	r8, r1, q0, q7
[^>]*> ee80 9e0f 	vmlsldavx.s16	r8, r1, q0, q7
[^>]*> ee80 9e2f 	vmlsldavax.s16	r8, r1, q0, q7
[^>]*> ee82 8e01 	vmlsldav.s16	r8, r1, q1, q0
[^>]*> ee82 8e21 	vmlsldava.s16	r8, r1, q1, q0
[^>]*> ee82 9e01 	vmlsldavx.s16	r8, r1, q1, q0
[^>]*> ee82 9e21 	vmlsldavax.s16	r8, r1, q1, q0
[^>]*> ee82 8e03 	vmlsldav.s16	r8, r1, q1, q1
[^>]*> ee82 8e23 	vmlsldava.s16	r8, r1, q1, q1
[^>]*> ee82 9e03 	vmlsldavx.s16	r8, r1, q1, q1
[^>]*> ee82 9e23 	vmlsldavax.s16	r8, r1, q1, q1
[^>]*> ee82 8e05 	vmlsldav.s16	r8, r1, q1, q2
[^>]*> ee82 8e25 	vmlsldava.s16	r8, r1, q1, q2
[^>]*> ee82 9e05 	vmlsldavx.s16	r8, r1, q1, q2
[^>]*> ee82 9e25 	vmlsldavax.s16	r8, r1, q1, q2
[^>]*> ee82 8e09 	vmlsldav.s16	r8, r1, q1, q4
[^>]*> ee82 8e29 	vmlsldava.s16	r8, r1, q1, q4
[^>]*> ee82 9e09 	vmlsldavx.s16	r8, r1, q1, q4
[^>]*> ee82 9e29 	vmlsldavax.s16	r8, r1, q1, q4
[^>]*> ee82 8e0f 	vmlsldav.s16	r8, r1, q1, q7
[^>]*> ee82 8e2f 	vmlsldava.s16	r8, r1, q1, q7
[^>]*> ee82 9e0f 	vmlsldavx.s16	r8, r1, q1, q7
[^>]*> ee82 9e2f 	vmlsldavax.s16	r8, r1, q1, q7
[^>]*> ee84 8e01 	vmlsldav.s16	r8, r1, q2, q0
[^>]*> ee84 8e21 	vmlsldava.s16	r8, r1, q2, q0
[^>]*> ee84 9e01 	vmlsldavx.s16	r8, r1, q2, q0
[^>]*> ee84 9e21 	vmlsldavax.s16	r8, r1, q2, q0
[^>]*> ee84 8e03 	vmlsldav.s16	r8, r1, q2, q1
[^>]*> ee84 8e23 	vmlsldava.s16	r8, r1, q2, q1
[^>]*> ee84 9e03 	vmlsldavx.s16	r8, r1, q2, q1
[^>]*> ee84 9e23 	vmlsldavax.s16	r8, r1, q2, q1
[^>]*> ee84 8e05 	vmlsldav.s16	r8, r1, q2, q2
[^>]*> ee84 8e25 	vmlsldava.s16	r8, r1, q2, q2
[^>]*> ee84 9e05 	vmlsldavx.s16	r8, r1, q2, q2
[^>]*> ee84 9e25 	vmlsldavax.s16	r8, r1, q2, q2
[^>]*> ee84 8e09 	vmlsldav.s16	r8, r1, q2, q4
[^>]*> ee84 8e29 	vmlsldava.s16	r8, r1, q2, q4
[^>]*> ee84 9e09 	vmlsldavx.s16	r8, r1, q2, q4
[^>]*> ee84 9e29 	vmlsldavax.s16	r8, r1, q2, q4
[^>]*> ee84 8e0f 	vmlsldav.s16	r8, r1, q2, q7
[^>]*> ee84 8e2f 	vmlsldava.s16	r8, r1, q2, q7
[^>]*> ee84 9e0f 	vmlsldavx.s16	r8, r1, q2, q7
[^>]*> ee84 9e2f 	vmlsldavax.s16	r8, r1, q2, q7
[^>]*> ee88 8e01 	vmlsldav.s16	r8, r1, q4, q0
[^>]*> ee88 8e21 	vmlsldava.s16	r8, r1, q4, q0
[^>]*> ee88 9e01 	vmlsldavx.s16	r8, r1, q4, q0
[^>]*> ee88 9e21 	vmlsldavax.s16	r8, r1, q4, q0
[^>]*> ee88 8e03 	vmlsldav.s16	r8, r1, q4, q1
[^>]*> ee88 8e23 	vmlsldava.s16	r8, r1, q4, q1
[^>]*> ee88 9e03 	vmlsldavx.s16	r8, r1, q4, q1
[^>]*> ee88 9e23 	vmlsldavax.s16	r8, r1, q4, q1
[^>]*> ee88 8e05 	vmlsldav.s16	r8, r1, q4, q2
[^>]*> ee88 8e25 	vmlsldava.s16	r8, r1, q4, q2
[^>]*> ee88 9e05 	vmlsldavx.s16	r8, r1, q4, q2
[^>]*> ee88 9e25 	vmlsldavax.s16	r8, r1, q4, q2
[^>]*> ee88 8e09 	vmlsldav.s16	r8, r1, q4, q4
[^>]*> ee88 8e29 	vmlsldava.s16	r8, r1, q4, q4
[^>]*> ee88 9e09 	vmlsldavx.s16	r8, r1, q4, q4
[^>]*> ee88 9e29 	vmlsldavax.s16	r8, r1, q4, q4
[^>]*> ee88 8e0f 	vmlsldav.s16	r8, r1, q4, q7
[^>]*> ee88 8e2f 	vmlsldava.s16	r8, r1, q4, q7
[^>]*> ee88 9e0f 	vmlsldavx.s16	r8, r1, q4, q7
[^>]*> ee88 9e2f 	vmlsldavax.s16	r8, r1, q4, q7
[^>]*> ee8e 8e01 	vmlsldav.s16	r8, r1, q7, q0
[^>]*> ee8e 8e21 	vmlsldava.s16	r8, r1, q7, q0
[^>]*> ee8e 9e01 	vmlsldavx.s16	r8, r1, q7, q0
[^>]*> ee8e 9e21 	vmlsldavax.s16	r8, r1, q7, q0
[^>]*> ee8e 8e03 	vmlsldav.s16	r8, r1, q7, q1
[^>]*> ee8e 8e23 	vmlsldava.s16	r8, r1, q7, q1
[^>]*> ee8e 9e03 	vmlsldavx.s16	r8, r1, q7, q1
[^>]*> ee8e 9e23 	vmlsldavax.s16	r8, r1, q7, q1
[^>]*> ee8e 8e05 	vmlsldav.s16	r8, r1, q7, q2
[^>]*> ee8e 8e25 	vmlsldava.s16	r8, r1, q7, q2
[^>]*> ee8e 9e05 	vmlsldavx.s16	r8, r1, q7, q2
[^>]*> ee8e 9e25 	vmlsldavax.s16	r8, r1, q7, q2
[^>]*> ee8e 8e09 	vmlsldav.s16	r8, r1, q7, q4
[^>]*> ee8e 8e29 	vmlsldava.s16	r8, r1, q7, q4
[^>]*> ee8e 9e09 	vmlsldavx.s16	r8, r1, q7, q4
[^>]*> ee8e 9e29 	vmlsldavax.s16	r8, r1, q7, q4
[^>]*> ee8e 8e0f 	vmlsldav.s16	r8, r1, q7, q7
[^>]*> ee8e 8e2f 	vmlsldava.s16	r8, r1, q7, q7
[^>]*> ee8e 9e0f 	vmlsldavx.s16	r8, r1, q7, q7
[^>]*> ee8e 9e2f 	vmlsldavax.s16	r8, r1, q7, q7
[^>]*> ee90 8e01 	vmlsldav.s16	r8, r3, q0, q0
[^>]*> ee90 8e21 	vmlsldava.s16	r8, r3, q0, q0
[^>]*> ee90 9e01 	vmlsldavx.s16	r8, r3, q0, q0
[^>]*> ee90 9e21 	vmlsldavax.s16	r8, r3, q0, q0
[^>]*> ee90 8e03 	vmlsldav.s16	r8, r3, q0, q1
[^>]*> ee90 8e23 	vmlsldava.s16	r8, r3, q0, q1
[^>]*> ee90 9e03 	vmlsldavx.s16	r8, r3, q0, q1
[^>]*> ee90 9e23 	vmlsldavax.s16	r8, r3, q0, q1
[^>]*> ee90 8e05 	vmlsldav.s16	r8, r3, q0, q2
[^>]*> ee90 8e25 	vmlsldava.s16	r8, r3, q0, q2
[^>]*> ee90 9e05 	vmlsldavx.s16	r8, r3, q0, q2
[^>]*> ee90 9e25 	vmlsldavax.s16	r8, r3, q0, q2
[^>]*> ee90 8e09 	vmlsldav.s16	r8, r3, q0, q4
[^>]*> ee90 8e29 	vmlsldava.s16	r8, r3, q0, q4
[^>]*> ee90 9e09 	vmlsldavx.s16	r8, r3, q0, q4
[^>]*> ee90 9e29 	vmlsldavax.s16	r8, r3, q0, q4
[^>]*> ee90 8e0f 	vmlsldav.s16	r8, r3, q0, q7
[^>]*> ee90 8e2f 	vmlsldava.s16	r8, r3, q0, q7
[^>]*> ee90 9e0f 	vmlsldavx.s16	r8, r3, q0, q7
[^>]*> ee90 9e2f 	vmlsldavax.s16	r8, r3, q0, q7
[^>]*> ee92 8e01 	vmlsldav.s16	r8, r3, q1, q0
[^>]*> ee92 8e21 	vmlsldava.s16	r8, r3, q1, q0
[^>]*> ee92 9e01 	vmlsldavx.s16	r8, r3, q1, q0
[^>]*> ee92 9e21 	vmlsldavax.s16	r8, r3, q1, q0
[^>]*> ee92 8e03 	vmlsldav.s16	r8, r3, q1, q1
[^>]*> ee92 8e23 	vmlsldava.s16	r8, r3, q1, q1
[^>]*> ee92 9e03 	vmlsldavx.s16	r8, r3, q1, q1
[^>]*> ee92 9e23 	vmlsldavax.s16	r8, r3, q1, q1
[^>]*> ee92 8e05 	vmlsldav.s16	r8, r3, q1, q2
[^>]*> ee92 8e25 	vmlsldava.s16	r8, r3, q1, q2
[^>]*> ee92 9e05 	vmlsldavx.s16	r8, r3, q1, q2
[^>]*> ee92 9e25 	vmlsldavax.s16	r8, r3, q1, q2
[^>]*> ee92 8e09 	vmlsldav.s16	r8, r3, q1, q4
[^>]*> ee92 8e29 	vmlsldava.s16	r8, r3, q1, q4
[^>]*> ee92 9e09 	vmlsldavx.s16	r8, r3, q1, q4
[^>]*> ee92 9e29 	vmlsldavax.s16	r8, r3, q1, q4
[^>]*> ee92 8e0f 	vmlsldav.s16	r8, r3, q1, q7
[^>]*> ee92 8e2f 	vmlsldava.s16	r8, r3, q1, q7
[^>]*> ee92 9e0f 	vmlsldavx.s16	r8, r3, q1, q7
[^>]*> ee92 9e2f 	vmlsldavax.s16	r8, r3, q1, q7
[^>]*> ee94 8e01 	vmlsldav.s16	r8, r3, q2, q0
[^>]*> ee94 8e21 	vmlsldava.s16	r8, r3, q2, q0
[^>]*> ee94 9e01 	vmlsldavx.s16	r8, r3, q2, q0
[^>]*> ee94 9e21 	vmlsldavax.s16	r8, r3, q2, q0
[^>]*> ee94 8e03 	vmlsldav.s16	r8, r3, q2, q1
[^>]*> ee94 8e23 	vmlsldava.s16	r8, r3, q2, q1
[^>]*> ee94 9e03 	vmlsldavx.s16	r8, r3, q2, q1
[^>]*> ee94 9e23 	vmlsldavax.s16	r8, r3, q2, q1
[^>]*> ee94 8e05 	vmlsldav.s16	r8, r3, q2, q2
[^>]*> ee94 8e25 	vmlsldava.s16	r8, r3, q2, q2
[^>]*> ee94 9e05 	vmlsldavx.s16	r8, r3, q2, q2
[^>]*> ee94 9e25 	vmlsldavax.s16	r8, r3, q2, q2
[^>]*> ee94 8e09 	vmlsldav.s16	r8, r3, q2, q4
[^>]*> ee94 8e29 	vmlsldava.s16	r8, r3, q2, q4
[^>]*> ee94 9e09 	vmlsldavx.s16	r8, r3, q2, q4
[^>]*> ee94 9e29 	vmlsldavax.s16	r8, r3, q2, q4
[^>]*> ee94 8e0f 	vmlsldav.s16	r8, r3, q2, q7
[^>]*> ee94 8e2f 	vmlsldava.s16	r8, r3, q2, q7
[^>]*> ee94 9e0f 	vmlsldavx.s16	r8, r3, q2, q7
[^>]*> ee94 9e2f 	vmlsldavax.s16	r8, r3, q2, q7
[^>]*> ee98 8e01 	vmlsldav.s16	r8, r3, q4, q0
[^>]*> ee98 8e21 	vmlsldava.s16	r8, r3, q4, q0
[^>]*> ee98 9e01 	vmlsldavx.s16	r8, r3, q4, q0
[^>]*> ee98 9e21 	vmlsldavax.s16	r8, r3, q4, q0
[^>]*> ee98 8e03 	vmlsldav.s16	r8, r3, q4, q1
[^>]*> ee98 8e23 	vmlsldava.s16	r8, r3, q4, q1
[^>]*> ee98 9e03 	vmlsldavx.s16	r8, r3, q4, q1
[^>]*> ee98 9e23 	vmlsldavax.s16	r8, r3, q4, q1
[^>]*> ee98 8e05 	vmlsldav.s16	r8, r3, q4, q2
[^>]*> ee98 8e25 	vmlsldava.s16	r8, r3, q4, q2
[^>]*> ee98 9e05 	vmlsldavx.s16	r8, r3, q4, q2
[^>]*> ee98 9e25 	vmlsldavax.s16	r8, r3, q4, q2
[^>]*> ee98 8e09 	vmlsldav.s16	r8, r3, q4, q4
[^>]*> ee98 8e29 	vmlsldava.s16	r8, r3, q4, q4
[^>]*> ee98 9e09 	vmlsldavx.s16	r8, r3, q4, q4
[^>]*> ee98 9e29 	vmlsldavax.s16	r8, r3, q4, q4
[^>]*> ee98 8e0f 	vmlsldav.s16	r8, r3, q4, q7
[^>]*> ee98 8e2f 	vmlsldava.s16	r8, r3, q4, q7
[^>]*> ee98 9e0f 	vmlsldavx.s16	r8, r3, q4, q7
[^>]*> ee98 9e2f 	vmlsldavax.s16	r8, r3, q4, q7
[^>]*> ee9e 8e01 	vmlsldav.s16	r8, r3, q7, q0
[^>]*> ee9e 8e21 	vmlsldava.s16	r8, r3, q7, q0
[^>]*> ee9e 9e01 	vmlsldavx.s16	r8, r3, q7, q0
[^>]*> ee9e 9e21 	vmlsldavax.s16	r8, r3, q7, q0
[^>]*> ee9e 8e03 	vmlsldav.s16	r8, r3, q7, q1
[^>]*> ee9e 8e23 	vmlsldava.s16	r8, r3, q7, q1
[^>]*> ee9e 9e03 	vmlsldavx.s16	r8, r3, q7, q1
[^>]*> ee9e 9e23 	vmlsldavax.s16	r8, r3, q7, q1
[^>]*> ee9e 8e05 	vmlsldav.s16	r8, r3, q7, q2
[^>]*> ee9e 8e25 	vmlsldava.s16	r8, r3, q7, q2
[^>]*> ee9e 9e05 	vmlsldavx.s16	r8, r3, q7, q2
[^>]*> ee9e 9e25 	vmlsldavax.s16	r8, r3, q7, q2
[^>]*> ee9e 8e09 	vmlsldav.s16	r8, r3, q7, q4
[^>]*> ee9e 8e29 	vmlsldava.s16	r8, r3, q7, q4
[^>]*> ee9e 9e09 	vmlsldavx.s16	r8, r3, q7, q4
[^>]*> ee9e 9e29 	vmlsldavax.s16	r8, r3, q7, q4
[^>]*> ee9e 8e0f 	vmlsldav.s16	r8, r3, q7, q7
[^>]*> ee9e 8e2f 	vmlsldava.s16	r8, r3, q7, q7
[^>]*> ee9e 9e0f 	vmlsldavx.s16	r8, r3, q7, q7
[^>]*> ee9e 9e2f 	vmlsldavax.s16	r8, r3, q7, q7
[^>]*> eea0 8e01 	vmlsldav.s16	r8, r5, q0, q0
[^>]*> eea0 8e21 	vmlsldava.s16	r8, r5, q0, q0
[^>]*> eea0 9e01 	vmlsldavx.s16	r8, r5, q0, q0
[^>]*> eea0 9e21 	vmlsldavax.s16	r8, r5, q0, q0
[^>]*> eea0 8e03 	vmlsldav.s16	r8, r5, q0, q1
[^>]*> eea0 8e23 	vmlsldava.s16	r8, r5, q0, q1
[^>]*> eea0 9e03 	vmlsldavx.s16	r8, r5, q0, q1
[^>]*> eea0 9e23 	vmlsldavax.s16	r8, r5, q0, q1
[^>]*> eea0 8e05 	vmlsldav.s16	r8, r5, q0, q2
[^>]*> eea0 8e25 	vmlsldava.s16	r8, r5, q0, q2
[^>]*> eea0 9e05 	vmlsldavx.s16	r8, r5, q0, q2
[^>]*> eea0 9e25 	vmlsldavax.s16	r8, r5, q0, q2
[^>]*> eea0 8e09 	vmlsldav.s16	r8, r5, q0, q4
[^>]*> eea0 8e29 	vmlsldava.s16	r8, r5, q0, q4
[^>]*> eea0 9e09 	vmlsldavx.s16	r8, r5, q0, q4
[^>]*> eea0 9e29 	vmlsldavax.s16	r8, r5, q0, q4
[^>]*> eea0 8e0f 	vmlsldav.s16	r8, r5, q0, q7
[^>]*> eea0 8e2f 	vmlsldava.s16	r8, r5, q0, q7
[^>]*> eea0 9e0f 	vmlsldavx.s16	r8, r5, q0, q7
[^>]*> eea0 9e2f 	vmlsldavax.s16	r8, r5, q0, q7
[^>]*> eea2 8e01 	vmlsldav.s16	r8, r5, q1, q0
[^>]*> eea2 8e21 	vmlsldava.s16	r8, r5, q1, q0
[^>]*> eea2 9e01 	vmlsldavx.s16	r8, r5, q1, q0
[^>]*> eea2 9e21 	vmlsldavax.s16	r8, r5, q1, q0
[^>]*> eea2 8e03 	vmlsldav.s16	r8, r5, q1, q1
[^>]*> eea2 8e23 	vmlsldava.s16	r8, r5, q1, q1
[^>]*> eea2 9e03 	vmlsldavx.s16	r8, r5, q1, q1
[^>]*> eea2 9e23 	vmlsldavax.s16	r8, r5, q1, q1
[^>]*> eea2 8e05 	vmlsldav.s16	r8, r5, q1, q2
[^>]*> eea2 8e25 	vmlsldava.s16	r8, r5, q1, q2
[^>]*> eea2 9e05 	vmlsldavx.s16	r8, r5, q1, q2
[^>]*> eea2 9e25 	vmlsldavax.s16	r8, r5, q1, q2
[^>]*> eea2 8e09 	vmlsldav.s16	r8, r5, q1, q4
[^>]*> eea2 8e29 	vmlsldava.s16	r8, r5, q1, q4
[^>]*> eea2 9e09 	vmlsldavx.s16	r8, r5, q1, q4
[^>]*> eea2 9e29 	vmlsldavax.s16	r8, r5, q1, q4
[^>]*> eea2 8e0f 	vmlsldav.s16	r8, r5, q1, q7
[^>]*> eea2 8e2f 	vmlsldava.s16	r8, r5, q1, q7
[^>]*> eea2 9e0f 	vmlsldavx.s16	r8, r5, q1, q7
[^>]*> eea2 9e2f 	vmlsldavax.s16	r8, r5, q1, q7
[^>]*> eea4 8e01 	vmlsldav.s16	r8, r5, q2, q0
[^>]*> eea4 8e21 	vmlsldava.s16	r8, r5, q2, q0
[^>]*> eea4 9e01 	vmlsldavx.s16	r8, r5, q2, q0
[^>]*> eea4 9e21 	vmlsldavax.s16	r8, r5, q2, q0
[^>]*> eea4 8e03 	vmlsldav.s16	r8, r5, q2, q1
[^>]*> eea4 8e23 	vmlsldava.s16	r8, r5, q2, q1
[^>]*> eea4 9e03 	vmlsldavx.s16	r8, r5, q2, q1
[^>]*> eea4 9e23 	vmlsldavax.s16	r8, r5, q2, q1
[^>]*> eea4 8e05 	vmlsldav.s16	r8, r5, q2, q2
[^>]*> eea4 8e25 	vmlsldava.s16	r8, r5, q2, q2
[^>]*> eea4 9e05 	vmlsldavx.s16	r8, r5, q2, q2
[^>]*> eea4 9e25 	vmlsldavax.s16	r8, r5, q2, q2
[^>]*> eea4 8e09 	vmlsldav.s16	r8, r5, q2, q4
[^>]*> eea4 8e29 	vmlsldava.s16	r8, r5, q2, q4
[^>]*> eea4 9e09 	vmlsldavx.s16	r8, r5, q2, q4
[^>]*> eea4 9e29 	vmlsldavax.s16	r8, r5, q2, q4
[^>]*> eea4 8e0f 	vmlsldav.s16	r8, r5, q2, q7
[^>]*> eea4 8e2f 	vmlsldava.s16	r8, r5, q2, q7
[^>]*> eea4 9e0f 	vmlsldavx.s16	r8, r5, q2, q7
[^>]*> eea4 9e2f 	vmlsldavax.s16	r8, r5, q2, q7
[^>]*> eea8 8e01 	vmlsldav.s16	r8, r5, q4, q0
[^>]*> eea8 8e21 	vmlsldava.s16	r8, r5, q4, q0
[^>]*> eea8 9e01 	vmlsldavx.s16	r8, r5, q4, q0
[^>]*> eea8 9e21 	vmlsldavax.s16	r8, r5, q4, q0
[^>]*> eea8 8e03 	vmlsldav.s16	r8, r5, q4, q1
[^>]*> eea8 8e23 	vmlsldava.s16	r8, r5, q4, q1
[^>]*> eea8 9e03 	vmlsldavx.s16	r8, r5, q4, q1
[^>]*> eea8 9e23 	vmlsldavax.s16	r8, r5, q4, q1
[^>]*> eea8 8e05 	vmlsldav.s16	r8, r5, q4, q2
[^>]*> eea8 8e25 	vmlsldava.s16	r8, r5, q4, q2
[^>]*> eea8 9e05 	vmlsldavx.s16	r8, r5, q4, q2
[^>]*> eea8 9e25 	vmlsldavax.s16	r8, r5, q4, q2
[^>]*> eea8 8e09 	vmlsldav.s16	r8, r5, q4, q4
[^>]*> eea8 8e29 	vmlsldava.s16	r8, r5, q4, q4
[^>]*> eea8 9e09 	vmlsldavx.s16	r8, r5, q4, q4
[^>]*> eea8 9e29 	vmlsldavax.s16	r8, r5, q4, q4
[^>]*> eea8 8e0f 	vmlsldav.s16	r8, r5, q4, q7
[^>]*> eea8 8e2f 	vmlsldava.s16	r8, r5, q4, q7
[^>]*> eea8 9e0f 	vmlsldavx.s16	r8, r5, q4, q7
[^>]*> eea8 9e2f 	vmlsldavax.s16	r8, r5, q4, q7
[^>]*> eeae 8e01 	vmlsldav.s16	r8, r5, q7, q0
[^>]*> eeae 8e21 	vmlsldava.s16	r8, r5, q7, q0
[^>]*> eeae 9e01 	vmlsldavx.s16	r8, r5, q7, q0
[^>]*> eeae 9e21 	vmlsldavax.s16	r8, r5, q7, q0
[^>]*> eeae 8e03 	vmlsldav.s16	r8, r5, q7, q1
[^>]*> eeae 8e23 	vmlsldava.s16	r8, r5, q7, q1
[^>]*> eeae 9e03 	vmlsldavx.s16	r8, r5, q7, q1
[^>]*> eeae 9e23 	vmlsldavax.s16	r8, r5, q7, q1
[^>]*> eeae 8e05 	vmlsldav.s16	r8, r5, q7, q2
[^>]*> eeae 8e25 	vmlsldava.s16	r8, r5, q7, q2
[^>]*> eeae 9e05 	vmlsldavx.s16	r8, r5, q7, q2
[^>]*> eeae 9e25 	vmlsldavax.s16	r8, r5, q7, q2
[^>]*> eeae 8e09 	vmlsldav.s16	r8, r5, q7, q4
[^>]*> eeae 8e29 	vmlsldava.s16	r8, r5, q7, q4
[^>]*> eeae 9e09 	vmlsldavx.s16	r8, r5, q7, q4
[^>]*> eeae 9e29 	vmlsldavax.s16	r8, r5, q7, q4
[^>]*> eeae 8e0f 	vmlsldav.s16	r8, r5, q7, q7
[^>]*> eeae 8e2f 	vmlsldava.s16	r8, r5, q7, q7
[^>]*> eeae 9e0f 	vmlsldavx.s16	r8, r5, q7, q7
[^>]*> eeae 9e2f 	vmlsldavax.s16	r8, r5, q7, q7
[^>]*> eeb0 8e01 	vmlsldav.s16	r8, r7, q0, q0
[^>]*> eeb0 8e21 	vmlsldava.s16	r8, r7, q0, q0
[^>]*> eeb0 9e01 	vmlsldavx.s16	r8, r7, q0, q0
[^>]*> eeb0 9e21 	vmlsldavax.s16	r8, r7, q0, q0
[^>]*> eeb0 8e03 	vmlsldav.s16	r8, r7, q0, q1
[^>]*> eeb0 8e23 	vmlsldava.s16	r8, r7, q0, q1
[^>]*> eeb0 9e03 	vmlsldavx.s16	r8, r7, q0, q1
[^>]*> eeb0 9e23 	vmlsldavax.s16	r8, r7, q0, q1
[^>]*> eeb0 8e05 	vmlsldav.s16	r8, r7, q0, q2
[^>]*> eeb0 8e25 	vmlsldava.s16	r8, r7, q0, q2
[^>]*> eeb0 9e05 	vmlsldavx.s16	r8, r7, q0, q2
[^>]*> eeb0 9e25 	vmlsldavax.s16	r8, r7, q0, q2
[^>]*> eeb0 8e09 	vmlsldav.s16	r8, r7, q0, q4
[^>]*> eeb0 8e29 	vmlsldava.s16	r8, r7, q0, q4
[^>]*> eeb0 9e09 	vmlsldavx.s16	r8, r7, q0, q4
[^>]*> eeb0 9e29 	vmlsldavax.s16	r8, r7, q0, q4
[^>]*> eeb0 8e0f 	vmlsldav.s16	r8, r7, q0, q7
[^>]*> eeb0 8e2f 	vmlsldava.s16	r8, r7, q0, q7
[^>]*> eeb0 9e0f 	vmlsldavx.s16	r8, r7, q0, q7
[^>]*> eeb0 9e2f 	vmlsldavax.s16	r8, r7, q0, q7
[^>]*> eeb2 8e01 	vmlsldav.s16	r8, r7, q1, q0
[^>]*> eeb2 8e21 	vmlsldava.s16	r8, r7, q1, q0
[^>]*> eeb2 9e01 	vmlsldavx.s16	r8, r7, q1, q0
[^>]*> eeb2 9e21 	vmlsldavax.s16	r8, r7, q1, q0
[^>]*> eeb2 8e03 	vmlsldav.s16	r8, r7, q1, q1
[^>]*> eeb2 8e23 	vmlsldava.s16	r8, r7, q1, q1
[^>]*> eeb2 9e03 	vmlsldavx.s16	r8, r7, q1, q1
[^>]*> eeb2 9e23 	vmlsldavax.s16	r8, r7, q1, q1
[^>]*> eeb2 8e05 	vmlsldav.s16	r8, r7, q1, q2
[^>]*> eeb2 8e25 	vmlsldava.s16	r8, r7, q1, q2
[^>]*> eeb2 9e05 	vmlsldavx.s16	r8, r7, q1, q2
[^>]*> eeb2 9e25 	vmlsldavax.s16	r8, r7, q1, q2
[^>]*> eeb2 8e09 	vmlsldav.s16	r8, r7, q1, q4
[^>]*> eeb2 8e29 	vmlsldava.s16	r8, r7, q1, q4
[^>]*> eeb2 9e09 	vmlsldavx.s16	r8, r7, q1, q4
[^>]*> eeb2 9e29 	vmlsldavax.s16	r8, r7, q1, q4
[^>]*> eeb2 8e0f 	vmlsldav.s16	r8, r7, q1, q7
[^>]*> eeb2 8e2f 	vmlsldava.s16	r8, r7, q1, q7
[^>]*> eeb2 9e0f 	vmlsldavx.s16	r8, r7, q1, q7
[^>]*> eeb2 9e2f 	vmlsldavax.s16	r8, r7, q1, q7
[^>]*> eeb4 8e01 	vmlsldav.s16	r8, r7, q2, q0
[^>]*> eeb4 8e21 	vmlsldava.s16	r8, r7, q2, q0
[^>]*> eeb4 9e01 	vmlsldavx.s16	r8, r7, q2, q0
[^>]*> eeb4 9e21 	vmlsldavax.s16	r8, r7, q2, q0
[^>]*> eeb4 8e03 	vmlsldav.s16	r8, r7, q2, q1
[^>]*> eeb4 8e23 	vmlsldava.s16	r8, r7, q2, q1
[^>]*> eeb4 9e03 	vmlsldavx.s16	r8, r7, q2, q1
[^>]*> eeb4 9e23 	vmlsldavax.s16	r8, r7, q2, q1
[^>]*> eeb4 8e05 	vmlsldav.s16	r8, r7, q2, q2
[^>]*> eeb4 8e25 	vmlsldava.s16	r8, r7, q2, q2
[^>]*> eeb4 9e05 	vmlsldavx.s16	r8, r7, q2, q2
[^>]*> eeb4 9e25 	vmlsldavax.s16	r8, r7, q2, q2
[^>]*> eeb4 8e09 	vmlsldav.s16	r8, r7, q2, q4
[^>]*> eeb4 8e29 	vmlsldava.s16	r8, r7, q2, q4
[^>]*> eeb4 9e09 	vmlsldavx.s16	r8, r7, q2, q4
[^>]*> eeb4 9e29 	vmlsldavax.s16	r8, r7, q2, q4
[^>]*> eeb4 8e0f 	vmlsldav.s16	r8, r7, q2, q7
[^>]*> eeb4 8e2f 	vmlsldava.s16	r8, r7, q2, q7
[^>]*> eeb4 9e0f 	vmlsldavx.s16	r8, r7, q2, q7
[^>]*> eeb4 9e2f 	vmlsldavax.s16	r8, r7, q2, q7
[^>]*> eeb8 8e01 	vmlsldav.s16	r8, r7, q4, q0
[^>]*> eeb8 8e21 	vmlsldava.s16	r8, r7, q4, q0
[^>]*> eeb8 9e01 	vmlsldavx.s16	r8, r7, q4, q0
[^>]*> eeb8 9e21 	vmlsldavax.s16	r8, r7, q4, q0
[^>]*> eeb8 8e03 	vmlsldav.s16	r8, r7, q4, q1
[^>]*> eeb8 8e23 	vmlsldava.s16	r8, r7, q4, q1
[^>]*> eeb8 9e03 	vmlsldavx.s16	r8, r7, q4, q1
[^>]*> eeb8 9e23 	vmlsldavax.s16	r8, r7, q4, q1
[^>]*> eeb8 8e05 	vmlsldav.s16	r8, r7, q4, q2
[^>]*> eeb8 8e25 	vmlsldava.s16	r8, r7, q4, q2
[^>]*> eeb8 9e05 	vmlsldavx.s16	r8, r7, q4, q2
[^>]*> eeb8 9e25 	vmlsldavax.s16	r8, r7, q4, q2
[^>]*> eeb8 8e09 	vmlsldav.s16	r8, r7, q4, q4
[^>]*> eeb8 8e29 	vmlsldava.s16	r8, r7, q4, q4
[^>]*> eeb8 9e09 	vmlsldavx.s16	r8, r7, q4, q4
[^>]*> eeb8 9e29 	vmlsldavax.s16	r8, r7, q4, q4
[^>]*> eeb8 8e0f 	vmlsldav.s16	r8, r7, q4, q7
[^>]*> eeb8 8e2f 	vmlsldava.s16	r8, r7, q4, q7
[^>]*> eeb8 9e0f 	vmlsldavx.s16	r8, r7, q4, q7
[^>]*> eeb8 9e2f 	vmlsldavax.s16	r8, r7, q4, q7
[^>]*> eebe 8e01 	vmlsldav.s16	r8, r7, q7, q0
[^>]*> eebe 8e21 	vmlsldava.s16	r8, r7, q7, q0
[^>]*> eebe 9e01 	vmlsldavx.s16	r8, r7, q7, q0
[^>]*> eebe 9e21 	vmlsldavax.s16	r8, r7, q7, q0
[^>]*> eebe 8e03 	vmlsldav.s16	r8, r7, q7, q1
[^>]*> eebe 8e23 	vmlsldava.s16	r8, r7, q7, q1
[^>]*> eebe 9e03 	vmlsldavx.s16	r8, r7, q7, q1
[^>]*> eebe 9e23 	vmlsldavax.s16	r8, r7, q7, q1
[^>]*> eebe 8e05 	vmlsldav.s16	r8, r7, q7, q2
[^>]*> eebe 8e25 	vmlsldava.s16	r8, r7, q7, q2
[^>]*> eebe 9e05 	vmlsldavx.s16	r8, r7, q7, q2
[^>]*> eebe 9e25 	vmlsldavax.s16	r8, r7, q7, q2
[^>]*> eebe 8e09 	vmlsldav.s16	r8, r7, q7, q4
[^>]*> eebe 8e29 	vmlsldava.s16	r8, r7, q7, q4
[^>]*> eebe 9e09 	vmlsldavx.s16	r8, r7, q7, q4
[^>]*> eebe 9e29 	vmlsldavax.s16	r8, r7, q7, q4
[^>]*> eebe 8e0f 	vmlsldav.s16	r8, r7, q7, q7
[^>]*> eebe 8e2f 	vmlsldava.s16	r8, r7, q7, q7
[^>]*> eebe 9e0f 	vmlsldavx.s16	r8, r7, q7, q7
[^>]*> eebe 9e2f 	vmlsldavax.s16	r8, r7, q7, q7
[^>]*> eec0 8e01 	vmlsldav.s16	r8, r9, q0, q0
[^>]*> eec0 8e21 	vmlsldava.s16	r8, r9, q0, q0
[^>]*> eec0 9e01 	vmlsldavx.s16	r8, r9, q0, q0
[^>]*> eec0 9e21 	vmlsldavax.s16	r8, r9, q0, q0
[^>]*> eec0 8e03 	vmlsldav.s16	r8, r9, q0, q1
[^>]*> eec0 8e23 	vmlsldava.s16	r8, r9, q0, q1
[^>]*> eec0 9e03 	vmlsldavx.s16	r8, r9, q0, q1
[^>]*> eec0 9e23 	vmlsldavax.s16	r8, r9, q0, q1
[^>]*> eec0 8e05 	vmlsldav.s16	r8, r9, q0, q2
[^>]*> eec0 8e25 	vmlsldava.s16	r8, r9, q0, q2
[^>]*> eec0 9e05 	vmlsldavx.s16	r8, r9, q0, q2
[^>]*> eec0 9e25 	vmlsldavax.s16	r8, r9, q0, q2
[^>]*> eec0 8e09 	vmlsldav.s16	r8, r9, q0, q4
[^>]*> eec0 8e29 	vmlsldava.s16	r8, r9, q0, q4
[^>]*> eec0 9e09 	vmlsldavx.s16	r8, r9, q0, q4
[^>]*> eec0 9e29 	vmlsldavax.s16	r8, r9, q0, q4
[^>]*> eec0 8e0f 	vmlsldav.s16	r8, r9, q0, q7
[^>]*> eec0 8e2f 	vmlsldava.s16	r8, r9, q0, q7
[^>]*> eec0 9e0f 	vmlsldavx.s16	r8, r9, q0, q7
[^>]*> eec0 9e2f 	vmlsldavax.s16	r8, r9, q0, q7
[^>]*> eec2 8e01 	vmlsldav.s16	r8, r9, q1, q0
[^>]*> eec2 8e21 	vmlsldava.s16	r8, r9, q1, q0
[^>]*> eec2 9e01 	vmlsldavx.s16	r8, r9, q1, q0
[^>]*> eec2 9e21 	vmlsldavax.s16	r8, r9, q1, q0
[^>]*> eec2 8e03 	vmlsldav.s16	r8, r9, q1, q1
[^>]*> eec2 8e23 	vmlsldava.s16	r8, r9, q1, q1
[^>]*> eec2 9e03 	vmlsldavx.s16	r8, r9, q1, q1
[^>]*> eec2 9e23 	vmlsldavax.s16	r8, r9, q1, q1
[^>]*> eec2 8e05 	vmlsldav.s16	r8, r9, q1, q2
[^>]*> eec2 8e25 	vmlsldava.s16	r8, r9, q1, q2
[^>]*> eec2 9e05 	vmlsldavx.s16	r8, r9, q1, q2
[^>]*> eec2 9e25 	vmlsldavax.s16	r8, r9, q1, q2
[^>]*> eec2 8e09 	vmlsldav.s16	r8, r9, q1, q4
[^>]*> eec2 8e29 	vmlsldava.s16	r8, r9, q1, q4
[^>]*> eec2 9e09 	vmlsldavx.s16	r8, r9, q1, q4
[^>]*> eec2 9e29 	vmlsldavax.s16	r8, r9, q1, q4
[^>]*> eec2 8e0f 	vmlsldav.s16	r8, r9, q1, q7
[^>]*> eec2 8e2f 	vmlsldava.s16	r8, r9, q1, q7
[^>]*> eec2 9e0f 	vmlsldavx.s16	r8, r9, q1, q7
[^>]*> eec2 9e2f 	vmlsldavax.s16	r8, r9, q1, q7
[^>]*> eec4 8e01 	vmlsldav.s16	r8, r9, q2, q0
[^>]*> eec4 8e21 	vmlsldava.s16	r8, r9, q2, q0
[^>]*> eec4 9e01 	vmlsldavx.s16	r8, r9, q2, q0
[^>]*> eec4 9e21 	vmlsldavax.s16	r8, r9, q2, q0
[^>]*> eec4 8e03 	vmlsldav.s16	r8, r9, q2, q1
[^>]*> eec4 8e23 	vmlsldava.s16	r8, r9, q2, q1
[^>]*> eec4 9e03 	vmlsldavx.s16	r8, r9, q2, q1
[^>]*> eec4 9e23 	vmlsldavax.s16	r8, r9, q2, q1
[^>]*> eec4 8e05 	vmlsldav.s16	r8, r9, q2, q2
[^>]*> eec4 8e25 	vmlsldava.s16	r8, r9, q2, q2
[^>]*> eec4 9e05 	vmlsldavx.s16	r8, r9, q2, q2
[^>]*> eec4 9e25 	vmlsldavax.s16	r8, r9, q2, q2
[^>]*> eec4 8e09 	vmlsldav.s16	r8, r9, q2, q4
[^>]*> eec4 8e29 	vmlsldava.s16	r8, r9, q2, q4
[^>]*> eec4 9e09 	vmlsldavx.s16	r8, r9, q2, q4
[^>]*> eec4 9e29 	vmlsldavax.s16	r8, r9, q2, q4
[^>]*> eec4 8e0f 	vmlsldav.s16	r8, r9, q2, q7
[^>]*> eec4 8e2f 	vmlsldava.s16	r8, r9, q2, q7
[^>]*> eec4 9e0f 	vmlsldavx.s16	r8, r9, q2, q7
[^>]*> eec4 9e2f 	vmlsldavax.s16	r8, r9, q2, q7
[^>]*> eec8 8e01 	vmlsldav.s16	r8, r9, q4, q0
[^>]*> eec8 8e21 	vmlsldava.s16	r8, r9, q4, q0
[^>]*> eec8 9e01 	vmlsldavx.s16	r8, r9, q4, q0
[^>]*> eec8 9e21 	vmlsldavax.s16	r8, r9, q4, q0
[^>]*> eec8 8e03 	vmlsldav.s16	r8, r9, q4, q1
[^>]*> eec8 8e23 	vmlsldava.s16	r8, r9, q4, q1
[^>]*> eec8 9e03 	vmlsldavx.s16	r8, r9, q4, q1
[^>]*> eec8 9e23 	vmlsldavax.s16	r8, r9, q4, q1
[^>]*> eec8 8e05 	vmlsldav.s16	r8, r9, q4, q2
[^>]*> eec8 8e25 	vmlsldava.s16	r8, r9, q4, q2
[^>]*> eec8 9e05 	vmlsldavx.s16	r8, r9, q4, q2
[^>]*> eec8 9e25 	vmlsldavax.s16	r8, r9, q4, q2
[^>]*> eec8 8e09 	vmlsldav.s16	r8, r9, q4, q4
[^>]*> eec8 8e29 	vmlsldava.s16	r8, r9, q4, q4
[^>]*> eec8 9e09 	vmlsldavx.s16	r8, r9, q4, q4
[^>]*> eec8 9e29 	vmlsldavax.s16	r8, r9, q4, q4
[^>]*> eec8 8e0f 	vmlsldav.s16	r8, r9, q4, q7
[^>]*> eec8 8e2f 	vmlsldava.s16	r8, r9, q4, q7
[^>]*> eec8 9e0f 	vmlsldavx.s16	r8, r9, q4, q7
[^>]*> eec8 9e2f 	vmlsldavax.s16	r8, r9, q4, q7
[^>]*> eece 8e01 	vmlsldav.s16	r8, r9, q7, q0
[^>]*> eece 8e21 	vmlsldava.s16	r8, r9, q7, q0
[^>]*> eece 9e01 	vmlsldavx.s16	r8, r9, q7, q0
[^>]*> eece 9e21 	vmlsldavax.s16	r8, r9, q7, q0
[^>]*> eece 8e03 	vmlsldav.s16	r8, r9, q7, q1
[^>]*> eece 8e23 	vmlsldava.s16	r8, r9, q7, q1
[^>]*> eece 9e03 	vmlsldavx.s16	r8, r9, q7, q1
[^>]*> eece 9e23 	vmlsldavax.s16	r8, r9, q7, q1
[^>]*> eece 8e05 	vmlsldav.s16	r8, r9, q7, q2
[^>]*> eece 8e25 	vmlsldava.s16	r8, r9, q7, q2
[^>]*> eece 9e05 	vmlsldavx.s16	r8, r9, q7, q2
[^>]*> eece 9e25 	vmlsldavax.s16	r8, r9, q7, q2
[^>]*> eece 8e09 	vmlsldav.s16	r8, r9, q7, q4
[^>]*> eece 8e29 	vmlsldava.s16	r8, r9, q7, q4
[^>]*> eece 9e09 	vmlsldavx.s16	r8, r9, q7, q4
[^>]*> eece 9e29 	vmlsldavax.s16	r8, r9, q7, q4
[^>]*> eece 8e0f 	vmlsldav.s16	r8, r9, q7, q7
[^>]*> eece 8e2f 	vmlsldava.s16	r8, r9, q7, q7
[^>]*> eece 9e0f 	vmlsldavx.s16	r8, r9, q7, q7
[^>]*> eece 9e2f 	vmlsldavax.s16	r8, r9, q7, q7
[^>]*> eed0 8e01 	vmlsldav.s16	r8, fp, q0, q0
[^>]*> eed0 8e21 	vmlsldava.s16	r8, fp, q0, q0
[^>]*> eed0 9e01 	vmlsldavx.s16	r8, fp, q0, q0
[^>]*> eed0 9e21 	vmlsldavax.s16	r8, fp, q0, q0
[^>]*> eed0 8e03 	vmlsldav.s16	r8, fp, q0, q1
[^>]*> eed0 8e23 	vmlsldava.s16	r8, fp, q0, q1
[^>]*> eed0 9e03 	vmlsldavx.s16	r8, fp, q0, q1
[^>]*> eed0 9e23 	vmlsldavax.s16	r8, fp, q0, q1
[^>]*> eed0 8e05 	vmlsldav.s16	r8, fp, q0, q2
[^>]*> eed0 8e25 	vmlsldava.s16	r8, fp, q0, q2
[^>]*> eed0 9e05 	vmlsldavx.s16	r8, fp, q0, q2
[^>]*> eed0 9e25 	vmlsldavax.s16	r8, fp, q0, q2
[^>]*> eed0 8e09 	vmlsldav.s16	r8, fp, q0, q4
[^>]*> eed0 8e29 	vmlsldava.s16	r8, fp, q0, q4
[^>]*> eed0 9e09 	vmlsldavx.s16	r8, fp, q0, q4
[^>]*> eed0 9e29 	vmlsldavax.s16	r8, fp, q0, q4
[^>]*> eed0 8e0f 	vmlsldav.s16	r8, fp, q0, q7
[^>]*> eed0 8e2f 	vmlsldava.s16	r8, fp, q0, q7
[^>]*> eed0 9e0f 	vmlsldavx.s16	r8, fp, q0, q7
[^>]*> eed0 9e2f 	vmlsldavax.s16	r8, fp, q0, q7
[^>]*> eed2 8e01 	vmlsldav.s16	r8, fp, q1, q0
[^>]*> eed2 8e21 	vmlsldava.s16	r8, fp, q1, q0
[^>]*> eed2 9e01 	vmlsldavx.s16	r8, fp, q1, q0
[^>]*> eed2 9e21 	vmlsldavax.s16	r8, fp, q1, q0
[^>]*> eed2 8e03 	vmlsldav.s16	r8, fp, q1, q1
[^>]*> eed2 8e23 	vmlsldava.s16	r8, fp, q1, q1
[^>]*> eed2 9e03 	vmlsldavx.s16	r8, fp, q1, q1
[^>]*> eed2 9e23 	vmlsldavax.s16	r8, fp, q1, q1
[^>]*> eed2 8e05 	vmlsldav.s16	r8, fp, q1, q2
[^>]*> eed2 8e25 	vmlsldava.s16	r8, fp, q1, q2
[^>]*> eed2 9e05 	vmlsldavx.s16	r8, fp, q1, q2
[^>]*> eed2 9e25 	vmlsldavax.s16	r8, fp, q1, q2
[^>]*> eed2 8e09 	vmlsldav.s16	r8, fp, q1, q4
[^>]*> eed2 8e29 	vmlsldava.s16	r8, fp, q1, q4
[^>]*> eed2 9e09 	vmlsldavx.s16	r8, fp, q1, q4
[^>]*> eed2 9e29 	vmlsldavax.s16	r8, fp, q1, q4
[^>]*> eed2 8e0f 	vmlsldav.s16	r8, fp, q1, q7
[^>]*> eed2 8e2f 	vmlsldava.s16	r8, fp, q1, q7
[^>]*> eed2 9e0f 	vmlsldavx.s16	r8, fp, q1, q7
[^>]*> eed2 9e2f 	vmlsldavax.s16	r8, fp, q1, q7
[^>]*> eed4 8e01 	vmlsldav.s16	r8, fp, q2, q0
[^>]*> eed4 8e21 	vmlsldava.s16	r8, fp, q2, q0
[^>]*> eed4 9e01 	vmlsldavx.s16	r8, fp, q2, q0
[^>]*> eed4 9e21 	vmlsldavax.s16	r8, fp, q2, q0
[^>]*> eed4 8e03 	vmlsldav.s16	r8, fp, q2, q1
[^>]*> eed4 8e23 	vmlsldava.s16	r8, fp, q2, q1
[^>]*> eed4 9e03 	vmlsldavx.s16	r8, fp, q2, q1
[^>]*> eed4 9e23 	vmlsldavax.s16	r8, fp, q2, q1
[^>]*> eed4 8e05 	vmlsldav.s16	r8, fp, q2, q2
[^>]*> eed4 8e25 	vmlsldava.s16	r8, fp, q2, q2
[^>]*> eed4 9e05 	vmlsldavx.s16	r8, fp, q2, q2
[^>]*> eed4 9e25 	vmlsldavax.s16	r8, fp, q2, q2
[^>]*> eed4 8e09 	vmlsldav.s16	r8, fp, q2, q4
[^>]*> eed4 8e29 	vmlsldava.s16	r8, fp, q2, q4
[^>]*> eed4 9e09 	vmlsldavx.s16	r8, fp, q2, q4
[^>]*> eed4 9e29 	vmlsldavax.s16	r8, fp, q2, q4
[^>]*> eed4 8e0f 	vmlsldav.s16	r8, fp, q2, q7
[^>]*> eed4 8e2f 	vmlsldava.s16	r8, fp, q2, q7
[^>]*> eed4 9e0f 	vmlsldavx.s16	r8, fp, q2, q7
[^>]*> eed4 9e2f 	vmlsldavax.s16	r8, fp, q2, q7
[^>]*> eed8 8e01 	vmlsldav.s16	r8, fp, q4, q0
[^>]*> eed8 8e21 	vmlsldava.s16	r8, fp, q4, q0
[^>]*> eed8 9e01 	vmlsldavx.s16	r8, fp, q4, q0
[^>]*> eed8 9e21 	vmlsldavax.s16	r8, fp, q4, q0
[^>]*> eed8 8e03 	vmlsldav.s16	r8, fp, q4, q1
[^>]*> eed8 8e23 	vmlsldava.s16	r8, fp, q4, q1
[^>]*> eed8 9e03 	vmlsldavx.s16	r8, fp, q4, q1
[^>]*> eed8 9e23 	vmlsldavax.s16	r8, fp, q4, q1
[^>]*> eed8 8e05 	vmlsldav.s16	r8, fp, q4, q2
[^>]*> eed8 8e25 	vmlsldava.s16	r8, fp, q4, q2
[^>]*> eed8 9e05 	vmlsldavx.s16	r8, fp, q4, q2
[^>]*> eed8 9e25 	vmlsldavax.s16	r8, fp, q4, q2
[^>]*> eed8 8e09 	vmlsldav.s16	r8, fp, q4, q4
[^>]*> eed8 8e29 	vmlsldava.s16	r8, fp, q4, q4
[^>]*> eed8 9e09 	vmlsldavx.s16	r8, fp, q4, q4
[^>]*> eed8 9e29 	vmlsldavax.s16	r8, fp, q4, q4
[^>]*> eed8 8e0f 	vmlsldav.s16	r8, fp, q4, q7
[^>]*> eed8 8e2f 	vmlsldava.s16	r8, fp, q4, q7
[^>]*> eed8 9e0f 	vmlsldavx.s16	r8, fp, q4, q7
[^>]*> eed8 9e2f 	vmlsldavax.s16	r8, fp, q4, q7
[^>]*> eede 8e01 	vmlsldav.s16	r8, fp, q7, q0
[^>]*> eede 8e21 	vmlsldava.s16	r8, fp, q7, q0
[^>]*> eede 9e01 	vmlsldavx.s16	r8, fp, q7, q0
[^>]*> eede 9e21 	vmlsldavax.s16	r8, fp, q7, q0
[^>]*> eede 8e03 	vmlsldav.s16	r8, fp, q7, q1
[^>]*> eede 8e23 	vmlsldava.s16	r8, fp, q7, q1
[^>]*> eede 9e03 	vmlsldavx.s16	r8, fp, q7, q1
[^>]*> eede 9e23 	vmlsldavax.s16	r8, fp, q7, q1
[^>]*> eede 8e05 	vmlsldav.s16	r8, fp, q7, q2
[^>]*> eede 8e25 	vmlsldava.s16	r8, fp, q7, q2
[^>]*> eede 9e05 	vmlsldavx.s16	r8, fp, q7, q2
[^>]*> eede 9e25 	vmlsldavax.s16	r8, fp, q7, q2
[^>]*> eede 8e09 	vmlsldav.s16	r8, fp, q7, q4
[^>]*> eede 8e29 	vmlsldava.s16	r8, fp, q7, q4
[^>]*> eede 9e09 	vmlsldavx.s16	r8, fp, q7, q4
[^>]*> eede 9e29 	vmlsldavax.s16	r8, fp, q7, q4
[^>]*> eede 8e0f 	vmlsldav.s16	r8, fp, q7, q7
[^>]*> eede 8e2f 	vmlsldava.s16	r8, fp, q7, q7
[^>]*> eede 9e0f 	vmlsldavx.s16	r8, fp, q7, q7
[^>]*> eede 9e2f 	vmlsldavax.s16	r8, fp, q7, q7
[^>]*> ee80 ae01 	vmlsldav.s16	sl, r1, q0, q0
[^>]*> ee80 ae21 	vmlsldava.s16	sl, r1, q0, q0
[^>]*> ee80 be01 	vmlsldavx.s16	sl, r1, q0, q0
[^>]*> ee80 be21 	vmlsldavax.s16	sl, r1, q0, q0
[^>]*> ee80 ae03 	vmlsldav.s16	sl, r1, q0, q1
[^>]*> ee80 ae23 	vmlsldava.s16	sl, r1, q0, q1
[^>]*> ee80 be03 	vmlsldavx.s16	sl, r1, q0, q1
[^>]*> ee80 be23 	vmlsldavax.s16	sl, r1, q0, q1
[^>]*> ee80 ae05 	vmlsldav.s16	sl, r1, q0, q2
[^>]*> ee80 ae25 	vmlsldava.s16	sl, r1, q0, q2
[^>]*> ee80 be05 	vmlsldavx.s16	sl, r1, q0, q2
[^>]*> ee80 be25 	vmlsldavax.s16	sl, r1, q0, q2
[^>]*> ee80 ae09 	vmlsldav.s16	sl, r1, q0, q4
[^>]*> ee80 ae29 	vmlsldava.s16	sl, r1, q0, q4
[^>]*> ee80 be09 	vmlsldavx.s16	sl, r1, q0, q4
[^>]*> ee80 be29 	vmlsldavax.s16	sl, r1, q0, q4
[^>]*> ee80 ae0f 	vmlsldav.s16	sl, r1, q0, q7
[^>]*> ee80 ae2f 	vmlsldava.s16	sl, r1, q0, q7
[^>]*> ee80 be0f 	vmlsldavx.s16	sl, r1, q0, q7
[^>]*> ee80 be2f 	vmlsldavax.s16	sl, r1, q0, q7
[^>]*> ee82 ae01 	vmlsldav.s16	sl, r1, q1, q0
[^>]*> ee82 ae21 	vmlsldava.s16	sl, r1, q1, q0
[^>]*> ee82 be01 	vmlsldavx.s16	sl, r1, q1, q0
[^>]*> ee82 be21 	vmlsldavax.s16	sl, r1, q1, q0
[^>]*> ee82 ae03 	vmlsldav.s16	sl, r1, q1, q1
[^>]*> ee82 ae23 	vmlsldava.s16	sl, r1, q1, q1
[^>]*> ee82 be03 	vmlsldavx.s16	sl, r1, q1, q1
[^>]*> ee82 be23 	vmlsldavax.s16	sl, r1, q1, q1
[^>]*> ee82 ae05 	vmlsldav.s16	sl, r1, q1, q2
[^>]*> ee82 ae25 	vmlsldava.s16	sl, r1, q1, q2
[^>]*> ee82 be05 	vmlsldavx.s16	sl, r1, q1, q2
[^>]*> ee82 be25 	vmlsldavax.s16	sl, r1, q1, q2
[^>]*> ee82 ae09 	vmlsldav.s16	sl, r1, q1, q4
[^>]*> ee82 ae29 	vmlsldava.s16	sl, r1, q1, q4
[^>]*> ee82 be09 	vmlsldavx.s16	sl, r1, q1, q4
[^>]*> ee82 be29 	vmlsldavax.s16	sl, r1, q1, q4
[^>]*> ee82 ae0f 	vmlsldav.s16	sl, r1, q1, q7
[^>]*> ee82 ae2f 	vmlsldava.s16	sl, r1, q1, q7
[^>]*> ee82 be0f 	vmlsldavx.s16	sl, r1, q1, q7
[^>]*> ee82 be2f 	vmlsldavax.s16	sl, r1, q1, q7
[^>]*> ee84 ae01 	vmlsldav.s16	sl, r1, q2, q0
[^>]*> ee84 ae21 	vmlsldava.s16	sl, r1, q2, q0
[^>]*> ee84 be01 	vmlsldavx.s16	sl, r1, q2, q0
[^>]*> ee84 be21 	vmlsldavax.s16	sl, r1, q2, q0
[^>]*> ee84 ae03 	vmlsldav.s16	sl, r1, q2, q1
[^>]*> ee84 ae23 	vmlsldava.s16	sl, r1, q2, q1
[^>]*> ee84 be03 	vmlsldavx.s16	sl, r1, q2, q1
[^>]*> ee84 be23 	vmlsldavax.s16	sl, r1, q2, q1
[^>]*> ee84 ae05 	vmlsldav.s16	sl, r1, q2, q2
[^>]*> ee84 ae25 	vmlsldava.s16	sl, r1, q2, q2
[^>]*> ee84 be05 	vmlsldavx.s16	sl, r1, q2, q2
[^>]*> ee84 be25 	vmlsldavax.s16	sl, r1, q2, q2
[^>]*> ee84 ae09 	vmlsldav.s16	sl, r1, q2, q4
[^>]*> ee84 ae29 	vmlsldava.s16	sl, r1, q2, q4
[^>]*> ee84 be09 	vmlsldavx.s16	sl, r1, q2, q4
[^>]*> ee84 be29 	vmlsldavax.s16	sl, r1, q2, q4
[^>]*> ee84 ae0f 	vmlsldav.s16	sl, r1, q2, q7
[^>]*> ee84 ae2f 	vmlsldava.s16	sl, r1, q2, q7
[^>]*> ee84 be0f 	vmlsldavx.s16	sl, r1, q2, q7
[^>]*> ee84 be2f 	vmlsldavax.s16	sl, r1, q2, q7
[^>]*> ee88 ae01 	vmlsldav.s16	sl, r1, q4, q0
[^>]*> ee88 ae21 	vmlsldava.s16	sl, r1, q4, q0
[^>]*> ee88 be01 	vmlsldavx.s16	sl, r1, q4, q0
[^>]*> ee88 be21 	vmlsldavax.s16	sl, r1, q4, q0
[^>]*> ee88 ae03 	vmlsldav.s16	sl, r1, q4, q1
[^>]*> ee88 ae23 	vmlsldava.s16	sl, r1, q4, q1
[^>]*> ee88 be03 	vmlsldavx.s16	sl, r1, q4, q1
[^>]*> ee88 be23 	vmlsldavax.s16	sl, r1, q4, q1
[^>]*> ee88 ae05 	vmlsldav.s16	sl, r1, q4, q2
[^>]*> ee88 ae25 	vmlsldava.s16	sl, r1, q4, q2
[^>]*> ee88 be05 	vmlsldavx.s16	sl, r1, q4, q2
[^>]*> ee88 be25 	vmlsldavax.s16	sl, r1, q4, q2
[^>]*> ee88 ae09 	vmlsldav.s16	sl, r1, q4, q4
[^>]*> ee88 ae29 	vmlsldava.s16	sl, r1, q4, q4
[^>]*> ee88 be09 	vmlsldavx.s16	sl, r1, q4, q4
[^>]*> ee88 be29 	vmlsldavax.s16	sl, r1, q4, q4
[^>]*> ee88 ae0f 	vmlsldav.s16	sl, r1, q4, q7
[^>]*> ee88 ae2f 	vmlsldava.s16	sl, r1, q4, q7
[^>]*> ee88 be0f 	vmlsldavx.s16	sl, r1, q4, q7
[^>]*> ee88 be2f 	vmlsldavax.s16	sl, r1, q4, q7
[^>]*> ee8e ae01 	vmlsldav.s16	sl, r1, q7, q0
[^>]*> ee8e ae21 	vmlsldava.s16	sl, r1, q7, q0
[^>]*> ee8e be01 	vmlsldavx.s16	sl, r1, q7, q0
[^>]*> ee8e be21 	vmlsldavax.s16	sl, r1, q7, q0
[^>]*> ee8e ae03 	vmlsldav.s16	sl, r1, q7, q1
[^>]*> ee8e ae23 	vmlsldava.s16	sl, r1, q7, q1
[^>]*> ee8e be03 	vmlsldavx.s16	sl, r1, q7, q1
[^>]*> ee8e be23 	vmlsldavax.s16	sl, r1, q7, q1
[^>]*> ee8e ae05 	vmlsldav.s16	sl, r1, q7, q2
[^>]*> ee8e ae25 	vmlsldava.s16	sl, r1, q7, q2
[^>]*> ee8e be05 	vmlsldavx.s16	sl, r1, q7, q2
[^>]*> ee8e be25 	vmlsldavax.s16	sl, r1, q7, q2
[^>]*> ee8e ae09 	vmlsldav.s16	sl, r1, q7, q4
[^>]*> ee8e ae29 	vmlsldava.s16	sl, r1, q7, q4
[^>]*> ee8e be09 	vmlsldavx.s16	sl, r1, q7, q4
[^>]*> ee8e be29 	vmlsldavax.s16	sl, r1, q7, q4
[^>]*> ee8e ae0f 	vmlsldav.s16	sl, r1, q7, q7
[^>]*> ee8e ae2f 	vmlsldava.s16	sl, r1, q7, q7
[^>]*> ee8e be0f 	vmlsldavx.s16	sl, r1, q7, q7
[^>]*> ee8e be2f 	vmlsldavax.s16	sl, r1, q7, q7
[^>]*> ee90 ae01 	vmlsldav.s16	sl, r3, q0, q0
[^>]*> ee90 ae21 	vmlsldava.s16	sl, r3, q0, q0
[^>]*> ee90 be01 	vmlsldavx.s16	sl, r3, q0, q0
[^>]*> ee90 be21 	vmlsldavax.s16	sl, r3, q0, q0
[^>]*> ee90 ae03 	vmlsldav.s16	sl, r3, q0, q1
[^>]*> ee90 ae23 	vmlsldava.s16	sl, r3, q0, q1
[^>]*> ee90 be03 	vmlsldavx.s16	sl, r3, q0, q1
[^>]*> ee90 be23 	vmlsldavax.s16	sl, r3, q0, q1
[^>]*> ee90 ae05 	vmlsldav.s16	sl, r3, q0, q2
[^>]*> ee90 ae25 	vmlsldava.s16	sl, r3, q0, q2
[^>]*> ee90 be05 	vmlsldavx.s16	sl, r3, q0, q2
[^>]*> ee90 be25 	vmlsldavax.s16	sl, r3, q0, q2
[^>]*> ee90 ae09 	vmlsldav.s16	sl, r3, q0, q4
[^>]*> ee90 ae29 	vmlsldava.s16	sl, r3, q0, q4
[^>]*> ee90 be09 	vmlsldavx.s16	sl, r3, q0, q4
[^>]*> ee90 be29 	vmlsldavax.s16	sl, r3, q0, q4
[^>]*> ee90 ae0f 	vmlsldav.s16	sl, r3, q0, q7
[^>]*> ee90 ae2f 	vmlsldava.s16	sl, r3, q0, q7
[^>]*> ee90 be0f 	vmlsldavx.s16	sl, r3, q0, q7
[^>]*> ee90 be2f 	vmlsldavax.s16	sl, r3, q0, q7
[^>]*> ee92 ae01 	vmlsldav.s16	sl, r3, q1, q0
[^>]*> ee92 ae21 	vmlsldava.s16	sl, r3, q1, q0
[^>]*> ee92 be01 	vmlsldavx.s16	sl, r3, q1, q0
[^>]*> ee92 be21 	vmlsldavax.s16	sl, r3, q1, q0
[^>]*> ee92 ae03 	vmlsldav.s16	sl, r3, q1, q1
[^>]*> ee92 ae23 	vmlsldava.s16	sl, r3, q1, q1
[^>]*> ee92 be03 	vmlsldavx.s16	sl, r3, q1, q1
[^>]*> ee92 be23 	vmlsldavax.s16	sl, r3, q1, q1
[^>]*> ee92 ae05 	vmlsldav.s16	sl, r3, q1, q2
[^>]*> ee92 ae25 	vmlsldava.s16	sl, r3, q1, q2
[^>]*> ee92 be05 	vmlsldavx.s16	sl, r3, q1, q2
[^>]*> ee92 be25 	vmlsldavax.s16	sl, r3, q1, q2
[^>]*> ee92 ae09 	vmlsldav.s16	sl, r3, q1, q4
[^>]*> ee92 ae29 	vmlsldava.s16	sl, r3, q1, q4
[^>]*> ee92 be09 	vmlsldavx.s16	sl, r3, q1, q4
[^>]*> ee92 be29 	vmlsldavax.s16	sl, r3, q1, q4
[^>]*> ee92 ae0f 	vmlsldav.s16	sl, r3, q1, q7
[^>]*> ee92 ae2f 	vmlsldava.s16	sl, r3, q1, q7
[^>]*> ee92 be0f 	vmlsldavx.s16	sl, r3, q1, q7
[^>]*> ee92 be2f 	vmlsldavax.s16	sl, r3, q1, q7
[^>]*> ee94 ae01 	vmlsldav.s16	sl, r3, q2, q0
[^>]*> ee94 ae21 	vmlsldava.s16	sl, r3, q2, q0
[^>]*> ee94 be01 	vmlsldavx.s16	sl, r3, q2, q0
[^>]*> ee94 be21 	vmlsldavax.s16	sl, r3, q2, q0
[^>]*> ee94 ae03 	vmlsldav.s16	sl, r3, q2, q1
[^>]*> ee94 ae23 	vmlsldava.s16	sl, r3, q2, q1
[^>]*> ee94 be03 	vmlsldavx.s16	sl, r3, q2, q1
[^>]*> ee94 be23 	vmlsldavax.s16	sl, r3, q2, q1
[^>]*> ee94 ae05 	vmlsldav.s16	sl, r3, q2, q2
[^>]*> ee94 ae25 	vmlsldava.s16	sl, r3, q2, q2
[^>]*> ee94 be05 	vmlsldavx.s16	sl, r3, q2, q2
[^>]*> ee94 be25 	vmlsldavax.s16	sl, r3, q2, q2
[^>]*> ee94 ae09 	vmlsldav.s16	sl, r3, q2, q4
[^>]*> ee94 ae29 	vmlsldava.s16	sl, r3, q2, q4
[^>]*> ee94 be09 	vmlsldavx.s16	sl, r3, q2, q4
[^>]*> ee94 be29 	vmlsldavax.s16	sl, r3, q2, q4
[^>]*> ee94 ae0f 	vmlsldav.s16	sl, r3, q2, q7
[^>]*> ee94 ae2f 	vmlsldava.s16	sl, r3, q2, q7
[^>]*> ee94 be0f 	vmlsldavx.s16	sl, r3, q2, q7
[^>]*> ee94 be2f 	vmlsldavax.s16	sl, r3, q2, q7
[^>]*> ee98 ae01 	vmlsldav.s16	sl, r3, q4, q0
[^>]*> ee98 ae21 	vmlsldava.s16	sl, r3, q4, q0
[^>]*> ee98 be01 	vmlsldavx.s16	sl, r3, q4, q0
[^>]*> ee98 be21 	vmlsldavax.s16	sl, r3, q4, q0
[^>]*> ee98 ae03 	vmlsldav.s16	sl, r3, q4, q1
[^>]*> ee98 ae23 	vmlsldava.s16	sl, r3, q4, q1
[^>]*> ee98 be03 	vmlsldavx.s16	sl, r3, q4, q1
[^>]*> ee98 be23 	vmlsldavax.s16	sl, r3, q4, q1
[^>]*> ee98 ae05 	vmlsldav.s16	sl, r3, q4, q2
[^>]*> ee98 ae25 	vmlsldava.s16	sl, r3, q4, q2
[^>]*> ee98 be05 	vmlsldavx.s16	sl, r3, q4, q2
[^>]*> ee98 be25 	vmlsldavax.s16	sl, r3, q4, q2
[^>]*> ee98 ae09 	vmlsldav.s16	sl, r3, q4, q4
[^>]*> ee98 ae29 	vmlsldava.s16	sl, r3, q4, q4
[^>]*> ee98 be09 	vmlsldavx.s16	sl, r3, q4, q4
[^>]*> ee98 be29 	vmlsldavax.s16	sl, r3, q4, q4
[^>]*> ee98 ae0f 	vmlsldav.s16	sl, r3, q4, q7
[^>]*> ee98 ae2f 	vmlsldava.s16	sl, r3, q4, q7
[^>]*> ee98 be0f 	vmlsldavx.s16	sl, r3, q4, q7
[^>]*> ee98 be2f 	vmlsldavax.s16	sl, r3, q4, q7
[^>]*> ee9e ae01 	vmlsldav.s16	sl, r3, q7, q0
[^>]*> ee9e ae21 	vmlsldava.s16	sl, r3, q7, q0
[^>]*> ee9e be01 	vmlsldavx.s16	sl, r3, q7, q0
[^>]*> ee9e be21 	vmlsldavax.s16	sl, r3, q7, q0
[^>]*> ee9e ae03 	vmlsldav.s16	sl, r3, q7, q1
[^>]*> ee9e ae23 	vmlsldava.s16	sl, r3, q7, q1
[^>]*> ee9e be03 	vmlsldavx.s16	sl, r3, q7, q1
[^>]*> ee9e be23 	vmlsldavax.s16	sl, r3, q7, q1
[^>]*> ee9e ae05 	vmlsldav.s16	sl, r3, q7, q2
[^>]*> ee9e ae25 	vmlsldava.s16	sl, r3, q7, q2
[^>]*> ee9e be05 	vmlsldavx.s16	sl, r3, q7, q2
[^>]*> ee9e be25 	vmlsldavax.s16	sl, r3, q7, q2
[^>]*> ee9e ae09 	vmlsldav.s16	sl, r3, q7, q4
[^>]*> ee9e ae29 	vmlsldava.s16	sl, r3, q7, q4
[^>]*> ee9e be09 	vmlsldavx.s16	sl, r3, q7, q4
[^>]*> ee9e be29 	vmlsldavax.s16	sl, r3, q7, q4
[^>]*> ee9e ae0f 	vmlsldav.s16	sl, r3, q7, q7
[^>]*> ee9e ae2f 	vmlsldava.s16	sl, r3, q7, q7
[^>]*> ee9e be0f 	vmlsldavx.s16	sl, r3, q7, q7
[^>]*> ee9e be2f 	vmlsldavax.s16	sl, r3, q7, q7
[^>]*> eea0 ae01 	vmlsldav.s16	sl, r5, q0, q0
[^>]*> eea0 ae21 	vmlsldava.s16	sl, r5, q0, q0
[^>]*> eea0 be01 	vmlsldavx.s16	sl, r5, q0, q0
[^>]*> eea0 be21 	vmlsldavax.s16	sl, r5, q0, q0
[^>]*> eea0 ae03 	vmlsldav.s16	sl, r5, q0, q1
[^>]*> eea0 ae23 	vmlsldava.s16	sl, r5, q0, q1
[^>]*> eea0 be03 	vmlsldavx.s16	sl, r5, q0, q1
[^>]*> eea0 be23 	vmlsldavax.s16	sl, r5, q0, q1
[^>]*> eea0 ae05 	vmlsldav.s16	sl, r5, q0, q2
[^>]*> eea0 ae25 	vmlsldava.s16	sl, r5, q0, q2
[^>]*> eea0 be05 	vmlsldavx.s16	sl, r5, q0, q2
[^>]*> eea0 be25 	vmlsldavax.s16	sl, r5, q0, q2
[^>]*> eea0 ae09 	vmlsldav.s16	sl, r5, q0, q4
[^>]*> eea0 ae29 	vmlsldava.s16	sl, r5, q0, q4
[^>]*> eea0 be09 	vmlsldavx.s16	sl, r5, q0, q4
[^>]*> eea0 be29 	vmlsldavax.s16	sl, r5, q0, q4
[^>]*> eea0 ae0f 	vmlsldav.s16	sl, r5, q0, q7
[^>]*> eea0 ae2f 	vmlsldava.s16	sl, r5, q0, q7
[^>]*> eea0 be0f 	vmlsldavx.s16	sl, r5, q0, q7
[^>]*> eea0 be2f 	vmlsldavax.s16	sl, r5, q0, q7
[^>]*> eea2 ae01 	vmlsldav.s16	sl, r5, q1, q0
[^>]*> eea2 ae21 	vmlsldava.s16	sl, r5, q1, q0
[^>]*> eea2 be01 	vmlsldavx.s16	sl, r5, q1, q0
[^>]*> eea2 be21 	vmlsldavax.s16	sl, r5, q1, q0
[^>]*> eea2 ae03 	vmlsldav.s16	sl, r5, q1, q1
[^>]*> eea2 ae23 	vmlsldava.s16	sl, r5, q1, q1
[^>]*> eea2 be03 	vmlsldavx.s16	sl, r5, q1, q1
[^>]*> eea2 be23 	vmlsldavax.s16	sl, r5, q1, q1
[^>]*> eea2 ae05 	vmlsldav.s16	sl, r5, q1, q2
[^>]*> eea2 ae25 	vmlsldava.s16	sl, r5, q1, q2
[^>]*> eea2 be05 	vmlsldavx.s16	sl, r5, q1, q2
[^>]*> eea2 be25 	vmlsldavax.s16	sl, r5, q1, q2
[^>]*> eea2 ae09 	vmlsldav.s16	sl, r5, q1, q4
[^>]*> eea2 ae29 	vmlsldava.s16	sl, r5, q1, q4
[^>]*> eea2 be09 	vmlsldavx.s16	sl, r5, q1, q4
[^>]*> eea2 be29 	vmlsldavax.s16	sl, r5, q1, q4
[^>]*> eea2 ae0f 	vmlsldav.s16	sl, r5, q1, q7
[^>]*> eea2 ae2f 	vmlsldava.s16	sl, r5, q1, q7
[^>]*> eea2 be0f 	vmlsldavx.s16	sl, r5, q1, q7
[^>]*> eea2 be2f 	vmlsldavax.s16	sl, r5, q1, q7
[^>]*> eea4 ae01 	vmlsldav.s16	sl, r5, q2, q0
[^>]*> eea4 ae21 	vmlsldava.s16	sl, r5, q2, q0
[^>]*> eea4 be01 	vmlsldavx.s16	sl, r5, q2, q0
[^>]*> eea4 be21 	vmlsldavax.s16	sl, r5, q2, q0
[^>]*> eea4 ae03 	vmlsldav.s16	sl, r5, q2, q1
[^>]*> eea4 ae23 	vmlsldava.s16	sl, r5, q2, q1
[^>]*> eea4 be03 	vmlsldavx.s16	sl, r5, q2, q1
[^>]*> eea4 be23 	vmlsldavax.s16	sl, r5, q2, q1
[^>]*> eea4 ae05 	vmlsldav.s16	sl, r5, q2, q2
[^>]*> eea4 ae25 	vmlsldava.s16	sl, r5, q2, q2
[^>]*> eea4 be05 	vmlsldavx.s16	sl, r5, q2, q2
[^>]*> eea4 be25 	vmlsldavax.s16	sl, r5, q2, q2
[^>]*> eea4 ae09 	vmlsldav.s16	sl, r5, q2, q4
[^>]*> eea4 ae29 	vmlsldava.s16	sl, r5, q2, q4
[^>]*> eea4 be09 	vmlsldavx.s16	sl, r5, q2, q4
[^>]*> eea4 be29 	vmlsldavax.s16	sl, r5, q2, q4
[^>]*> eea4 ae0f 	vmlsldav.s16	sl, r5, q2, q7
[^>]*> eea4 ae2f 	vmlsldava.s16	sl, r5, q2, q7
[^>]*> eea4 be0f 	vmlsldavx.s16	sl, r5, q2, q7
[^>]*> eea4 be2f 	vmlsldavax.s16	sl, r5, q2, q7
[^>]*> eea8 ae01 	vmlsldav.s16	sl, r5, q4, q0
[^>]*> eea8 ae21 	vmlsldava.s16	sl, r5, q4, q0
[^>]*> eea8 be01 	vmlsldavx.s16	sl, r5, q4, q0
[^>]*> eea8 be21 	vmlsldavax.s16	sl, r5, q4, q0
[^>]*> eea8 ae03 	vmlsldav.s16	sl, r5, q4, q1
[^>]*> eea8 ae23 	vmlsldava.s16	sl, r5, q4, q1
[^>]*> eea8 be03 	vmlsldavx.s16	sl, r5, q4, q1
[^>]*> eea8 be23 	vmlsldavax.s16	sl, r5, q4, q1
[^>]*> eea8 ae05 	vmlsldav.s16	sl, r5, q4, q2
[^>]*> eea8 ae25 	vmlsldava.s16	sl, r5, q4, q2
[^>]*> eea8 be05 	vmlsldavx.s16	sl, r5, q4, q2
[^>]*> eea8 be25 	vmlsldavax.s16	sl, r5, q4, q2
[^>]*> eea8 ae09 	vmlsldav.s16	sl, r5, q4, q4
[^>]*> eea8 ae29 	vmlsldava.s16	sl, r5, q4, q4
[^>]*> eea8 be09 	vmlsldavx.s16	sl, r5, q4, q4
[^>]*> eea8 be29 	vmlsldavax.s16	sl, r5, q4, q4
[^>]*> eea8 ae0f 	vmlsldav.s16	sl, r5, q4, q7
[^>]*> eea8 ae2f 	vmlsldava.s16	sl, r5, q4, q7
[^>]*> eea8 be0f 	vmlsldavx.s16	sl, r5, q4, q7
[^>]*> eea8 be2f 	vmlsldavax.s16	sl, r5, q4, q7
[^>]*> eeae ae01 	vmlsldav.s16	sl, r5, q7, q0
[^>]*> eeae ae21 	vmlsldava.s16	sl, r5, q7, q0
[^>]*> eeae be01 	vmlsldavx.s16	sl, r5, q7, q0
[^>]*> eeae be21 	vmlsldavax.s16	sl, r5, q7, q0
[^>]*> eeae ae03 	vmlsldav.s16	sl, r5, q7, q1
[^>]*> eeae ae23 	vmlsldava.s16	sl, r5, q7, q1
[^>]*> eeae be03 	vmlsldavx.s16	sl, r5, q7, q1
[^>]*> eeae be23 	vmlsldavax.s16	sl, r5, q7, q1
[^>]*> eeae ae05 	vmlsldav.s16	sl, r5, q7, q2
[^>]*> eeae ae25 	vmlsldava.s16	sl, r5, q7, q2
[^>]*> eeae be05 	vmlsldavx.s16	sl, r5, q7, q2
[^>]*> eeae be25 	vmlsldavax.s16	sl, r5, q7, q2
[^>]*> eeae ae09 	vmlsldav.s16	sl, r5, q7, q4
[^>]*> eeae ae29 	vmlsldava.s16	sl, r5, q7, q4
[^>]*> eeae be09 	vmlsldavx.s16	sl, r5, q7, q4
[^>]*> eeae be29 	vmlsldavax.s16	sl, r5, q7, q4
[^>]*> eeae ae0f 	vmlsldav.s16	sl, r5, q7, q7
[^>]*> eeae ae2f 	vmlsldava.s16	sl, r5, q7, q7
[^>]*> eeae be0f 	vmlsldavx.s16	sl, r5, q7, q7
[^>]*> eeae be2f 	vmlsldavax.s16	sl, r5, q7, q7
[^>]*> eeb0 ae01 	vmlsldav.s16	sl, r7, q0, q0
[^>]*> eeb0 ae21 	vmlsldava.s16	sl, r7, q0, q0
[^>]*> eeb0 be01 	vmlsldavx.s16	sl, r7, q0, q0
[^>]*> eeb0 be21 	vmlsldavax.s16	sl, r7, q0, q0
[^>]*> eeb0 ae03 	vmlsldav.s16	sl, r7, q0, q1
[^>]*> eeb0 ae23 	vmlsldava.s16	sl, r7, q0, q1
[^>]*> eeb0 be03 	vmlsldavx.s16	sl, r7, q0, q1
[^>]*> eeb0 be23 	vmlsldavax.s16	sl, r7, q0, q1
[^>]*> eeb0 ae05 	vmlsldav.s16	sl, r7, q0, q2
[^>]*> eeb0 ae25 	vmlsldava.s16	sl, r7, q0, q2
[^>]*> eeb0 be05 	vmlsldavx.s16	sl, r7, q0, q2
[^>]*> eeb0 be25 	vmlsldavax.s16	sl, r7, q0, q2
[^>]*> eeb0 ae09 	vmlsldav.s16	sl, r7, q0, q4
[^>]*> eeb0 ae29 	vmlsldava.s16	sl, r7, q0, q4
[^>]*> eeb0 be09 	vmlsldavx.s16	sl, r7, q0, q4
[^>]*> eeb0 be29 	vmlsldavax.s16	sl, r7, q0, q4
[^>]*> eeb0 ae0f 	vmlsldav.s16	sl, r7, q0, q7
[^>]*> eeb0 ae2f 	vmlsldava.s16	sl, r7, q0, q7
[^>]*> eeb0 be0f 	vmlsldavx.s16	sl, r7, q0, q7
[^>]*> eeb0 be2f 	vmlsldavax.s16	sl, r7, q0, q7
[^>]*> eeb2 ae01 	vmlsldav.s16	sl, r7, q1, q0
[^>]*> eeb2 ae21 	vmlsldava.s16	sl, r7, q1, q0
[^>]*> eeb2 be01 	vmlsldavx.s16	sl, r7, q1, q0
[^>]*> eeb2 be21 	vmlsldavax.s16	sl, r7, q1, q0
[^>]*> eeb2 ae03 	vmlsldav.s16	sl, r7, q1, q1
[^>]*> eeb2 ae23 	vmlsldava.s16	sl, r7, q1, q1
[^>]*> eeb2 be03 	vmlsldavx.s16	sl, r7, q1, q1
[^>]*> eeb2 be23 	vmlsldavax.s16	sl, r7, q1, q1
[^>]*> eeb2 ae05 	vmlsldav.s16	sl, r7, q1, q2
[^>]*> eeb2 ae25 	vmlsldava.s16	sl, r7, q1, q2
[^>]*> eeb2 be05 	vmlsldavx.s16	sl, r7, q1, q2
[^>]*> eeb2 be25 	vmlsldavax.s16	sl, r7, q1, q2
[^>]*> eeb2 ae09 	vmlsldav.s16	sl, r7, q1, q4
[^>]*> eeb2 ae29 	vmlsldava.s16	sl, r7, q1, q4
[^>]*> eeb2 be09 	vmlsldavx.s16	sl, r7, q1, q4
[^>]*> eeb2 be29 	vmlsldavax.s16	sl, r7, q1, q4
[^>]*> eeb2 ae0f 	vmlsldav.s16	sl, r7, q1, q7
[^>]*> eeb2 ae2f 	vmlsldava.s16	sl, r7, q1, q7
[^>]*> eeb2 be0f 	vmlsldavx.s16	sl, r7, q1, q7
[^>]*> eeb2 be2f 	vmlsldavax.s16	sl, r7, q1, q7
[^>]*> eeb4 ae01 	vmlsldav.s16	sl, r7, q2, q0
[^>]*> eeb4 ae21 	vmlsldava.s16	sl, r7, q2, q0
[^>]*> eeb4 be01 	vmlsldavx.s16	sl, r7, q2, q0
[^>]*> eeb4 be21 	vmlsldavax.s16	sl, r7, q2, q0
[^>]*> eeb4 ae03 	vmlsldav.s16	sl, r7, q2, q1
[^>]*> eeb4 ae23 	vmlsldava.s16	sl, r7, q2, q1
[^>]*> eeb4 be03 	vmlsldavx.s16	sl, r7, q2, q1
[^>]*> eeb4 be23 	vmlsldavax.s16	sl, r7, q2, q1
[^>]*> eeb4 ae05 	vmlsldav.s16	sl, r7, q2, q2
[^>]*> eeb4 ae25 	vmlsldava.s16	sl, r7, q2, q2
[^>]*> eeb4 be05 	vmlsldavx.s16	sl, r7, q2, q2
[^>]*> eeb4 be25 	vmlsldavax.s16	sl, r7, q2, q2
[^>]*> eeb4 ae09 	vmlsldav.s16	sl, r7, q2, q4
[^>]*> eeb4 ae29 	vmlsldava.s16	sl, r7, q2, q4
[^>]*> eeb4 be09 	vmlsldavx.s16	sl, r7, q2, q4
[^>]*> eeb4 be29 	vmlsldavax.s16	sl, r7, q2, q4
[^>]*> eeb4 ae0f 	vmlsldav.s16	sl, r7, q2, q7
[^>]*> eeb4 ae2f 	vmlsldava.s16	sl, r7, q2, q7
[^>]*> eeb4 be0f 	vmlsldavx.s16	sl, r7, q2, q7
[^>]*> eeb4 be2f 	vmlsldavax.s16	sl, r7, q2, q7
[^>]*> eeb8 ae01 	vmlsldav.s16	sl, r7, q4, q0
[^>]*> eeb8 ae21 	vmlsldava.s16	sl, r7, q4, q0
[^>]*> eeb8 be01 	vmlsldavx.s16	sl, r7, q4, q0
[^>]*> eeb8 be21 	vmlsldavax.s16	sl, r7, q4, q0
[^>]*> eeb8 ae03 	vmlsldav.s16	sl, r7, q4, q1
[^>]*> eeb8 ae23 	vmlsldava.s16	sl, r7, q4, q1
[^>]*> eeb8 be03 	vmlsldavx.s16	sl, r7, q4, q1
[^>]*> eeb8 be23 	vmlsldavax.s16	sl, r7, q4, q1
[^>]*> eeb8 ae05 	vmlsldav.s16	sl, r7, q4, q2
[^>]*> eeb8 ae25 	vmlsldava.s16	sl, r7, q4, q2
[^>]*> eeb8 be05 	vmlsldavx.s16	sl, r7, q4, q2
[^>]*> eeb8 be25 	vmlsldavax.s16	sl, r7, q4, q2
[^>]*> eeb8 ae09 	vmlsldav.s16	sl, r7, q4, q4
[^>]*> eeb8 ae29 	vmlsldava.s16	sl, r7, q4, q4
[^>]*> eeb8 be09 	vmlsldavx.s16	sl, r7, q4, q4
[^>]*> eeb8 be29 	vmlsldavax.s16	sl, r7, q4, q4
[^>]*> eeb8 ae0f 	vmlsldav.s16	sl, r7, q4, q7
[^>]*> eeb8 ae2f 	vmlsldava.s16	sl, r7, q4, q7
[^>]*> eeb8 be0f 	vmlsldavx.s16	sl, r7, q4, q7
[^>]*> eeb8 be2f 	vmlsldavax.s16	sl, r7, q4, q7
[^>]*> eebe ae01 	vmlsldav.s16	sl, r7, q7, q0
[^>]*> eebe ae21 	vmlsldava.s16	sl, r7, q7, q0
[^>]*> eebe be01 	vmlsldavx.s16	sl, r7, q7, q0
[^>]*> eebe be21 	vmlsldavax.s16	sl, r7, q7, q0
[^>]*> eebe ae03 	vmlsldav.s16	sl, r7, q7, q1
[^>]*> eebe ae23 	vmlsldava.s16	sl, r7, q7, q1
[^>]*> eebe be03 	vmlsldavx.s16	sl, r7, q7, q1
[^>]*> eebe be23 	vmlsldavax.s16	sl, r7, q7, q1
[^>]*> eebe ae05 	vmlsldav.s16	sl, r7, q7, q2
[^>]*> eebe ae25 	vmlsldava.s16	sl, r7, q7, q2
[^>]*> eebe be05 	vmlsldavx.s16	sl, r7, q7, q2
[^>]*> eebe be25 	vmlsldavax.s16	sl, r7, q7, q2
[^>]*> eebe ae09 	vmlsldav.s16	sl, r7, q7, q4
[^>]*> eebe ae29 	vmlsldava.s16	sl, r7, q7, q4
[^>]*> eebe be09 	vmlsldavx.s16	sl, r7, q7, q4
[^>]*> eebe be29 	vmlsldavax.s16	sl, r7, q7, q4
[^>]*> eebe ae0f 	vmlsldav.s16	sl, r7, q7, q7
[^>]*> eebe ae2f 	vmlsldava.s16	sl, r7, q7, q7
[^>]*> eebe be0f 	vmlsldavx.s16	sl, r7, q7, q7
[^>]*> eebe be2f 	vmlsldavax.s16	sl, r7, q7, q7
[^>]*> eec0 ae01 	vmlsldav.s16	sl, r9, q0, q0
[^>]*> eec0 ae21 	vmlsldava.s16	sl, r9, q0, q0
[^>]*> eec0 be01 	vmlsldavx.s16	sl, r9, q0, q0
[^>]*> eec0 be21 	vmlsldavax.s16	sl, r9, q0, q0
[^>]*> eec0 ae03 	vmlsldav.s16	sl, r9, q0, q1
[^>]*> eec0 ae23 	vmlsldava.s16	sl, r9, q0, q1
[^>]*> eec0 be03 	vmlsldavx.s16	sl, r9, q0, q1
[^>]*> eec0 be23 	vmlsldavax.s16	sl, r9, q0, q1
[^>]*> eec0 ae05 	vmlsldav.s16	sl, r9, q0, q2
[^>]*> eec0 ae25 	vmlsldava.s16	sl, r9, q0, q2
[^>]*> eec0 be05 	vmlsldavx.s16	sl, r9, q0, q2
[^>]*> eec0 be25 	vmlsldavax.s16	sl, r9, q0, q2
[^>]*> eec0 ae09 	vmlsldav.s16	sl, r9, q0, q4
[^>]*> eec0 ae29 	vmlsldava.s16	sl, r9, q0, q4
[^>]*> eec0 be09 	vmlsldavx.s16	sl, r9, q0, q4
[^>]*> eec0 be29 	vmlsldavax.s16	sl, r9, q0, q4
[^>]*> eec0 ae0f 	vmlsldav.s16	sl, r9, q0, q7
[^>]*> eec0 ae2f 	vmlsldava.s16	sl, r9, q0, q7
[^>]*> eec0 be0f 	vmlsldavx.s16	sl, r9, q0, q7
[^>]*> eec0 be2f 	vmlsldavax.s16	sl, r9, q0, q7
[^>]*> eec2 ae01 	vmlsldav.s16	sl, r9, q1, q0
[^>]*> eec2 ae21 	vmlsldava.s16	sl, r9, q1, q0
[^>]*> eec2 be01 	vmlsldavx.s16	sl, r9, q1, q0
[^>]*> eec2 be21 	vmlsldavax.s16	sl, r9, q1, q0
[^>]*> eec2 ae03 	vmlsldav.s16	sl, r9, q1, q1
[^>]*> eec2 ae23 	vmlsldava.s16	sl, r9, q1, q1
[^>]*> eec2 be03 	vmlsldavx.s16	sl, r9, q1, q1
[^>]*> eec2 be23 	vmlsldavax.s16	sl, r9, q1, q1
[^>]*> eec2 ae05 	vmlsldav.s16	sl, r9, q1, q2
[^>]*> eec2 ae25 	vmlsldava.s16	sl, r9, q1, q2
[^>]*> eec2 be05 	vmlsldavx.s16	sl, r9, q1, q2
[^>]*> eec2 be25 	vmlsldavax.s16	sl, r9, q1, q2
[^>]*> eec2 ae09 	vmlsldav.s16	sl, r9, q1, q4
[^>]*> eec2 ae29 	vmlsldava.s16	sl, r9, q1, q4
[^>]*> eec2 be09 	vmlsldavx.s16	sl, r9, q1, q4
[^>]*> eec2 be29 	vmlsldavax.s16	sl, r9, q1, q4
[^>]*> eec2 ae0f 	vmlsldav.s16	sl, r9, q1, q7
[^>]*> eec2 ae2f 	vmlsldava.s16	sl, r9, q1, q7
[^>]*> eec2 be0f 	vmlsldavx.s16	sl, r9, q1, q7
[^>]*> eec2 be2f 	vmlsldavax.s16	sl, r9, q1, q7
[^>]*> eec4 ae01 	vmlsldav.s16	sl, r9, q2, q0
[^>]*> eec4 ae21 	vmlsldava.s16	sl, r9, q2, q0
[^>]*> eec4 be01 	vmlsldavx.s16	sl, r9, q2, q0
[^>]*> eec4 be21 	vmlsldavax.s16	sl, r9, q2, q0
[^>]*> eec4 ae03 	vmlsldav.s16	sl, r9, q2, q1
[^>]*> eec4 ae23 	vmlsldava.s16	sl, r9, q2, q1
[^>]*> eec4 be03 	vmlsldavx.s16	sl, r9, q2, q1
[^>]*> eec4 be23 	vmlsldavax.s16	sl, r9, q2, q1
[^>]*> eec4 ae05 	vmlsldav.s16	sl, r9, q2, q2
[^>]*> eec4 ae25 	vmlsldava.s16	sl, r9, q2, q2
[^>]*> eec4 be05 	vmlsldavx.s16	sl, r9, q2, q2
[^>]*> eec4 be25 	vmlsldavax.s16	sl, r9, q2, q2
[^>]*> eec4 ae09 	vmlsldav.s16	sl, r9, q2, q4
[^>]*> eec4 ae29 	vmlsldava.s16	sl, r9, q2, q4
[^>]*> eec4 be09 	vmlsldavx.s16	sl, r9, q2, q4
[^>]*> eec4 be29 	vmlsldavax.s16	sl, r9, q2, q4
[^>]*> eec4 ae0f 	vmlsldav.s16	sl, r9, q2, q7
[^>]*> eec4 ae2f 	vmlsldava.s16	sl, r9, q2, q7
[^>]*> eec4 be0f 	vmlsldavx.s16	sl, r9, q2, q7
[^>]*> eec4 be2f 	vmlsldavax.s16	sl, r9, q2, q7
[^>]*> eec8 ae01 	vmlsldav.s16	sl, r9, q4, q0
[^>]*> eec8 ae21 	vmlsldava.s16	sl, r9, q4, q0
[^>]*> eec8 be01 	vmlsldavx.s16	sl, r9, q4, q0
[^>]*> eec8 be21 	vmlsldavax.s16	sl, r9, q4, q0
[^>]*> eec8 ae03 	vmlsldav.s16	sl, r9, q4, q1
[^>]*> eec8 ae23 	vmlsldava.s16	sl, r9, q4, q1
[^>]*> eec8 be03 	vmlsldavx.s16	sl, r9, q4, q1
[^>]*> eec8 be23 	vmlsldavax.s16	sl, r9, q4, q1
[^>]*> eec8 ae05 	vmlsldav.s16	sl, r9, q4, q2
[^>]*> eec8 ae25 	vmlsldava.s16	sl, r9, q4, q2
[^>]*> eec8 be05 	vmlsldavx.s16	sl, r9, q4, q2
[^>]*> eec8 be25 	vmlsldavax.s16	sl, r9, q4, q2
[^>]*> eec8 ae09 	vmlsldav.s16	sl, r9, q4, q4
[^>]*> eec8 ae29 	vmlsldava.s16	sl, r9, q4, q4
[^>]*> eec8 be09 	vmlsldavx.s16	sl, r9, q4, q4
[^>]*> eec8 be29 	vmlsldavax.s16	sl, r9, q4, q4
[^>]*> eec8 ae0f 	vmlsldav.s16	sl, r9, q4, q7
[^>]*> eec8 ae2f 	vmlsldava.s16	sl, r9, q4, q7
[^>]*> eec8 be0f 	vmlsldavx.s16	sl, r9, q4, q7
[^>]*> eec8 be2f 	vmlsldavax.s16	sl, r9, q4, q7
[^>]*> eece ae01 	vmlsldav.s16	sl, r9, q7, q0
[^>]*> eece ae21 	vmlsldava.s16	sl, r9, q7, q0
[^>]*> eece be01 	vmlsldavx.s16	sl, r9, q7, q0
[^>]*> eece be21 	vmlsldavax.s16	sl, r9, q7, q0
[^>]*> eece ae03 	vmlsldav.s16	sl, r9, q7, q1
[^>]*> eece ae23 	vmlsldava.s16	sl, r9, q7, q1
[^>]*> eece be03 	vmlsldavx.s16	sl, r9, q7, q1
[^>]*> eece be23 	vmlsldavax.s16	sl, r9, q7, q1
[^>]*> eece ae05 	vmlsldav.s16	sl, r9, q7, q2
[^>]*> eece ae25 	vmlsldava.s16	sl, r9, q7, q2
[^>]*> eece be05 	vmlsldavx.s16	sl, r9, q7, q2
[^>]*> eece be25 	vmlsldavax.s16	sl, r9, q7, q2
[^>]*> eece ae09 	vmlsldav.s16	sl, r9, q7, q4
[^>]*> eece ae29 	vmlsldava.s16	sl, r9, q7, q4
[^>]*> eece be09 	vmlsldavx.s16	sl, r9, q7, q4
[^>]*> eece be29 	vmlsldavax.s16	sl, r9, q7, q4
[^>]*> eece ae0f 	vmlsldav.s16	sl, r9, q7, q7
[^>]*> eece ae2f 	vmlsldava.s16	sl, r9, q7, q7
[^>]*> eece be0f 	vmlsldavx.s16	sl, r9, q7, q7
[^>]*> eece be2f 	vmlsldavax.s16	sl, r9, q7, q7
[^>]*> eed0 ae01 	vmlsldav.s16	sl, fp, q0, q0
[^>]*> eed0 ae21 	vmlsldava.s16	sl, fp, q0, q0
[^>]*> eed0 be01 	vmlsldavx.s16	sl, fp, q0, q0
[^>]*> eed0 be21 	vmlsldavax.s16	sl, fp, q0, q0
[^>]*> eed0 ae03 	vmlsldav.s16	sl, fp, q0, q1
[^>]*> eed0 ae23 	vmlsldava.s16	sl, fp, q0, q1
[^>]*> eed0 be03 	vmlsldavx.s16	sl, fp, q0, q1
[^>]*> eed0 be23 	vmlsldavax.s16	sl, fp, q0, q1
[^>]*> eed0 ae05 	vmlsldav.s16	sl, fp, q0, q2
[^>]*> eed0 ae25 	vmlsldava.s16	sl, fp, q0, q2
[^>]*> eed0 be05 	vmlsldavx.s16	sl, fp, q0, q2
[^>]*> eed0 be25 	vmlsldavax.s16	sl, fp, q0, q2
[^>]*> eed0 ae09 	vmlsldav.s16	sl, fp, q0, q4
[^>]*> eed0 ae29 	vmlsldava.s16	sl, fp, q0, q4
[^>]*> eed0 be09 	vmlsldavx.s16	sl, fp, q0, q4
[^>]*> eed0 be29 	vmlsldavax.s16	sl, fp, q0, q4
[^>]*> eed0 ae0f 	vmlsldav.s16	sl, fp, q0, q7
[^>]*> eed0 ae2f 	vmlsldava.s16	sl, fp, q0, q7
[^>]*> eed0 be0f 	vmlsldavx.s16	sl, fp, q0, q7
[^>]*> eed0 be2f 	vmlsldavax.s16	sl, fp, q0, q7
[^>]*> eed2 ae01 	vmlsldav.s16	sl, fp, q1, q0
[^>]*> eed2 ae21 	vmlsldava.s16	sl, fp, q1, q0
[^>]*> eed2 be01 	vmlsldavx.s16	sl, fp, q1, q0
[^>]*> eed2 be21 	vmlsldavax.s16	sl, fp, q1, q0
[^>]*> eed2 ae03 	vmlsldav.s16	sl, fp, q1, q1
[^>]*> eed2 ae23 	vmlsldava.s16	sl, fp, q1, q1
[^>]*> eed2 be03 	vmlsldavx.s16	sl, fp, q1, q1
[^>]*> eed2 be23 	vmlsldavax.s16	sl, fp, q1, q1
[^>]*> eed2 ae05 	vmlsldav.s16	sl, fp, q1, q2
[^>]*> eed2 ae25 	vmlsldava.s16	sl, fp, q1, q2
[^>]*> eed2 be05 	vmlsldavx.s16	sl, fp, q1, q2
[^>]*> eed2 be25 	vmlsldavax.s16	sl, fp, q1, q2
[^>]*> eed2 ae09 	vmlsldav.s16	sl, fp, q1, q4
[^>]*> eed2 ae29 	vmlsldava.s16	sl, fp, q1, q4
[^>]*> eed2 be09 	vmlsldavx.s16	sl, fp, q1, q4
[^>]*> eed2 be29 	vmlsldavax.s16	sl, fp, q1, q4
[^>]*> eed2 ae0f 	vmlsldav.s16	sl, fp, q1, q7
[^>]*> eed2 ae2f 	vmlsldava.s16	sl, fp, q1, q7
[^>]*> eed2 be0f 	vmlsldavx.s16	sl, fp, q1, q7
[^>]*> eed2 be2f 	vmlsldavax.s16	sl, fp, q1, q7
[^>]*> eed4 ae01 	vmlsldav.s16	sl, fp, q2, q0
[^>]*> eed4 ae21 	vmlsldava.s16	sl, fp, q2, q0
[^>]*> eed4 be01 	vmlsldavx.s16	sl, fp, q2, q0
[^>]*> eed4 be21 	vmlsldavax.s16	sl, fp, q2, q0
[^>]*> eed4 ae03 	vmlsldav.s16	sl, fp, q2, q1
[^>]*> eed4 ae23 	vmlsldava.s16	sl, fp, q2, q1
[^>]*> eed4 be03 	vmlsldavx.s16	sl, fp, q2, q1
[^>]*> eed4 be23 	vmlsldavax.s16	sl, fp, q2, q1
[^>]*> eed4 ae05 	vmlsldav.s16	sl, fp, q2, q2
[^>]*> eed4 ae25 	vmlsldava.s16	sl, fp, q2, q2
[^>]*> eed4 be05 	vmlsldavx.s16	sl, fp, q2, q2
[^>]*> eed4 be25 	vmlsldavax.s16	sl, fp, q2, q2
[^>]*> eed4 ae09 	vmlsldav.s16	sl, fp, q2, q4
[^>]*> eed4 ae29 	vmlsldava.s16	sl, fp, q2, q4
[^>]*> eed4 be09 	vmlsldavx.s16	sl, fp, q2, q4
[^>]*> eed4 be29 	vmlsldavax.s16	sl, fp, q2, q4
[^>]*> eed4 ae0f 	vmlsldav.s16	sl, fp, q2, q7
[^>]*> eed4 ae2f 	vmlsldava.s16	sl, fp, q2, q7
[^>]*> eed4 be0f 	vmlsldavx.s16	sl, fp, q2, q7
[^>]*> eed4 be2f 	vmlsldavax.s16	sl, fp, q2, q7
[^>]*> eed8 ae01 	vmlsldav.s16	sl, fp, q4, q0
[^>]*> eed8 ae21 	vmlsldava.s16	sl, fp, q4, q0
[^>]*> eed8 be01 	vmlsldavx.s16	sl, fp, q4, q0
[^>]*> eed8 be21 	vmlsldavax.s16	sl, fp, q4, q0
[^>]*> eed8 ae03 	vmlsldav.s16	sl, fp, q4, q1
[^>]*> eed8 ae23 	vmlsldava.s16	sl, fp, q4, q1
[^>]*> eed8 be03 	vmlsldavx.s16	sl, fp, q4, q1
[^>]*> eed8 be23 	vmlsldavax.s16	sl, fp, q4, q1
[^>]*> eed8 ae05 	vmlsldav.s16	sl, fp, q4, q2
[^>]*> eed8 ae25 	vmlsldava.s16	sl, fp, q4, q2
[^>]*> eed8 be05 	vmlsldavx.s16	sl, fp, q4, q2
[^>]*> eed8 be25 	vmlsldavax.s16	sl, fp, q4, q2
[^>]*> eed8 ae09 	vmlsldav.s16	sl, fp, q4, q4
[^>]*> eed8 ae29 	vmlsldava.s16	sl, fp, q4, q4
[^>]*> eed8 be09 	vmlsldavx.s16	sl, fp, q4, q4
[^>]*> eed8 be29 	vmlsldavax.s16	sl, fp, q4, q4
[^>]*> eed8 ae0f 	vmlsldav.s16	sl, fp, q4, q7
[^>]*> eed8 ae2f 	vmlsldava.s16	sl, fp, q4, q7
[^>]*> eed8 be0f 	vmlsldavx.s16	sl, fp, q4, q7
[^>]*> eed8 be2f 	vmlsldavax.s16	sl, fp, q4, q7
[^>]*> eede ae01 	vmlsldav.s16	sl, fp, q7, q0
[^>]*> eede ae21 	vmlsldava.s16	sl, fp, q7, q0
[^>]*> eede be01 	vmlsldavx.s16	sl, fp, q7, q0
[^>]*> eede be21 	vmlsldavax.s16	sl, fp, q7, q0
[^>]*> eede ae03 	vmlsldav.s16	sl, fp, q7, q1
[^>]*> eede ae23 	vmlsldava.s16	sl, fp, q7, q1
[^>]*> eede be03 	vmlsldavx.s16	sl, fp, q7, q1
[^>]*> eede be23 	vmlsldavax.s16	sl, fp, q7, q1
[^>]*> eede ae05 	vmlsldav.s16	sl, fp, q7, q2
[^>]*> eede ae25 	vmlsldava.s16	sl, fp, q7, q2
[^>]*> eede be05 	vmlsldavx.s16	sl, fp, q7, q2
[^>]*> eede be25 	vmlsldavax.s16	sl, fp, q7, q2
[^>]*> eede ae09 	vmlsldav.s16	sl, fp, q7, q4
[^>]*> eede ae29 	vmlsldava.s16	sl, fp, q7, q4
[^>]*> eede be09 	vmlsldavx.s16	sl, fp, q7, q4
[^>]*> eede be29 	vmlsldavax.s16	sl, fp, q7, q4
[^>]*> eede ae0f 	vmlsldav.s16	sl, fp, q7, q7
[^>]*> eede ae2f 	vmlsldava.s16	sl, fp, q7, q7
[^>]*> eede be0f 	vmlsldavx.s16	sl, fp, q7, q7
[^>]*> eede be2f 	vmlsldavax.s16	sl, fp, q7, q7
[^>]*> ee80 ce01 	vmlsldav.s16	ip, r1, q0, q0
[^>]*> ee80 ce21 	vmlsldava.s16	ip, r1, q0, q0
[^>]*> ee80 de01 	vmlsldavx.s16	ip, r1, q0, q0
[^>]*> ee80 de21 	vmlsldavax.s16	ip, r1, q0, q0
[^>]*> ee80 ce03 	vmlsldav.s16	ip, r1, q0, q1
[^>]*> ee80 ce23 	vmlsldava.s16	ip, r1, q0, q1
[^>]*> ee80 de03 	vmlsldavx.s16	ip, r1, q0, q1
[^>]*> ee80 de23 	vmlsldavax.s16	ip, r1, q0, q1
[^>]*> ee80 ce05 	vmlsldav.s16	ip, r1, q0, q2
[^>]*> ee80 ce25 	vmlsldava.s16	ip, r1, q0, q2
[^>]*> ee80 de05 	vmlsldavx.s16	ip, r1, q0, q2
[^>]*> ee80 de25 	vmlsldavax.s16	ip, r1, q0, q2
[^>]*> ee80 ce09 	vmlsldav.s16	ip, r1, q0, q4
[^>]*> ee80 ce29 	vmlsldava.s16	ip, r1, q0, q4
[^>]*> ee80 de09 	vmlsldavx.s16	ip, r1, q0, q4
[^>]*> ee80 de29 	vmlsldavax.s16	ip, r1, q0, q4
[^>]*> ee80 ce0f 	vmlsldav.s16	ip, r1, q0, q7
[^>]*> ee80 ce2f 	vmlsldava.s16	ip, r1, q0, q7
[^>]*> ee80 de0f 	vmlsldavx.s16	ip, r1, q0, q7
[^>]*> ee80 de2f 	vmlsldavax.s16	ip, r1, q0, q7
[^>]*> ee82 ce01 	vmlsldav.s16	ip, r1, q1, q0
[^>]*> ee82 ce21 	vmlsldava.s16	ip, r1, q1, q0
[^>]*> ee82 de01 	vmlsldavx.s16	ip, r1, q1, q0
[^>]*> ee82 de21 	vmlsldavax.s16	ip, r1, q1, q0
[^>]*> ee82 ce03 	vmlsldav.s16	ip, r1, q1, q1
[^>]*> ee82 ce23 	vmlsldava.s16	ip, r1, q1, q1
[^>]*> ee82 de03 	vmlsldavx.s16	ip, r1, q1, q1
[^>]*> ee82 de23 	vmlsldavax.s16	ip, r1, q1, q1
[^>]*> ee82 ce05 	vmlsldav.s16	ip, r1, q1, q2
[^>]*> ee82 ce25 	vmlsldava.s16	ip, r1, q1, q2
[^>]*> ee82 de05 	vmlsldavx.s16	ip, r1, q1, q2
[^>]*> ee82 de25 	vmlsldavax.s16	ip, r1, q1, q2
[^>]*> ee82 ce09 	vmlsldav.s16	ip, r1, q1, q4
[^>]*> ee82 ce29 	vmlsldava.s16	ip, r1, q1, q4
[^>]*> ee82 de09 	vmlsldavx.s16	ip, r1, q1, q4
[^>]*> ee82 de29 	vmlsldavax.s16	ip, r1, q1, q4
[^>]*> ee82 ce0f 	vmlsldav.s16	ip, r1, q1, q7
[^>]*> ee82 ce2f 	vmlsldava.s16	ip, r1, q1, q7
[^>]*> ee82 de0f 	vmlsldavx.s16	ip, r1, q1, q7
[^>]*> ee82 de2f 	vmlsldavax.s16	ip, r1, q1, q7
[^>]*> ee84 ce01 	vmlsldav.s16	ip, r1, q2, q0
[^>]*> ee84 ce21 	vmlsldava.s16	ip, r1, q2, q0
[^>]*> ee84 de01 	vmlsldavx.s16	ip, r1, q2, q0
[^>]*> ee84 de21 	vmlsldavax.s16	ip, r1, q2, q0
[^>]*> ee84 ce03 	vmlsldav.s16	ip, r1, q2, q1
[^>]*> ee84 ce23 	vmlsldava.s16	ip, r1, q2, q1
[^>]*> ee84 de03 	vmlsldavx.s16	ip, r1, q2, q1
[^>]*> ee84 de23 	vmlsldavax.s16	ip, r1, q2, q1
[^>]*> ee84 ce05 	vmlsldav.s16	ip, r1, q2, q2
[^>]*> ee84 ce25 	vmlsldava.s16	ip, r1, q2, q2
[^>]*> ee84 de05 	vmlsldavx.s16	ip, r1, q2, q2
[^>]*> ee84 de25 	vmlsldavax.s16	ip, r1, q2, q2
[^>]*> ee84 ce09 	vmlsldav.s16	ip, r1, q2, q4
[^>]*> ee84 ce29 	vmlsldava.s16	ip, r1, q2, q4
[^>]*> ee84 de09 	vmlsldavx.s16	ip, r1, q2, q4
[^>]*> ee84 de29 	vmlsldavax.s16	ip, r1, q2, q4
[^>]*> ee84 ce0f 	vmlsldav.s16	ip, r1, q2, q7
[^>]*> ee84 ce2f 	vmlsldava.s16	ip, r1, q2, q7
[^>]*> ee84 de0f 	vmlsldavx.s16	ip, r1, q2, q7
[^>]*> ee84 de2f 	vmlsldavax.s16	ip, r1, q2, q7
[^>]*> ee88 ce01 	vmlsldav.s16	ip, r1, q4, q0
[^>]*> ee88 ce21 	vmlsldava.s16	ip, r1, q4, q0
[^>]*> ee88 de01 	vmlsldavx.s16	ip, r1, q4, q0
[^>]*> ee88 de21 	vmlsldavax.s16	ip, r1, q4, q0
[^>]*> ee88 ce03 	vmlsldav.s16	ip, r1, q4, q1
[^>]*> ee88 ce23 	vmlsldava.s16	ip, r1, q4, q1
[^>]*> ee88 de03 	vmlsldavx.s16	ip, r1, q4, q1
[^>]*> ee88 de23 	vmlsldavax.s16	ip, r1, q4, q1
[^>]*> ee88 ce05 	vmlsldav.s16	ip, r1, q4, q2
[^>]*> ee88 ce25 	vmlsldava.s16	ip, r1, q4, q2
[^>]*> ee88 de05 	vmlsldavx.s16	ip, r1, q4, q2
[^>]*> ee88 de25 	vmlsldavax.s16	ip, r1, q4, q2
[^>]*> ee88 ce09 	vmlsldav.s16	ip, r1, q4, q4
[^>]*> ee88 ce29 	vmlsldava.s16	ip, r1, q4, q4
[^>]*> ee88 de09 	vmlsldavx.s16	ip, r1, q4, q4
[^>]*> ee88 de29 	vmlsldavax.s16	ip, r1, q4, q4
[^>]*> ee88 ce0f 	vmlsldav.s16	ip, r1, q4, q7
[^>]*> ee88 ce2f 	vmlsldava.s16	ip, r1, q4, q7
[^>]*> ee88 de0f 	vmlsldavx.s16	ip, r1, q4, q7
[^>]*> ee88 de2f 	vmlsldavax.s16	ip, r1, q4, q7
[^>]*> ee8e ce01 	vmlsldav.s16	ip, r1, q7, q0
[^>]*> ee8e ce21 	vmlsldava.s16	ip, r1, q7, q0
[^>]*> ee8e de01 	vmlsldavx.s16	ip, r1, q7, q0
[^>]*> ee8e de21 	vmlsldavax.s16	ip, r1, q7, q0
[^>]*> ee8e ce03 	vmlsldav.s16	ip, r1, q7, q1
[^>]*> ee8e ce23 	vmlsldava.s16	ip, r1, q7, q1
[^>]*> ee8e de03 	vmlsldavx.s16	ip, r1, q7, q1
[^>]*> ee8e de23 	vmlsldavax.s16	ip, r1, q7, q1
[^>]*> ee8e ce05 	vmlsldav.s16	ip, r1, q7, q2
[^>]*> ee8e ce25 	vmlsldava.s16	ip, r1, q7, q2
[^>]*> ee8e de05 	vmlsldavx.s16	ip, r1, q7, q2
[^>]*> ee8e de25 	vmlsldavax.s16	ip, r1, q7, q2
[^>]*> ee8e ce09 	vmlsldav.s16	ip, r1, q7, q4
[^>]*> ee8e ce29 	vmlsldava.s16	ip, r1, q7, q4
[^>]*> ee8e de09 	vmlsldavx.s16	ip, r1, q7, q4
[^>]*> ee8e de29 	vmlsldavax.s16	ip, r1, q7, q4
[^>]*> ee8e ce0f 	vmlsldav.s16	ip, r1, q7, q7
[^>]*> ee8e ce2f 	vmlsldava.s16	ip, r1, q7, q7
[^>]*> ee8e de0f 	vmlsldavx.s16	ip, r1, q7, q7
[^>]*> ee8e de2f 	vmlsldavax.s16	ip, r1, q7, q7
[^>]*> ee90 ce01 	vmlsldav.s16	ip, r3, q0, q0
[^>]*> ee90 ce21 	vmlsldava.s16	ip, r3, q0, q0
[^>]*> ee90 de01 	vmlsldavx.s16	ip, r3, q0, q0
[^>]*> ee90 de21 	vmlsldavax.s16	ip, r3, q0, q0
[^>]*> ee90 ce03 	vmlsldav.s16	ip, r3, q0, q1
[^>]*> ee90 ce23 	vmlsldava.s16	ip, r3, q0, q1
[^>]*> ee90 de03 	vmlsldavx.s16	ip, r3, q0, q1
[^>]*> ee90 de23 	vmlsldavax.s16	ip, r3, q0, q1
[^>]*> ee90 ce05 	vmlsldav.s16	ip, r3, q0, q2
[^>]*> ee90 ce25 	vmlsldava.s16	ip, r3, q0, q2
[^>]*> ee90 de05 	vmlsldavx.s16	ip, r3, q0, q2
[^>]*> ee90 de25 	vmlsldavax.s16	ip, r3, q0, q2
[^>]*> ee90 ce09 	vmlsldav.s16	ip, r3, q0, q4
[^>]*> ee90 ce29 	vmlsldava.s16	ip, r3, q0, q4
[^>]*> ee90 de09 	vmlsldavx.s16	ip, r3, q0, q4
[^>]*> ee90 de29 	vmlsldavax.s16	ip, r3, q0, q4
[^>]*> ee90 ce0f 	vmlsldav.s16	ip, r3, q0, q7
[^>]*> ee90 ce2f 	vmlsldava.s16	ip, r3, q0, q7
[^>]*> ee90 de0f 	vmlsldavx.s16	ip, r3, q0, q7
[^>]*> ee90 de2f 	vmlsldavax.s16	ip, r3, q0, q7
[^>]*> ee92 ce01 	vmlsldav.s16	ip, r3, q1, q0
[^>]*> ee92 ce21 	vmlsldava.s16	ip, r3, q1, q0
[^>]*> ee92 de01 	vmlsldavx.s16	ip, r3, q1, q0
[^>]*> ee92 de21 	vmlsldavax.s16	ip, r3, q1, q0
[^>]*> ee92 ce03 	vmlsldav.s16	ip, r3, q1, q1
[^>]*> ee92 ce23 	vmlsldava.s16	ip, r3, q1, q1
[^>]*> ee92 de03 	vmlsldavx.s16	ip, r3, q1, q1
[^>]*> ee92 de23 	vmlsldavax.s16	ip, r3, q1, q1
[^>]*> ee92 ce05 	vmlsldav.s16	ip, r3, q1, q2
[^>]*> ee92 ce25 	vmlsldava.s16	ip, r3, q1, q2
[^>]*> ee92 de05 	vmlsldavx.s16	ip, r3, q1, q2
[^>]*> ee92 de25 	vmlsldavax.s16	ip, r3, q1, q2
[^>]*> ee92 ce09 	vmlsldav.s16	ip, r3, q1, q4
[^>]*> ee92 ce29 	vmlsldava.s16	ip, r3, q1, q4
[^>]*> ee92 de09 	vmlsldavx.s16	ip, r3, q1, q4
[^>]*> ee92 de29 	vmlsldavax.s16	ip, r3, q1, q4
[^>]*> ee92 ce0f 	vmlsldav.s16	ip, r3, q1, q7
[^>]*> ee92 ce2f 	vmlsldava.s16	ip, r3, q1, q7
[^>]*> ee92 de0f 	vmlsldavx.s16	ip, r3, q1, q7
[^>]*> ee92 de2f 	vmlsldavax.s16	ip, r3, q1, q7
[^>]*> ee94 ce01 	vmlsldav.s16	ip, r3, q2, q0
[^>]*> ee94 ce21 	vmlsldava.s16	ip, r3, q2, q0
[^>]*> ee94 de01 	vmlsldavx.s16	ip, r3, q2, q0
[^>]*> ee94 de21 	vmlsldavax.s16	ip, r3, q2, q0
[^>]*> ee94 ce03 	vmlsldav.s16	ip, r3, q2, q1
[^>]*> ee94 ce23 	vmlsldava.s16	ip, r3, q2, q1
[^>]*> ee94 de03 	vmlsldavx.s16	ip, r3, q2, q1
[^>]*> ee94 de23 	vmlsldavax.s16	ip, r3, q2, q1
[^>]*> ee94 ce05 	vmlsldav.s16	ip, r3, q2, q2
[^>]*> ee94 ce25 	vmlsldava.s16	ip, r3, q2, q2
[^>]*> ee94 de05 	vmlsldavx.s16	ip, r3, q2, q2
[^>]*> ee94 de25 	vmlsldavax.s16	ip, r3, q2, q2
[^>]*> ee94 ce09 	vmlsldav.s16	ip, r3, q2, q4
[^>]*> ee94 ce29 	vmlsldava.s16	ip, r3, q2, q4
[^>]*> ee94 de09 	vmlsldavx.s16	ip, r3, q2, q4
[^>]*> ee94 de29 	vmlsldavax.s16	ip, r3, q2, q4
[^>]*> ee94 ce0f 	vmlsldav.s16	ip, r3, q2, q7
[^>]*> ee94 ce2f 	vmlsldava.s16	ip, r3, q2, q7
[^>]*> ee94 de0f 	vmlsldavx.s16	ip, r3, q2, q7
[^>]*> ee94 de2f 	vmlsldavax.s16	ip, r3, q2, q7
[^>]*> ee98 ce01 	vmlsldav.s16	ip, r3, q4, q0
[^>]*> ee98 ce21 	vmlsldava.s16	ip, r3, q4, q0
[^>]*> ee98 de01 	vmlsldavx.s16	ip, r3, q4, q0
[^>]*> ee98 de21 	vmlsldavax.s16	ip, r3, q4, q0
[^>]*> ee98 ce03 	vmlsldav.s16	ip, r3, q4, q1
[^>]*> ee98 ce23 	vmlsldava.s16	ip, r3, q4, q1
[^>]*> ee98 de03 	vmlsldavx.s16	ip, r3, q4, q1
[^>]*> ee98 de23 	vmlsldavax.s16	ip, r3, q4, q1
[^>]*> ee98 ce05 	vmlsldav.s16	ip, r3, q4, q2
[^>]*> ee98 ce25 	vmlsldava.s16	ip, r3, q4, q2
[^>]*> ee98 de05 	vmlsldavx.s16	ip, r3, q4, q2
[^>]*> ee98 de25 	vmlsldavax.s16	ip, r3, q4, q2
[^>]*> ee98 ce09 	vmlsldav.s16	ip, r3, q4, q4
[^>]*> ee98 ce29 	vmlsldava.s16	ip, r3, q4, q4
[^>]*> ee98 de09 	vmlsldavx.s16	ip, r3, q4, q4
[^>]*> ee98 de29 	vmlsldavax.s16	ip, r3, q4, q4
[^>]*> ee98 ce0f 	vmlsldav.s16	ip, r3, q4, q7
[^>]*> ee98 ce2f 	vmlsldava.s16	ip, r3, q4, q7
[^>]*> ee98 de0f 	vmlsldavx.s16	ip, r3, q4, q7
[^>]*> ee98 de2f 	vmlsldavax.s16	ip, r3, q4, q7
[^>]*> ee9e ce01 	vmlsldav.s16	ip, r3, q7, q0
[^>]*> ee9e ce21 	vmlsldava.s16	ip, r3, q7, q0
[^>]*> ee9e de01 	vmlsldavx.s16	ip, r3, q7, q0
[^>]*> ee9e de21 	vmlsldavax.s16	ip, r3, q7, q0
[^>]*> ee9e ce03 	vmlsldav.s16	ip, r3, q7, q1
[^>]*> ee9e ce23 	vmlsldava.s16	ip, r3, q7, q1
[^>]*> ee9e de03 	vmlsldavx.s16	ip, r3, q7, q1
[^>]*> ee9e de23 	vmlsldavax.s16	ip, r3, q7, q1
[^>]*> ee9e ce05 	vmlsldav.s16	ip, r3, q7, q2
[^>]*> ee9e ce25 	vmlsldava.s16	ip, r3, q7, q2
[^>]*> ee9e de05 	vmlsldavx.s16	ip, r3, q7, q2
[^>]*> ee9e de25 	vmlsldavax.s16	ip, r3, q7, q2
[^>]*> ee9e ce09 	vmlsldav.s16	ip, r3, q7, q4
[^>]*> ee9e ce29 	vmlsldava.s16	ip, r3, q7, q4
[^>]*> ee9e de09 	vmlsldavx.s16	ip, r3, q7, q4
[^>]*> ee9e de29 	vmlsldavax.s16	ip, r3, q7, q4
[^>]*> ee9e ce0f 	vmlsldav.s16	ip, r3, q7, q7
[^>]*> ee9e ce2f 	vmlsldava.s16	ip, r3, q7, q7
[^>]*> ee9e de0f 	vmlsldavx.s16	ip, r3, q7, q7
[^>]*> ee9e de2f 	vmlsldavax.s16	ip, r3, q7, q7
[^>]*> eea0 ce01 	vmlsldav.s16	ip, r5, q0, q0
[^>]*> eea0 ce21 	vmlsldava.s16	ip, r5, q0, q0
[^>]*> eea0 de01 	vmlsldavx.s16	ip, r5, q0, q0
[^>]*> eea0 de21 	vmlsldavax.s16	ip, r5, q0, q0
[^>]*> eea0 ce03 	vmlsldav.s16	ip, r5, q0, q1
[^>]*> eea0 ce23 	vmlsldava.s16	ip, r5, q0, q1
[^>]*> eea0 de03 	vmlsldavx.s16	ip, r5, q0, q1
[^>]*> eea0 de23 	vmlsldavax.s16	ip, r5, q0, q1
[^>]*> eea0 ce05 	vmlsldav.s16	ip, r5, q0, q2
[^>]*> eea0 ce25 	vmlsldava.s16	ip, r5, q0, q2
[^>]*> eea0 de05 	vmlsldavx.s16	ip, r5, q0, q2
[^>]*> eea0 de25 	vmlsldavax.s16	ip, r5, q0, q2
[^>]*> eea0 ce09 	vmlsldav.s16	ip, r5, q0, q4
[^>]*> eea0 ce29 	vmlsldava.s16	ip, r5, q0, q4
[^>]*> eea0 de09 	vmlsldavx.s16	ip, r5, q0, q4
[^>]*> eea0 de29 	vmlsldavax.s16	ip, r5, q0, q4
[^>]*> eea0 ce0f 	vmlsldav.s16	ip, r5, q0, q7
[^>]*> eea0 ce2f 	vmlsldava.s16	ip, r5, q0, q7
[^>]*> eea0 de0f 	vmlsldavx.s16	ip, r5, q0, q7
[^>]*> eea0 de2f 	vmlsldavax.s16	ip, r5, q0, q7
[^>]*> eea2 ce01 	vmlsldav.s16	ip, r5, q1, q0
[^>]*> eea2 ce21 	vmlsldava.s16	ip, r5, q1, q0
[^>]*> eea2 de01 	vmlsldavx.s16	ip, r5, q1, q0
[^>]*> eea2 de21 	vmlsldavax.s16	ip, r5, q1, q0
[^>]*> eea2 ce03 	vmlsldav.s16	ip, r5, q1, q1
[^>]*> eea2 ce23 	vmlsldava.s16	ip, r5, q1, q1
[^>]*> eea2 de03 	vmlsldavx.s16	ip, r5, q1, q1
[^>]*> eea2 de23 	vmlsldavax.s16	ip, r5, q1, q1
[^>]*> eea2 ce05 	vmlsldav.s16	ip, r5, q1, q2
[^>]*> eea2 ce25 	vmlsldava.s16	ip, r5, q1, q2
[^>]*> eea2 de05 	vmlsldavx.s16	ip, r5, q1, q2
[^>]*> eea2 de25 	vmlsldavax.s16	ip, r5, q1, q2
[^>]*> eea2 ce09 	vmlsldav.s16	ip, r5, q1, q4
[^>]*> eea2 ce29 	vmlsldava.s16	ip, r5, q1, q4
[^>]*> eea2 de09 	vmlsldavx.s16	ip, r5, q1, q4
[^>]*> eea2 de29 	vmlsldavax.s16	ip, r5, q1, q4
[^>]*> eea2 ce0f 	vmlsldav.s16	ip, r5, q1, q7
[^>]*> eea2 ce2f 	vmlsldava.s16	ip, r5, q1, q7
[^>]*> eea2 de0f 	vmlsldavx.s16	ip, r5, q1, q7
[^>]*> eea2 de2f 	vmlsldavax.s16	ip, r5, q1, q7
[^>]*> eea4 ce01 	vmlsldav.s16	ip, r5, q2, q0
[^>]*> eea4 ce21 	vmlsldava.s16	ip, r5, q2, q0
[^>]*> eea4 de01 	vmlsldavx.s16	ip, r5, q2, q0
[^>]*> eea4 de21 	vmlsldavax.s16	ip, r5, q2, q0
[^>]*> eea4 ce03 	vmlsldav.s16	ip, r5, q2, q1
[^>]*> eea4 ce23 	vmlsldava.s16	ip, r5, q2, q1
[^>]*> eea4 de03 	vmlsldavx.s16	ip, r5, q2, q1
[^>]*> eea4 de23 	vmlsldavax.s16	ip, r5, q2, q1
[^>]*> eea4 ce05 	vmlsldav.s16	ip, r5, q2, q2
[^>]*> eea4 ce25 	vmlsldava.s16	ip, r5, q2, q2
[^>]*> eea4 de05 	vmlsldavx.s16	ip, r5, q2, q2
[^>]*> eea4 de25 	vmlsldavax.s16	ip, r5, q2, q2
[^>]*> eea4 ce09 	vmlsldav.s16	ip, r5, q2, q4
[^>]*> eea4 ce29 	vmlsldava.s16	ip, r5, q2, q4
[^>]*> eea4 de09 	vmlsldavx.s16	ip, r5, q2, q4
[^>]*> eea4 de29 	vmlsldavax.s16	ip, r5, q2, q4
[^>]*> eea4 ce0f 	vmlsldav.s16	ip, r5, q2, q7
[^>]*> eea4 ce2f 	vmlsldava.s16	ip, r5, q2, q7
[^>]*> eea4 de0f 	vmlsldavx.s16	ip, r5, q2, q7
[^>]*> eea4 de2f 	vmlsldavax.s16	ip, r5, q2, q7
[^>]*> eea8 ce01 	vmlsldav.s16	ip, r5, q4, q0
[^>]*> eea8 ce21 	vmlsldava.s16	ip, r5, q4, q0
[^>]*> eea8 de01 	vmlsldavx.s16	ip, r5, q4, q0
[^>]*> eea8 de21 	vmlsldavax.s16	ip, r5, q4, q0
[^>]*> eea8 ce03 	vmlsldav.s16	ip, r5, q4, q1
[^>]*> eea8 ce23 	vmlsldava.s16	ip, r5, q4, q1
[^>]*> eea8 de03 	vmlsldavx.s16	ip, r5, q4, q1
[^>]*> eea8 de23 	vmlsldavax.s16	ip, r5, q4, q1
[^>]*> eea8 ce05 	vmlsldav.s16	ip, r5, q4, q2
[^>]*> eea8 ce25 	vmlsldava.s16	ip, r5, q4, q2
[^>]*> eea8 de05 	vmlsldavx.s16	ip, r5, q4, q2
[^>]*> eea8 de25 	vmlsldavax.s16	ip, r5, q4, q2
[^>]*> eea8 ce09 	vmlsldav.s16	ip, r5, q4, q4
[^>]*> eea8 ce29 	vmlsldava.s16	ip, r5, q4, q4
[^>]*> eea8 de09 	vmlsldavx.s16	ip, r5, q4, q4
[^>]*> eea8 de29 	vmlsldavax.s16	ip, r5, q4, q4
[^>]*> eea8 ce0f 	vmlsldav.s16	ip, r5, q4, q7
[^>]*> eea8 ce2f 	vmlsldava.s16	ip, r5, q4, q7
[^>]*> eea8 de0f 	vmlsldavx.s16	ip, r5, q4, q7
[^>]*> eea8 de2f 	vmlsldavax.s16	ip, r5, q4, q7
[^>]*> eeae ce01 	vmlsldav.s16	ip, r5, q7, q0
[^>]*> eeae ce21 	vmlsldava.s16	ip, r5, q7, q0
[^>]*> eeae de01 	vmlsldavx.s16	ip, r5, q7, q0
[^>]*> eeae de21 	vmlsldavax.s16	ip, r5, q7, q0
[^>]*> eeae ce03 	vmlsldav.s16	ip, r5, q7, q1
[^>]*> eeae ce23 	vmlsldava.s16	ip, r5, q7, q1
[^>]*> eeae de03 	vmlsldavx.s16	ip, r5, q7, q1
[^>]*> eeae de23 	vmlsldavax.s16	ip, r5, q7, q1
[^>]*> eeae ce05 	vmlsldav.s16	ip, r5, q7, q2
[^>]*> eeae ce25 	vmlsldava.s16	ip, r5, q7, q2
[^>]*> eeae de05 	vmlsldavx.s16	ip, r5, q7, q2
[^>]*> eeae de25 	vmlsldavax.s16	ip, r5, q7, q2
[^>]*> eeae ce09 	vmlsldav.s16	ip, r5, q7, q4
[^>]*> eeae ce29 	vmlsldava.s16	ip, r5, q7, q4
[^>]*> eeae de09 	vmlsldavx.s16	ip, r5, q7, q4
[^>]*> eeae de29 	vmlsldavax.s16	ip, r5, q7, q4
[^>]*> eeae ce0f 	vmlsldav.s16	ip, r5, q7, q7
[^>]*> eeae ce2f 	vmlsldava.s16	ip, r5, q7, q7
[^>]*> eeae de0f 	vmlsldavx.s16	ip, r5, q7, q7
[^>]*> eeae de2f 	vmlsldavax.s16	ip, r5, q7, q7
[^>]*> eeb0 ce01 	vmlsldav.s16	ip, r7, q0, q0
[^>]*> eeb0 ce21 	vmlsldava.s16	ip, r7, q0, q0
[^>]*> eeb0 de01 	vmlsldavx.s16	ip, r7, q0, q0
[^>]*> eeb0 de21 	vmlsldavax.s16	ip, r7, q0, q0
[^>]*> eeb0 ce03 	vmlsldav.s16	ip, r7, q0, q1
[^>]*> eeb0 ce23 	vmlsldava.s16	ip, r7, q0, q1
[^>]*> eeb0 de03 	vmlsldavx.s16	ip, r7, q0, q1
[^>]*> eeb0 de23 	vmlsldavax.s16	ip, r7, q0, q1
[^>]*> eeb0 ce05 	vmlsldav.s16	ip, r7, q0, q2
[^>]*> eeb0 ce25 	vmlsldava.s16	ip, r7, q0, q2
[^>]*> eeb0 de05 	vmlsldavx.s16	ip, r7, q0, q2
[^>]*> eeb0 de25 	vmlsldavax.s16	ip, r7, q0, q2
[^>]*> eeb0 ce09 	vmlsldav.s16	ip, r7, q0, q4
[^>]*> eeb0 ce29 	vmlsldava.s16	ip, r7, q0, q4
[^>]*> eeb0 de09 	vmlsldavx.s16	ip, r7, q0, q4
[^>]*> eeb0 de29 	vmlsldavax.s16	ip, r7, q0, q4
[^>]*> eeb0 ce0f 	vmlsldav.s16	ip, r7, q0, q7
[^>]*> eeb0 ce2f 	vmlsldava.s16	ip, r7, q0, q7
[^>]*> eeb0 de0f 	vmlsldavx.s16	ip, r7, q0, q7
[^>]*> eeb0 de2f 	vmlsldavax.s16	ip, r7, q0, q7
[^>]*> eeb2 ce01 	vmlsldav.s16	ip, r7, q1, q0
[^>]*> eeb2 ce21 	vmlsldava.s16	ip, r7, q1, q0
[^>]*> eeb2 de01 	vmlsldavx.s16	ip, r7, q1, q0
[^>]*> eeb2 de21 	vmlsldavax.s16	ip, r7, q1, q0
[^>]*> eeb2 ce03 	vmlsldav.s16	ip, r7, q1, q1
[^>]*> eeb2 ce23 	vmlsldava.s16	ip, r7, q1, q1
[^>]*> eeb2 de03 	vmlsldavx.s16	ip, r7, q1, q1
[^>]*> eeb2 de23 	vmlsldavax.s16	ip, r7, q1, q1
[^>]*> eeb2 ce05 	vmlsldav.s16	ip, r7, q1, q2
[^>]*> eeb2 ce25 	vmlsldava.s16	ip, r7, q1, q2
[^>]*> eeb2 de05 	vmlsldavx.s16	ip, r7, q1, q2
[^>]*> eeb2 de25 	vmlsldavax.s16	ip, r7, q1, q2
[^>]*> eeb2 ce09 	vmlsldav.s16	ip, r7, q1, q4
[^>]*> eeb2 ce29 	vmlsldava.s16	ip, r7, q1, q4
[^>]*> eeb2 de09 	vmlsldavx.s16	ip, r7, q1, q4
[^>]*> eeb2 de29 	vmlsldavax.s16	ip, r7, q1, q4
[^>]*> eeb2 ce0f 	vmlsldav.s16	ip, r7, q1, q7
[^>]*> eeb2 ce2f 	vmlsldava.s16	ip, r7, q1, q7
[^>]*> eeb2 de0f 	vmlsldavx.s16	ip, r7, q1, q7
[^>]*> eeb2 de2f 	vmlsldavax.s16	ip, r7, q1, q7
[^>]*> eeb4 ce01 	vmlsldav.s16	ip, r7, q2, q0
[^>]*> eeb4 ce21 	vmlsldava.s16	ip, r7, q2, q0
[^>]*> eeb4 de01 	vmlsldavx.s16	ip, r7, q2, q0
[^>]*> eeb4 de21 	vmlsldavax.s16	ip, r7, q2, q0
[^>]*> eeb4 ce03 	vmlsldav.s16	ip, r7, q2, q1
[^>]*> eeb4 ce23 	vmlsldava.s16	ip, r7, q2, q1
[^>]*> eeb4 de03 	vmlsldavx.s16	ip, r7, q2, q1
[^>]*> eeb4 de23 	vmlsldavax.s16	ip, r7, q2, q1
[^>]*> eeb4 ce05 	vmlsldav.s16	ip, r7, q2, q2
[^>]*> eeb4 ce25 	vmlsldava.s16	ip, r7, q2, q2
[^>]*> eeb4 de05 	vmlsldavx.s16	ip, r7, q2, q2
[^>]*> eeb4 de25 	vmlsldavax.s16	ip, r7, q2, q2
[^>]*> eeb4 ce09 	vmlsldav.s16	ip, r7, q2, q4
[^>]*> eeb4 ce29 	vmlsldava.s16	ip, r7, q2, q4
[^>]*> eeb4 de09 	vmlsldavx.s16	ip, r7, q2, q4
[^>]*> eeb4 de29 	vmlsldavax.s16	ip, r7, q2, q4
[^>]*> eeb4 ce0f 	vmlsldav.s16	ip, r7, q2, q7
[^>]*> eeb4 ce2f 	vmlsldava.s16	ip, r7, q2, q7
[^>]*> eeb4 de0f 	vmlsldavx.s16	ip, r7, q2, q7
[^>]*> eeb4 de2f 	vmlsldavax.s16	ip, r7, q2, q7
[^>]*> eeb8 ce01 	vmlsldav.s16	ip, r7, q4, q0
[^>]*> eeb8 ce21 	vmlsldava.s16	ip, r7, q4, q0
[^>]*> eeb8 de01 	vmlsldavx.s16	ip, r7, q4, q0
[^>]*> eeb8 de21 	vmlsldavax.s16	ip, r7, q4, q0
[^>]*> eeb8 ce03 	vmlsldav.s16	ip, r7, q4, q1
[^>]*> eeb8 ce23 	vmlsldava.s16	ip, r7, q4, q1
[^>]*> eeb8 de03 	vmlsldavx.s16	ip, r7, q4, q1
[^>]*> eeb8 de23 	vmlsldavax.s16	ip, r7, q4, q1
[^>]*> eeb8 ce05 	vmlsldav.s16	ip, r7, q4, q2
[^>]*> eeb8 ce25 	vmlsldava.s16	ip, r7, q4, q2
[^>]*> eeb8 de05 	vmlsldavx.s16	ip, r7, q4, q2
[^>]*> eeb8 de25 	vmlsldavax.s16	ip, r7, q4, q2
[^>]*> eeb8 ce09 	vmlsldav.s16	ip, r7, q4, q4
[^>]*> eeb8 ce29 	vmlsldava.s16	ip, r7, q4, q4
[^>]*> eeb8 de09 	vmlsldavx.s16	ip, r7, q4, q4
[^>]*> eeb8 de29 	vmlsldavax.s16	ip, r7, q4, q4
[^>]*> eeb8 ce0f 	vmlsldav.s16	ip, r7, q4, q7
[^>]*> eeb8 ce2f 	vmlsldava.s16	ip, r7, q4, q7
[^>]*> eeb8 de0f 	vmlsldavx.s16	ip, r7, q4, q7
[^>]*> eeb8 de2f 	vmlsldavax.s16	ip, r7, q4, q7
[^>]*> eebe ce01 	vmlsldav.s16	ip, r7, q7, q0
[^>]*> eebe ce21 	vmlsldava.s16	ip, r7, q7, q0
[^>]*> eebe de01 	vmlsldavx.s16	ip, r7, q7, q0
[^>]*> eebe de21 	vmlsldavax.s16	ip, r7, q7, q0
[^>]*> eebe ce03 	vmlsldav.s16	ip, r7, q7, q1
[^>]*> eebe ce23 	vmlsldava.s16	ip, r7, q7, q1
[^>]*> eebe de03 	vmlsldavx.s16	ip, r7, q7, q1
[^>]*> eebe de23 	vmlsldavax.s16	ip, r7, q7, q1
[^>]*> eebe ce05 	vmlsldav.s16	ip, r7, q7, q2
[^>]*> eebe ce25 	vmlsldava.s16	ip, r7, q7, q2
[^>]*> eebe de05 	vmlsldavx.s16	ip, r7, q7, q2
[^>]*> eebe de25 	vmlsldavax.s16	ip, r7, q7, q2
[^>]*> eebe ce09 	vmlsldav.s16	ip, r7, q7, q4
[^>]*> eebe ce29 	vmlsldava.s16	ip, r7, q7, q4
[^>]*> eebe de09 	vmlsldavx.s16	ip, r7, q7, q4
[^>]*> eebe de29 	vmlsldavax.s16	ip, r7, q7, q4
[^>]*> eebe ce0f 	vmlsldav.s16	ip, r7, q7, q7
[^>]*> eebe ce2f 	vmlsldava.s16	ip, r7, q7, q7
[^>]*> eebe de0f 	vmlsldavx.s16	ip, r7, q7, q7
[^>]*> eebe de2f 	vmlsldavax.s16	ip, r7, q7, q7
[^>]*> eec0 ce01 	vmlsldav.s16	ip, r9, q0, q0
[^>]*> eec0 ce21 	vmlsldava.s16	ip, r9, q0, q0
[^>]*> eec0 de01 	vmlsldavx.s16	ip, r9, q0, q0
[^>]*> eec0 de21 	vmlsldavax.s16	ip, r9, q0, q0
[^>]*> eec0 ce03 	vmlsldav.s16	ip, r9, q0, q1
[^>]*> eec0 ce23 	vmlsldava.s16	ip, r9, q0, q1
[^>]*> eec0 de03 	vmlsldavx.s16	ip, r9, q0, q1
[^>]*> eec0 de23 	vmlsldavax.s16	ip, r9, q0, q1
[^>]*> eec0 ce05 	vmlsldav.s16	ip, r9, q0, q2
[^>]*> eec0 ce25 	vmlsldava.s16	ip, r9, q0, q2
[^>]*> eec0 de05 	vmlsldavx.s16	ip, r9, q0, q2
[^>]*> eec0 de25 	vmlsldavax.s16	ip, r9, q0, q2
[^>]*> eec0 ce09 	vmlsldav.s16	ip, r9, q0, q4
[^>]*> eec0 ce29 	vmlsldava.s16	ip, r9, q0, q4
[^>]*> eec0 de09 	vmlsldavx.s16	ip, r9, q0, q4
[^>]*> eec0 de29 	vmlsldavax.s16	ip, r9, q0, q4
[^>]*> eec0 ce0f 	vmlsldav.s16	ip, r9, q0, q7
[^>]*> eec0 ce2f 	vmlsldava.s16	ip, r9, q0, q7
[^>]*> eec0 de0f 	vmlsldavx.s16	ip, r9, q0, q7
[^>]*> eec0 de2f 	vmlsldavax.s16	ip, r9, q0, q7
[^>]*> eec2 ce01 	vmlsldav.s16	ip, r9, q1, q0
[^>]*> eec2 ce21 	vmlsldava.s16	ip, r9, q1, q0
[^>]*> eec2 de01 	vmlsldavx.s16	ip, r9, q1, q0
[^>]*> eec2 de21 	vmlsldavax.s16	ip, r9, q1, q0
[^>]*> eec2 ce03 	vmlsldav.s16	ip, r9, q1, q1
[^>]*> eec2 ce23 	vmlsldava.s16	ip, r9, q1, q1
[^>]*> eec2 de03 	vmlsldavx.s16	ip, r9, q1, q1
[^>]*> eec2 de23 	vmlsldavax.s16	ip, r9, q1, q1
[^>]*> eec2 ce05 	vmlsldav.s16	ip, r9, q1, q2
[^>]*> eec2 ce25 	vmlsldava.s16	ip, r9, q1, q2
[^>]*> eec2 de05 	vmlsldavx.s16	ip, r9, q1, q2
[^>]*> eec2 de25 	vmlsldavax.s16	ip, r9, q1, q2
[^>]*> eec2 ce09 	vmlsldav.s16	ip, r9, q1, q4
[^>]*> eec2 ce29 	vmlsldava.s16	ip, r9, q1, q4
[^>]*> eec2 de09 	vmlsldavx.s16	ip, r9, q1, q4
[^>]*> eec2 de29 	vmlsldavax.s16	ip, r9, q1, q4
[^>]*> eec2 ce0f 	vmlsldav.s16	ip, r9, q1, q7
[^>]*> eec2 ce2f 	vmlsldava.s16	ip, r9, q1, q7
[^>]*> eec2 de0f 	vmlsldavx.s16	ip, r9, q1, q7
[^>]*> eec2 de2f 	vmlsldavax.s16	ip, r9, q1, q7
[^>]*> eec4 ce01 	vmlsldav.s16	ip, r9, q2, q0
[^>]*> eec4 ce21 	vmlsldava.s16	ip, r9, q2, q0
[^>]*> eec4 de01 	vmlsldavx.s16	ip, r9, q2, q0
[^>]*> eec4 de21 	vmlsldavax.s16	ip, r9, q2, q0
[^>]*> eec4 ce03 	vmlsldav.s16	ip, r9, q2, q1
[^>]*> eec4 ce23 	vmlsldava.s16	ip, r9, q2, q1
[^>]*> eec4 de03 	vmlsldavx.s16	ip, r9, q2, q1
[^>]*> eec4 de23 	vmlsldavax.s16	ip, r9, q2, q1
[^>]*> eec4 ce05 	vmlsldav.s16	ip, r9, q2, q2
[^>]*> eec4 ce25 	vmlsldava.s16	ip, r9, q2, q2
[^>]*> eec4 de05 	vmlsldavx.s16	ip, r9, q2, q2
[^>]*> eec4 de25 	vmlsldavax.s16	ip, r9, q2, q2
[^>]*> eec4 ce09 	vmlsldav.s16	ip, r9, q2, q4
[^>]*> eec4 ce29 	vmlsldava.s16	ip, r9, q2, q4
[^>]*> eec4 de09 	vmlsldavx.s16	ip, r9, q2, q4
[^>]*> eec4 de29 	vmlsldavax.s16	ip, r9, q2, q4
[^>]*> eec4 ce0f 	vmlsldav.s16	ip, r9, q2, q7
[^>]*> eec4 ce2f 	vmlsldava.s16	ip, r9, q2, q7
[^>]*> eec4 de0f 	vmlsldavx.s16	ip, r9, q2, q7
[^>]*> eec4 de2f 	vmlsldavax.s16	ip, r9, q2, q7
[^>]*> eec8 ce01 	vmlsldav.s16	ip, r9, q4, q0
[^>]*> eec8 ce21 	vmlsldava.s16	ip, r9, q4, q0
[^>]*> eec8 de01 	vmlsldavx.s16	ip, r9, q4, q0
[^>]*> eec8 de21 	vmlsldavax.s16	ip, r9, q4, q0
[^>]*> eec8 ce03 	vmlsldav.s16	ip, r9, q4, q1
[^>]*> eec8 ce23 	vmlsldava.s16	ip, r9, q4, q1
[^>]*> eec8 de03 	vmlsldavx.s16	ip, r9, q4, q1
[^>]*> eec8 de23 	vmlsldavax.s16	ip, r9, q4, q1
[^>]*> eec8 ce05 	vmlsldav.s16	ip, r9, q4, q2
[^>]*> eec8 ce25 	vmlsldava.s16	ip, r9, q4, q2
[^>]*> eec8 de05 	vmlsldavx.s16	ip, r9, q4, q2
[^>]*> eec8 de25 	vmlsldavax.s16	ip, r9, q4, q2
[^>]*> eec8 ce09 	vmlsldav.s16	ip, r9, q4, q4
[^>]*> eec8 ce29 	vmlsldava.s16	ip, r9, q4, q4
[^>]*> eec8 de09 	vmlsldavx.s16	ip, r9, q4, q4
[^>]*> eec8 de29 	vmlsldavax.s16	ip, r9, q4, q4
[^>]*> eec8 ce0f 	vmlsldav.s16	ip, r9, q4, q7
[^>]*> eec8 ce2f 	vmlsldava.s16	ip, r9, q4, q7
[^>]*> eec8 de0f 	vmlsldavx.s16	ip, r9, q4, q7
[^>]*> eec8 de2f 	vmlsldavax.s16	ip, r9, q4, q7
[^>]*> eece ce01 	vmlsldav.s16	ip, r9, q7, q0
[^>]*> eece ce21 	vmlsldava.s16	ip, r9, q7, q0
[^>]*> eece de01 	vmlsldavx.s16	ip, r9, q7, q0
[^>]*> eece de21 	vmlsldavax.s16	ip, r9, q7, q0
[^>]*> eece ce03 	vmlsldav.s16	ip, r9, q7, q1
[^>]*> eece ce23 	vmlsldava.s16	ip, r9, q7, q1
[^>]*> eece de03 	vmlsldavx.s16	ip, r9, q7, q1
[^>]*> eece de23 	vmlsldavax.s16	ip, r9, q7, q1
[^>]*> eece ce05 	vmlsldav.s16	ip, r9, q7, q2
[^>]*> eece ce25 	vmlsldava.s16	ip, r9, q7, q2
[^>]*> eece de05 	vmlsldavx.s16	ip, r9, q7, q2
[^>]*> eece de25 	vmlsldavax.s16	ip, r9, q7, q2
[^>]*> eece ce09 	vmlsldav.s16	ip, r9, q7, q4
[^>]*> eece ce29 	vmlsldava.s16	ip, r9, q7, q4
[^>]*> eece de09 	vmlsldavx.s16	ip, r9, q7, q4
[^>]*> eece de29 	vmlsldavax.s16	ip, r9, q7, q4
[^>]*> eece ce0f 	vmlsldav.s16	ip, r9, q7, q7
[^>]*> eece ce2f 	vmlsldava.s16	ip, r9, q7, q7
[^>]*> eece de0f 	vmlsldavx.s16	ip, r9, q7, q7
[^>]*> eece de2f 	vmlsldavax.s16	ip, r9, q7, q7
[^>]*> eed0 ce01 	vmlsldav.s16	ip, fp, q0, q0
[^>]*> eed0 ce21 	vmlsldava.s16	ip, fp, q0, q0
[^>]*> eed0 de01 	vmlsldavx.s16	ip, fp, q0, q0
[^>]*> eed0 de21 	vmlsldavax.s16	ip, fp, q0, q0
[^>]*> eed0 ce03 	vmlsldav.s16	ip, fp, q0, q1
[^>]*> eed0 ce23 	vmlsldava.s16	ip, fp, q0, q1
[^>]*> eed0 de03 	vmlsldavx.s16	ip, fp, q0, q1
[^>]*> eed0 de23 	vmlsldavax.s16	ip, fp, q0, q1
[^>]*> eed0 ce05 	vmlsldav.s16	ip, fp, q0, q2
[^>]*> eed0 ce25 	vmlsldava.s16	ip, fp, q0, q2
[^>]*> eed0 de05 	vmlsldavx.s16	ip, fp, q0, q2
[^>]*> eed0 de25 	vmlsldavax.s16	ip, fp, q0, q2
[^>]*> eed0 ce09 	vmlsldav.s16	ip, fp, q0, q4
[^>]*> eed0 ce29 	vmlsldava.s16	ip, fp, q0, q4
[^>]*> eed0 de09 	vmlsldavx.s16	ip, fp, q0, q4
[^>]*> eed0 de29 	vmlsldavax.s16	ip, fp, q0, q4
[^>]*> eed0 ce0f 	vmlsldav.s16	ip, fp, q0, q7
[^>]*> eed0 ce2f 	vmlsldava.s16	ip, fp, q0, q7
[^>]*> eed0 de0f 	vmlsldavx.s16	ip, fp, q0, q7
[^>]*> eed0 de2f 	vmlsldavax.s16	ip, fp, q0, q7
[^>]*> eed2 ce01 	vmlsldav.s16	ip, fp, q1, q0
[^>]*> eed2 ce21 	vmlsldava.s16	ip, fp, q1, q0
[^>]*> eed2 de01 	vmlsldavx.s16	ip, fp, q1, q0
[^>]*> eed2 de21 	vmlsldavax.s16	ip, fp, q1, q0
[^>]*> eed2 ce03 	vmlsldav.s16	ip, fp, q1, q1
[^>]*> eed2 ce23 	vmlsldava.s16	ip, fp, q1, q1
[^>]*> eed2 de03 	vmlsldavx.s16	ip, fp, q1, q1
[^>]*> eed2 de23 	vmlsldavax.s16	ip, fp, q1, q1
[^>]*> eed2 ce05 	vmlsldav.s16	ip, fp, q1, q2
[^>]*> eed2 ce25 	vmlsldava.s16	ip, fp, q1, q2
[^>]*> eed2 de05 	vmlsldavx.s16	ip, fp, q1, q2
[^>]*> eed2 de25 	vmlsldavax.s16	ip, fp, q1, q2
[^>]*> eed2 ce09 	vmlsldav.s16	ip, fp, q1, q4
[^>]*> eed2 ce29 	vmlsldava.s16	ip, fp, q1, q4
[^>]*> eed2 de09 	vmlsldavx.s16	ip, fp, q1, q4
[^>]*> eed2 de29 	vmlsldavax.s16	ip, fp, q1, q4
[^>]*> eed2 ce0f 	vmlsldav.s16	ip, fp, q1, q7
[^>]*> eed2 ce2f 	vmlsldava.s16	ip, fp, q1, q7
[^>]*> eed2 de0f 	vmlsldavx.s16	ip, fp, q1, q7
[^>]*> eed2 de2f 	vmlsldavax.s16	ip, fp, q1, q7
[^>]*> eed4 ce01 	vmlsldav.s16	ip, fp, q2, q0
[^>]*> eed4 ce21 	vmlsldava.s16	ip, fp, q2, q0
[^>]*> eed4 de01 	vmlsldavx.s16	ip, fp, q2, q0
[^>]*> eed4 de21 	vmlsldavax.s16	ip, fp, q2, q0
[^>]*> eed4 ce03 	vmlsldav.s16	ip, fp, q2, q1
[^>]*> eed4 ce23 	vmlsldava.s16	ip, fp, q2, q1
[^>]*> eed4 de03 	vmlsldavx.s16	ip, fp, q2, q1
[^>]*> eed4 de23 	vmlsldavax.s16	ip, fp, q2, q1
[^>]*> eed4 ce05 	vmlsldav.s16	ip, fp, q2, q2
[^>]*> eed4 ce25 	vmlsldava.s16	ip, fp, q2, q2
[^>]*> eed4 de05 	vmlsldavx.s16	ip, fp, q2, q2
[^>]*> eed4 de25 	vmlsldavax.s16	ip, fp, q2, q2
[^>]*> eed4 ce09 	vmlsldav.s16	ip, fp, q2, q4
[^>]*> eed4 ce29 	vmlsldava.s16	ip, fp, q2, q4
[^>]*> eed4 de09 	vmlsldavx.s16	ip, fp, q2, q4
[^>]*> eed4 de29 	vmlsldavax.s16	ip, fp, q2, q4
[^>]*> eed4 ce0f 	vmlsldav.s16	ip, fp, q2, q7
[^>]*> eed4 ce2f 	vmlsldava.s16	ip, fp, q2, q7
[^>]*> eed4 de0f 	vmlsldavx.s16	ip, fp, q2, q7
[^>]*> eed4 de2f 	vmlsldavax.s16	ip, fp, q2, q7
[^>]*> eed8 ce01 	vmlsldav.s16	ip, fp, q4, q0
[^>]*> eed8 ce21 	vmlsldava.s16	ip, fp, q4, q0
[^>]*> eed8 de01 	vmlsldavx.s16	ip, fp, q4, q0
[^>]*> eed8 de21 	vmlsldavax.s16	ip, fp, q4, q0
[^>]*> eed8 ce03 	vmlsldav.s16	ip, fp, q4, q1
[^>]*> eed8 ce23 	vmlsldava.s16	ip, fp, q4, q1
[^>]*> eed8 de03 	vmlsldavx.s16	ip, fp, q4, q1
[^>]*> eed8 de23 	vmlsldavax.s16	ip, fp, q4, q1
[^>]*> eed8 ce05 	vmlsldav.s16	ip, fp, q4, q2
[^>]*> eed8 ce25 	vmlsldava.s16	ip, fp, q4, q2
[^>]*> eed8 de05 	vmlsldavx.s16	ip, fp, q4, q2
[^>]*> eed8 de25 	vmlsldavax.s16	ip, fp, q4, q2
[^>]*> eed8 ce09 	vmlsldav.s16	ip, fp, q4, q4
[^>]*> eed8 ce29 	vmlsldava.s16	ip, fp, q4, q4
[^>]*> eed8 de09 	vmlsldavx.s16	ip, fp, q4, q4
[^>]*> eed8 de29 	vmlsldavax.s16	ip, fp, q4, q4
[^>]*> eed8 ce0f 	vmlsldav.s16	ip, fp, q4, q7
[^>]*> eed8 ce2f 	vmlsldava.s16	ip, fp, q4, q7
[^>]*> eed8 de0f 	vmlsldavx.s16	ip, fp, q4, q7
[^>]*> eed8 de2f 	vmlsldavax.s16	ip, fp, q4, q7
[^>]*> eede ce01 	vmlsldav.s16	ip, fp, q7, q0
[^>]*> eede ce21 	vmlsldava.s16	ip, fp, q7, q0
[^>]*> eede de01 	vmlsldavx.s16	ip, fp, q7, q0
[^>]*> eede de21 	vmlsldavax.s16	ip, fp, q7, q0
[^>]*> eede ce03 	vmlsldav.s16	ip, fp, q7, q1
[^>]*> eede ce23 	vmlsldava.s16	ip, fp, q7, q1
[^>]*> eede de03 	vmlsldavx.s16	ip, fp, q7, q1
[^>]*> eede de23 	vmlsldavax.s16	ip, fp, q7, q1
[^>]*> eede ce05 	vmlsldav.s16	ip, fp, q7, q2
[^>]*> eede ce25 	vmlsldava.s16	ip, fp, q7, q2
[^>]*> eede de05 	vmlsldavx.s16	ip, fp, q7, q2
[^>]*> eede de25 	vmlsldavax.s16	ip, fp, q7, q2
[^>]*> eede ce09 	vmlsldav.s16	ip, fp, q7, q4
[^>]*> eede ce29 	vmlsldava.s16	ip, fp, q7, q4
[^>]*> eede de09 	vmlsldavx.s16	ip, fp, q7, q4
[^>]*> eede de29 	vmlsldavax.s16	ip, fp, q7, q4
[^>]*> eede ce0f 	vmlsldav.s16	ip, fp, q7, q7
[^>]*> eede ce2f 	vmlsldava.s16	ip, fp, q7, q7
[^>]*> eede de0f 	vmlsldavx.s16	ip, fp, q7, q7
[^>]*> eede de2f 	vmlsldavax.s16	ip, fp, q7, q7
[^>]*> ee80 ee01 	vmlsldav.s16	lr, r1, q0, q0
[^>]*> ee80 ee21 	vmlsldava.s16	lr, r1, q0, q0
[^>]*> ee80 fe01 	vmlsldavx.s16	lr, r1, q0, q0
[^>]*> ee80 fe21 	vmlsldavax.s16	lr, r1, q0, q0
[^>]*> ee80 ee03 	vmlsldav.s16	lr, r1, q0, q1
[^>]*> ee80 ee23 	vmlsldava.s16	lr, r1, q0, q1
[^>]*> ee80 fe03 	vmlsldavx.s16	lr, r1, q0, q1
[^>]*> ee80 fe23 	vmlsldavax.s16	lr, r1, q0, q1
[^>]*> ee80 ee05 	vmlsldav.s16	lr, r1, q0, q2
[^>]*> ee80 ee25 	vmlsldava.s16	lr, r1, q0, q2
[^>]*> ee80 fe05 	vmlsldavx.s16	lr, r1, q0, q2
[^>]*> ee80 fe25 	vmlsldavax.s16	lr, r1, q0, q2
[^>]*> ee80 ee09 	vmlsldav.s16	lr, r1, q0, q4
[^>]*> ee80 ee29 	vmlsldava.s16	lr, r1, q0, q4
[^>]*> ee80 fe09 	vmlsldavx.s16	lr, r1, q0, q4
[^>]*> ee80 fe29 	vmlsldavax.s16	lr, r1, q0, q4
[^>]*> ee80 ee0f 	vmlsldav.s16	lr, r1, q0, q7
[^>]*> ee80 ee2f 	vmlsldava.s16	lr, r1, q0, q7
[^>]*> ee80 fe0f 	vmlsldavx.s16	lr, r1, q0, q7
[^>]*> ee80 fe2f 	vmlsldavax.s16	lr, r1, q0, q7
[^>]*> ee82 ee01 	vmlsldav.s16	lr, r1, q1, q0
[^>]*> ee82 ee21 	vmlsldava.s16	lr, r1, q1, q0
[^>]*> ee82 fe01 	vmlsldavx.s16	lr, r1, q1, q0
[^>]*> ee82 fe21 	vmlsldavax.s16	lr, r1, q1, q0
[^>]*> ee82 ee03 	vmlsldav.s16	lr, r1, q1, q1
[^>]*> ee82 ee23 	vmlsldava.s16	lr, r1, q1, q1
[^>]*> ee82 fe03 	vmlsldavx.s16	lr, r1, q1, q1
[^>]*> ee82 fe23 	vmlsldavax.s16	lr, r1, q1, q1
[^>]*> ee82 ee05 	vmlsldav.s16	lr, r1, q1, q2
[^>]*> ee82 ee25 	vmlsldava.s16	lr, r1, q1, q2
[^>]*> ee82 fe05 	vmlsldavx.s16	lr, r1, q1, q2
[^>]*> ee82 fe25 	vmlsldavax.s16	lr, r1, q1, q2
[^>]*> ee82 ee09 	vmlsldav.s16	lr, r1, q1, q4
[^>]*> ee82 ee29 	vmlsldava.s16	lr, r1, q1, q4
[^>]*> ee82 fe09 	vmlsldavx.s16	lr, r1, q1, q4
[^>]*> ee82 fe29 	vmlsldavax.s16	lr, r1, q1, q4
[^>]*> ee82 ee0f 	vmlsldav.s16	lr, r1, q1, q7
[^>]*> ee82 ee2f 	vmlsldava.s16	lr, r1, q1, q7
[^>]*> ee82 fe0f 	vmlsldavx.s16	lr, r1, q1, q7
[^>]*> ee82 fe2f 	vmlsldavax.s16	lr, r1, q1, q7
[^>]*> ee84 ee01 	vmlsldav.s16	lr, r1, q2, q0
[^>]*> ee84 ee21 	vmlsldava.s16	lr, r1, q2, q0
[^>]*> ee84 fe01 	vmlsldavx.s16	lr, r1, q2, q0
[^>]*> ee84 fe21 	vmlsldavax.s16	lr, r1, q2, q0
[^>]*> ee84 ee03 	vmlsldav.s16	lr, r1, q2, q1
[^>]*> ee84 ee23 	vmlsldava.s16	lr, r1, q2, q1
[^>]*> ee84 fe03 	vmlsldavx.s16	lr, r1, q2, q1
[^>]*> ee84 fe23 	vmlsldavax.s16	lr, r1, q2, q1
[^>]*> ee84 ee05 	vmlsldav.s16	lr, r1, q2, q2
[^>]*> ee84 ee25 	vmlsldava.s16	lr, r1, q2, q2
[^>]*> ee84 fe05 	vmlsldavx.s16	lr, r1, q2, q2
[^>]*> ee84 fe25 	vmlsldavax.s16	lr, r1, q2, q2
[^>]*> ee84 ee09 	vmlsldav.s16	lr, r1, q2, q4
[^>]*> ee84 ee29 	vmlsldava.s16	lr, r1, q2, q4
[^>]*> ee84 fe09 	vmlsldavx.s16	lr, r1, q2, q4
[^>]*> ee84 fe29 	vmlsldavax.s16	lr, r1, q2, q4
[^>]*> ee84 ee0f 	vmlsldav.s16	lr, r1, q2, q7
[^>]*> ee84 ee2f 	vmlsldava.s16	lr, r1, q2, q7
[^>]*> ee84 fe0f 	vmlsldavx.s16	lr, r1, q2, q7
[^>]*> ee84 fe2f 	vmlsldavax.s16	lr, r1, q2, q7
[^>]*> ee88 ee01 	vmlsldav.s16	lr, r1, q4, q0
[^>]*> ee88 ee21 	vmlsldava.s16	lr, r1, q4, q0
[^>]*> ee88 fe01 	vmlsldavx.s16	lr, r1, q4, q0
[^>]*> ee88 fe21 	vmlsldavax.s16	lr, r1, q4, q0
[^>]*> ee88 ee03 	vmlsldav.s16	lr, r1, q4, q1
[^>]*> ee88 ee23 	vmlsldava.s16	lr, r1, q4, q1
[^>]*> ee88 fe03 	vmlsldavx.s16	lr, r1, q4, q1
[^>]*> ee88 fe23 	vmlsldavax.s16	lr, r1, q4, q1
[^>]*> ee88 ee05 	vmlsldav.s16	lr, r1, q4, q2
[^>]*> ee88 ee25 	vmlsldava.s16	lr, r1, q4, q2
[^>]*> ee88 fe05 	vmlsldavx.s16	lr, r1, q4, q2
[^>]*> ee88 fe25 	vmlsldavax.s16	lr, r1, q4, q2
[^>]*> ee88 ee09 	vmlsldav.s16	lr, r1, q4, q4
[^>]*> ee88 ee29 	vmlsldava.s16	lr, r1, q4, q4
[^>]*> ee88 fe09 	vmlsldavx.s16	lr, r1, q4, q4
[^>]*> ee88 fe29 	vmlsldavax.s16	lr, r1, q4, q4
[^>]*> ee88 ee0f 	vmlsldav.s16	lr, r1, q4, q7
[^>]*> ee88 ee2f 	vmlsldava.s16	lr, r1, q4, q7
[^>]*> ee88 fe0f 	vmlsldavx.s16	lr, r1, q4, q7
[^>]*> ee88 fe2f 	vmlsldavax.s16	lr, r1, q4, q7
[^>]*> ee8e ee01 	vmlsldav.s16	lr, r1, q7, q0
[^>]*> ee8e ee21 	vmlsldava.s16	lr, r1, q7, q0
[^>]*> ee8e fe01 	vmlsldavx.s16	lr, r1, q7, q0
[^>]*> ee8e fe21 	vmlsldavax.s16	lr, r1, q7, q0
[^>]*> ee8e ee03 	vmlsldav.s16	lr, r1, q7, q1
[^>]*> ee8e ee23 	vmlsldava.s16	lr, r1, q7, q1
[^>]*> ee8e fe03 	vmlsldavx.s16	lr, r1, q7, q1
[^>]*> ee8e fe23 	vmlsldavax.s16	lr, r1, q7, q1
[^>]*> ee8e ee05 	vmlsldav.s16	lr, r1, q7, q2
[^>]*> ee8e ee25 	vmlsldava.s16	lr, r1, q7, q2
[^>]*> ee8e fe05 	vmlsldavx.s16	lr, r1, q7, q2
[^>]*> ee8e fe25 	vmlsldavax.s16	lr, r1, q7, q2
[^>]*> ee8e ee09 	vmlsldav.s16	lr, r1, q7, q4
[^>]*> ee8e ee29 	vmlsldava.s16	lr, r1, q7, q4
[^>]*> ee8e fe09 	vmlsldavx.s16	lr, r1, q7, q4
[^>]*> ee8e fe29 	vmlsldavax.s16	lr, r1, q7, q4
[^>]*> ee8e ee0f 	vmlsldav.s16	lr, r1, q7, q7
[^>]*> ee8e ee2f 	vmlsldava.s16	lr, r1, q7, q7
[^>]*> ee8e fe0f 	vmlsldavx.s16	lr, r1, q7, q7
[^>]*> ee8e fe2f 	vmlsldavax.s16	lr, r1, q7, q7
[^>]*> ee90 ee01 	vmlsldav.s16	lr, r3, q0, q0
[^>]*> ee90 ee21 	vmlsldava.s16	lr, r3, q0, q0
[^>]*> ee90 fe01 	vmlsldavx.s16	lr, r3, q0, q0
[^>]*> ee90 fe21 	vmlsldavax.s16	lr, r3, q0, q0
[^>]*> ee90 ee03 	vmlsldav.s16	lr, r3, q0, q1
[^>]*> ee90 ee23 	vmlsldava.s16	lr, r3, q0, q1
[^>]*> ee90 fe03 	vmlsldavx.s16	lr, r3, q0, q1
[^>]*> ee90 fe23 	vmlsldavax.s16	lr, r3, q0, q1
[^>]*> ee90 ee05 	vmlsldav.s16	lr, r3, q0, q2
[^>]*> ee90 ee25 	vmlsldava.s16	lr, r3, q0, q2
[^>]*> ee90 fe05 	vmlsldavx.s16	lr, r3, q0, q2
[^>]*> ee90 fe25 	vmlsldavax.s16	lr, r3, q0, q2
[^>]*> ee90 ee09 	vmlsldav.s16	lr, r3, q0, q4
[^>]*> ee90 ee29 	vmlsldava.s16	lr, r3, q0, q4
[^>]*> ee90 fe09 	vmlsldavx.s16	lr, r3, q0, q4
[^>]*> ee90 fe29 	vmlsldavax.s16	lr, r3, q0, q4
[^>]*> ee90 ee0f 	vmlsldav.s16	lr, r3, q0, q7
[^>]*> ee90 ee2f 	vmlsldava.s16	lr, r3, q0, q7
[^>]*> ee90 fe0f 	vmlsldavx.s16	lr, r3, q0, q7
[^>]*> ee90 fe2f 	vmlsldavax.s16	lr, r3, q0, q7
[^>]*> ee92 ee01 	vmlsldav.s16	lr, r3, q1, q0
[^>]*> ee92 ee21 	vmlsldava.s16	lr, r3, q1, q0
[^>]*> ee92 fe01 	vmlsldavx.s16	lr, r3, q1, q0
[^>]*> ee92 fe21 	vmlsldavax.s16	lr, r3, q1, q0
[^>]*> ee92 ee03 	vmlsldav.s16	lr, r3, q1, q1
[^>]*> ee92 ee23 	vmlsldava.s16	lr, r3, q1, q1
[^>]*> ee92 fe03 	vmlsldavx.s16	lr, r3, q1, q1
[^>]*> ee92 fe23 	vmlsldavax.s16	lr, r3, q1, q1
[^>]*> ee92 ee05 	vmlsldav.s16	lr, r3, q1, q2
[^>]*> ee92 ee25 	vmlsldava.s16	lr, r3, q1, q2
[^>]*> ee92 fe05 	vmlsldavx.s16	lr, r3, q1, q2
[^>]*> ee92 fe25 	vmlsldavax.s16	lr, r3, q1, q2
[^>]*> ee92 ee09 	vmlsldav.s16	lr, r3, q1, q4
[^>]*> ee92 ee29 	vmlsldava.s16	lr, r3, q1, q4
[^>]*> ee92 fe09 	vmlsldavx.s16	lr, r3, q1, q4
[^>]*> ee92 fe29 	vmlsldavax.s16	lr, r3, q1, q4
[^>]*> ee92 ee0f 	vmlsldav.s16	lr, r3, q1, q7
[^>]*> ee92 ee2f 	vmlsldava.s16	lr, r3, q1, q7
[^>]*> ee92 fe0f 	vmlsldavx.s16	lr, r3, q1, q7
[^>]*> ee92 fe2f 	vmlsldavax.s16	lr, r3, q1, q7
[^>]*> ee94 ee01 	vmlsldav.s16	lr, r3, q2, q0
[^>]*> ee94 ee21 	vmlsldava.s16	lr, r3, q2, q0
[^>]*> ee94 fe01 	vmlsldavx.s16	lr, r3, q2, q0
[^>]*> ee94 fe21 	vmlsldavax.s16	lr, r3, q2, q0
[^>]*> ee94 ee03 	vmlsldav.s16	lr, r3, q2, q1
[^>]*> ee94 ee23 	vmlsldava.s16	lr, r3, q2, q1
[^>]*> ee94 fe03 	vmlsldavx.s16	lr, r3, q2, q1
[^>]*> ee94 fe23 	vmlsldavax.s16	lr, r3, q2, q1
[^>]*> ee94 ee05 	vmlsldav.s16	lr, r3, q2, q2
[^>]*> ee94 ee25 	vmlsldava.s16	lr, r3, q2, q2
[^>]*> ee94 fe05 	vmlsldavx.s16	lr, r3, q2, q2
[^>]*> ee94 fe25 	vmlsldavax.s16	lr, r3, q2, q2
[^>]*> ee94 ee09 	vmlsldav.s16	lr, r3, q2, q4
[^>]*> ee94 ee29 	vmlsldava.s16	lr, r3, q2, q4
[^>]*> ee94 fe09 	vmlsldavx.s16	lr, r3, q2, q4
[^>]*> ee94 fe29 	vmlsldavax.s16	lr, r3, q2, q4
[^>]*> ee94 ee0f 	vmlsldav.s16	lr, r3, q2, q7
[^>]*> ee94 ee2f 	vmlsldava.s16	lr, r3, q2, q7
[^>]*> ee94 fe0f 	vmlsldavx.s16	lr, r3, q2, q7
[^>]*> ee94 fe2f 	vmlsldavax.s16	lr, r3, q2, q7
[^>]*> ee98 ee01 	vmlsldav.s16	lr, r3, q4, q0
[^>]*> ee98 ee21 	vmlsldava.s16	lr, r3, q4, q0
[^>]*> ee98 fe01 	vmlsldavx.s16	lr, r3, q4, q0
[^>]*> ee98 fe21 	vmlsldavax.s16	lr, r3, q4, q0
[^>]*> ee98 ee03 	vmlsldav.s16	lr, r3, q4, q1
[^>]*> ee98 ee23 	vmlsldava.s16	lr, r3, q4, q1
[^>]*> ee98 fe03 	vmlsldavx.s16	lr, r3, q4, q1
[^>]*> ee98 fe23 	vmlsldavax.s16	lr, r3, q4, q1
[^>]*> ee98 ee05 	vmlsldav.s16	lr, r3, q4, q2
[^>]*> ee98 ee25 	vmlsldava.s16	lr, r3, q4, q2
[^>]*> ee98 fe05 	vmlsldavx.s16	lr, r3, q4, q2
[^>]*> ee98 fe25 	vmlsldavax.s16	lr, r3, q4, q2
[^>]*> ee98 ee09 	vmlsldav.s16	lr, r3, q4, q4
[^>]*> ee98 ee29 	vmlsldava.s16	lr, r3, q4, q4
[^>]*> ee98 fe09 	vmlsldavx.s16	lr, r3, q4, q4
[^>]*> ee98 fe29 	vmlsldavax.s16	lr, r3, q4, q4
[^>]*> ee98 ee0f 	vmlsldav.s16	lr, r3, q4, q7
[^>]*> ee98 ee2f 	vmlsldava.s16	lr, r3, q4, q7
[^>]*> ee98 fe0f 	vmlsldavx.s16	lr, r3, q4, q7
[^>]*> ee98 fe2f 	vmlsldavax.s16	lr, r3, q4, q7
[^>]*> ee9e ee01 	vmlsldav.s16	lr, r3, q7, q0
[^>]*> ee9e ee21 	vmlsldava.s16	lr, r3, q7, q0
[^>]*> ee9e fe01 	vmlsldavx.s16	lr, r3, q7, q0
[^>]*> ee9e fe21 	vmlsldavax.s16	lr, r3, q7, q0
[^>]*> ee9e ee03 	vmlsldav.s16	lr, r3, q7, q1
[^>]*> ee9e ee23 	vmlsldava.s16	lr, r3, q7, q1
[^>]*> ee9e fe03 	vmlsldavx.s16	lr, r3, q7, q1
[^>]*> ee9e fe23 	vmlsldavax.s16	lr, r3, q7, q1
[^>]*> ee9e ee05 	vmlsldav.s16	lr, r3, q7, q2
[^>]*> ee9e ee25 	vmlsldava.s16	lr, r3, q7, q2
[^>]*> ee9e fe05 	vmlsldavx.s16	lr, r3, q7, q2
[^>]*> ee9e fe25 	vmlsldavax.s16	lr, r3, q7, q2
[^>]*> ee9e ee09 	vmlsldav.s16	lr, r3, q7, q4
[^>]*> ee9e ee29 	vmlsldava.s16	lr, r3, q7, q4
[^>]*> ee9e fe09 	vmlsldavx.s16	lr, r3, q7, q4
[^>]*> ee9e fe29 	vmlsldavax.s16	lr, r3, q7, q4
[^>]*> ee9e ee0f 	vmlsldav.s16	lr, r3, q7, q7
[^>]*> ee9e ee2f 	vmlsldava.s16	lr, r3, q7, q7
[^>]*> ee9e fe0f 	vmlsldavx.s16	lr, r3, q7, q7
[^>]*> ee9e fe2f 	vmlsldavax.s16	lr, r3, q7, q7
[^>]*> eea0 ee01 	vmlsldav.s16	lr, r5, q0, q0
[^>]*> eea0 ee21 	vmlsldava.s16	lr, r5, q0, q0
[^>]*> eea0 fe01 	vmlsldavx.s16	lr, r5, q0, q0
[^>]*> eea0 fe21 	vmlsldavax.s16	lr, r5, q0, q0
[^>]*> eea0 ee03 	vmlsldav.s16	lr, r5, q0, q1
[^>]*> eea0 ee23 	vmlsldava.s16	lr, r5, q0, q1
[^>]*> eea0 fe03 	vmlsldavx.s16	lr, r5, q0, q1
[^>]*> eea0 fe23 	vmlsldavax.s16	lr, r5, q0, q1
[^>]*> eea0 ee05 	vmlsldav.s16	lr, r5, q0, q2
[^>]*> eea0 ee25 	vmlsldava.s16	lr, r5, q0, q2
[^>]*> eea0 fe05 	vmlsldavx.s16	lr, r5, q0, q2
[^>]*> eea0 fe25 	vmlsldavax.s16	lr, r5, q0, q2
[^>]*> eea0 ee09 	vmlsldav.s16	lr, r5, q0, q4
[^>]*> eea0 ee29 	vmlsldava.s16	lr, r5, q0, q4
[^>]*> eea0 fe09 	vmlsldavx.s16	lr, r5, q0, q4
[^>]*> eea0 fe29 	vmlsldavax.s16	lr, r5, q0, q4
[^>]*> eea0 ee0f 	vmlsldav.s16	lr, r5, q0, q7
[^>]*> eea0 ee2f 	vmlsldava.s16	lr, r5, q0, q7
[^>]*> eea0 fe0f 	vmlsldavx.s16	lr, r5, q0, q7
[^>]*> eea0 fe2f 	vmlsldavax.s16	lr, r5, q0, q7
[^>]*> eea2 ee01 	vmlsldav.s16	lr, r5, q1, q0
[^>]*> eea2 ee21 	vmlsldava.s16	lr, r5, q1, q0
[^>]*> eea2 fe01 	vmlsldavx.s16	lr, r5, q1, q0
[^>]*> eea2 fe21 	vmlsldavax.s16	lr, r5, q1, q0
[^>]*> eea2 ee03 	vmlsldav.s16	lr, r5, q1, q1
[^>]*> eea2 ee23 	vmlsldava.s16	lr, r5, q1, q1
[^>]*> eea2 fe03 	vmlsldavx.s16	lr, r5, q1, q1
[^>]*> eea2 fe23 	vmlsldavax.s16	lr, r5, q1, q1
[^>]*> eea2 ee05 	vmlsldav.s16	lr, r5, q1, q2
[^>]*> eea2 ee25 	vmlsldava.s16	lr, r5, q1, q2
[^>]*> eea2 fe05 	vmlsldavx.s16	lr, r5, q1, q2
[^>]*> eea2 fe25 	vmlsldavax.s16	lr, r5, q1, q2
[^>]*> eea2 ee09 	vmlsldav.s16	lr, r5, q1, q4
[^>]*> eea2 ee29 	vmlsldava.s16	lr, r5, q1, q4
[^>]*> eea2 fe09 	vmlsldavx.s16	lr, r5, q1, q4
[^>]*> eea2 fe29 	vmlsldavax.s16	lr, r5, q1, q4
[^>]*> eea2 ee0f 	vmlsldav.s16	lr, r5, q1, q7
[^>]*> eea2 ee2f 	vmlsldava.s16	lr, r5, q1, q7
[^>]*> eea2 fe0f 	vmlsldavx.s16	lr, r5, q1, q7
[^>]*> eea2 fe2f 	vmlsldavax.s16	lr, r5, q1, q7
[^>]*> eea4 ee01 	vmlsldav.s16	lr, r5, q2, q0
[^>]*> eea4 ee21 	vmlsldava.s16	lr, r5, q2, q0
[^>]*> eea4 fe01 	vmlsldavx.s16	lr, r5, q2, q0
[^>]*> eea4 fe21 	vmlsldavax.s16	lr, r5, q2, q0
[^>]*> eea4 ee03 	vmlsldav.s16	lr, r5, q2, q1
[^>]*> eea4 ee23 	vmlsldava.s16	lr, r5, q2, q1
[^>]*> eea4 fe03 	vmlsldavx.s16	lr, r5, q2, q1
[^>]*> eea4 fe23 	vmlsldavax.s16	lr, r5, q2, q1
[^>]*> eea4 ee05 	vmlsldav.s16	lr, r5, q2, q2
[^>]*> eea4 ee25 	vmlsldava.s16	lr, r5, q2, q2
[^>]*> eea4 fe05 	vmlsldavx.s16	lr, r5, q2, q2
[^>]*> eea4 fe25 	vmlsldavax.s16	lr, r5, q2, q2
[^>]*> eea4 ee09 	vmlsldav.s16	lr, r5, q2, q4
[^>]*> eea4 ee29 	vmlsldava.s16	lr, r5, q2, q4
[^>]*> eea4 fe09 	vmlsldavx.s16	lr, r5, q2, q4
[^>]*> eea4 fe29 	vmlsldavax.s16	lr, r5, q2, q4
[^>]*> eea4 ee0f 	vmlsldav.s16	lr, r5, q2, q7
[^>]*> eea4 ee2f 	vmlsldava.s16	lr, r5, q2, q7
[^>]*> eea4 fe0f 	vmlsldavx.s16	lr, r5, q2, q7
[^>]*> eea4 fe2f 	vmlsldavax.s16	lr, r5, q2, q7
[^>]*> eea8 ee01 	vmlsldav.s16	lr, r5, q4, q0
[^>]*> eea8 ee21 	vmlsldava.s16	lr, r5, q4, q0
[^>]*> eea8 fe01 	vmlsldavx.s16	lr, r5, q4, q0
[^>]*> eea8 fe21 	vmlsldavax.s16	lr, r5, q4, q0
[^>]*> eea8 ee03 	vmlsldav.s16	lr, r5, q4, q1
[^>]*> eea8 ee23 	vmlsldava.s16	lr, r5, q4, q1
[^>]*> eea8 fe03 	vmlsldavx.s16	lr, r5, q4, q1
[^>]*> eea8 fe23 	vmlsldavax.s16	lr, r5, q4, q1
[^>]*> eea8 ee05 	vmlsldav.s16	lr, r5, q4, q2
[^>]*> eea8 ee25 	vmlsldava.s16	lr, r5, q4, q2
[^>]*> eea8 fe05 	vmlsldavx.s16	lr, r5, q4, q2
[^>]*> eea8 fe25 	vmlsldavax.s16	lr, r5, q4, q2
[^>]*> eea8 ee09 	vmlsldav.s16	lr, r5, q4, q4
[^>]*> eea8 ee29 	vmlsldava.s16	lr, r5, q4, q4
[^>]*> eea8 fe09 	vmlsldavx.s16	lr, r5, q4, q4
[^>]*> eea8 fe29 	vmlsldavax.s16	lr, r5, q4, q4
[^>]*> eea8 ee0f 	vmlsldav.s16	lr, r5, q4, q7
[^>]*> eea8 ee2f 	vmlsldava.s16	lr, r5, q4, q7
[^>]*> eea8 fe0f 	vmlsldavx.s16	lr, r5, q4, q7
[^>]*> eea8 fe2f 	vmlsldavax.s16	lr, r5, q4, q7
[^>]*> eeae ee01 	vmlsldav.s16	lr, r5, q7, q0
[^>]*> eeae ee21 	vmlsldava.s16	lr, r5, q7, q0
[^>]*> eeae fe01 	vmlsldavx.s16	lr, r5, q7, q0
[^>]*> eeae fe21 	vmlsldavax.s16	lr, r5, q7, q0
[^>]*> eeae ee03 	vmlsldav.s16	lr, r5, q7, q1
[^>]*> eeae ee23 	vmlsldava.s16	lr, r5, q7, q1
[^>]*> eeae fe03 	vmlsldavx.s16	lr, r5, q7, q1
[^>]*> eeae fe23 	vmlsldavax.s16	lr, r5, q7, q1
[^>]*> eeae ee05 	vmlsldav.s16	lr, r5, q7, q2
[^>]*> eeae ee25 	vmlsldava.s16	lr, r5, q7, q2
[^>]*> eeae fe05 	vmlsldavx.s16	lr, r5, q7, q2
[^>]*> eeae fe25 	vmlsldavax.s16	lr, r5, q7, q2
[^>]*> eeae ee09 	vmlsldav.s16	lr, r5, q7, q4
[^>]*> eeae ee29 	vmlsldava.s16	lr, r5, q7, q4
[^>]*> eeae fe09 	vmlsldavx.s16	lr, r5, q7, q4
[^>]*> eeae fe29 	vmlsldavax.s16	lr, r5, q7, q4
[^>]*> eeae ee0f 	vmlsldav.s16	lr, r5, q7, q7
[^>]*> eeae ee2f 	vmlsldava.s16	lr, r5, q7, q7
[^>]*> eeae fe0f 	vmlsldavx.s16	lr, r5, q7, q7
[^>]*> eeae fe2f 	vmlsldavax.s16	lr, r5, q7, q7
[^>]*> eeb0 ee01 	vmlsldav.s16	lr, r7, q0, q0
[^>]*> eeb0 ee21 	vmlsldava.s16	lr, r7, q0, q0
[^>]*> eeb0 fe01 	vmlsldavx.s16	lr, r7, q0, q0
[^>]*> eeb0 fe21 	vmlsldavax.s16	lr, r7, q0, q0
[^>]*> eeb0 ee03 	vmlsldav.s16	lr, r7, q0, q1
[^>]*> eeb0 ee23 	vmlsldava.s16	lr, r7, q0, q1
[^>]*> eeb0 fe03 	vmlsldavx.s16	lr, r7, q0, q1
[^>]*> eeb0 fe23 	vmlsldavax.s16	lr, r7, q0, q1
[^>]*> eeb0 ee05 	vmlsldav.s16	lr, r7, q0, q2
[^>]*> eeb0 ee25 	vmlsldava.s16	lr, r7, q0, q2
[^>]*> eeb0 fe05 	vmlsldavx.s16	lr, r7, q0, q2
[^>]*> eeb0 fe25 	vmlsldavax.s16	lr, r7, q0, q2
[^>]*> eeb0 ee09 	vmlsldav.s16	lr, r7, q0, q4
[^>]*> eeb0 ee29 	vmlsldava.s16	lr, r7, q0, q4
[^>]*> eeb0 fe09 	vmlsldavx.s16	lr, r7, q0, q4
[^>]*> eeb0 fe29 	vmlsldavax.s16	lr, r7, q0, q4
[^>]*> eeb0 ee0f 	vmlsldav.s16	lr, r7, q0, q7
[^>]*> eeb0 ee2f 	vmlsldava.s16	lr, r7, q0, q7
[^>]*> eeb0 fe0f 	vmlsldavx.s16	lr, r7, q0, q7
[^>]*> eeb0 fe2f 	vmlsldavax.s16	lr, r7, q0, q7
[^>]*> eeb2 ee01 	vmlsldav.s16	lr, r7, q1, q0
[^>]*> eeb2 ee21 	vmlsldava.s16	lr, r7, q1, q0
[^>]*> eeb2 fe01 	vmlsldavx.s16	lr, r7, q1, q0
[^>]*> eeb2 fe21 	vmlsldavax.s16	lr, r7, q1, q0
[^>]*> eeb2 ee03 	vmlsldav.s16	lr, r7, q1, q1
[^>]*> eeb2 ee23 	vmlsldava.s16	lr, r7, q1, q1
[^>]*> eeb2 fe03 	vmlsldavx.s16	lr, r7, q1, q1
[^>]*> eeb2 fe23 	vmlsldavax.s16	lr, r7, q1, q1
[^>]*> eeb2 ee05 	vmlsldav.s16	lr, r7, q1, q2
[^>]*> eeb2 ee25 	vmlsldava.s16	lr, r7, q1, q2
[^>]*> eeb2 fe05 	vmlsldavx.s16	lr, r7, q1, q2
[^>]*> eeb2 fe25 	vmlsldavax.s16	lr, r7, q1, q2
[^>]*> eeb2 ee09 	vmlsldav.s16	lr, r7, q1, q4
[^>]*> eeb2 ee29 	vmlsldava.s16	lr, r7, q1, q4
[^>]*> eeb2 fe09 	vmlsldavx.s16	lr, r7, q1, q4
[^>]*> eeb2 fe29 	vmlsldavax.s16	lr, r7, q1, q4
[^>]*> eeb2 ee0f 	vmlsldav.s16	lr, r7, q1, q7
[^>]*> eeb2 ee2f 	vmlsldava.s16	lr, r7, q1, q7
[^>]*> eeb2 fe0f 	vmlsldavx.s16	lr, r7, q1, q7
[^>]*> eeb2 fe2f 	vmlsldavax.s16	lr, r7, q1, q7
[^>]*> eeb4 ee01 	vmlsldav.s16	lr, r7, q2, q0
[^>]*> eeb4 ee21 	vmlsldava.s16	lr, r7, q2, q0
[^>]*> eeb4 fe01 	vmlsldavx.s16	lr, r7, q2, q0
[^>]*> eeb4 fe21 	vmlsldavax.s16	lr, r7, q2, q0
[^>]*> eeb4 ee03 	vmlsldav.s16	lr, r7, q2, q1
[^>]*> eeb4 ee23 	vmlsldava.s16	lr, r7, q2, q1
[^>]*> eeb4 fe03 	vmlsldavx.s16	lr, r7, q2, q1
[^>]*> eeb4 fe23 	vmlsldavax.s16	lr, r7, q2, q1
[^>]*> eeb4 ee05 	vmlsldav.s16	lr, r7, q2, q2
[^>]*> eeb4 ee25 	vmlsldava.s16	lr, r7, q2, q2
[^>]*> eeb4 fe05 	vmlsldavx.s16	lr, r7, q2, q2
[^>]*> eeb4 fe25 	vmlsldavax.s16	lr, r7, q2, q2
[^>]*> eeb4 ee09 	vmlsldav.s16	lr, r7, q2, q4
[^>]*> eeb4 ee29 	vmlsldava.s16	lr, r7, q2, q4
[^>]*> eeb4 fe09 	vmlsldavx.s16	lr, r7, q2, q4
[^>]*> eeb4 fe29 	vmlsldavax.s16	lr, r7, q2, q4
[^>]*> eeb4 ee0f 	vmlsldav.s16	lr, r7, q2, q7
[^>]*> eeb4 ee2f 	vmlsldava.s16	lr, r7, q2, q7
[^>]*> eeb4 fe0f 	vmlsldavx.s16	lr, r7, q2, q7
[^>]*> eeb4 fe2f 	vmlsldavax.s16	lr, r7, q2, q7
[^>]*> eeb8 ee01 	vmlsldav.s16	lr, r7, q4, q0
[^>]*> eeb8 ee21 	vmlsldava.s16	lr, r7, q4, q0
[^>]*> eeb8 fe01 	vmlsldavx.s16	lr, r7, q4, q0
[^>]*> eeb8 fe21 	vmlsldavax.s16	lr, r7, q4, q0
[^>]*> eeb8 ee03 	vmlsldav.s16	lr, r7, q4, q1
[^>]*> eeb8 ee23 	vmlsldava.s16	lr, r7, q4, q1
[^>]*> eeb8 fe03 	vmlsldavx.s16	lr, r7, q4, q1
[^>]*> eeb8 fe23 	vmlsldavax.s16	lr, r7, q4, q1
[^>]*> eeb8 ee05 	vmlsldav.s16	lr, r7, q4, q2
[^>]*> eeb8 ee25 	vmlsldava.s16	lr, r7, q4, q2
[^>]*> eeb8 fe05 	vmlsldavx.s16	lr, r7, q4, q2
[^>]*> eeb8 fe25 	vmlsldavax.s16	lr, r7, q4, q2
[^>]*> eeb8 ee09 	vmlsldav.s16	lr, r7, q4, q4
[^>]*> eeb8 ee29 	vmlsldava.s16	lr, r7, q4, q4
[^>]*> eeb8 fe09 	vmlsldavx.s16	lr, r7, q4, q4
[^>]*> eeb8 fe29 	vmlsldavax.s16	lr, r7, q4, q4
[^>]*> eeb8 ee0f 	vmlsldav.s16	lr, r7, q4, q7
[^>]*> eeb8 ee2f 	vmlsldava.s16	lr, r7, q4, q7
[^>]*> eeb8 fe0f 	vmlsldavx.s16	lr, r7, q4, q7
[^>]*> eeb8 fe2f 	vmlsldavax.s16	lr, r7, q4, q7
[^>]*> eebe ee01 	vmlsldav.s16	lr, r7, q7, q0
[^>]*> eebe ee21 	vmlsldava.s16	lr, r7, q7, q0
[^>]*> eebe fe01 	vmlsldavx.s16	lr, r7, q7, q0
[^>]*> eebe fe21 	vmlsldavax.s16	lr, r7, q7, q0
[^>]*> eebe ee03 	vmlsldav.s16	lr, r7, q7, q1
[^>]*> eebe ee23 	vmlsldava.s16	lr, r7, q7, q1
[^>]*> eebe fe03 	vmlsldavx.s16	lr, r7, q7, q1
[^>]*> eebe fe23 	vmlsldavax.s16	lr, r7, q7, q1
[^>]*> eebe ee05 	vmlsldav.s16	lr, r7, q7, q2
[^>]*> eebe ee25 	vmlsldava.s16	lr, r7, q7, q2
[^>]*> eebe fe05 	vmlsldavx.s16	lr, r7, q7, q2
[^>]*> eebe fe25 	vmlsldavax.s16	lr, r7, q7, q2
[^>]*> eebe ee09 	vmlsldav.s16	lr, r7, q7, q4
[^>]*> eebe ee29 	vmlsldava.s16	lr, r7, q7, q4
[^>]*> eebe fe09 	vmlsldavx.s16	lr, r7, q7, q4
[^>]*> eebe fe29 	vmlsldavax.s16	lr, r7, q7, q4
[^>]*> eebe ee0f 	vmlsldav.s16	lr, r7, q7, q7
[^>]*> eebe ee2f 	vmlsldava.s16	lr, r7, q7, q7
[^>]*> eebe fe0f 	vmlsldavx.s16	lr, r7, q7, q7
[^>]*> eebe fe2f 	vmlsldavax.s16	lr, r7, q7, q7
[^>]*> eec0 ee01 	vmlsldav.s16	lr, r9, q0, q0
[^>]*> eec0 ee21 	vmlsldava.s16	lr, r9, q0, q0
[^>]*> eec0 fe01 	vmlsldavx.s16	lr, r9, q0, q0
[^>]*> eec0 fe21 	vmlsldavax.s16	lr, r9, q0, q0
[^>]*> eec0 ee03 	vmlsldav.s16	lr, r9, q0, q1
[^>]*> eec0 ee23 	vmlsldava.s16	lr, r9, q0, q1
[^>]*> eec0 fe03 	vmlsldavx.s16	lr, r9, q0, q1
[^>]*> eec0 fe23 	vmlsldavax.s16	lr, r9, q0, q1
[^>]*> eec0 ee05 	vmlsldav.s16	lr, r9, q0, q2
[^>]*> eec0 ee25 	vmlsldava.s16	lr, r9, q0, q2
[^>]*> eec0 fe05 	vmlsldavx.s16	lr, r9, q0, q2
[^>]*> eec0 fe25 	vmlsldavax.s16	lr, r9, q0, q2
[^>]*> eec0 ee09 	vmlsldav.s16	lr, r9, q0, q4
[^>]*> eec0 ee29 	vmlsldava.s16	lr, r9, q0, q4
[^>]*> eec0 fe09 	vmlsldavx.s16	lr, r9, q0, q4
[^>]*> eec0 fe29 	vmlsldavax.s16	lr, r9, q0, q4
[^>]*> eec0 ee0f 	vmlsldav.s16	lr, r9, q0, q7
[^>]*> eec0 ee2f 	vmlsldava.s16	lr, r9, q0, q7
[^>]*> eec0 fe0f 	vmlsldavx.s16	lr, r9, q0, q7
[^>]*> eec0 fe2f 	vmlsldavax.s16	lr, r9, q0, q7
[^>]*> eec2 ee01 	vmlsldav.s16	lr, r9, q1, q0
[^>]*> eec2 ee21 	vmlsldava.s16	lr, r9, q1, q0
[^>]*> eec2 fe01 	vmlsldavx.s16	lr, r9, q1, q0
[^>]*> eec2 fe21 	vmlsldavax.s16	lr, r9, q1, q0
[^>]*> eec2 ee03 	vmlsldav.s16	lr, r9, q1, q1
[^>]*> eec2 ee23 	vmlsldava.s16	lr, r9, q1, q1
[^>]*> eec2 fe03 	vmlsldavx.s16	lr, r9, q1, q1
[^>]*> eec2 fe23 	vmlsldavax.s16	lr, r9, q1, q1
[^>]*> eec2 ee05 	vmlsldav.s16	lr, r9, q1, q2
[^>]*> eec2 ee25 	vmlsldava.s16	lr, r9, q1, q2
[^>]*> eec2 fe05 	vmlsldavx.s16	lr, r9, q1, q2
[^>]*> eec2 fe25 	vmlsldavax.s16	lr, r9, q1, q2
[^>]*> eec2 ee09 	vmlsldav.s16	lr, r9, q1, q4
[^>]*> eec2 ee29 	vmlsldava.s16	lr, r9, q1, q4
[^>]*> eec2 fe09 	vmlsldavx.s16	lr, r9, q1, q4
[^>]*> eec2 fe29 	vmlsldavax.s16	lr, r9, q1, q4
[^>]*> eec2 ee0f 	vmlsldav.s16	lr, r9, q1, q7
[^>]*> eec2 ee2f 	vmlsldava.s16	lr, r9, q1, q7
[^>]*> eec2 fe0f 	vmlsldavx.s16	lr, r9, q1, q7
[^>]*> eec2 fe2f 	vmlsldavax.s16	lr, r9, q1, q7
[^>]*> eec4 ee01 	vmlsldav.s16	lr, r9, q2, q0
[^>]*> eec4 ee21 	vmlsldava.s16	lr, r9, q2, q0
[^>]*> eec4 fe01 	vmlsldavx.s16	lr, r9, q2, q0
[^>]*> eec4 fe21 	vmlsldavax.s16	lr, r9, q2, q0
[^>]*> eec4 ee03 	vmlsldav.s16	lr, r9, q2, q1
[^>]*> eec4 ee23 	vmlsldava.s16	lr, r9, q2, q1
[^>]*> eec4 fe03 	vmlsldavx.s16	lr, r9, q2, q1
[^>]*> eec4 fe23 	vmlsldavax.s16	lr, r9, q2, q1
[^>]*> eec4 ee05 	vmlsldav.s16	lr, r9, q2, q2
[^>]*> eec4 ee25 	vmlsldava.s16	lr, r9, q2, q2
[^>]*> eec4 fe05 	vmlsldavx.s16	lr, r9, q2, q2
[^>]*> eec4 fe25 	vmlsldavax.s16	lr, r9, q2, q2
[^>]*> eec4 ee09 	vmlsldav.s16	lr, r9, q2, q4
[^>]*> eec4 ee29 	vmlsldava.s16	lr, r9, q2, q4
[^>]*> eec4 fe09 	vmlsldavx.s16	lr, r9, q2, q4
[^>]*> eec4 fe29 	vmlsldavax.s16	lr, r9, q2, q4
[^>]*> eec4 ee0f 	vmlsldav.s16	lr, r9, q2, q7
[^>]*> eec4 ee2f 	vmlsldava.s16	lr, r9, q2, q7
[^>]*> eec4 fe0f 	vmlsldavx.s16	lr, r9, q2, q7
[^>]*> eec4 fe2f 	vmlsldavax.s16	lr, r9, q2, q7
[^>]*> eec8 ee01 	vmlsldav.s16	lr, r9, q4, q0
[^>]*> eec8 ee21 	vmlsldava.s16	lr, r9, q4, q0
[^>]*> eec8 fe01 	vmlsldavx.s16	lr, r9, q4, q0
[^>]*> eec8 fe21 	vmlsldavax.s16	lr, r9, q4, q0
[^>]*> eec8 ee03 	vmlsldav.s16	lr, r9, q4, q1
[^>]*> eec8 ee23 	vmlsldava.s16	lr, r9, q4, q1
[^>]*> eec8 fe03 	vmlsldavx.s16	lr, r9, q4, q1
[^>]*> eec8 fe23 	vmlsldavax.s16	lr, r9, q4, q1
[^>]*> eec8 ee05 	vmlsldav.s16	lr, r9, q4, q2
[^>]*> eec8 ee25 	vmlsldava.s16	lr, r9, q4, q2
[^>]*> eec8 fe05 	vmlsldavx.s16	lr, r9, q4, q2
[^>]*> eec8 fe25 	vmlsldavax.s16	lr, r9, q4, q2
[^>]*> eec8 ee09 	vmlsldav.s16	lr, r9, q4, q4
[^>]*> eec8 ee29 	vmlsldava.s16	lr, r9, q4, q4
[^>]*> eec8 fe09 	vmlsldavx.s16	lr, r9, q4, q4
[^>]*> eec8 fe29 	vmlsldavax.s16	lr, r9, q4, q4
[^>]*> eec8 ee0f 	vmlsldav.s16	lr, r9, q4, q7
[^>]*> eec8 ee2f 	vmlsldava.s16	lr, r9, q4, q7
[^>]*> eec8 fe0f 	vmlsldavx.s16	lr, r9, q4, q7
[^>]*> eec8 fe2f 	vmlsldavax.s16	lr, r9, q4, q7
[^>]*> eece ee01 	vmlsldav.s16	lr, r9, q7, q0
[^>]*> eece ee21 	vmlsldava.s16	lr, r9, q7, q0
[^>]*> eece fe01 	vmlsldavx.s16	lr, r9, q7, q0
[^>]*> eece fe21 	vmlsldavax.s16	lr, r9, q7, q0
[^>]*> eece ee03 	vmlsldav.s16	lr, r9, q7, q1
[^>]*> eece ee23 	vmlsldava.s16	lr, r9, q7, q1
[^>]*> eece fe03 	vmlsldavx.s16	lr, r9, q7, q1
[^>]*> eece fe23 	vmlsldavax.s16	lr, r9, q7, q1
[^>]*> eece ee05 	vmlsldav.s16	lr, r9, q7, q2
[^>]*> eece ee25 	vmlsldava.s16	lr, r9, q7, q2
[^>]*> eece fe05 	vmlsldavx.s16	lr, r9, q7, q2
[^>]*> eece fe25 	vmlsldavax.s16	lr, r9, q7, q2
[^>]*> eece ee09 	vmlsldav.s16	lr, r9, q7, q4
[^>]*> eece ee29 	vmlsldava.s16	lr, r9, q7, q4
[^>]*> eece fe09 	vmlsldavx.s16	lr, r9, q7, q4
[^>]*> eece fe29 	vmlsldavax.s16	lr, r9, q7, q4
[^>]*> eece ee0f 	vmlsldav.s16	lr, r9, q7, q7
[^>]*> eece ee2f 	vmlsldava.s16	lr, r9, q7, q7
[^>]*> eece fe0f 	vmlsldavx.s16	lr, r9, q7, q7
[^>]*> eece fe2f 	vmlsldavax.s16	lr, r9, q7, q7
[^>]*> eed0 ee01 	vmlsldav.s16	lr, fp, q0, q0
[^>]*> eed0 ee21 	vmlsldava.s16	lr, fp, q0, q0
[^>]*> eed0 fe01 	vmlsldavx.s16	lr, fp, q0, q0
[^>]*> eed0 fe21 	vmlsldavax.s16	lr, fp, q0, q0
[^>]*> eed0 ee03 	vmlsldav.s16	lr, fp, q0, q1
[^>]*> eed0 ee23 	vmlsldava.s16	lr, fp, q0, q1
[^>]*> eed0 fe03 	vmlsldavx.s16	lr, fp, q0, q1
[^>]*> eed0 fe23 	vmlsldavax.s16	lr, fp, q0, q1
[^>]*> eed0 ee05 	vmlsldav.s16	lr, fp, q0, q2
[^>]*> eed0 ee25 	vmlsldava.s16	lr, fp, q0, q2
[^>]*> eed0 fe05 	vmlsldavx.s16	lr, fp, q0, q2
[^>]*> eed0 fe25 	vmlsldavax.s16	lr, fp, q0, q2
[^>]*> eed0 ee09 	vmlsldav.s16	lr, fp, q0, q4
[^>]*> eed0 ee29 	vmlsldava.s16	lr, fp, q0, q4
[^>]*> eed0 fe09 	vmlsldavx.s16	lr, fp, q0, q4
[^>]*> eed0 fe29 	vmlsldavax.s16	lr, fp, q0, q4
[^>]*> eed0 ee0f 	vmlsldav.s16	lr, fp, q0, q7
[^>]*> eed0 ee2f 	vmlsldava.s16	lr, fp, q0, q7
[^>]*> eed0 fe0f 	vmlsldavx.s16	lr, fp, q0, q7
[^>]*> eed0 fe2f 	vmlsldavax.s16	lr, fp, q0, q7
[^>]*> eed2 ee01 	vmlsldav.s16	lr, fp, q1, q0
[^>]*> eed2 ee21 	vmlsldava.s16	lr, fp, q1, q0
[^>]*> eed2 fe01 	vmlsldavx.s16	lr, fp, q1, q0
[^>]*> eed2 fe21 	vmlsldavax.s16	lr, fp, q1, q0
[^>]*> eed2 ee03 	vmlsldav.s16	lr, fp, q1, q1
[^>]*> eed2 ee23 	vmlsldava.s16	lr, fp, q1, q1
[^>]*> eed2 fe03 	vmlsldavx.s16	lr, fp, q1, q1
[^>]*> eed2 fe23 	vmlsldavax.s16	lr, fp, q1, q1
[^>]*> eed2 ee05 	vmlsldav.s16	lr, fp, q1, q2
[^>]*> eed2 ee25 	vmlsldava.s16	lr, fp, q1, q2
[^>]*> eed2 fe05 	vmlsldavx.s16	lr, fp, q1, q2
[^>]*> eed2 fe25 	vmlsldavax.s16	lr, fp, q1, q2
[^>]*> eed2 ee09 	vmlsldav.s16	lr, fp, q1, q4
[^>]*> eed2 ee29 	vmlsldava.s16	lr, fp, q1, q4
[^>]*> eed2 fe09 	vmlsldavx.s16	lr, fp, q1, q4
[^>]*> eed2 fe29 	vmlsldavax.s16	lr, fp, q1, q4
[^>]*> eed2 ee0f 	vmlsldav.s16	lr, fp, q1, q7
[^>]*> eed2 ee2f 	vmlsldava.s16	lr, fp, q1, q7
[^>]*> eed2 fe0f 	vmlsldavx.s16	lr, fp, q1, q7
[^>]*> eed2 fe2f 	vmlsldavax.s16	lr, fp, q1, q7
[^>]*> eed4 ee01 	vmlsldav.s16	lr, fp, q2, q0
[^>]*> eed4 ee21 	vmlsldava.s16	lr, fp, q2, q0
[^>]*> eed4 fe01 	vmlsldavx.s16	lr, fp, q2, q0
[^>]*> eed4 fe21 	vmlsldavax.s16	lr, fp, q2, q0
[^>]*> eed4 ee03 	vmlsldav.s16	lr, fp, q2, q1
[^>]*> eed4 ee23 	vmlsldava.s16	lr, fp, q2, q1
[^>]*> eed4 fe03 	vmlsldavx.s16	lr, fp, q2, q1
[^>]*> eed4 fe23 	vmlsldavax.s16	lr, fp, q2, q1
[^>]*> eed4 ee05 	vmlsldav.s16	lr, fp, q2, q2
[^>]*> eed4 ee25 	vmlsldava.s16	lr, fp, q2, q2
[^>]*> eed4 fe05 	vmlsldavx.s16	lr, fp, q2, q2
[^>]*> eed4 fe25 	vmlsldavax.s16	lr, fp, q2, q2
[^>]*> eed4 ee09 	vmlsldav.s16	lr, fp, q2, q4
[^>]*> eed4 ee29 	vmlsldava.s16	lr, fp, q2, q4
[^>]*> eed4 fe09 	vmlsldavx.s16	lr, fp, q2, q4
[^>]*> eed4 fe29 	vmlsldavax.s16	lr, fp, q2, q4
[^>]*> eed4 ee0f 	vmlsldav.s16	lr, fp, q2, q7
[^>]*> eed4 ee2f 	vmlsldava.s16	lr, fp, q2, q7
[^>]*> eed4 fe0f 	vmlsldavx.s16	lr, fp, q2, q7
[^>]*> eed4 fe2f 	vmlsldavax.s16	lr, fp, q2, q7
[^>]*> eed8 ee01 	vmlsldav.s16	lr, fp, q4, q0
[^>]*> eed8 ee21 	vmlsldava.s16	lr, fp, q4, q0
[^>]*> eed8 fe01 	vmlsldavx.s16	lr, fp, q4, q0
[^>]*> eed8 fe21 	vmlsldavax.s16	lr, fp, q4, q0
[^>]*> eed8 ee03 	vmlsldav.s16	lr, fp, q4, q1
[^>]*> eed8 ee23 	vmlsldava.s16	lr, fp, q4, q1
[^>]*> eed8 fe03 	vmlsldavx.s16	lr, fp, q4, q1
[^>]*> eed8 fe23 	vmlsldavax.s16	lr, fp, q4, q1
[^>]*> eed8 ee05 	vmlsldav.s16	lr, fp, q4, q2
[^>]*> eed8 ee25 	vmlsldava.s16	lr, fp, q4, q2
[^>]*> eed8 fe05 	vmlsldavx.s16	lr, fp, q4, q2
[^>]*> eed8 fe25 	vmlsldavax.s16	lr, fp, q4, q2
[^>]*> eed8 ee09 	vmlsldav.s16	lr, fp, q4, q4
[^>]*> eed8 ee29 	vmlsldava.s16	lr, fp, q4, q4
[^>]*> eed8 fe09 	vmlsldavx.s16	lr, fp, q4, q4
[^>]*> eed8 fe29 	vmlsldavax.s16	lr, fp, q4, q4
[^>]*> eed8 ee0f 	vmlsldav.s16	lr, fp, q4, q7
[^>]*> eed8 ee2f 	vmlsldava.s16	lr, fp, q4, q7
[^>]*> eed8 fe0f 	vmlsldavx.s16	lr, fp, q4, q7
[^>]*> eed8 fe2f 	vmlsldavax.s16	lr, fp, q4, q7
[^>]*> eede ee01 	vmlsldav.s16	lr, fp, q7, q0
[^>]*> eede ee21 	vmlsldava.s16	lr, fp, q7, q0
[^>]*> eede fe01 	vmlsldavx.s16	lr, fp, q7, q0
[^>]*> eede fe21 	vmlsldavax.s16	lr, fp, q7, q0
[^>]*> eede ee03 	vmlsldav.s16	lr, fp, q7, q1
[^>]*> eede ee23 	vmlsldava.s16	lr, fp, q7, q1
[^>]*> eede fe03 	vmlsldavx.s16	lr, fp, q7, q1
[^>]*> eede fe23 	vmlsldavax.s16	lr, fp, q7, q1
[^>]*> eede ee05 	vmlsldav.s16	lr, fp, q7, q2
[^>]*> eede ee25 	vmlsldava.s16	lr, fp, q7, q2
[^>]*> eede fe05 	vmlsldavx.s16	lr, fp, q7, q2
[^>]*> eede fe25 	vmlsldavax.s16	lr, fp, q7, q2
[^>]*> eede ee09 	vmlsldav.s16	lr, fp, q7, q4
[^>]*> eede ee29 	vmlsldava.s16	lr, fp, q7, q4
[^>]*> eede fe09 	vmlsldavx.s16	lr, fp, q7, q4
[^>]*> eede fe29 	vmlsldavax.s16	lr, fp, q7, q4
[^>]*> eede ee0f 	vmlsldav.s16	lr, fp, q7, q7
[^>]*> eede ee2f 	vmlsldava.s16	lr, fp, q7, q7
[^>]*> eede fe0f 	vmlsldavx.s16	lr, fp, q7, q7
[^>]*> eede fe2f 	vmlsldavax.s16	lr, fp, q7, q7
[^>]*> ee81 0e01 	vmlsldav.s32	r0, r1, q0, q0
[^>]*> ee81 0e21 	vmlsldava.s32	r0, r1, q0, q0
[^>]*> ee81 1e01 	vmlsldavx.s32	r0, r1, q0, q0
[^>]*> ee81 1e21 	vmlsldavax.s32	r0, r1, q0, q0
[^>]*> ee81 0e03 	vmlsldav.s32	r0, r1, q0, q1
[^>]*> ee81 0e23 	vmlsldava.s32	r0, r1, q0, q1
[^>]*> ee81 1e03 	vmlsldavx.s32	r0, r1, q0, q1
[^>]*> ee81 1e23 	vmlsldavax.s32	r0, r1, q0, q1
[^>]*> ee81 0e05 	vmlsldav.s32	r0, r1, q0, q2
[^>]*> ee81 0e25 	vmlsldava.s32	r0, r1, q0, q2
[^>]*> ee81 1e05 	vmlsldavx.s32	r0, r1, q0, q2
[^>]*> ee81 1e25 	vmlsldavax.s32	r0, r1, q0, q2
[^>]*> ee81 0e09 	vmlsldav.s32	r0, r1, q0, q4
[^>]*> ee81 0e29 	vmlsldava.s32	r0, r1, q0, q4
[^>]*> ee81 1e09 	vmlsldavx.s32	r0, r1, q0, q4
[^>]*> ee81 1e29 	vmlsldavax.s32	r0, r1, q0, q4
[^>]*> ee81 0e0f 	vmlsldav.s32	r0, r1, q0, q7
[^>]*> ee81 0e2f 	vmlsldava.s32	r0, r1, q0, q7
[^>]*> ee81 1e0f 	vmlsldavx.s32	r0, r1, q0, q7
[^>]*> ee81 1e2f 	vmlsldavax.s32	r0, r1, q0, q7
[^>]*> ee83 0e01 	vmlsldav.s32	r0, r1, q1, q0
[^>]*> ee83 0e21 	vmlsldava.s32	r0, r1, q1, q0
[^>]*> ee83 1e01 	vmlsldavx.s32	r0, r1, q1, q0
[^>]*> ee83 1e21 	vmlsldavax.s32	r0, r1, q1, q0
[^>]*> ee83 0e03 	vmlsldav.s32	r0, r1, q1, q1
[^>]*> ee83 0e23 	vmlsldava.s32	r0, r1, q1, q1
[^>]*> ee83 1e03 	vmlsldavx.s32	r0, r1, q1, q1
[^>]*> ee83 1e23 	vmlsldavax.s32	r0, r1, q1, q1
[^>]*> ee83 0e05 	vmlsldav.s32	r0, r1, q1, q2
[^>]*> ee83 0e25 	vmlsldava.s32	r0, r1, q1, q2
[^>]*> ee83 1e05 	vmlsldavx.s32	r0, r1, q1, q2
[^>]*> ee83 1e25 	vmlsldavax.s32	r0, r1, q1, q2
[^>]*> ee83 0e09 	vmlsldav.s32	r0, r1, q1, q4
[^>]*> ee83 0e29 	vmlsldava.s32	r0, r1, q1, q4
[^>]*> ee83 1e09 	vmlsldavx.s32	r0, r1, q1, q4
[^>]*> ee83 1e29 	vmlsldavax.s32	r0, r1, q1, q4
[^>]*> ee83 0e0f 	vmlsldav.s32	r0, r1, q1, q7
[^>]*> ee83 0e2f 	vmlsldava.s32	r0, r1, q1, q7
[^>]*> ee83 1e0f 	vmlsldavx.s32	r0, r1, q1, q7
[^>]*> ee83 1e2f 	vmlsldavax.s32	r0, r1, q1, q7
[^>]*> ee85 0e01 	vmlsldav.s32	r0, r1, q2, q0
[^>]*> ee85 0e21 	vmlsldava.s32	r0, r1, q2, q0
[^>]*> ee85 1e01 	vmlsldavx.s32	r0, r1, q2, q0
[^>]*> ee85 1e21 	vmlsldavax.s32	r0, r1, q2, q0
[^>]*> ee85 0e03 	vmlsldav.s32	r0, r1, q2, q1
[^>]*> ee85 0e23 	vmlsldava.s32	r0, r1, q2, q1
[^>]*> ee85 1e03 	vmlsldavx.s32	r0, r1, q2, q1
[^>]*> ee85 1e23 	vmlsldavax.s32	r0, r1, q2, q1
[^>]*> ee85 0e05 	vmlsldav.s32	r0, r1, q2, q2
[^>]*> ee85 0e25 	vmlsldava.s32	r0, r1, q2, q2
[^>]*> ee85 1e05 	vmlsldavx.s32	r0, r1, q2, q2
[^>]*> ee85 1e25 	vmlsldavax.s32	r0, r1, q2, q2
[^>]*> ee85 0e09 	vmlsldav.s32	r0, r1, q2, q4
[^>]*> ee85 0e29 	vmlsldava.s32	r0, r1, q2, q4
[^>]*> ee85 1e09 	vmlsldavx.s32	r0, r1, q2, q4
[^>]*> ee85 1e29 	vmlsldavax.s32	r0, r1, q2, q4
[^>]*> ee85 0e0f 	vmlsldav.s32	r0, r1, q2, q7
[^>]*> ee85 0e2f 	vmlsldava.s32	r0, r1, q2, q7
[^>]*> ee85 1e0f 	vmlsldavx.s32	r0, r1, q2, q7
[^>]*> ee85 1e2f 	vmlsldavax.s32	r0, r1, q2, q7
[^>]*> ee89 0e01 	vmlsldav.s32	r0, r1, q4, q0
[^>]*> ee89 0e21 	vmlsldava.s32	r0, r1, q4, q0
[^>]*> ee89 1e01 	vmlsldavx.s32	r0, r1, q4, q0
[^>]*> ee89 1e21 	vmlsldavax.s32	r0, r1, q4, q0
[^>]*> ee89 0e03 	vmlsldav.s32	r0, r1, q4, q1
[^>]*> ee89 0e23 	vmlsldava.s32	r0, r1, q4, q1
[^>]*> ee89 1e03 	vmlsldavx.s32	r0, r1, q4, q1
[^>]*> ee89 1e23 	vmlsldavax.s32	r0, r1, q4, q1
[^>]*> ee89 0e05 	vmlsldav.s32	r0, r1, q4, q2
[^>]*> ee89 0e25 	vmlsldava.s32	r0, r1, q4, q2
[^>]*> ee89 1e05 	vmlsldavx.s32	r0, r1, q4, q2
[^>]*> ee89 1e25 	vmlsldavax.s32	r0, r1, q4, q2
[^>]*> ee89 0e09 	vmlsldav.s32	r0, r1, q4, q4
[^>]*> ee89 0e29 	vmlsldava.s32	r0, r1, q4, q4
[^>]*> ee89 1e09 	vmlsldavx.s32	r0, r1, q4, q4
[^>]*> ee89 1e29 	vmlsldavax.s32	r0, r1, q4, q4
[^>]*> ee89 0e0f 	vmlsldav.s32	r0, r1, q4, q7
[^>]*> ee89 0e2f 	vmlsldava.s32	r0, r1, q4, q7
[^>]*> ee89 1e0f 	vmlsldavx.s32	r0, r1, q4, q7
[^>]*> ee89 1e2f 	vmlsldavax.s32	r0, r1, q4, q7
[^>]*> ee8f 0e01 	vmlsldav.s32	r0, r1, q7, q0
[^>]*> ee8f 0e21 	vmlsldava.s32	r0, r1, q7, q0
[^>]*> ee8f 1e01 	vmlsldavx.s32	r0, r1, q7, q0
[^>]*> ee8f 1e21 	vmlsldavax.s32	r0, r1, q7, q0
[^>]*> ee8f 0e03 	vmlsldav.s32	r0, r1, q7, q1
[^>]*> ee8f 0e23 	vmlsldava.s32	r0, r1, q7, q1
[^>]*> ee8f 1e03 	vmlsldavx.s32	r0, r1, q7, q1
[^>]*> ee8f 1e23 	vmlsldavax.s32	r0, r1, q7, q1
[^>]*> ee8f 0e05 	vmlsldav.s32	r0, r1, q7, q2
[^>]*> ee8f 0e25 	vmlsldava.s32	r0, r1, q7, q2
[^>]*> ee8f 1e05 	vmlsldavx.s32	r0, r1, q7, q2
[^>]*> ee8f 1e25 	vmlsldavax.s32	r0, r1, q7, q2
[^>]*> ee8f 0e09 	vmlsldav.s32	r0, r1, q7, q4
[^>]*> ee8f 0e29 	vmlsldava.s32	r0, r1, q7, q4
[^>]*> ee8f 1e09 	vmlsldavx.s32	r0, r1, q7, q4
[^>]*> ee8f 1e29 	vmlsldavax.s32	r0, r1, q7, q4
[^>]*> ee8f 0e0f 	vmlsldav.s32	r0, r1, q7, q7
[^>]*> ee8f 0e2f 	vmlsldava.s32	r0, r1, q7, q7
[^>]*> ee8f 1e0f 	vmlsldavx.s32	r0, r1, q7, q7
[^>]*> ee8f 1e2f 	vmlsldavax.s32	r0, r1, q7, q7
[^>]*> ee91 0e01 	vmlsldav.s32	r0, r3, q0, q0
[^>]*> ee91 0e21 	vmlsldava.s32	r0, r3, q0, q0
[^>]*> ee91 1e01 	vmlsldavx.s32	r0, r3, q0, q0
[^>]*> ee91 1e21 	vmlsldavax.s32	r0, r3, q0, q0
[^>]*> ee91 0e03 	vmlsldav.s32	r0, r3, q0, q1
[^>]*> ee91 0e23 	vmlsldava.s32	r0, r3, q0, q1
[^>]*> ee91 1e03 	vmlsldavx.s32	r0, r3, q0, q1
[^>]*> ee91 1e23 	vmlsldavax.s32	r0, r3, q0, q1
[^>]*> ee91 0e05 	vmlsldav.s32	r0, r3, q0, q2
[^>]*> ee91 0e25 	vmlsldava.s32	r0, r3, q0, q2
[^>]*> ee91 1e05 	vmlsldavx.s32	r0, r3, q0, q2
[^>]*> ee91 1e25 	vmlsldavax.s32	r0, r3, q0, q2
[^>]*> ee91 0e09 	vmlsldav.s32	r0, r3, q0, q4
[^>]*> ee91 0e29 	vmlsldava.s32	r0, r3, q0, q4
[^>]*> ee91 1e09 	vmlsldavx.s32	r0, r3, q0, q4
[^>]*> ee91 1e29 	vmlsldavax.s32	r0, r3, q0, q4
[^>]*> ee91 0e0f 	vmlsldav.s32	r0, r3, q0, q7
[^>]*> ee91 0e2f 	vmlsldava.s32	r0, r3, q0, q7
[^>]*> ee91 1e0f 	vmlsldavx.s32	r0, r3, q0, q7
[^>]*> ee91 1e2f 	vmlsldavax.s32	r0, r3, q0, q7
[^>]*> ee93 0e01 	vmlsldav.s32	r0, r3, q1, q0
[^>]*> ee93 0e21 	vmlsldava.s32	r0, r3, q1, q0
[^>]*> ee93 1e01 	vmlsldavx.s32	r0, r3, q1, q0
[^>]*> ee93 1e21 	vmlsldavax.s32	r0, r3, q1, q0
[^>]*> ee93 0e03 	vmlsldav.s32	r0, r3, q1, q1
[^>]*> ee93 0e23 	vmlsldava.s32	r0, r3, q1, q1
[^>]*> ee93 1e03 	vmlsldavx.s32	r0, r3, q1, q1
[^>]*> ee93 1e23 	vmlsldavax.s32	r0, r3, q1, q1
[^>]*> ee93 0e05 	vmlsldav.s32	r0, r3, q1, q2
[^>]*> ee93 0e25 	vmlsldava.s32	r0, r3, q1, q2
[^>]*> ee93 1e05 	vmlsldavx.s32	r0, r3, q1, q2
[^>]*> ee93 1e25 	vmlsldavax.s32	r0, r3, q1, q2
[^>]*> ee93 0e09 	vmlsldav.s32	r0, r3, q1, q4
[^>]*> ee93 0e29 	vmlsldava.s32	r0, r3, q1, q4
[^>]*> ee93 1e09 	vmlsldavx.s32	r0, r3, q1, q4
[^>]*> ee93 1e29 	vmlsldavax.s32	r0, r3, q1, q4
[^>]*> ee93 0e0f 	vmlsldav.s32	r0, r3, q1, q7
[^>]*> ee93 0e2f 	vmlsldava.s32	r0, r3, q1, q7
[^>]*> ee93 1e0f 	vmlsldavx.s32	r0, r3, q1, q7
[^>]*> ee93 1e2f 	vmlsldavax.s32	r0, r3, q1, q7
[^>]*> ee95 0e01 	vmlsldav.s32	r0, r3, q2, q0
[^>]*> ee95 0e21 	vmlsldava.s32	r0, r3, q2, q0
[^>]*> ee95 1e01 	vmlsldavx.s32	r0, r3, q2, q0
[^>]*> ee95 1e21 	vmlsldavax.s32	r0, r3, q2, q0
[^>]*> ee95 0e03 	vmlsldav.s32	r0, r3, q2, q1
[^>]*> ee95 0e23 	vmlsldava.s32	r0, r3, q2, q1
[^>]*> ee95 1e03 	vmlsldavx.s32	r0, r3, q2, q1
[^>]*> ee95 1e23 	vmlsldavax.s32	r0, r3, q2, q1
[^>]*> ee95 0e05 	vmlsldav.s32	r0, r3, q2, q2
[^>]*> ee95 0e25 	vmlsldava.s32	r0, r3, q2, q2
[^>]*> ee95 1e05 	vmlsldavx.s32	r0, r3, q2, q2
[^>]*> ee95 1e25 	vmlsldavax.s32	r0, r3, q2, q2
[^>]*> ee95 0e09 	vmlsldav.s32	r0, r3, q2, q4
[^>]*> ee95 0e29 	vmlsldava.s32	r0, r3, q2, q4
[^>]*> ee95 1e09 	vmlsldavx.s32	r0, r3, q2, q4
[^>]*> ee95 1e29 	vmlsldavax.s32	r0, r3, q2, q4
[^>]*> ee95 0e0f 	vmlsldav.s32	r0, r3, q2, q7
[^>]*> ee95 0e2f 	vmlsldava.s32	r0, r3, q2, q7
[^>]*> ee95 1e0f 	vmlsldavx.s32	r0, r3, q2, q7
[^>]*> ee95 1e2f 	vmlsldavax.s32	r0, r3, q2, q7
[^>]*> ee99 0e01 	vmlsldav.s32	r0, r3, q4, q0
[^>]*> ee99 0e21 	vmlsldava.s32	r0, r3, q4, q0
[^>]*> ee99 1e01 	vmlsldavx.s32	r0, r3, q4, q0
[^>]*> ee99 1e21 	vmlsldavax.s32	r0, r3, q4, q0
[^>]*> ee99 0e03 	vmlsldav.s32	r0, r3, q4, q1
[^>]*> ee99 0e23 	vmlsldava.s32	r0, r3, q4, q1
[^>]*> ee99 1e03 	vmlsldavx.s32	r0, r3, q4, q1
[^>]*> ee99 1e23 	vmlsldavax.s32	r0, r3, q4, q1
[^>]*> ee99 0e05 	vmlsldav.s32	r0, r3, q4, q2
[^>]*> ee99 0e25 	vmlsldava.s32	r0, r3, q4, q2
[^>]*> ee99 1e05 	vmlsldavx.s32	r0, r3, q4, q2
[^>]*> ee99 1e25 	vmlsldavax.s32	r0, r3, q4, q2
[^>]*> ee99 0e09 	vmlsldav.s32	r0, r3, q4, q4
[^>]*> ee99 0e29 	vmlsldava.s32	r0, r3, q4, q4
[^>]*> ee99 1e09 	vmlsldavx.s32	r0, r3, q4, q4
[^>]*> ee99 1e29 	vmlsldavax.s32	r0, r3, q4, q4
[^>]*> ee99 0e0f 	vmlsldav.s32	r0, r3, q4, q7
[^>]*> ee99 0e2f 	vmlsldava.s32	r0, r3, q4, q7
[^>]*> ee99 1e0f 	vmlsldavx.s32	r0, r3, q4, q7
[^>]*> ee99 1e2f 	vmlsldavax.s32	r0, r3, q4, q7
[^>]*> ee9f 0e01 	vmlsldav.s32	r0, r3, q7, q0
[^>]*> ee9f 0e21 	vmlsldava.s32	r0, r3, q7, q0
[^>]*> ee9f 1e01 	vmlsldavx.s32	r0, r3, q7, q0
[^>]*> ee9f 1e21 	vmlsldavax.s32	r0, r3, q7, q0
[^>]*> ee9f 0e03 	vmlsldav.s32	r0, r3, q7, q1
[^>]*> ee9f 0e23 	vmlsldava.s32	r0, r3, q7, q1
[^>]*> ee9f 1e03 	vmlsldavx.s32	r0, r3, q7, q1
[^>]*> ee9f 1e23 	vmlsldavax.s32	r0, r3, q7, q1
[^>]*> ee9f 0e05 	vmlsldav.s32	r0, r3, q7, q2
[^>]*> ee9f 0e25 	vmlsldava.s32	r0, r3, q7, q2
[^>]*> ee9f 1e05 	vmlsldavx.s32	r0, r3, q7, q2
[^>]*> ee9f 1e25 	vmlsldavax.s32	r0, r3, q7, q2
[^>]*> ee9f 0e09 	vmlsldav.s32	r0, r3, q7, q4
[^>]*> ee9f 0e29 	vmlsldava.s32	r0, r3, q7, q4
[^>]*> ee9f 1e09 	vmlsldavx.s32	r0, r3, q7, q4
[^>]*> ee9f 1e29 	vmlsldavax.s32	r0, r3, q7, q4
[^>]*> ee9f 0e0f 	vmlsldav.s32	r0, r3, q7, q7
[^>]*> ee9f 0e2f 	vmlsldava.s32	r0, r3, q7, q7
[^>]*> ee9f 1e0f 	vmlsldavx.s32	r0, r3, q7, q7
[^>]*> ee9f 1e2f 	vmlsldavax.s32	r0, r3, q7, q7
[^>]*> eea1 0e01 	vmlsldav.s32	r0, r5, q0, q0
[^>]*> eea1 0e21 	vmlsldava.s32	r0, r5, q0, q0
[^>]*> eea1 1e01 	vmlsldavx.s32	r0, r5, q0, q0
[^>]*> eea1 1e21 	vmlsldavax.s32	r0, r5, q0, q0
[^>]*> eea1 0e03 	vmlsldav.s32	r0, r5, q0, q1
[^>]*> eea1 0e23 	vmlsldava.s32	r0, r5, q0, q1
[^>]*> eea1 1e03 	vmlsldavx.s32	r0, r5, q0, q1
[^>]*> eea1 1e23 	vmlsldavax.s32	r0, r5, q0, q1
[^>]*> eea1 0e05 	vmlsldav.s32	r0, r5, q0, q2
[^>]*> eea1 0e25 	vmlsldava.s32	r0, r5, q0, q2
[^>]*> eea1 1e05 	vmlsldavx.s32	r0, r5, q0, q2
[^>]*> eea1 1e25 	vmlsldavax.s32	r0, r5, q0, q2
[^>]*> eea1 0e09 	vmlsldav.s32	r0, r5, q0, q4
[^>]*> eea1 0e29 	vmlsldava.s32	r0, r5, q0, q4
[^>]*> eea1 1e09 	vmlsldavx.s32	r0, r5, q0, q4
[^>]*> eea1 1e29 	vmlsldavax.s32	r0, r5, q0, q4
[^>]*> eea1 0e0f 	vmlsldav.s32	r0, r5, q0, q7
[^>]*> eea1 0e2f 	vmlsldava.s32	r0, r5, q0, q7
[^>]*> eea1 1e0f 	vmlsldavx.s32	r0, r5, q0, q7
[^>]*> eea1 1e2f 	vmlsldavax.s32	r0, r5, q0, q7
[^>]*> eea3 0e01 	vmlsldav.s32	r0, r5, q1, q0
[^>]*> eea3 0e21 	vmlsldava.s32	r0, r5, q1, q0
[^>]*> eea3 1e01 	vmlsldavx.s32	r0, r5, q1, q0
[^>]*> eea3 1e21 	vmlsldavax.s32	r0, r5, q1, q0
[^>]*> eea3 0e03 	vmlsldav.s32	r0, r5, q1, q1
[^>]*> eea3 0e23 	vmlsldava.s32	r0, r5, q1, q1
[^>]*> eea3 1e03 	vmlsldavx.s32	r0, r5, q1, q1
[^>]*> eea3 1e23 	vmlsldavax.s32	r0, r5, q1, q1
[^>]*> eea3 0e05 	vmlsldav.s32	r0, r5, q1, q2
[^>]*> eea3 0e25 	vmlsldava.s32	r0, r5, q1, q2
[^>]*> eea3 1e05 	vmlsldavx.s32	r0, r5, q1, q2
[^>]*> eea3 1e25 	vmlsldavax.s32	r0, r5, q1, q2
[^>]*> eea3 0e09 	vmlsldav.s32	r0, r5, q1, q4
[^>]*> eea3 0e29 	vmlsldava.s32	r0, r5, q1, q4
[^>]*> eea3 1e09 	vmlsldavx.s32	r0, r5, q1, q4
[^>]*> eea3 1e29 	vmlsldavax.s32	r0, r5, q1, q4
[^>]*> eea3 0e0f 	vmlsldav.s32	r0, r5, q1, q7
[^>]*> eea3 0e2f 	vmlsldava.s32	r0, r5, q1, q7
[^>]*> eea3 1e0f 	vmlsldavx.s32	r0, r5, q1, q7
[^>]*> eea3 1e2f 	vmlsldavax.s32	r0, r5, q1, q7
[^>]*> eea5 0e01 	vmlsldav.s32	r0, r5, q2, q0
[^>]*> eea5 0e21 	vmlsldava.s32	r0, r5, q2, q0
[^>]*> eea5 1e01 	vmlsldavx.s32	r0, r5, q2, q0
[^>]*> eea5 1e21 	vmlsldavax.s32	r0, r5, q2, q0
[^>]*> eea5 0e03 	vmlsldav.s32	r0, r5, q2, q1
[^>]*> eea5 0e23 	vmlsldava.s32	r0, r5, q2, q1
[^>]*> eea5 1e03 	vmlsldavx.s32	r0, r5, q2, q1
[^>]*> eea5 1e23 	vmlsldavax.s32	r0, r5, q2, q1
[^>]*> eea5 0e05 	vmlsldav.s32	r0, r5, q2, q2
[^>]*> eea5 0e25 	vmlsldava.s32	r0, r5, q2, q2
[^>]*> eea5 1e05 	vmlsldavx.s32	r0, r5, q2, q2
[^>]*> eea5 1e25 	vmlsldavax.s32	r0, r5, q2, q2
[^>]*> eea5 0e09 	vmlsldav.s32	r0, r5, q2, q4
[^>]*> eea5 0e29 	vmlsldava.s32	r0, r5, q2, q4
[^>]*> eea5 1e09 	vmlsldavx.s32	r0, r5, q2, q4
[^>]*> eea5 1e29 	vmlsldavax.s32	r0, r5, q2, q4
[^>]*> eea5 0e0f 	vmlsldav.s32	r0, r5, q2, q7
[^>]*> eea5 0e2f 	vmlsldava.s32	r0, r5, q2, q7
[^>]*> eea5 1e0f 	vmlsldavx.s32	r0, r5, q2, q7
[^>]*> eea5 1e2f 	vmlsldavax.s32	r0, r5, q2, q7
[^>]*> eea9 0e01 	vmlsldav.s32	r0, r5, q4, q0
[^>]*> eea9 0e21 	vmlsldava.s32	r0, r5, q4, q0
[^>]*> eea9 1e01 	vmlsldavx.s32	r0, r5, q4, q0
[^>]*> eea9 1e21 	vmlsldavax.s32	r0, r5, q4, q0
[^>]*> eea9 0e03 	vmlsldav.s32	r0, r5, q4, q1
[^>]*> eea9 0e23 	vmlsldava.s32	r0, r5, q4, q1
[^>]*> eea9 1e03 	vmlsldavx.s32	r0, r5, q4, q1
[^>]*> eea9 1e23 	vmlsldavax.s32	r0, r5, q4, q1
[^>]*> eea9 0e05 	vmlsldav.s32	r0, r5, q4, q2
[^>]*> eea9 0e25 	vmlsldava.s32	r0, r5, q4, q2
[^>]*> eea9 1e05 	vmlsldavx.s32	r0, r5, q4, q2
[^>]*> eea9 1e25 	vmlsldavax.s32	r0, r5, q4, q2
[^>]*> eea9 0e09 	vmlsldav.s32	r0, r5, q4, q4
[^>]*> eea9 0e29 	vmlsldava.s32	r0, r5, q4, q4
[^>]*> eea9 1e09 	vmlsldavx.s32	r0, r5, q4, q4
[^>]*> eea9 1e29 	vmlsldavax.s32	r0, r5, q4, q4
[^>]*> eea9 0e0f 	vmlsldav.s32	r0, r5, q4, q7
[^>]*> eea9 0e2f 	vmlsldava.s32	r0, r5, q4, q7
[^>]*> eea9 1e0f 	vmlsldavx.s32	r0, r5, q4, q7
[^>]*> eea9 1e2f 	vmlsldavax.s32	r0, r5, q4, q7
[^>]*> eeaf 0e01 	vmlsldav.s32	r0, r5, q7, q0
[^>]*> eeaf 0e21 	vmlsldava.s32	r0, r5, q7, q0
[^>]*> eeaf 1e01 	vmlsldavx.s32	r0, r5, q7, q0
[^>]*> eeaf 1e21 	vmlsldavax.s32	r0, r5, q7, q0
[^>]*> eeaf 0e03 	vmlsldav.s32	r0, r5, q7, q1
[^>]*> eeaf 0e23 	vmlsldava.s32	r0, r5, q7, q1
[^>]*> eeaf 1e03 	vmlsldavx.s32	r0, r5, q7, q1
[^>]*> eeaf 1e23 	vmlsldavax.s32	r0, r5, q7, q1
[^>]*> eeaf 0e05 	vmlsldav.s32	r0, r5, q7, q2
[^>]*> eeaf 0e25 	vmlsldava.s32	r0, r5, q7, q2
[^>]*> eeaf 1e05 	vmlsldavx.s32	r0, r5, q7, q2
[^>]*> eeaf 1e25 	vmlsldavax.s32	r0, r5, q7, q2
[^>]*> eeaf 0e09 	vmlsldav.s32	r0, r5, q7, q4
[^>]*> eeaf 0e29 	vmlsldava.s32	r0, r5, q7, q4
[^>]*> eeaf 1e09 	vmlsldavx.s32	r0, r5, q7, q4
[^>]*> eeaf 1e29 	vmlsldavax.s32	r0, r5, q7, q4
[^>]*> eeaf 0e0f 	vmlsldav.s32	r0, r5, q7, q7
[^>]*> eeaf 0e2f 	vmlsldava.s32	r0, r5, q7, q7
[^>]*> eeaf 1e0f 	vmlsldavx.s32	r0, r5, q7, q7
[^>]*> eeaf 1e2f 	vmlsldavax.s32	r0, r5, q7, q7
[^>]*> eeb1 0e01 	vmlsldav.s32	r0, r7, q0, q0
[^>]*> eeb1 0e21 	vmlsldava.s32	r0, r7, q0, q0
[^>]*> eeb1 1e01 	vmlsldavx.s32	r0, r7, q0, q0
[^>]*> eeb1 1e21 	vmlsldavax.s32	r0, r7, q0, q0
[^>]*> eeb1 0e03 	vmlsldav.s32	r0, r7, q0, q1
[^>]*> eeb1 0e23 	vmlsldava.s32	r0, r7, q0, q1
[^>]*> eeb1 1e03 	vmlsldavx.s32	r0, r7, q0, q1
[^>]*> eeb1 1e23 	vmlsldavax.s32	r0, r7, q0, q1
[^>]*> eeb1 0e05 	vmlsldav.s32	r0, r7, q0, q2
[^>]*> eeb1 0e25 	vmlsldava.s32	r0, r7, q0, q2
[^>]*> eeb1 1e05 	vmlsldavx.s32	r0, r7, q0, q2
[^>]*> eeb1 1e25 	vmlsldavax.s32	r0, r7, q0, q2
[^>]*> eeb1 0e09 	vmlsldav.s32	r0, r7, q0, q4
[^>]*> eeb1 0e29 	vmlsldava.s32	r0, r7, q0, q4
[^>]*> eeb1 1e09 	vmlsldavx.s32	r0, r7, q0, q4
[^>]*> eeb1 1e29 	vmlsldavax.s32	r0, r7, q0, q4
[^>]*> eeb1 0e0f 	vmlsldav.s32	r0, r7, q0, q7
[^>]*> eeb1 0e2f 	vmlsldava.s32	r0, r7, q0, q7
[^>]*> eeb1 1e0f 	vmlsldavx.s32	r0, r7, q0, q7
[^>]*> eeb1 1e2f 	vmlsldavax.s32	r0, r7, q0, q7
[^>]*> eeb3 0e01 	vmlsldav.s32	r0, r7, q1, q0
[^>]*> eeb3 0e21 	vmlsldava.s32	r0, r7, q1, q0
[^>]*> eeb3 1e01 	vmlsldavx.s32	r0, r7, q1, q0
[^>]*> eeb3 1e21 	vmlsldavax.s32	r0, r7, q1, q0
[^>]*> eeb3 0e03 	vmlsldav.s32	r0, r7, q1, q1
[^>]*> eeb3 0e23 	vmlsldava.s32	r0, r7, q1, q1
[^>]*> eeb3 1e03 	vmlsldavx.s32	r0, r7, q1, q1
[^>]*> eeb3 1e23 	vmlsldavax.s32	r0, r7, q1, q1
[^>]*> eeb3 0e05 	vmlsldav.s32	r0, r7, q1, q2
[^>]*> eeb3 0e25 	vmlsldava.s32	r0, r7, q1, q2
[^>]*> eeb3 1e05 	vmlsldavx.s32	r0, r7, q1, q2
[^>]*> eeb3 1e25 	vmlsldavax.s32	r0, r7, q1, q2
[^>]*> eeb3 0e09 	vmlsldav.s32	r0, r7, q1, q4
[^>]*> eeb3 0e29 	vmlsldava.s32	r0, r7, q1, q4
[^>]*> eeb3 1e09 	vmlsldavx.s32	r0, r7, q1, q4
[^>]*> eeb3 1e29 	vmlsldavax.s32	r0, r7, q1, q4
[^>]*> eeb3 0e0f 	vmlsldav.s32	r0, r7, q1, q7
[^>]*> eeb3 0e2f 	vmlsldava.s32	r0, r7, q1, q7
[^>]*> eeb3 1e0f 	vmlsldavx.s32	r0, r7, q1, q7
[^>]*> eeb3 1e2f 	vmlsldavax.s32	r0, r7, q1, q7
[^>]*> eeb5 0e01 	vmlsldav.s32	r0, r7, q2, q0
[^>]*> eeb5 0e21 	vmlsldava.s32	r0, r7, q2, q0
[^>]*> eeb5 1e01 	vmlsldavx.s32	r0, r7, q2, q0
[^>]*> eeb5 1e21 	vmlsldavax.s32	r0, r7, q2, q0
[^>]*> eeb5 0e03 	vmlsldav.s32	r0, r7, q2, q1
[^>]*> eeb5 0e23 	vmlsldava.s32	r0, r7, q2, q1
[^>]*> eeb5 1e03 	vmlsldavx.s32	r0, r7, q2, q1
[^>]*> eeb5 1e23 	vmlsldavax.s32	r0, r7, q2, q1
[^>]*> eeb5 0e05 	vmlsldav.s32	r0, r7, q2, q2
[^>]*> eeb5 0e25 	vmlsldava.s32	r0, r7, q2, q2
[^>]*> eeb5 1e05 	vmlsldavx.s32	r0, r7, q2, q2
[^>]*> eeb5 1e25 	vmlsldavax.s32	r0, r7, q2, q2
[^>]*> eeb5 0e09 	vmlsldav.s32	r0, r7, q2, q4
[^>]*> eeb5 0e29 	vmlsldava.s32	r0, r7, q2, q4
[^>]*> eeb5 1e09 	vmlsldavx.s32	r0, r7, q2, q4
[^>]*> eeb5 1e29 	vmlsldavax.s32	r0, r7, q2, q4
[^>]*> eeb5 0e0f 	vmlsldav.s32	r0, r7, q2, q7
[^>]*> eeb5 0e2f 	vmlsldava.s32	r0, r7, q2, q7
[^>]*> eeb5 1e0f 	vmlsldavx.s32	r0, r7, q2, q7
[^>]*> eeb5 1e2f 	vmlsldavax.s32	r0, r7, q2, q7
[^>]*> eeb9 0e01 	vmlsldav.s32	r0, r7, q4, q0
[^>]*> eeb9 0e21 	vmlsldava.s32	r0, r7, q4, q0
[^>]*> eeb9 1e01 	vmlsldavx.s32	r0, r7, q4, q0
[^>]*> eeb9 1e21 	vmlsldavax.s32	r0, r7, q4, q0
[^>]*> eeb9 0e03 	vmlsldav.s32	r0, r7, q4, q1
[^>]*> eeb9 0e23 	vmlsldava.s32	r0, r7, q4, q1
[^>]*> eeb9 1e03 	vmlsldavx.s32	r0, r7, q4, q1
[^>]*> eeb9 1e23 	vmlsldavax.s32	r0, r7, q4, q1
[^>]*> eeb9 0e05 	vmlsldav.s32	r0, r7, q4, q2
[^>]*> eeb9 0e25 	vmlsldava.s32	r0, r7, q4, q2
[^>]*> eeb9 1e05 	vmlsldavx.s32	r0, r7, q4, q2
[^>]*> eeb9 1e25 	vmlsldavax.s32	r0, r7, q4, q2
[^>]*> eeb9 0e09 	vmlsldav.s32	r0, r7, q4, q4
[^>]*> eeb9 0e29 	vmlsldava.s32	r0, r7, q4, q4
[^>]*> eeb9 1e09 	vmlsldavx.s32	r0, r7, q4, q4
[^>]*> eeb9 1e29 	vmlsldavax.s32	r0, r7, q4, q4
[^>]*> eeb9 0e0f 	vmlsldav.s32	r0, r7, q4, q7
[^>]*> eeb9 0e2f 	vmlsldava.s32	r0, r7, q4, q7
[^>]*> eeb9 1e0f 	vmlsldavx.s32	r0, r7, q4, q7
[^>]*> eeb9 1e2f 	vmlsldavax.s32	r0, r7, q4, q7
[^>]*> eebf 0e01 	vmlsldav.s32	r0, r7, q7, q0
[^>]*> eebf 0e21 	vmlsldava.s32	r0, r7, q7, q0
[^>]*> eebf 1e01 	vmlsldavx.s32	r0, r7, q7, q0
[^>]*> eebf 1e21 	vmlsldavax.s32	r0, r7, q7, q0
[^>]*> eebf 0e03 	vmlsldav.s32	r0, r7, q7, q1
[^>]*> eebf 0e23 	vmlsldava.s32	r0, r7, q7, q1
[^>]*> eebf 1e03 	vmlsldavx.s32	r0, r7, q7, q1
[^>]*> eebf 1e23 	vmlsldavax.s32	r0, r7, q7, q1
[^>]*> eebf 0e05 	vmlsldav.s32	r0, r7, q7, q2
[^>]*> eebf 0e25 	vmlsldava.s32	r0, r7, q7, q2
[^>]*> eebf 1e05 	vmlsldavx.s32	r0, r7, q7, q2
[^>]*> eebf 1e25 	vmlsldavax.s32	r0, r7, q7, q2
[^>]*> eebf 0e09 	vmlsldav.s32	r0, r7, q7, q4
[^>]*> eebf 0e29 	vmlsldava.s32	r0, r7, q7, q4
[^>]*> eebf 1e09 	vmlsldavx.s32	r0, r7, q7, q4
[^>]*> eebf 1e29 	vmlsldavax.s32	r0, r7, q7, q4
[^>]*> eebf 0e0f 	vmlsldav.s32	r0, r7, q7, q7
[^>]*> eebf 0e2f 	vmlsldava.s32	r0, r7, q7, q7
[^>]*> eebf 1e0f 	vmlsldavx.s32	r0, r7, q7, q7
[^>]*> eebf 1e2f 	vmlsldavax.s32	r0, r7, q7, q7
[^>]*> eec1 0e01 	vmlsldav.s32	r0, r9, q0, q0
[^>]*> eec1 0e21 	vmlsldava.s32	r0, r9, q0, q0
[^>]*> eec1 1e01 	vmlsldavx.s32	r0, r9, q0, q0
[^>]*> eec1 1e21 	vmlsldavax.s32	r0, r9, q0, q0
[^>]*> eec1 0e03 	vmlsldav.s32	r0, r9, q0, q1
[^>]*> eec1 0e23 	vmlsldava.s32	r0, r9, q0, q1
[^>]*> eec1 1e03 	vmlsldavx.s32	r0, r9, q0, q1
[^>]*> eec1 1e23 	vmlsldavax.s32	r0, r9, q0, q1
[^>]*> eec1 0e05 	vmlsldav.s32	r0, r9, q0, q2
[^>]*> eec1 0e25 	vmlsldava.s32	r0, r9, q0, q2
[^>]*> eec1 1e05 	vmlsldavx.s32	r0, r9, q0, q2
[^>]*> eec1 1e25 	vmlsldavax.s32	r0, r9, q0, q2
[^>]*> eec1 0e09 	vmlsldav.s32	r0, r9, q0, q4
[^>]*> eec1 0e29 	vmlsldava.s32	r0, r9, q0, q4
[^>]*> eec1 1e09 	vmlsldavx.s32	r0, r9, q0, q4
[^>]*> eec1 1e29 	vmlsldavax.s32	r0, r9, q0, q4
[^>]*> eec1 0e0f 	vmlsldav.s32	r0, r9, q0, q7
[^>]*> eec1 0e2f 	vmlsldava.s32	r0, r9, q0, q7
[^>]*> eec1 1e0f 	vmlsldavx.s32	r0, r9, q0, q7
[^>]*> eec1 1e2f 	vmlsldavax.s32	r0, r9, q0, q7
[^>]*> eec3 0e01 	vmlsldav.s32	r0, r9, q1, q0
[^>]*> eec3 0e21 	vmlsldava.s32	r0, r9, q1, q0
[^>]*> eec3 1e01 	vmlsldavx.s32	r0, r9, q1, q0
[^>]*> eec3 1e21 	vmlsldavax.s32	r0, r9, q1, q0
[^>]*> eec3 0e03 	vmlsldav.s32	r0, r9, q1, q1
[^>]*> eec3 0e23 	vmlsldava.s32	r0, r9, q1, q1
[^>]*> eec3 1e03 	vmlsldavx.s32	r0, r9, q1, q1
[^>]*> eec3 1e23 	vmlsldavax.s32	r0, r9, q1, q1
[^>]*> eec3 0e05 	vmlsldav.s32	r0, r9, q1, q2
[^>]*> eec3 0e25 	vmlsldava.s32	r0, r9, q1, q2
[^>]*> eec3 1e05 	vmlsldavx.s32	r0, r9, q1, q2
[^>]*> eec3 1e25 	vmlsldavax.s32	r0, r9, q1, q2
[^>]*> eec3 0e09 	vmlsldav.s32	r0, r9, q1, q4
[^>]*> eec3 0e29 	vmlsldava.s32	r0, r9, q1, q4
[^>]*> eec3 1e09 	vmlsldavx.s32	r0, r9, q1, q4
[^>]*> eec3 1e29 	vmlsldavax.s32	r0, r9, q1, q4
[^>]*> eec3 0e0f 	vmlsldav.s32	r0, r9, q1, q7
[^>]*> eec3 0e2f 	vmlsldava.s32	r0, r9, q1, q7
[^>]*> eec3 1e0f 	vmlsldavx.s32	r0, r9, q1, q7
[^>]*> eec3 1e2f 	vmlsldavax.s32	r0, r9, q1, q7
[^>]*> eec5 0e01 	vmlsldav.s32	r0, r9, q2, q0
[^>]*> eec5 0e21 	vmlsldava.s32	r0, r9, q2, q0
[^>]*> eec5 1e01 	vmlsldavx.s32	r0, r9, q2, q0
[^>]*> eec5 1e21 	vmlsldavax.s32	r0, r9, q2, q0
[^>]*> eec5 0e03 	vmlsldav.s32	r0, r9, q2, q1
[^>]*> eec5 0e23 	vmlsldava.s32	r0, r9, q2, q1
[^>]*> eec5 1e03 	vmlsldavx.s32	r0, r9, q2, q1
[^>]*> eec5 1e23 	vmlsldavax.s32	r0, r9, q2, q1
[^>]*> eec5 0e05 	vmlsldav.s32	r0, r9, q2, q2
[^>]*> eec5 0e25 	vmlsldava.s32	r0, r9, q2, q2
[^>]*> eec5 1e05 	vmlsldavx.s32	r0, r9, q2, q2
[^>]*> eec5 1e25 	vmlsldavax.s32	r0, r9, q2, q2
[^>]*> eec5 0e09 	vmlsldav.s32	r0, r9, q2, q4
[^>]*> eec5 0e29 	vmlsldava.s32	r0, r9, q2, q4
[^>]*> eec5 1e09 	vmlsldavx.s32	r0, r9, q2, q4
[^>]*> eec5 1e29 	vmlsldavax.s32	r0, r9, q2, q4
[^>]*> eec5 0e0f 	vmlsldav.s32	r0, r9, q2, q7
[^>]*> eec5 0e2f 	vmlsldava.s32	r0, r9, q2, q7
[^>]*> eec5 1e0f 	vmlsldavx.s32	r0, r9, q2, q7
[^>]*> eec5 1e2f 	vmlsldavax.s32	r0, r9, q2, q7
[^>]*> eec9 0e01 	vmlsldav.s32	r0, r9, q4, q0
[^>]*> eec9 0e21 	vmlsldava.s32	r0, r9, q4, q0
[^>]*> eec9 1e01 	vmlsldavx.s32	r0, r9, q4, q0
[^>]*> eec9 1e21 	vmlsldavax.s32	r0, r9, q4, q0
[^>]*> eec9 0e03 	vmlsldav.s32	r0, r9, q4, q1
[^>]*> eec9 0e23 	vmlsldava.s32	r0, r9, q4, q1
[^>]*> eec9 1e03 	vmlsldavx.s32	r0, r9, q4, q1
[^>]*> eec9 1e23 	vmlsldavax.s32	r0, r9, q4, q1
[^>]*> eec9 0e05 	vmlsldav.s32	r0, r9, q4, q2
[^>]*> eec9 0e25 	vmlsldava.s32	r0, r9, q4, q2
[^>]*> eec9 1e05 	vmlsldavx.s32	r0, r9, q4, q2
[^>]*> eec9 1e25 	vmlsldavax.s32	r0, r9, q4, q2
[^>]*> eec9 0e09 	vmlsldav.s32	r0, r9, q4, q4
[^>]*> eec9 0e29 	vmlsldava.s32	r0, r9, q4, q4
[^>]*> eec9 1e09 	vmlsldavx.s32	r0, r9, q4, q4
[^>]*> eec9 1e29 	vmlsldavax.s32	r0, r9, q4, q4
[^>]*> eec9 0e0f 	vmlsldav.s32	r0, r9, q4, q7
[^>]*> eec9 0e2f 	vmlsldava.s32	r0, r9, q4, q7
[^>]*> eec9 1e0f 	vmlsldavx.s32	r0, r9, q4, q7
[^>]*> eec9 1e2f 	vmlsldavax.s32	r0, r9, q4, q7
[^>]*> eecf 0e01 	vmlsldav.s32	r0, r9, q7, q0
[^>]*> eecf 0e21 	vmlsldava.s32	r0, r9, q7, q0
[^>]*> eecf 1e01 	vmlsldavx.s32	r0, r9, q7, q0
[^>]*> eecf 1e21 	vmlsldavax.s32	r0, r9, q7, q0
[^>]*> eecf 0e03 	vmlsldav.s32	r0, r9, q7, q1
[^>]*> eecf 0e23 	vmlsldava.s32	r0, r9, q7, q1
[^>]*> eecf 1e03 	vmlsldavx.s32	r0, r9, q7, q1
[^>]*> eecf 1e23 	vmlsldavax.s32	r0, r9, q7, q1
[^>]*> eecf 0e05 	vmlsldav.s32	r0, r9, q7, q2
[^>]*> eecf 0e25 	vmlsldava.s32	r0, r9, q7, q2
[^>]*> eecf 1e05 	vmlsldavx.s32	r0, r9, q7, q2
[^>]*> eecf 1e25 	vmlsldavax.s32	r0, r9, q7, q2
[^>]*> eecf 0e09 	vmlsldav.s32	r0, r9, q7, q4
[^>]*> eecf 0e29 	vmlsldava.s32	r0, r9, q7, q4
[^>]*> eecf 1e09 	vmlsldavx.s32	r0, r9, q7, q4
[^>]*> eecf 1e29 	vmlsldavax.s32	r0, r9, q7, q4
[^>]*> eecf 0e0f 	vmlsldav.s32	r0, r9, q7, q7
[^>]*> eecf 0e2f 	vmlsldava.s32	r0, r9, q7, q7
[^>]*> eecf 1e0f 	vmlsldavx.s32	r0, r9, q7, q7
[^>]*> eecf 1e2f 	vmlsldavax.s32	r0, r9, q7, q7
[^>]*> eed1 0e01 	vmlsldav.s32	r0, fp, q0, q0
[^>]*> eed1 0e21 	vmlsldava.s32	r0, fp, q0, q0
[^>]*> eed1 1e01 	vmlsldavx.s32	r0, fp, q0, q0
[^>]*> eed1 1e21 	vmlsldavax.s32	r0, fp, q0, q0
[^>]*> eed1 0e03 	vmlsldav.s32	r0, fp, q0, q1
[^>]*> eed1 0e23 	vmlsldava.s32	r0, fp, q0, q1
[^>]*> eed1 1e03 	vmlsldavx.s32	r0, fp, q0, q1
[^>]*> eed1 1e23 	vmlsldavax.s32	r0, fp, q0, q1
[^>]*> eed1 0e05 	vmlsldav.s32	r0, fp, q0, q2
[^>]*> eed1 0e25 	vmlsldava.s32	r0, fp, q0, q2
[^>]*> eed1 1e05 	vmlsldavx.s32	r0, fp, q0, q2
[^>]*> eed1 1e25 	vmlsldavax.s32	r0, fp, q0, q2
[^>]*> eed1 0e09 	vmlsldav.s32	r0, fp, q0, q4
[^>]*> eed1 0e29 	vmlsldava.s32	r0, fp, q0, q4
[^>]*> eed1 1e09 	vmlsldavx.s32	r0, fp, q0, q4
[^>]*> eed1 1e29 	vmlsldavax.s32	r0, fp, q0, q4
[^>]*> eed1 0e0f 	vmlsldav.s32	r0, fp, q0, q7
[^>]*> eed1 0e2f 	vmlsldava.s32	r0, fp, q0, q7
[^>]*> eed1 1e0f 	vmlsldavx.s32	r0, fp, q0, q7
[^>]*> eed1 1e2f 	vmlsldavax.s32	r0, fp, q0, q7
[^>]*> eed3 0e01 	vmlsldav.s32	r0, fp, q1, q0
[^>]*> eed3 0e21 	vmlsldava.s32	r0, fp, q1, q0
[^>]*> eed3 1e01 	vmlsldavx.s32	r0, fp, q1, q0
[^>]*> eed3 1e21 	vmlsldavax.s32	r0, fp, q1, q0
[^>]*> eed3 0e03 	vmlsldav.s32	r0, fp, q1, q1
[^>]*> eed3 0e23 	vmlsldava.s32	r0, fp, q1, q1
[^>]*> eed3 1e03 	vmlsldavx.s32	r0, fp, q1, q1
[^>]*> eed3 1e23 	vmlsldavax.s32	r0, fp, q1, q1
[^>]*> eed3 0e05 	vmlsldav.s32	r0, fp, q1, q2
[^>]*> eed3 0e25 	vmlsldava.s32	r0, fp, q1, q2
[^>]*> eed3 1e05 	vmlsldavx.s32	r0, fp, q1, q2
[^>]*> eed3 1e25 	vmlsldavax.s32	r0, fp, q1, q2
[^>]*> eed3 0e09 	vmlsldav.s32	r0, fp, q1, q4
[^>]*> eed3 0e29 	vmlsldava.s32	r0, fp, q1, q4
[^>]*> eed3 1e09 	vmlsldavx.s32	r0, fp, q1, q4
[^>]*> eed3 1e29 	vmlsldavax.s32	r0, fp, q1, q4
[^>]*> eed3 0e0f 	vmlsldav.s32	r0, fp, q1, q7
[^>]*> eed3 0e2f 	vmlsldava.s32	r0, fp, q1, q7
[^>]*> eed3 1e0f 	vmlsldavx.s32	r0, fp, q1, q7
[^>]*> eed3 1e2f 	vmlsldavax.s32	r0, fp, q1, q7
[^>]*> eed5 0e01 	vmlsldav.s32	r0, fp, q2, q0
[^>]*> eed5 0e21 	vmlsldava.s32	r0, fp, q2, q0
[^>]*> eed5 1e01 	vmlsldavx.s32	r0, fp, q2, q0
[^>]*> eed5 1e21 	vmlsldavax.s32	r0, fp, q2, q0
[^>]*> eed5 0e03 	vmlsldav.s32	r0, fp, q2, q1
[^>]*> eed5 0e23 	vmlsldava.s32	r0, fp, q2, q1
[^>]*> eed5 1e03 	vmlsldavx.s32	r0, fp, q2, q1
[^>]*> eed5 1e23 	vmlsldavax.s32	r0, fp, q2, q1
[^>]*> eed5 0e05 	vmlsldav.s32	r0, fp, q2, q2
[^>]*> eed5 0e25 	vmlsldava.s32	r0, fp, q2, q2
[^>]*> eed5 1e05 	vmlsldavx.s32	r0, fp, q2, q2
[^>]*> eed5 1e25 	vmlsldavax.s32	r0, fp, q2, q2
[^>]*> eed5 0e09 	vmlsldav.s32	r0, fp, q2, q4
[^>]*> eed5 0e29 	vmlsldava.s32	r0, fp, q2, q4
[^>]*> eed5 1e09 	vmlsldavx.s32	r0, fp, q2, q4
[^>]*> eed5 1e29 	vmlsldavax.s32	r0, fp, q2, q4
[^>]*> eed5 0e0f 	vmlsldav.s32	r0, fp, q2, q7
[^>]*> eed5 0e2f 	vmlsldava.s32	r0, fp, q2, q7
[^>]*> eed5 1e0f 	vmlsldavx.s32	r0, fp, q2, q7
[^>]*> eed5 1e2f 	vmlsldavax.s32	r0, fp, q2, q7
[^>]*> eed9 0e01 	vmlsldav.s32	r0, fp, q4, q0
[^>]*> eed9 0e21 	vmlsldava.s32	r0, fp, q4, q0
[^>]*> eed9 1e01 	vmlsldavx.s32	r0, fp, q4, q0
[^>]*> eed9 1e21 	vmlsldavax.s32	r0, fp, q4, q0
[^>]*> eed9 0e03 	vmlsldav.s32	r0, fp, q4, q1
[^>]*> eed9 0e23 	vmlsldava.s32	r0, fp, q4, q1
[^>]*> eed9 1e03 	vmlsldavx.s32	r0, fp, q4, q1
[^>]*> eed9 1e23 	vmlsldavax.s32	r0, fp, q4, q1
[^>]*> eed9 0e05 	vmlsldav.s32	r0, fp, q4, q2
[^>]*> eed9 0e25 	vmlsldava.s32	r0, fp, q4, q2
[^>]*> eed9 1e05 	vmlsldavx.s32	r0, fp, q4, q2
[^>]*> eed9 1e25 	vmlsldavax.s32	r0, fp, q4, q2
[^>]*> eed9 0e09 	vmlsldav.s32	r0, fp, q4, q4
[^>]*> eed9 0e29 	vmlsldava.s32	r0, fp, q4, q4
[^>]*> eed9 1e09 	vmlsldavx.s32	r0, fp, q4, q4
[^>]*> eed9 1e29 	vmlsldavax.s32	r0, fp, q4, q4
[^>]*> eed9 0e0f 	vmlsldav.s32	r0, fp, q4, q7
[^>]*> eed9 0e2f 	vmlsldava.s32	r0, fp, q4, q7
[^>]*> eed9 1e0f 	vmlsldavx.s32	r0, fp, q4, q7
[^>]*> eed9 1e2f 	vmlsldavax.s32	r0, fp, q4, q7
[^>]*> eedf 0e01 	vmlsldav.s32	r0, fp, q7, q0
[^>]*> eedf 0e21 	vmlsldava.s32	r0, fp, q7, q0
[^>]*> eedf 1e01 	vmlsldavx.s32	r0, fp, q7, q0
[^>]*> eedf 1e21 	vmlsldavax.s32	r0, fp, q7, q0
[^>]*> eedf 0e03 	vmlsldav.s32	r0, fp, q7, q1
[^>]*> eedf 0e23 	vmlsldava.s32	r0, fp, q7, q1
[^>]*> eedf 1e03 	vmlsldavx.s32	r0, fp, q7, q1
[^>]*> eedf 1e23 	vmlsldavax.s32	r0, fp, q7, q1
[^>]*> eedf 0e05 	vmlsldav.s32	r0, fp, q7, q2
[^>]*> eedf 0e25 	vmlsldava.s32	r0, fp, q7, q2
[^>]*> eedf 1e05 	vmlsldavx.s32	r0, fp, q7, q2
[^>]*> eedf 1e25 	vmlsldavax.s32	r0, fp, q7, q2
[^>]*> eedf 0e09 	vmlsldav.s32	r0, fp, q7, q4
[^>]*> eedf 0e29 	vmlsldava.s32	r0, fp, q7, q4
[^>]*> eedf 1e09 	vmlsldavx.s32	r0, fp, q7, q4
[^>]*> eedf 1e29 	vmlsldavax.s32	r0, fp, q7, q4
[^>]*> eedf 0e0f 	vmlsldav.s32	r0, fp, q7, q7
[^>]*> eedf 0e2f 	vmlsldava.s32	r0, fp, q7, q7
[^>]*> eedf 1e0f 	vmlsldavx.s32	r0, fp, q7, q7
[^>]*> eedf 1e2f 	vmlsldavax.s32	r0, fp, q7, q7
[^>]*> ee81 2e01 	vmlsldav.s32	r2, r1, q0, q0
[^>]*> ee81 2e21 	vmlsldava.s32	r2, r1, q0, q0
[^>]*> ee81 3e01 	vmlsldavx.s32	r2, r1, q0, q0
[^>]*> ee81 3e21 	vmlsldavax.s32	r2, r1, q0, q0
[^>]*> ee81 2e03 	vmlsldav.s32	r2, r1, q0, q1
[^>]*> ee81 2e23 	vmlsldava.s32	r2, r1, q0, q1
[^>]*> ee81 3e03 	vmlsldavx.s32	r2, r1, q0, q1
[^>]*> ee81 3e23 	vmlsldavax.s32	r2, r1, q0, q1
[^>]*> ee81 2e05 	vmlsldav.s32	r2, r1, q0, q2
[^>]*> ee81 2e25 	vmlsldava.s32	r2, r1, q0, q2
[^>]*> ee81 3e05 	vmlsldavx.s32	r2, r1, q0, q2
[^>]*> ee81 3e25 	vmlsldavax.s32	r2, r1, q0, q2
[^>]*> ee81 2e09 	vmlsldav.s32	r2, r1, q0, q4
[^>]*> ee81 2e29 	vmlsldava.s32	r2, r1, q0, q4
[^>]*> ee81 3e09 	vmlsldavx.s32	r2, r1, q0, q4
[^>]*> ee81 3e29 	vmlsldavax.s32	r2, r1, q0, q4
[^>]*> ee81 2e0f 	vmlsldav.s32	r2, r1, q0, q7
[^>]*> ee81 2e2f 	vmlsldava.s32	r2, r1, q0, q7
[^>]*> ee81 3e0f 	vmlsldavx.s32	r2, r1, q0, q7
[^>]*> ee81 3e2f 	vmlsldavax.s32	r2, r1, q0, q7
[^>]*> ee83 2e01 	vmlsldav.s32	r2, r1, q1, q0
[^>]*> ee83 2e21 	vmlsldava.s32	r2, r1, q1, q0
[^>]*> ee83 3e01 	vmlsldavx.s32	r2, r1, q1, q0
[^>]*> ee83 3e21 	vmlsldavax.s32	r2, r1, q1, q0
[^>]*> ee83 2e03 	vmlsldav.s32	r2, r1, q1, q1
[^>]*> ee83 2e23 	vmlsldava.s32	r2, r1, q1, q1
[^>]*> ee83 3e03 	vmlsldavx.s32	r2, r1, q1, q1
[^>]*> ee83 3e23 	vmlsldavax.s32	r2, r1, q1, q1
[^>]*> ee83 2e05 	vmlsldav.s32	r2, r1, q1, q2
[^>]*> ee83 2e25 	vmlsldava.s32	r2, r1, q1, q2
[^>]*> ee83 3e05 	vmlsldavx.s32	r2, r1, q1, q2
[^>]*> ee83 3e25 	vmlsldavax.s32	r2, r1, q1, q2
[^>]*> ee83 2e09 	vmlsldav.s32	r2, r1, q1, q4
[^>]*> ee83 2e29 	vmlsldava.s32	r2, r1, q1, q4
[^>]*> ee83 3e09 	vmlsldavx.s32	r2, r1, q1, q4
[^>]*> ee83 3e29 	vmlsldavax.s32	r2, r1, q1, q4
[^>]*> ee83 2e0f 	vmlsldav.s32	r2, r1, q1, q7
[^>]*> ee83 2e2f 	vmlsldava.s32	r2, r1, q1, q7
[^>]*> ee83 3e0f 	vmlsldavx.s32	r2, r1, q1, q7
[^>]*> ee83 3e2f 	vmlsldavax.s32	r2, r1, q1, q7
[^>]*> ee85 2e01 	vmlsldav.s32	r2, r1, q2, q0
[^>]*> ee85 2e21 	vmlsldava.s32	r2, r1, q2, q0
[^>]*> ee85 3e01 	vmlsldavx.s32	r2, r1, q2, q0
[^>]*> ee85 3e21 	vmlsldavax.s32	r2, r1, q2, q0
[^>]*> ee85 2e03 	vmlsldav.s32	r2, r1, q2, q1
[^>]*> ee85 2e23 	vmlsldava.s32	r2, r1, q2, q1
[^>]*> ee85 3e03 	vmlsldavx.s32	r2, r1, q2, q1
[^>]*> ee85 3e23 	vmlsldavax.s32	r2, r1, q2, q1
[^>]*> ee85 2e05 	vmlsldav.s32	r2, r1, q2, q2
[^>]*> ee85 2e25 	vmlsldava.s32	r2, r1, q2, q2
[^>]*> ee85 3e05 	vmlsldavx.s32	r2, r1, q2, q2
[^>]*> ee85 3e25 	vmlsldavax.s32	r2, r1, q2, q2
[^>]*> ee85 2e09 	vmlsldav.s32	r2, r1, q2, q4
[^>]*> ee85 2e29 	vmlsldava.s32	r2, r1, q2, q4
[^>]*> ee85 3e09 	vmlsldavx.s32	r2, r1, q2, q4
[^>]*> ee85 3e29 	vmlsldavax.s32	r2, r1, q2, q4
[^>]*> ee85 2e0f 	vmlsldav.s32	r2, r1, q2, q7
[^>]*> ee85 2e2f 	vmlsldava.s32	r2, r1, q2, q7
[^>]*> ee85 3e0f 	vmlsldavx.s32	r2, r1, q2, q7
[^>]*> ee85 3e2f 	vmlsldavax.s32	r2, r1, q2, q7
[^>]*> ee89 2e01 	vmlsldav.s32	r2, r1, q4, q0
[^>]*> ee89 2e21 	vmlsldava.s32	r2, r1, q4, q0
[^>]*> ee89 3e01 	vmlsldavx.s32	r2, r1, q4, q0
[^>]*> ee89 3e21 	vmlsldavax.s32	r2, r1, q4, q0
[^>]*> ee89 2e03 	vmlsldav.s32	r2, r1, q4, q1
[^>]*> ee89 2e23 	vmlsldava.s32	r2, r1, q4, q1
[^>]*> ee89 3e03 	vmlsldavx.s32	r2, r1, q4, q1
[^>]*> ee89 3e23 	vmlsldavax.s32	r2, r1, q4, q1
[^>]*> ee89 2e05 	vmlsldav.s32	r2, r1, q4, q2
[^>]*> ee89 2e25 	vmlsldava.s32	r2, r1, q4, q2
[^>]*> ee89 3e05 	vmlsldavx.s32	r2, r1, q4, q2
[^>]*> ee89 3e25 	vmlsldavax.s32	r2, r1, q4, q2
[^>]*> ee89 2e09 	vmlsldav.s32	r2, r1, q4, q4
[^>]*> ee89 2e29 	vmlsldava.s32	r2, r1, q4, q4
[^>]*> ee89 3e09 	vmlsldavx.s32	r2, r1, q4, q4
[^>]*> ee89 3e29 	vmlsldavax.s32	r2, r1, q4, q4
[^>]*> ee89 2e0f 	vmlsldav.s32	r2, r1, q4, q7
[^>]*> ee89 2e2f 	vmlsldava.s32	r2, r1, q4, q7
[^>]*> ee89 3e0f 	vmlsldavx.s32	r2, r1, q4, q7
[^>]*> ee89 3e2f 	vmlsldavax.s32	r2, r1, q4, q7
[^>]*> ee8f 2e01 	vmlsldav.s32	r2, r1, q7, q0
[^>]*> ee8f 2e21 	vmlsldava.s32	r2, r1, q7, q0
[^>]*> ee8f 3e01 	vmlsldavx.s32	r2, r1, q7, q0
[^>]*> ee8f 3e21 	vmlsldavax.s32	r2, r1, q7, q0
[^>]*> ee8f 2e03 	vmlsldav.s32	r2, r1, q7, q1
[^>]*> ee8f 2e23 	vmlsldava.s32	r2, r1, q7, q1
[^>]*> ee8f 3e03 	vmlsldavx.s32	r2, r1, q7, q1
[^>]*> ee8f 3e23 	vmlsldavax.s32	r2, r1, q7, q1
[^>]*> ee8f 2e05 	vmlsldav.s32	r2, r1, q7, q2
[^>]*> ee8f 2e25 	vmlsldava.s32	r2, r1, q7, q2
[^>]*> ee8f 3e05 	vmlsldavx.s32	r2, r1, q7, q2
[^>]*> ee8f 3e25 	vmlsldavax.s32	r2, r1, q7, q2
[^>]*> ee8f 2e09 	vmlsldav.s32	r2, r1, q7, q4
[^>]*> ee8f 2e29 	vmlsldava.s32	r2, r1, q7, q4
[^>]*> ee8f 3e09 	vmlsldavx.s32	r2, r1, q7, q4
[^>]*> ee8f 3e29 	vmlsldavax.s32	r2, r1, q7, q4
[^>]*> ee8f 2e0f 	vmlsldav.s32	r2, r1, q7, q7
[^>]*> ee8f 2e2f 	vmlsldava.s32	r2, r1, q7, q7
[^>]*> ee8f 3e0f 	vmlsldavx.s32	r2, r1, q7, q7
[^>]*> ee8f 3e2f 	vmlsldavax.s32	r2, r1, q7, q7
[^>]*> ee91 2e01 	vmlsldav.s32	r2, r3, q0, q0
[^>]*> ee91 2e21 	vmlsldava.s32	r2, r3, q0, q0
[^>]*> ee91 3e01 	vmlsldavx.s32	r2, r3, q0, q0
[^>]*> ee91 3e21 	vmlsldavax.s32	r2, r3, q0, q0
[^>]*> ee91 2e03 	vmlsldav.s32	r2, r3, q0, q1
[^>]*> ee91 2e23 	vmlsldava.s32	r2, r3, q0, q1
[^>]*> ee91 3e03 	vmlsldavx.s32	r2, r3, q0, q1
[^>]*> ee91 3e23 	vmlsldavax.s32	r2, r3, q0, q1
[^>]*> ee91 2e05 	vmlsldav.s32	r2, r3, q0, q2
[^>]*> ee91 2e25 	vmlsldava.s32	r2, r3, q0, q2
[^>]*> ee91 3e05 	vmlsldavx.s32	r2, r3, q0, q2
[^>]*> ee91 3e25 	vmlsldavax.s32	r2, r3, q0, q2
[^>]*> ee91 2e09 	vmlsldav.s32	r2, r3, q0, q4
[^>]*> ee91 2e29 	vmlsldava.s32	r2, r3, q0, q4
[^>]*> ee91 3e09 	vmlsldavx.s32	r2, r3, q0, q4
[^>]*> ee91 3e29 	vmlsldavax.s32	r2, r3, q0, q4
[^>]*> ee91 2e0f 	vmlsldav.s32	r2, r3, q0, q7
[^>]*> ee91 2e2f 	vmlsldava.s32	r2, r3, q0, q7
[^>]*> ee91 3e0f 	vmlsldavx.s32	r2, r3, q0, q7
[^>]*> ee91 3e2f 	vmlsldavax.s32	r2, r3, q0, q7
[^>]*> ee93 2e01 	vmlsldav.s32	r2, r3, q1, q0
[^>]*> ee93 2e21 	vmlsldava.s32	r2, r3, q1, q0
[^>]*> ee93 3e01 	vmlsldavx.s32	r2, r3, q1, q0
[^>]*> ee93 3e21 	vmlsldavax.s32	r2, r3, q1, q0
[^>]*> ee93 2e03 	vmlsldav.s32	r2, r3, q1, q1
[^>]*> ee93 2e23 	vmlsldava.s32	r2, r3, q1, q1
[^>]*> ee93 3e03 	vmlsldavx.s32	r2, r3, q1, q1
[^>]*> ee93 3e23 	vmlsldavax.s32	r2, r3, q1, q1
[^>]*> ee93 2e05 	vmlsldav.s32	r2, r3, q1, q2
[^>]*> ee93 2e25 	vmlsldava.s32	r2, r3, q1, q2
[^>]*> ee93 3e05 	vmlsldavx.s32	r2, r3, q1, q2
[^>]*> ee93 3e25 	vmlsldavax.s32	r2, r3, q1, q2
[^>]*> ee93 2e09 	vmlsldav.s32	r2, r3, q1, q4
[^>]*> ee93 2e29 	vmlsldava.s32	r2, r3, q1, q4
[^>]*> ee93 3e09 	vmlsldavx.s32	r2, r3, q1, q4
[^>]*> ee93 3e29 	vmlsldavax.s32	r2, r3, q1, q4
[^>]*> ee93 2e0f 	vmlsldav.s32	r2, r3, q1, q7
[^>]*> ee93 2e2f 	vmlsldava.s32	r2, r3, q1, q7
[^>]*> ee93 3e0f 	vmlsldavx.s32	r2, r3, q1, q7
[^>]*> ee93 3e2f 	vmlsldavax.s32	r2, r3, q1, q7
[^>]*> ee95 2e01 	vmlsldav.s32	r2, r3, q2, q0
[^>]*> ee95 2e21 	vmlsldava.s32	r2, r3, q2, q0
[^>]*> ee95 3e01 	vmlsldavx.s32	r2, r3, q2, q0
[^>]*> ee95 3e21 	vmlsldavax.s32	r2, r3, q2, q0
[^>]*> ee95 2e03 	vmlsldav.s32	r2, r3, q2, q1
[^>]*> ee95 2e23 	vmlsldava.s32	r2, r3, q2, q1
[^>]*> ee95 3e03 	vmlsldavx.s32	r2, r3, q2, q1
[^>]*> ee95 3e23 	vmlsldavax.s32	r2, r3, q2, q1
[^>]*> ee95 2e05 	vmlsldav.s32	r2, r3, q2, q2
[^>]*> ee95 2e25 	vmlsldava.s32	r2, r3, q2, q2
[^>]*> ee95 3e05 	vmlsldavx.s32	r2, r3, q2, q2
[^>]*> ee95 3e25 	vmlsldavax.s32	r2, r3, q2, q2
[^>]*> ee95 2e09 	vmlsldav.s32	r2, r3, q2, q4
[^>]*> ee95 2e29 	vmlsldava.s32	r2, r3, q2, q4
[^>]*> ee95 3e09 	vmlsldavx.s32	r2, r3, q2, q4
[^>]*> ee95 3e29 	vmlsldavax.s32	r2, r3, q2, q4
[^>]*> ee95 2e0f 	vmlsldav.s32	r2, r3, q2, q7
[^>]*> ee95 2e2f 	vmlsldava.s32	r2, r3, q2, q7
[^>]*> ee95 3e0f 	vmlsldavx.s32	r2, r3, q2, q7
[^>]*> ee95 3e2f 	vmlsldavax.s32	r2, r3, q2, q7
[^>]*> ee99 2e01 	vmlsldav.s32	r2, r3, q4, q0
[^>]*> ee99 2e21 	vmlsldava.s32	r2, r3, q4, q0
[^>]*> ee99 3e01 	vmlsldavx.s32	r2, r3, q4, q0
[^>]*> ee99 3e21 	vmlsldavax.s32	r2, r3, q4, q0
[^>]*> ee99 2e03 	vmlsldav.s32	r2, r3, q4, q1
[^>]*> ee99 2e23 	vmlsldava.s32	r2, r3, q4, q1
[^>]*> ee99 3e03 	vmlsldavx.s32	r2, r3, q4, q1
[^>]*> ee99 3e23 	vmlsldavax.s32	r2, r3, q4, q1
[^>]*> ee99 2e05 	vmlsldav.s32	r2, r3, q4, q2
[^>]*> ee99 2e25 	vmlsldava.s32	r2, r3, q4, q2
[^>]*> ee99 3e05 	vmlsldavx.s32	r2, r3, q4, q2
[^>]*> ee99 3e25 	vmlsldavax.s32	r2, r3, q4, q2
[^>]*> ee99 2e09 	vmlsldav.s32	r2, r3, q4, q4
[^>]*> ee99 2e29 	vmlsldava.s32	r2, r3, q4, q4
[^>]*> ee99 3e09 	vmlsldavx.s32	r2, r3, q4, q4
[^>]*> ee99 3e29 	vmlsldavax.s32	r2, r3, q4, q4
[^>]*> ee99 2e0f 	vmlsldav.s32	r2, r3, q4, q7
[^>]*> ee99 2e2f 	vmlsldava.s32	r2, r3, q4, q7
[^>]*> ee99 3e0f 	vmlsldavx.s32	r2, r3, q4, q7
[^>]*> ee99 3e2f 	vmlsldavax.s32	r2, r3, q4, q7
[^>]*> ee9f 2e01 	vmlsldav.s32	r2, r3, q7, q0
[^>]*> ee9f 2e21 	vmlsldava.s32	r2, r3, q7, q0
[^>]*> ee9f 3e01 	vmlsldavx.s32	r2, r3, q7, q0
[^>]*> ee9f 3e21 	vmlsldavax.s32	r2, r3, q7, q0
[^>]*> ee9f 2e03 	vmlsldav.s32	r2, r3, q7, q1
[^>]*> ee9f 2e23 	vmlsldava.s32	r2, r3, q7, q1
[^>]*> ee9f 3e03 	vmlsldavx.s32	r2, r3, q7, q1
[^>]*> ee9f 3e23 	vmlsldavax.s32	r2, r3, q7, q1
[^>]*> ee9f 2e05 	vmlsldav.s32	r2, r3, q7, q2
[^>]*> ee9f 2e25 	vmlsldava.s32	r2, r3, q7, q2
[^>]*> ee9f 3e05 	vmlsldavx.s32	r2, r3, q7, q2
[^>]*> ee9f 3e25 	vmlsldavax.s32	r2, r3, q7, q2
[^>]*> ee9f 2e09 	vmlsldav.s32	r2, r3, q7, q4
[^>]*> ee9f 2e29 	vmlsldava.s32	r2, r3, q7, q4
[^>]*> ee9f 3e09 	vmlsldavx.s32	r2, r3, q7, q4
[^>]*> ee9f 3e29 	vmlsldavax.s32	r2, r3, q7, q4
[^>]*> ee9f 2e0f 	vmlsldav.s32	r2, r3, q7, q7
[^>]*> ee9f 2e2f 	vmlsldava.s32	r2, r3, q7, q7
[^>]*> ee9f 3e0f 	vmlsldavx.s32	r2, r3, q7, q7
[^>]*> ee9f 3e2f 	vmlsldavax.s32	r2, r3, q7, q7
[^>]*> eea1 2e01 	vmlsldav.s32	r2, r5, q0, q0
[^>]*> eea1 2e21 	vmlsldava.s32	r2, r5, q0, q0
[^>]*> eea1 3e01 	vmlsldavx.s32	r2, r5, q0, q0
[^>]*> eea1 3e21 	vmlsldavax.s32	r2, r5, q0, q0
[^>]*> eea1 2e03 	vmlsldav.s32	r2, r5, q0, q1
[^>]*> eea1 2e23 	vmlsldava.s32	r2, r5, q0, q1
[^>]*> eea1 3e03 	vmlsldavx.s32	r2, r5, q0, q1
[^>]*> eea1 3e23 	vmlsldavax.s32	r2, r5, q0, q1
[^>]*> eea1 2e05 	vmlsldav.s32	r2, r5, q0, q2
[^>]*> eea1 2e25 	vmlsldava.s32	r2, r5, q0, q2
[^>]*> eea1 3e05 	vmlsldavx.s32	r2, r5, q0, q2
[^>]*> eea1 3e25 	vmlsldavax.s32	r2, r5, q0, q2
[^>]*> eea1 2e09 	vmlsldav.s32	r2, r5, q0, q4
[^>]*> eea1 2e29 	vmlsldava.s32	r2, r5, q0, q4
[^>]*> eea1 3e09 	vmlsldavx.s32	r2, r5, q0, q4
[^>]*> eea1 3e29 	vmlsldavax.s32	r2, r5, q0, q4
[^>]*> eea1 2e0f 	vmlsldav.s32	r2, r5, q0, q7
[^>]*> eea1 2e2f 	vmlsldava.s32	r2, r5, q0, q7
[^>]*> eea1 3e0f 	vmlsldavx.s32	r2, r5, q0, q7
[^>]*> eea1 3e2f 	vmlsldavax.s32	r2, r5, q0, q7
[^>]*> eea3 2e01 	vmlsldav.s32	r2, r5, q1, q0
[^>]*> eea3 2e21 	vmlsldava.s32	r2, r5, q1, q0
[^>]*> eea3 3e01 	vmlsldavx.s32	r2, r5, q1, q0
[^>]*> eea3 3e21 	vmlsldavax.s32	r2, r5, q1, q0
[^>]*> eea3 2e03 	vmlsldav.s32	r2, r5, q1, q1
[^>]*> eea3 2e23 	vmlsldava.s32	r2, r5, q1, q1
[^>]*> eea3 3e03 	vmlsldavx.s32	r2, r5, q1, q1
[^>]*> eea3 3e23 	vmlsldavax.s32	r2, r5, q1, q1
[^>]*> eea3 2e05 	vmlsldav.s32	r2, r5, q1, q2
[^>]*> eea3 2e25 	vmlsldava.s32	r2, r5, q1, q2
[^>]*> eea3 3e05 	vmlsldavx.s32	r2, r5, q1, q2
[^>]*> eea3 3e25 	vmlsldavax.s32	r2, r5, q1, q2
[^>]*> eea3 2e09 	vmlsldav.s32	r2, r5, q1, q4
[^>]*> eea3 2e29 	vmlsldava.s32	r2, r5, q1, q4
[^>]*> eea3 3e09 	vmlsldavx.s32	r2, r5, q1, q4
[^>]*> eea3 3e29 	vmlsldavax.s32	r2, r5, q1, q4
[^>]*> eea3 2e0f 	vmlsldav.s32	r2, r5, q1, q7
[^>]*> eea3 2e2f 	vmlsldava.s32	r2, r5, q1, q7
[^>]*> eea3 3e0f 	vmlsldavx.s32	r2, r5, q1, q7
[^>]*> eea3 3e2f 	vmlsldavax.s32	r2, r5, q1, q7
[^>]*> eea5 2e01 	vmlsldav.s32	r2, r5, q2, q0
[^>]*> eea5 2e21 	vmlsldava.s32	r2, r5, q2, q0
[^>]*> eea5 3e01 	vmlsldavx.s32	r2, r5, q2, q0
[^>]*> eea5 3e21 	vmlsldavax.s32	r2, r5, q2, q0
[^>]*> eea5 2e03 	vmlsldav.s32	r2, r5, q2, q1
[^>]*> eea5 2e23 	vmlsldava.s32	r2, r5, q2, q1
[^>]*> eea5 3e03 	vmlsldavx.s32	r2, r5, q2, q1
[^>]*> eea5 3e23 	vmlsldavax.s32	r2, r5, q2, q1
[^>]*> eea5 2e05 	vmlsldav.s32	r2, r5, q2, q2
[^>]*> eea5 2e25 	vmlsldava.s32	r2, r5, q2, q2
[^>]*> eea5 3e05 	vmlsldavx.s32	r2, r5, q2, q2
[^>]*> eea5 3e25 	vmlsldavax.s32	r2, r5, q2, q2
[^>]*> eea5 2e09 	vmlsldav.s32	r2, r5, q2, q4
[^>]*> eea5 2e29 	vmlsldava.s32	r2, r5, q2, q4
[^>]*> eea5 3e09 	vmlsldavx.s32	r2, r5, q2, q4
[^>]*> eea5 3e29 	vmlsldavax.s32	r2, r5, q2, q4
[^>]*> eea5 2e0f 	vmlsldav.s32	r2, r5, q2, q7
[^>]*> eea5 2e2f 	vmlsldava.s32	r2, r5, q2, q7
[^>]*> eea5 3e0f 	vmlsldavx.s32	r2, r5, q2, q7
[^>]*> eea5 3e2f 	vmlsldavax.s32	r2, r5, q2, q7
[^>]*> eea9 2e01 	vmlsldav.s32	r2, r5, q4, q0
[^>]*> eea9 2e21 	vmlsldava.s32	r2, r5, q4, q0
[^>]*> eea9 3e01 	vmlsldavx.s32	r2, r5, q4, q0
[^>]*> eea9 3e21 	vmlsldavax.s32	r2, r5, q4, q0
[^>]*> eea9 2e03 	vmlsldav.s32	r2, r5, q4, q1
[^>]*> eea9 2e23 	vmlsldava.s32	r2, r5, q4, q1
[^>]*> eea9 3e03 	vmlsldavx.s32	r2, r5, q4, q1
[^>]*> eea9 3e23 	vmlsldavax.s32	r2, r5, q4, q1
[^>]*> eea9 2e05 	vmlsldav.s32	r2, r5, q4, q2
[^>]*> eea9 2e25 	vmlsldava.s32	r2, r5, q4, q2
[^>]*> eea9 3e05 	vmlsldavx.s32	r2, r5, q4, q2
[^>]*> eea9 3e25 	vmlsldavax.s32	r2, r5, q4, q2
[^>]*> eea9 2e09 	vmlsldav.s32	r2, r5, q4, q4
[^>]*> eea9 2e29 	vmlsldava.s32	r2, r5, q4, q4
[^>]*> eea9 3e09 	vmlsldavx.s32	r2, r5, q4, q4
[^>]*> eea9 3e29 	vmlsldavax.s32	r2, r5, q4, q4
[^>]*> eea9 2e0f 	vmlsldav.s32	r2, r5, q4, q7
[^>]*> eea9 2e2f 	vmlsldava.s32	r2, r5, q4, q7
[^>]*> eea9 3e0f 	vmlsldavx.s32	r2, r5, q4, q7
[^>]*> eea9 3e2f 	vmlsldavax.s32	r2, r5, q4, q7
[^>]*> eeaf 2e01 	vmlsldav.s32	r2, r5, q7, q0
[^>]*> eeaf 2e21 	vmlsldava.s32	r2, r5, q7, q0
[^>]*> eeaf 3e01 	vmlsldavx.s32	r2, r5, q7, q0
[^>]*> eeaf 3e21 	vmlsldavax.s32	r2, r5, q7, q0
[^>]*> eeaf 2e03 	vmlsldav.s32	r2, r5, q7, q1
[^>]*> eeaf 2e23 	vmlsldava.s32	r2, r5, q7, q1
[^>]*> eeaf 3e03 	vmlsldavx.s32	r2, r5, q7, q1
[^>]*> eeaf 3e23 	vmlsldavax.s32	r2, r5, q7, q1
[^>]*> eeaf 2e05 	vmlsldav.s32	r2, r5, q7, q2
[^>]*> eeaf 2e25 	vmlsldava.s32	r2, r5, q7, q2
[^>]*> eeaf 3e05 	vmlsldavx.s32	r2, r5, q7, q2
[^>]*> eeaf 3e25 	vmlsldavax.s32	r2, r5, q7, q2
[^>]*> eeaf 2e09 	vmlsldav.s32	r2, r5, q7, q4
[^>]*> eeaf 2e29 	vmlsldava.s32	r2, r5, q7, q4
[^>]*> eeaf 3e09 	vmlsldavx.s32	r2, r5, q7, q4
[^>]*> eeaf 3e29 	vmlsldavax.s32	r2, r5, q7, q4
[^>]*> eeaf 2e0f 	vmlsldav.s32	r2, r5, q7, q7
[^>]*> eeaf 2e2f 	vmlsldava.s32	r2, r5, q7, q7
[^>]*> eeaf 3e0f 	vmlsldavx.s32	r2, r5, q7, q7
[^>]*> eeaf 3e2f 	vmlsldavax.s32	r2, r5, q7, q7
[^>]*> eeb1 2e01 	vmlsldav.s32	r2, r7, q0, q0
[^>]*> eeb1 2e21 	vmlsldava.s32	r2, r7, q0, q0
[^>]*> eeb1 3e01 	vmlsldavx.s32	r2, r7, q0, q0
[^>]*> eeb1 3e21 	vmlsldavax.s32	r2, r7, q0, q0
[^>]*> eeb1 2e03 	vmlsldav.s32	r2, r7, q0, q1
[^>]*> eeb1 2e23 	vmlsldava.s32	r2, r7, q0, q1
[^>]*> eeb1 3e03 	vmlsldavx.s32	r2, r7, q0, q1
[^>]*> eeb1 3e23 	vmlsldavax.s32	r2, r7, q0, q1
[^>]*> eeb1 2e05 	vmlsldav.s32	r2, r7, q0, q2
[^>]*> eeb1 2e25 	vmlsldava.s32	r2, r7, q0, q2
[^>]*> eeb1 3e05 	vmlsldavx.s32	r2, r7, q0, q2
[^>]*> eeb1 3e25 	vmlsldavax.s32	r2, r7, q0, q2
[^>]*> eeb1 2e09 	vmlsldav.s32	r2, r7, q0, q4
[^>]*> eeb1 2e29 	vmlsldava.s32	r2, r7, q0, q4
[^>]*> eeb1 3e09 	vmlsldavx.s32	r2, r7, q0, q4
[^>]*> eeb1 3e29 	vmlsldavax.s32	r2, r7, q0, q4
[^>]*> eeb1 2e0f 	vmlsldav.s32	r2, r7, q0, q7
[^>]*> eeb1 2e2f 	vmlsldava.s32	r2, r7, q0, q7
[^>]*> eeb1 3e0f 	vmlsldavx.s32	r2, r7, q0, q7
[^>]*> eeb1 3e2f 	vmlsldavax.s32	r2, r7, q0, q7
[^>]*> eeb3 2e01 	vmlsldav.s32	r2, r7, q1, q0
[^>]*> eeb3 2e21 	vmlsldava.s32	r2, r7, q1, q0
[^>]*> eeb3 3e01 	vmlsldavx.s32	r2, r7, q1, q0
[^>]*> eeb3 3e21 	vmlsldavax.s32	r2, r7, q1, q0
[^>]*> eeb3 2e03 	vmlsldav.s32	r2, r7, q1, q1
[^>]*> eeb3 2e23 	vmlsldava.s32	r2, r7, q1, q1
[^>]*> eeb3 3e03 	vmlsldavx.s32	r2, r7, q1, q1
[^>]*> eeb3 3e23 	vmlsldavax.s32	r2, r7, q1, q1
[^>]*> eeb3 2e05 	vmlsldav.s32	r2, r7, q1, q2
[^>]*> eeb3 2e25 	vmlsldava.s32	r2, r7, q1, q2
[^>]*> eeb3 3e05 	vmlsldavx.s32	r2, r7, q1, q2
[^>]*> eeb3 3e25 	vmlsldavax.s32	r2, r7, q1, q2
[^>]*> eeb3 2e09 	vmlsldav.s32	r2, r7, q1, q4
[^>]*> eeb3 2e29 	vmlsldava.s32	r2, r7, q1, q4
[^>]*> eeb3 3e09 	vmlsldavx.s32	r2, r7, q1, q4
[^>]*> eeb3 3e29 	vmlsldavax.s32	r2, r7, q1, q4
[^>]*> eeb3 2e0f 	vmlsldav.s32	r2, r7, q1, q7
[^>]*> eeb3 2e2f 	vmlsldava.s32	r2, r7, q1, q7
[^>]*> eeb3 3e0f 	vmlsldavx.s32	r2, r7, q1, q7
[^>]*> eeb3 3e2f 	vmlsldavax.s32	r2, r7, q1, q7
[^>]*> eeb5 2e01 	vmlsldav.s32	r2, r7, q2, q0
[^>]*> eeb5 2e21 	vmlsldava.s32	r2, r7, q2, q0
[^>]*> eeb5 3e01 	vmlsldavx.s32	r2, r7, q2, q0
[^>]*> eeb5 3e21 	vmlsldavax.s32	r2, r7, q2, q0
[^>]*> eeb5 2e03 	vmlsldav.s32	r2, r7, q2, q1
[^>]*> eeb5 2e23 	vmlsldava.s32	r2, r7, q2, q1
[^>]*> eeb5 3e03 	vmlsldavx.s32	r2, r7, q2, q1
[^>]*> eeb5 3e23 	vmlsldavax.s32	r2, r7, q2, q1
[^>]*> eeb5 2e05 	vmlsldav.s32	r2, r7, q2, q2
[^>]*> eeb5 2e25 	vmlsldava.s32	r2, r7, q2, q2
[^>]*> eeb5 3e05 	vmlsldavx.s32	r2, r7, q2, q2
[^>]*> eeb5 3e25 	vmlsldavax.s32	r2, r7, q2, q2
[^>]*> eeb5 2e09 	vmlsldav.s32	r2, r7, q2, q4
[^>]*> eeb5 2e29 	vmlsldava.s32	r2, r7, q2, q4
[^>]*> eeb5 3e09 	vmlsldavx.s32	r2, r7, q2, q4
[^>]*> eeb5 3e29 	vmlsldavax.s32	r2, r7, q2, q4
[^>]*> eeb5 2e0f 	vmlsldav.s32	r2, r7, q2, q7
[^>]*> eeb5 2e2f 	vmlsldava.s32	r2, r7, q2, q7
[^>]*> eeb5 3e0f 	vmlsldavx.s32	r2, r7, q2, q7
[^>]*> eeb5 3e2f 	vmlsldavax.s32	r2, r7, q2, q7
[^>]*> eeb9 2e01 	vmlsldav.s32	r2, r7, q4, q0
[^>]*> eeb9 2e21 	vmlsldava.s32	r2, r7, q4, q0
[^>]*> eeb9 3e01 	vmlsldavx.s32	r2, r7, q4, q0
[^>]*> eeb9 3e21 	vmlsldavax.s32	r2, r7, q4, q0
[^>]*> eeb9 2e03 	vmlsldav.s32	r2, r7, q4, q1
[^>]*> eeb9 2e23 	vmlsldava.s32	r2, r7, q4, q1
[^>]*> eeb9 3e03 	vmlsldavx.s32	r2, r7, q4, q1
[^>]*> eeb9 3e23 	vmlsldavax.s32	r2, r7, q4, q1
[^>]*> eeb9 2e05 	vmlsldav.s32	r2, r7, q4, q2
[^>]*> eeb9 2e25 	vmlsldava.s32	r2, r7, q4, q2
[^>]*> eeb9 3e05 	vmlsldavx.s32	r2, r7, q4, q2
[^>]*> eeb9 3e25 	vmlsldavax.s32	r2, r7, q4, q2
[^>]*> eeb9 2e09 	vmlsldav.s32	r2, r7, q4, q4
[^>]*> eeb9 2e29 	vmlsldava.s32	r2, r7, q4, q4
[^>]*> eeb9 3e09 	vmlsldavx.s32	r2, r7, q4, q4
[^>]*> eeb9 3e29 	vmlsldavax.s32	r2, r7, q4, q4
[^>]*> eeb9 2e0f 	vmlsldav.s32	r2, r7, q4, q7
[^>]*> eeb9 2e2f 	vmlsldava.s32	r2, r7, q4, q7
[^>]*> eeb9 3e0f 	vmlsldavx.s32	r2, r7, q4, q7
[^>]*> eeb9 3e2f 	vmlsldavax.s32	r2, r7, q4, q7
[^>]*> eebf 2e01 	vmlsldav.s32	r2, r7, q7, q0
[^>]*> eebf 2e21 	vmlsldava.s32	r2, r7, q7, q0
[^>]*> eebf 3e01 	vmlsldavx.s32	r2, r7, q7, q0
[^>]*> eebf 3e21 	vmlsldavax.s32	r2, r7, q7, q0
[^>]*> eebf 2e03 	vmlsldav.s32	r2, r7, q7, q1
[^>]*> eebf 2e23 	vmlsldava.s32	r2, r7, q7, q1
[^>]*> eebf 3e03 	vmlsldavx.s32	r2, r7, q7, q1
[^>]*> eebf 3e23 	vmlsldavax.s32	r2, r7, q7, q1
[^>]*> eebf 2e05 	vmlsldav.s32	r2, r7, q7, q2
[^>]*> eebf 2e25 	vmlsldava.s32	r2, r7, q7, q2
[^>]*> eebf 3e05 	vmlsldavx.s32	r2, r7, q7, q2
[^>]*> eebf 3e25 	vmlsldavax.s32	r2, r7, q7, q2
[^>]*> eebf 2e09 	vmlsldav.s32	r2, r7, q7, q4
[^>]*> eebf 2e29 	vmlsldava.s32	r2, r7, q7, q4
[^>]*> eebf 3e09 	vmlsldavx.s32	r2, r7, q7, q4
[^>]*> eebf 3e29 	vmlsldavax.s32	r2, r7, q7, q4
[^>]*> eebf 2e0f 	vmlsldav.s32	r2, r7, q7, q7
[^>]*> eebf 2e2f 	vmlsldava.s32	r2, r7, q7, q7
[^>]*> eebf 3e0f 	vmlsldavx.s32	r2, r7, q7, q7
[^>]*> eebf 3e2f 	vmlsldavax.s32	r2, r7, q7, q7
[^>]*> eec1 2e01 	vmlsldav.s32	r2, r9, q0, q0
[^>]*> eec1 2e21 	vmlsldava.s32	r2, r9, q0, q0
[^>]*> eec1 3e01 	vmlsldavx.s32	r2, r9, q0, q0
[^>]*> eec1 3e21 	vmlsldavax.s32	r2, r9, q0, q0
[^>]*> eec1 2e03 	vmlsldav.s32	r2, r9, q0, q1
[^>]*> eec1 2e23 	vmlsldava.s32	r2, r9, q0, q1
[^>]*> eec1 3e03 	vmlsldavx.s32	r2, r9, q0, q1
[^>]*> eec1 3e23 	vmlsldavax.s32	r2, r9, q0, q1
[^>]*> eec1 2e05 	vmlsldav.s32	r2, r9, q0, q2
[^>]*> eec1 2e25 	vmlsldava.s32	r2, r9, q0, q2
[^>]*> eec1 3e05 	vmlsldavx.s32	r2, r9, q0, q2
[^>]*> eec1 3e25 	vmlsldavax.s32	r2, r9, q0, q2
[^>]*> eec1 2e09 	vmlsldav.s32	r2, r9, q0, q4
[^>]*> eec1 2e29 	vmlsldava.s32	r2, r9, q0, q4
[^>]*> eec1 3e09 	vmlsldavx.s32	r2, r9, q0, q4
[^>]*> eec1 3e29 	vmlsldavax.s32	r2, r9, q0, q4
[^>]*> eec1 2e0f 	vmlsldav.s32	r2, r9, q0, q7
[^>]*> eec1 2e2f 	vmlsldava.s32	r2, r9, q0, q7
[^>]*> eec1 3e0f 	vmlsldavx.s32	r2, r9, q0, q7
[^>]*> eec1 3e2f 	vmlsldavax.s32	r2, r9, q0, q7
[^>]*> eec3 2e01 	vmlsldav.s32	r2, r9, q1, q0
[^>]*> eec3 2e21 	vmlsldava.s32	r2, r9, q1, q0
[^>]*> eec3 3e01 	vmlsldavx.s32	r2, r9, q1, q0
[^>]*> eec3 3e21 	vmlsldavax.s32	r2, r9, q1, q0
[^>]*> eec3 2e03 	vmlsldav.s32	r2, r9, q1, q1
[^>]*> eec3 2e23 	vmlsldava.s32	r2, r9, q1, q1
[^>]*> eec3 3e03 	vmlsldavx.s32	r2, r9, q1, q1
[^>]*> eec3 3e23 	vmlsldavax.s32	r2, r9, q1, q1
[^>]*> eec3 2e05 	vmlsldav.s32	r2, r9, q1, q2
[^>]*> eec3 2e25 	vmlsldava.s32	r2, r9, q1, q2
[^>]*> eec3 3e05 	vmlsldavx.s32	r2, r9, q1, q2
[^>]*> eec3 3e25 	vmlsldavax.s32	r2, r9, q1, q2
[^>]*> eec3 2e09 	vmlsldav.s32	r2, r9, q1, q4
[^>]*> eec3 2e29 	vmlsldava.s32	r2, r9, q1, q4
[^>]*> eec3 3e09 	vmlsldavx.s32	r2, r9, q1, q4
[^>]*> eec3 3e29 	vmlsldavax.s32	r2, r9, q1, q4
[^>]*> eec3 2e0f 	vmlsldav.s32	r2, r9, q1, q7
[^>]*> eec3 2e2f 	vmlsldava.s32	r2, r9, q1, q7
[^>]*> eec3 3e0f 	vmlsldavx.s32	r2, r9, q1, q7
[^>]*> eec3 3e2f 	vmlsldavax.s32	r2, r9, q1, q7
[^>]*> eec5 2e01 	vmlsldav.s32	r2, r9, q2, q0
[^>]*> eec5 2e21 	vmlsldava.s32	r2, r9, q2, q0
[^>]*> eec5 3e01 	vmlsldavx.s32	r2, r9, q2, q0
[^>]*> eec5 3e21 	vmlsldavax.s32	r2, r9, q2, q0
[^>]*> eec5 2e03 	vmlsldav.s32	r2, r9, q2, q1
[^>]*> eec5 2e23 	vmlsldava.s32	r2, r9, q2, q1
[^>]*> eec5 3e03 	vmlsldavx.s32	r2, r9, q2, q1
[^>]*> eec5 3e23 	vmlsldavax.s32	r2, r9, q2, q1
[^>]*> eec5 2e05 	vmlsldav.s32	r2, r9, q2, q2
[^>]*> eec5 2e25 	vmlsldava.s32	r2, r9, q2, q2
[^>]*> eec5 3e05 	vmlsldavx.s32	r2, r9, q2, q2
[^>]*> eec5 3e25 	vmlsldavax.s32	r2, r9, q2, q2
[^>]*> eec5 2e09 	vmlsldav.s32	r2, r9, q2, q4
[^>]*> eec5 2e29 	vmlsldava.s32	r2, r9, q2, q4
[^>]*> eec5 3e09 	vmlsldavx.s32	r2, r9, q2, q4
[^>]*> eec5 3e29 	vmlsldavax.s32	r2, r9, q2, q4
[^>]*> eec5 2e0f 	vmlsldav.s32	r2, r9, q2, q7
[^>]*> eec5 2e2f 	vmlsldava.s32	r2, r9, q2, q7
[^>]*> eec5 3e0f 	vmlsldavx.s32	r2, r9, q2, q7
[^>]*> eec5 3e2f 	vmlsldavax.s32	r2, r9, q2, q7
[^>]*> eec9 2e01 	vmlsldav.s32	r2, r9, q4, q0
[^>]*> eec9 2e21 	vmlsldava.s32	r2, r9, q4, q0
[^>]*> eec9 3e01 	vmlsldavx.s32	r2, r9, q4, q0
[^>]*> eec9 3e21 	vmlsldavax.s32	r2, r9, q4, q0
[^>]*> eec9 2e03 	vmlsldav.s32	r2, r9, q4, q1
[^>]*> eec9 2e23 	vmlsldava.s32	r2, r9, q4, q1
[^>]*> eec9 3e03 	vmlsldavx.s32	r2, r9, q4, q1
[^>]*> eec9 3e23 	vmlsldavax.s32	r2, r9, q4, q1
[^>]*> eec9 2e05 	vmlsldav.s32	r2, r9, q4, q2
[^>]*> eec9 2e25 	vmlsldava.s32	r2, r9, q4, q2
[^>]*> eec9 3e05 	vmlsldavx.s32	r2, r9, q4, q2
[^>]*> eec9 3e25 	vmlsldavax.s32	r2, r9, q4, q2
[^>]*> eec9 2e09 	vmlsldav.s32	r2, r9, q4, q4
[^>]*> eec9 2e29 	vmlsldava.s32	r2, r9, q4, q4
[^>]*> eec9 3e09 	vmlsldavx.s32	r2, r9, q4, q4
[^>]*> eec9 3e29 	vmlsldavax.s32	r2, r9, q4, q4
[^>]*> eec9 2e0f 	vmlsldav.s32	r2, r9, q4, q7
[^>]*> eec9 2e2f 	vmlsldava.s32	r2, r9, q4, q7
[^>]*> eec9 3e0f 	vmlsldavx.s32	r2, r9, q4, q7
[^>]*> eec9 3e2f 	vmlsldavax.s32	r2, r9, q4, q7
[^>]*> eecf 2e01 	vmlsldav.s32	r2, r9, q7, q0
[^>]*> eecf 2e21 	vmlsldava.s32	r2, r9, q7, q0
[^>]*> eecf 3e01 	vmlsldavx.s32	r2, r9, q7, q0
[^>]*> eecf 3e21 	vmlsldavax.s32	r2, r9, q7, q0
[^>]*> eecf 2e03 	vmlsldav.s32	r2, r9, q7, q1
[^>]*> eecf 2e23 	vmlsldava.s32	r2, r9, q7, q1
[^>]*> eecf 3e03 	vmlsldavx.s32	r2, r9, q7, q1
[^>]*> eecf 3e23 	vmlsldavax.s32	r2, r9, q7, q1
[^>]*> eecf 2e05 	vmlsldav.s32	r2, r9, q7, q2
[^>]*> eecf 2e25 	vmlsldava.s32	r2, r9, q7, q2
[^>]*> eecf 3e05 	vmlsldavx.s32	r2, r9, q7, q2
[^>]*> eecf 3e25 	vmlsldavax.s32	r2, r9, q7, q2
[^>]*> eecf 2e09 	vmlsldav.s32	r2, r9, q7, q4
[^>]*> eecf 2e29 	vmlsldava.s32	r2, r9, q7, q4
[^>]*> eecf 3e09 	vmlsldavx.s32	r2, r9, q7, q4
[^>]*> eecf 3e29 	vmlsldavax.s32	r2, r9, q7, q4
[^>]*> eecf 2e0f 	vmlsldav.s32	r2, r9, q7, q7
[^>]*> eecf 2e2f 	vmlsldava.s32	r2, r9, q7, q7
[^>]*> eecf 3e0f 	vmlsldavx.s32	r2, r9, q7, q7
[^>]*> eecf 3e2f 	vmlsldavax.s32	r2, r9, q7, q7
[^>]*> eed1 2e01 	vmlsldav.s32	r2, fp, q0, q0
[^>]*> eed1 2e21 	vmlsldava.s32	r2, fp, q0, q0
[^>]*> eed1 3e01 	vmlsldavx.s32	r2, fp, q0, q0
[^>]*> eed1 3e21 	vmlsldavax.s32	r2, fp, q0, q0
[^>]*> eed1 2e03 	vmlsldav.s32	r2, fp, q0, q1
[^>]*> eed1 2e23 	vmlsldava.s32	r2, fp, q0, q1
[^>]*> eed1 3e03 	vmlsldavx.s32	r2, fp, q0, q1
[^>]*> eed1 3e23 	vmlsldavax.s32	r2, fp, q0, q1
[^>]*> eed1 2e05 	vmlsldav.s32	r2, fp, q0, q2
[^>]*> eed1 2e25 	vmlsldava.s32	r2, fp, q0, q2
[^>]*> eed1 3e05 	vmlsldavx.s32	r2, fp, q0, q2
[^>]*> eed1 3e25 	vmlsldavax.s32	r2, fp, q0, q2
[^>]*> eed1 2e09 	vmlsldav.s32	r2, fp, q0, q4
[^>]*> eed1 2e29 	vmlsldava.s32	r2, fp, q0, q4
[^>]*> eed1 3e09 	vmlsldavx.s32	r2, fp, q0, q4
[^>]*> eed1 3e29 	vmlsldavax.s32	r2, fp, q0, q4
[^>]*> eed1 2e0f 	vmlsldav.s32	r2, fp, q0, q7
[^>]*> eed1 2e2f 	vmlsldava.s32	r2, fp, q0, q7
[^>]*> eed1 3e0f 	vmlsldavx.s32	r2, fp, q0, q7
[^>]*> eed1 3e2f 	vmlsldavax.s32	r2, fp, q0, q7
[^>]*> eed3 2e01 	vmlsldav.s32	r2, fp, q1, q0
[^>]*> eed3 2e21 	vmlsldava.s32	r2, fp, q1, q0
[^>]*> eed3 3e01 	vmlsldavx.s32	r2, fp, q1, q0
[^>]*> eed3 3e21 	vmlsldavax.s32	r2, fp, q1, q0
[^>]*> eed3 2e03 	vmlsldav.s32	r2, fp, q1, q1
[^>]*> eed3 2e23 	vmlsldava.s32	r2, fp, q1, q1
[^>]*> eed3 3e03 	vmlsldavx.s32	r2, fp, q1, q1
[^>]*> eed3 3e23 	vmlsldavax.s32	r2, fp, q1, q1
[^>]*> eed3 2e05 	vmlsldav.s32	r2, fp, q1, q2
[^>]*> eed3 2e25 	vmlsldava.s32	r2, fp, q1, q2
[^>]*> eed3 3e05 	vmlsldavx.s32	r2, fp, q1, q2
[^>]*> eed3 3e25 	vmlsldavax.s32	r2, fp, q1, q2
[^>]*> eed3 2e09 	vmlsldav.s32	r2, fp, q1, q4
[^>]*> eed3 2e29 	vmlsldava.s32	r2, fp, q1, q4
[^>]*> eed3 3e09 	vmlsldavx.s32	r2, fp, q1, q4
[^>]*> eed3 3e29 	vmlsldavax.s32	r2, fp, q1, q4
[^>]*> eed3 2e0f 	vmlsldav.s32	r2, fp, q1, q7
[^>]*> eed3 2e2f 	vmlsldava.s32	r2, fp, q1, q7
[^>]*> eed3 3e0f 	vmlsldavx.s32	r2, fp, q1, q7
[^>]*> eed3 3e2f 	vmlsldavax.s32	r2, fp, q1, q7
[^>]*> eed5 2e01 	vmlsldav.s32	r2, fp, q2, q0
[^>]*> eed5 2e21 	vmlsldava.s32	r2, fp, q2, q0
[^>]*> eed5 3e01 	vmlsldavx.s32	r2, fp, q2, q0
[^>]*> eed5 3e21 	vmlsldavax.s32	r2, fp, q2, q0
[^>]*> eed5 2e03 	vmlsldav.s32	r2, fp, q2, q1
[^>]*> eed5 2e23 	vmlsldava.s32	r2, fp, q2, q1
[^>]*> eed5 3e03 	vmlsldavx.s32	r2, fp, q2, q1
[^>]*> eed5 3e23 	vmlsldavax.s32	r2, fp, q2, q1
[^>]*> eed5 2e05 	vmlsldav.s32	r2, fp, q2, q2
[^>]*> eed5 2e25 	vmlsldava.s32	r2, fp, q2, q2
[^>]*> eed5 3e05 	vmlsldavx.s32	r2, fp, q2, q2
[^>]*> eed5 3e25 	vmlsldavax.s32	r2, fp, q2, q2
[^>]*> eed5 2e09 	vmlsldav.s32	r2, fp, q2, q4
[^>]*> eed5 2e29 	vmlsldava.s32	r2, fp, q2, q4
[^>]*> eed5 3e09 	vmlsldavx.s32	r2, fp, q2, q4
[^>]*> eed5 3e29 	vmlsldavax.s32	r2, fp, q2, q4
[^>]*> eed5 2e0f 	vmlsldav.s32	r2, fp, q2, q7
[^>]*> eed5 2e2f 	vmlsldava.s32	r2, fp, q2, q7
[^>]*> eed5 3e0f 	vmlsldavx.s32	r2, fp, q2, q7
[^>]*> eed5 3e2f 	vmlsldavax.s32	r2, fp, q2, q7
[^>]*> eed9 2e01 	vmlsldav.s32	r2, fp, q4, q0
[^>]*> eed9 2e21 	vmlsldava.s32	r2, fp, q4, q0
[^>]*> eed9 3e01 	vmlsldavx.s32	r2, fp, q4, q0
[^>]*> eed9 3e21 	vmlsldavax.s32	r2, fp, q4, q0
[^>]*> eed9 2e03 	vmlsldav.s32	r2, fp, q4, q1
[^>]*> eed9 2e23 	vmlsldava.s32	r2, fp, q4, q1
[^>]*> eed9 3e03 	vmlsldavx.s32	r2, fp, q4, q1
[^>]*> eed9 3e23 	vmlsldavax.s32	r2, fp, q4, q1
[^>]*> eed9 2e05 	vmlsldav.s32	r2, fp, q4, q2
[^>]*> eed9 2e25 	vmlsldava.s32	r2, fp, q4, q2
[^>]*> eed9 3e05 	vmlsldavx.s32	r2, fp, q4, q2
[^>]*> eed9 3e25 	vmlsldavax.s32	r2, fp, q4, q2
[^>]*> eed9 2e09 	vmlsldav.s32	r2, fp, q4, q4
[^>]*> eed9 2e29 	vmlsldava.s32	r2, fp, q4, q4
[^>]*> eed9 3e09 	vmlsldavx.s32	r2, fp, q4, q4
[^>]*> eed9 3e29 	vmlsldavax.s32	r2, fp, q4, q4
[^>]*> eed9 2e0f 	vmlsldav.s32	r2, fp, q4, q7
[^>]*> eed9 2e2f 	vmlsldava.s32	r2, fp, q4, q7
[^>]*> eed9 3e0f 	vmlsldavx.s32	r2, fp, q4, q7
[^>]*> eed9 3e2f 	vmlsldavax.s32	r2, fp, q4, q7
[^>]*> eedf 2e01 	vmlsldav.s32	r2, fp, q7, q0
[^>]*> eedf 2e21 	vmlsldava.s32	r2, fp, q7, q0
[^>]*> eedf 3e01 	vmlsldavx.s32	r2, fp, q7, q0
[^>]*> eedf 3e21 	vmlsldavax.s32	r2, fp, q7, q0
[^>]*> eedf 2e03 	vmlsldav.s32	r2, fp, q7, q1
[^>]*> eedf 2e23 	vmlsldava.s32	r2, fp, q7, q1
[^>]*> eedf 3e03 	vmlsldavx.s32	r2, fp, q7, q1
[^>]*> eedf 3e23 	vmlsldavax.s32	r2, fp, q7, q1
[^>]*> eedf 2e05 	vmlsldav.s32	r2, fp, q7, q2
[^>]*> eedf 2e25 	vmlsldava.s32	r2, fp, q7, q2
[^>]*> eedf 3e05 	vmlsldavx.s32	r2, fp, q7, q2
[^>]*> eedf 3e25 	vmlsldavax.s32	r2, fp, q7, q2
[^>]*> eedf 2e09 	vmlsldav.s32	r2, fp, q7, q4
[^>]*> eedf 2e29 	vmlsldava.s32	r2, fp, q7, q4
[^>]*> eedf 3e09 	vmlsldavx.s32	r2, fp, q7, q4
[^>]*> eedf 3e29 	vmlsldavax.s32	r2, fp, q7, q4
[^>]*> eedf 2e0f 	vmlsldav.s32	r2, fp, q7, q7
[^>]*> eedf 2e2f 	vmlsldava.s32	r2, fp, q7, q7
[^>]*> eedf 3e0f 	vmlsldavx.s32	r2, fp, q7, q7
[^>]*> eedf 3e2f 	vmlsldavax.s32	r2, fp, q7, q7
[^>]*> ee81 4e01 	vmlsldav.s32	r4, r1, q0, q0
[^>]*> ee81 4e21 	vmlsldava.s32	r4, r1, q0, q0
[^>]*> ee81 5e01 	vmlsldavx.s32	r4, r1, q0, q0
[^>]*> ee81 5e21 	vmlsldavax.s32	r4, r1, q0, q0
[^>]*> ee81 4e03 	vmlsldav.s32	r4, r1, q0, q1
[^>]*> ee81 4e23 	vmlsldava.s32	r4, r1, q0, q1
[^>]*> ee81 5e03 	vmlsldavx.s32	r4, r1, q0, q1
[^>]*> ee81 5e23 	vmlsldavax.s32	r4, r1, q0, q1
[^>]*> ee81 4e05 	vmlsldav.s32	r4, r1, q0, q2
[^>]*> ee81 4e25 	vmlsldava.s32	r4, r1, q0, q2
[^>]*> ee81 5e05 	vmlsldavx.s32	r4, r1, q0, q2
[^>]*> ee81 5e25 	vmlsldavax.s32	r4, r1, q0, q2
[^>]*> ee81 4e09 	vmlsldav.s32	r4, r1, q0, q4
[^>]*> ee81 4e29 	vmlsldava.s32	r4, r1, q0, q4
[^>]*> ee81 5e09 	vmlsldavx.s32	r4, r1, q0, q4
[^>]*> ee81 5e29 	vmlsldavax.s32	r4, r1, q0, q4
[^>]*> ee81 4e0f 	vmlsldav.s32	r4, r1, q0, q7
[^>]*> ee81 4e2f 	vmlsldava.s32	r4, r1, q0, q7
[^>]*> ee81 5e0f 	vmlsldavx.s32	r4, r1, q0, q7
[^>]*> ee81 5e2f 	vmlsldavax.s32	r4, r1, q0, q7
[^>]*> ee83 4e01 	vmlsldav.s32	r4, r1, q1, q0
[^>]*> ee83 4e21 	vmlsldava.s32	r4, r1, q1, q0
[^>]*> ee83 5e01 	vmlsldavx.s32	r4, r1, q1, q0
[^>]*> ee83 5e21 	vmlsldavax.s32	r4, r1, q1, q0
[^>]*> ee83 4e03 	vmlsldav.s32	r4, r1, q1, q1
[^>]*> ee83 4e23 	vmlsldava.s32	r4, r1, q1, q1
[^>]*> ee83 5e03 	vmlsldavx.s32	r4, r1, q1, q1
[^>]*> ee83 5e23 	vmlsldavax.s32	r4, r1, q1, q1
[^>]*> ee83 4e05 	vmlsldav.s32	r4, r1, q1, q2
[^>]*> ee83 4e25 	vmlsldava.s32	r4, r1, q1, q2
[^>]*> ee83 5e05 	vmlsldavx.s32	r4, r1, q1, q2
[^>]*> ee83 5e25 	vmlsldavax.s32	r4, r1, q1, q2
[^>]*> ee83 4e09 	vmlsldav.s32	r4, r1, q1, q4
[^>]*> ee83 4e29 	vmlsldava.s32	r4, r1, q1, q4
[^>]*> ee83 5e09 	vmlsldavx.s32	r4, r1, q1, q4
[^>]*> ee83 5e29 	vmlsldavax.s32	r4, r1, q1, q4
[^>]*> ee83 4e0f 	vmlsldav.s32	r4, r1, q1, q7
[^>]*> ee83 4e2f 	vmlsldava.s32	r4, r1, q1, q7
[^>]*> ee83 5e0f 	vmlsldavx.s32	r4, r1, q1, q7
[^>]*> ee83 5e2f 	vmlsldavax.s32	r4, r1, q1, q7
[^>]*> ee85 4e01 	vmlsldav.s32	r4, r1, q2, q0
[^>]*> ee85 4e21 	vmlsldava.s32	r4, r1, q2, q0
[^>]*> ee85 5e01 	vmlsldavx.s32	r4, r1, q2, q0
[^>]*> ee85 5e21 	vmlsldavax.s32	r4, r1, q2, q0
[^>]*> ee85 4e03 	vmlsldav.s32	r4, r1, q2, q1
[^>]*> ee85 4e23 	vmlsldava.s32	r4, r1, q2, q1
[^>]*> ee85 5e03 	vmlsldavx.s32	r4, r1, q2, q1
[^>]*> ee85 5e23 	vmlsldavax.s32	r4, r1, q2, q1
[^>]*> ee85 4e05 	vmlsldav.s32	r4, r1, q2, q2
[^>]*> ee85 4e25 	vmlsldava.s32	r4, r1, q2, q2
[^>]*> ee85 5e05 	vmlsldavx.s32	r4, r1, q2, q2
[^>]*> ee85 5e25 	vmlsldavax.s32	r4, r1, q2, q2
[^>]*> ee85 4e09 	vmlsldav.s32	r4, r1, q2, q4
[^>]*> ee85 4e29 	vmlsldava.s32	r4, r1, q2, q4
[^>]*> ee85 5e09 	vmlsldavx.s32	r4, r1, q2, q4
[^>]*> ee85 5e29 	vmlsldavax.s32	r4, r1, q2, q4
[^>]*> ee85 4e0f 	vmlsldav.s32	r4, r1, q2, q7
[^>]*> ee85 4e2f 	vmlsldava.s32	r4, r1, q2, q7
[^>]*> ee85 5e0f 	vmlsldavx.s32	r4, r1, q2, q7
[^>]*> ee85 5e2f 	vmlsldavax.s32	r4, r1, q2, q7
[^>]*> ee89 4e01 	vmlsldav.s32	r4, r1, q4, q0
[^>]*> ee89 4e21 	vmlsldava.s32	r4, r1, q4, q0
[^>]*> ee89 5e01 	vmlsldavx.s32	r4, r1, q4, q0
[^>]*> ee89 5e21 	vmlsldavax.s32	r4, r1, q4, q0
[^>]*> ee89 4e03 	vmlsldav.s32	r4, r1, q4, q1
[^>]*> ee89 4e23 	vmlsldava.s32	r4, r1, q4, q1
[^>]*> ee89 5e03 	vmlsldavx.s32	r4, r1, q4, q1
[^>]*> ee89 5e23 	vmlsldavax.s32	r4, r1, q4, q1
[^>]*> ee89 4e05 	vmlsldav.s32	r4, r1, q4, q2
[^>]*> ee89 4e25 	vmlsldava.s32	r4, r1, q4, q2
[^>]*> ee89 5e05 	vmlsldavx.s32	r4, r1, q4, q2
[^>]*> ee89 5e25 	vmlsldavax.s32	r4, r1, q4, q2
[^>]*> ee89 4e09 	vmlsldav.s32	r4, r1, q4, q4
[^>]*> ee89 4e29 	vmlsldava.s32	r4, r1, q4, q4
[^>]*> ee89 5e09 	vmlsldavx.s32	r4, r1, q4, q4
[^>]*> ee89 5e29 	vmlsldavax.s32	r4, r1, q4, q4
[^>]*> ee89 4e0f 	vmlsldav.s32	r4, r1, q4, q7
[^>]*> ee89 4e2f 	vmlsldava.s32	r4, r1, q4, q7
[^>]*> ee89 5e0f 	vmlsldavx.s32	r4, r1, q4, q7
[^>]*> ee89 5e2f 	vmlsldavax.s32	r4, r1, q4, q7
[^>]*> ee8f 4e01 	vmlsldav.s32	r4, r1, q7, q0
[^>]*> ee8f 4e21 	vmlsldava.s32	r4, r1, q7, q0
[^>]*> ee8f 5e01 	vmlsldavx.s32	r4, r1, q7, q0
[^>]*> ee8f 5e21 	vmlsldavax.s32	r4, r1, q7, q0
[^>]*> ee8f 4e03 	vmlsldav.s32	r4, r1, q7, q1
[^>]*> ee8f 4e23 	vmlsldava.s32	r4, r1, q7, q1
[^>]*> ee8f 5e03 	vmlsldavx.s32	r4, r1, q7, q1
[^>]*> ee8f 5e23 	vmlsldavax.s32	r4, r1, q7, q1
[^>]*> ee8f 4e05 	vmlsldav.s32	r4, r1, q7, q2
[^>]*> ee8f 4e25 	vmlsldava.s32	r4, r1, q7, q2
[^>]*> ee8f 5e05 	vmlsldavx.s32	r4, r1, q7, q2
[^>]*> ee8f 5e25 	vmlsldavax.s32	r4, r1, q7, q2
[^>]*> ee8f 4e09 	vmlsldav.s32	r4, r1, q7, q4
[^>]*> ee8f 4e29 	vmlsldava.s32	r4, r1, q7, q4
[^>]*> ee8f 5e09 	vmlsldavx.s32	r4, r1, q7, q4
[^>]*> ee8f 5e29 	vmlsldavax.s32	r4, r1, q7, q4
[^>]*> ee8f 4e0f 	vmlsldav.s32	r4, r1, q7, q7
[^>]*> ee8f 4e2f 	vmlsldava.s32	r4, r1, q7, q7
[^>]*> ee8f 5e0f 	vmlsldavx.s32	r4, r1, q7, q7
[^>]*> ee8f 5e2f 	vmlsldavax.s32	r4, r1, q7, q7
[^>]*> ee91 4e01 	vmlsldav.s32	r4, r3, q0, q0
[^>]*> ee91 4e21 	vmlsldava.s32	r4, r3, q0, q0
[^>]*> ee91 5e01 	vmlsldavx.s32	r4, r3, q0, q0
[^>]*> ee91 5e21 	vmlsldavax.s32	r4, r3, q0, q0
[^>]*> ee91 4e03 	vmlsldav.s32	r4, r3, q0, q1
[^>]*> ee91 4e23 	vmlsldava.s32	r4, r3, q0, q1
[^>]*> ee91 5e03 	vmlsldavx.s32	r4, r3, q0, q1
[^>]*> ee91 5e23 	vmlsldavax.s32	r4, r3, q0, q1
[^>]*> ee91 4e05 	vmlsldav.s32	r4, r3, q0, q2
[^>]*> ee91 4e25 	vmlsldava.s32	r4, r3, q0, q2
[^>]*> ee91 5e05 	vmlsldavx.s32	r4, r3, q0, q2
[^>]*> ee91 5e25 	vmlsldavax.s32	r4, r3, q0, q2
[^>]*> ee91 4e09 	vmlsldav.s32	r4, r3, q0, q4
[^>]*> ee91 4e29 	vmlsldava.s32	r4, r3, q0, q4
[^>]*> ee91 5e09 	vmlsldavx.s32	r4, r3, q0, q4
[^>]*> ee91 5e29 	vmlsldavax.s32	r4, r3, q0, q4
[^>]*> ee91 4e0f 	vmlsldav.s32	r4, r3, q0, q7
[^>]*> ee91 4e2f 	vmlsldava.s32	r4, r3, q0, q7
[^>]*> ee91 5e0f 	vmlsldavx.s32	r4, r3, q0, q7
[^>]*> ee91 5e2f 	vmlsldavax.s32	r4, r3, q0, q7
[^>]*> ee93 4e01 	vmlsldav.s32	r4, r3, q1, q0
[^>]*> ee93 4e21 	vmlsldava.s32	r4, r3, q1, q0
[^>]*> ee93 5e01 	vmlsldavx.s32	r4, r3, q1, q0
[^>]*> ee93 5e21 	vmlsldavax.s32	r4, r3, q1, q0
[^>]*> ee93 4e03 	vmlsldav.s32	r4, r3, q1, q1
[^>]*> ee93 4e23 	vmlsldava.s32	r4, r3, q1, q1
[^>]*> ee93 5e03 	vmlsldavx.s32	r4, r3, q1, q1
[^>]*> ee93 5e23 	vmlsldavax.s32	r4, r3, q1, q1
[^>]*> ee93 4e05 	vmlsldav.s32	r4, r3, q1, q2
[^>]*> ee93 4e25 	vmlsldava.s32	r4, r3, q1, q2
[^>]*> ee93 5e05 	vmlsldavx.s32	r4, r3, q1, q2
[^>]*> ee93 5e25 	vmlsldavax.s32	r4, r3, q1, q2
[^>]*> ee93 4e09 	vmlsldav.s32	r4, r3, q1, q4
[^>]*> ee93 4e29 	vmlsldava.s32	r4, r3, q1, q4
[^>]*> ee93 5e09 	vmlsldavx.s32	r4, r3, q1, q4
[^>]*> ee93 5e29 	vmlsldavax.s32	r4, r3, q1, q4
[^>]*> ee93 4e0f 	vmlsldav.s32	r4, r3, q1, q7
[^>]*> ee93 4e2f 	vmlsldava.s32	r4, r3, q1, q7
[^>]*> ee93 5e0f 	vmlsldavx.s32	r4, r3, q1, q7
[^>]*> ee93 5e2f 	vmlsldavax.s32	r4, r3, q1, q7
[^>]*> ee95 4e01 	vmlsldav.s32	r4, r3, q2, q0
[^>]*> ee95 4e21 	vmlsldava.s32	r4, r3, q2, q0
[^>]*> ee95 5e01 	vmlsldavx.s32	r4, r3, q2, q0
[^>]*> ee95 5e21 	vmlsldavax.s32	r4, r3, q2, q0
[^>]*> ee95 4e03 	vmlsldav.s32	r4, r3, q2, q1
[^>]*> ee95 4e23 	vmlsldava.s32	r4, r3, q2, q1
[^>]*> ee95 5e03 	vmlsldavx.s32	r4, r3, q2, q1
[^>]*> ee95 5e23 	vmlsldavax.s32	r4, r3, q2, q1
[^>]*> ee95 4e05 	vmlsldav.s32	r4, r3, q2, q2
[^>]*> ee95 4e25 	vmlsldava.s32	r4, r3, q2, q2
[^>]*> ee95 5e05 	vmlsldavx.s32	r4, r3, q2, q2
[^>]*> ee95 5e25 	vmlsldavax.s32	r4, r3, q2, q2
[^>]*> ee95 4e09 	vmlsldav.s32	r4, r3, q2, q4
[^>]*> ee95 4e29 	vmlsldava.s32	r4, r3, q2, q4
[^>]*> ee95 5e09 	vmlsldavx.s32	r4, r3, q2, q4
[^>]*> ee95 5e29 	vmlsldavax.s32	r4, r3, q2, q4
[^>]*> ee95 4e0f 	vmlsldav.s32	r4, r3, q2, q7
[^>]*> ee95 4e2f 	vmlsldava.s32	r4, r3, q2, q7
[^>]*> ee95 5e0f 	vmlsldavx.s32	r4, r3, q2, q7
[^>]*> ee95 5e2f 	vmlsldavax.s32	r4, r3, q2, q7
[^>]*> ee99 4e01 	vmlsldav.s32	r4, r3, q4, q0
[^>]*> ee99 4e21 	vmlsldava.s32	r4, r3, q4, q0
[^>]*> ee99 5e01 	vmlsldavx.s32	r4, r3, q4, q0
[^>]*> ee99 5e21 	vmlsldavax.s32	r4, r3, q4, q0
[^>]*> ee99 4e03 	vmlsldav.s32	r4, r3, q4, q1
[^>]*> ee99 4e23 	vmlsldava.s32	r4, r3, q4, q1
[^>]*> ee99 5e03 	vmlsldavx.s32	r4, r3, q4, q1
[^>]*> ee99 5e23 	vmlsldavax.s32	r4, r3, q4, q1
[^>]*> ee99 4e05 	vmlsldav.s32	r4, r3, q4, q2
[^>]*> ee99 4e25 	vmlsldava.s32	r4, r3, q4, q2
[^>]*> ee99 5e05 	vmlsldavx.s32	r4, r3, q4, q2
[^>]*> ee99 5e25 	vmlsldavax.s32	r4, r3, q4, q2
[^>]*> ee99 4e09 	vmlsldav.s32	r4, r3, q4, q4
[^>]*> ee99 4e29 	vmlsldava.s32	r4, r3, q4, q4
[^>]*> ee99 5e09 	vmlsldavx.s32	r4, r3, q4, q4
[^>]*> ee99 5e29 	vmlsldavax.s32	r4, r3, q4, q4
[^>]*> ee99 4e0f 	vmlsldav.s32	r4, r3, q4, q7
[^>]*> ee99 4e2f 	vmlsldava.s32	r4, r3, q4, q7
[^>]*> ee99 5e0f 	vmlsldavx.s32	r4, r3, q4, q7
[^>]*> ee99 5e2f 	vmlsldavax.s32	r4, r3, q4, q7
[^>]*> ee9f 4e01 	vmlsldav.s32	r4, r3, q7, q0
[^>]*> ee9f 4e21 	vmlsldava.s32	r4, r3, q7, q0
[^>]*> ee9f 5e01 	vmlsldavx.s32	r4, r3, q7, q0
[^>]*> ee9f 5e21 	vmlsldavax.s32	r4, r3, q7, q0
[^>]*> ee9f 4e03 	vmlsldav.s32	r4, r3, q7, q1
[^>]*> ee9f 4e23 	vmlsldava.s32	r4, r3, q7, q1
[^>]*> ee9f 5e03 	vmlsldavx.s32	r4, r3, q7, q1
[^>]*> ee9f 5e23 	vmlsldavax.s32	r4, r3, q7, q1
[^>]*> ee9f 4e05 	vmlsldav.s32	r4, r3, q7, q2
[^>]*> ee9f 4e25 	vmlsldava.s32	r4, r3, q7, q2
[^>]*> ee9f 5e05 	vmlsldavx.s32	r4, r3, q7, q2
[^>]*> ee9f 5e25 	vmlsldavax.s32	r4, r3, q7, q2
[^>]*> ee9f 4e09 	vmlsldav.s32	r4, r3, q7, q4
[^>]*> ee9f 4e29 	vmlsldava.s32	r4, r3, q7, q4
[^>]*> ee9f 5e09 	vmlsldavx.s32	r4, r3, q7, q4
[^>]*> ee9f 5e29 	vmlsldavax.s32	r4, r3, q7, q4
[^>]*> ee9f 4e0f 	vmlsldav.s32	r4, r3, q7, q7
[^>]*> ee9f 4e2f 	vmlsldava.s32	r4, r3, q7, q7
[^>]*> ee9f 5e0f 	vmlsldavx.s32	r4, r3, q7, q7
[^>]*> ee9f 5e2f 	vmlsldavax.s32	r4, r3, q7, q7
[^>]*> eea1 4e01 	vmlsldav.s32	r4, r5, q0, q0
[^>]*> eea1 4e21 	vmlsldava.s32	r4, r5, q0, q0
[^>]*> eea1 5e01 	vmlsldavx.s32	r4, r5, q0, q0
[^>]*> eea1 5e21 	vmlsldavax.s32	r4, r5, q0, q0
[^>]*> eea1 4e03 	vmlsldav.s32	r4, r5, q0, q1
[^>]*> eea1 4e23 	vmlsldava.s32	r4, r5, q0, q1
[^>]*> eea1 5e03 	vmlsldavx.s32	r4, r5, q0, q1
[^>]*> eea1 5e23 	vmlsldavax.s32	r4, r5, q0, q1
[^>]*> eea1 4e05 	vmlsldav.s32	r4, r5, q0, q2
[^>]*> eea1 4e25 	vmlsldava.s32	r4, r5, q0, q2
[^>]*> eea1 5e05 	vmlsldavx.s32	r4, r5, q0, q2
[^>]*> eea1 5e25 	vmlsldavax.s32	r4, r5, q0, q2
[^>]*> eea1 4e09 	vmlsldav.s32	r4, r5, q0, q4
[^>]*> eea1 4e29 	vmlsldava.s32	r4, r5, q0, q4
[^>]*> eea1 5e09 	vmlsldavx.s32	r4, r5, q0, q4
[^>]*> eea1 5e29 	vmlsldavax.s32	r4, r5, q0, q4
[^>]*> eea1 4e0f 	vmlsldav.s32	r4, r5, q0, q7
[^>]*> eea1 4e2f 	vmlsldava.s32	r4, r5, q0, q7
[^>]*> eea1 5e0f 	vmlsldavx.s32	r4, r5, q0, q7
[^>]*> eea1 5e2f 	vmlsldavax.s32	r4, r5, q0, q7
[^>]*> eea3 4e01 	vmlsldav.s32	r4, r5, q1, q0
[^>]*> eea3 4e21 	vmlsldava.s32	r4, r5, q1, q0
[^>]*> eea3 5e01 	vmlsldavx.s32	r4, r5, q1, q0
[^>]*> eea3 5e21 	vmlsldavax.s32	r4, r5, q1, q0
[^>]*> eea3 4e03 	vmlsldav.s32	r4, r5, q1, q1
[^>]*> eea3 4e23 	vmlsldava.s32	r4, r5, q1, q1
[^>]*> eea3 5e03 	vmlsldavx.s32	r4, r5, q1, q1
[^>]*> eea3 5e23 	vmlsldavax.s32	r4, r5, q1, q1
[^>]*> eea3 4e05 	vmlsldav.s32	r4, r5, q1, q2
[^>]*> eea3 4e25 	vmlsldava.s32	r4, r5, q1, q2
[^>]*> eea3 5e05 	vmlsldavx.s32	r4, r5, q1, q2
[^>]*> eea3 5e25 	vmlsldavax.s32	r4, r5, q1, q2
[^>]*> eea3 4e09 	vmlsldav.s32	r4, r5, q1, q4
[^>]*> eea3 4e29 	vmlsldava.s32	r4, r5, q1, q4
[^>]*> eea3 5e09 	vmlsldavx.s32	r4, r5, q1, q4
[^>]*> eea3 5e29 	vmlsldavax.s32	r4, r5, q1, q4
[^>]*> eea3 4e0f 	vmlsldav.s32	r4, r5, q1, q7
[^>]*> eea3 4e2f 	vmlsldava.s32	r4, r5, q1, q7
[^>]*> eea3 5e0f 	vmlsldavx.s32	r4, r5, q1, q7
[^>]*> eea3 5e2f 	vmlsldavax.s32	r4, r5, q1, q7
[^>]*> eea5 4e01 	vmlsldav.s32	r4, r5, q2, q0
[^>]*> eea5 4e21 	vmlsldava.s32	r4, r5, q2, q0
[^>]*> eea5 5e01 	vmlsldavx.s32	r4, r5, q2, q0
[^>]*> eea5 5e21 	vmlsldavax.s32	r4, r5, q2, q0
[^>]*> eea5 4e03 	vmlsldav.s32	r4, r5, q2, q1
[^>]*> eea5 4e23 	vmlsldava.s32	r4, r5, q2, q1
[^>]*> eea5 5e03 	vmlsldavx.s32	r4, r5, q2, q1
[^>]*> eea5 5e23 	vmlsldavax.s32	r4, r5, q2, q1
[^>]*> eea5 4e05 	vmlsldav.s32	r4, r5, q2, q2
[^>]*> eea5 4e25 	vmlsldava.s32	r4, r5, q2, q2
[^>]*> eea5 5e05 	vmlsldavx.s32	r4, r5, q2, q2
[^>]*> eea5 5e25 	vmlsldavax.s32	r4, r5, q2, q2
[^>]*> eea5 4e09 	vmlsldav.s32	r4, r5, q2, q4
[^>]*> eea5 4e29 	vmlsldava.s32	r4, r5, q2, q4
[^>]*> eea5 5e09 	vmlsldavx.s32	r4, r5, q2, q4
[^>]*> eea5 5e29 	vmlsldavax.s32	r4, r5, q2, q4
[^>]*> eea5 4e0f 	vmlsldav.s32	r4, r5, q2, q7
[^>]*> eea5 4e2f 	vmlsldava.s32	r4, r5, q2, q7
[^>]*> eea5 5e0f 	vmlsldavx.s32	r4, r5, q2, q7
[^>]*> eea5 5e2f 	vmlsldavax.s32	r4, r5, q2, q7
[^>]*> eea9 4e01 	vmlsldav.s32	r4, r5, q4, q0
[^>]*> eea9 4e21 	vmlsldava.s32	r4, r5, q4, q0
[^>]*> eea9 5e01 	vmlsldavx.s32	r4, r5, q4, q0
[^>]*> eea9 5e21 	vmlsldavax.s32	r4, r5, q4, q0
[^>]*> eea9 4e03 	vmlsldav.s32	r4, r5, q4, q1
[^>]*> eea9 4e23 	vmlsldava.s32	r4, r5, q4, q1
[^>]*> eea9 5e03 	vmlsldavx.s32	r4, r5, q4, q1
[^>]*> eea9 5e23 	vmlsldavax.s32	r4, r5, q4, q1
[^>]*> eea9 4e05 	vmlsldav.s32	r4, r5, q4, q2
[^>]*> eea9 4e25 	vmlsldava.s32	r4, r5, q4, q2
[^>]*> eea9 5e05 	vmlsldavx.s32	r4, r5, q4, q2
[^>]*> eea9 5e25 	vmlsldavax.s32	r4, r5, q4, q2
[^>]*> eea9 4e09 	vmlsldav.s32	r4, r5, q4, q4
[^>]*> eea9 4e29 	vmlsldava.s32	r4, r5, q4, q4
[^>]*> eea9 5e09 	vmlsldavx.s32	r4, r5, q4, q4
[^>]*> eea9 5e29 	vmlsldavax.s32	r4, r5, q4, q4
[^>]*> eea9 4e0f 	vmlsldav.s32	r4, r5, q4, q7
[^>]*> eea9 4e2f 	vmlsldava.s32	r4, r5, q4, q7
[^>]*> eea9 5e0f 	vmlsldavx.s32	r4, r5, q4, q7
[^>]*> eea9 5e2f 	vmlsldavax.s32	r4, r5, q4, q7
[^>]*> eeaf 4e01 	vmlsldav.s32	r4, r5, q7, q0
[^>]*> eeaf 4e21 	vmlsldava.s32	r4, r5, q7, q0
[^>]*> eeaf 5e01 	vmlsldavx.s32	r4, r5, q7, q0
[^>]*> eeaf 5e21 	vmlsldavax.s32	r4, r5, q7, q0
[^>]*> eeaf 4e03 	vmlsldav.s32	r4, r5, q7, q1
[^>]*> eeaf 4e23 	vmlsldava.s32	r4, r5, q7, q1
[^>]*> eeaf 5e03 	vmlsldavx.s32	r4, r5, q7, q1
[^>]*> eeaf 5e23 	vmlsldavax.s32	r4, r5, q7, q1
[^>]*> eeaf 4e05 	vmlsldav.s32	r4, r5, q7, q2
[^>]*> eeaf 4e25 	vmlsldava.s32	r4, r5, q7, q2
[^>]*> eeaf 5e05 	vmlsldavx.s32	r4, r5, q7, q2
[^>]*> eeaf 5e25 	vmlsldavax.s32	r4, r5, q7, q2
[^>]*> eeaf 4e09 	vmlsldav.s32	r4, r5, q7, q4
[^>]*> eeaf 4e29 	vmlsldava.s32	r4, r5, q7, q4
[^>]*> eeaf 5e09 	vmlsldavx.s32	r4, r5, q7, q4
[^>]*> eeaf 5e29 	vmlsldavax.s32	r4, r5, q7, q4
[^>]*> eeaf 4e0f 	vmlsldav.s32	r4, r5, q7, q7
[^>]*> eeaf 4e2f 	vmlsldava.s32	r4, r5, q7, q7
[^>]*> eeaf 5e0f 	vmlsldavx.s32	r4, r5, q7, q7
[^>]*> eeaf 5e2f 	vmlsldavax.s32	r4, r5, q7, q7
[^>]*> eeb1 4e01 	vmlsldav.s32	r4, r7, q0, q0
[^>]*> eeb1 4e21 	vmlsldava.s32	r4, r7, q0, q0
[^>]*> eeb1 5e01 	vmlsldavx.s32	r4, r7, q0, q0
[^>]*> eeb1 5e21 	vmlsldavax.s32	r4, r7, q0, q0
[^>]*> eeb1 4e03 	vmlsldav.s32	r4, r7, q0, q1
[^>]*> eeb1 4e23 	vmlsldava.s32	r4, r7, q0, q1
[^>]*> eeb1 5e03 	vmlsldavx.s32	r4, r7, q0, q1
[^>]*> eeb1 5e23 	vmlsldavax.s32	r4, r7, q0, q1
[^>]*> eeb1 4e05 	vmlsldav.s32	r4, r7, q0, q2
[^>]*> eeb1 4e25 	vmlsldava.s32	r4, r7, q0, q2
[^>]*> eeb1 5e05 	vmlsldavx.s32	r4, r7, q0, q2
[^>]*> eeb1 5e25 	vmlsldavax.s32	r4, r7, q0, q2
[^>]*> eeb1 4e09 	vmlsldav.s32	r4, r7, q0, q4
[^>]*> eeb1 4e29 	vmlsldava.s32	r4, r7, q0, q4
[^>]*> eeb1 5e09 	vmlsldavx.s32	r4, r7, q0, q4
[^>]*> eeb1 5e29 	vmlsldavax.s32	r4, r7, q0, q4
[^>]*> eeb1 4e0f 	vmlsldav.s32	r4, r7, q0, q7
[^>]*> eeb1 4e2f 	vmlsldava.s32	r4, r7, q0, q7
[^>]*> eeb1 5e0f 	vmlsldavx.s32	r4, r7, q0, q7
[^>]*> eeb1 5e2f 	vmlsldavax.s32	r4, r7, q0, q7
[^>]*> eeb3 4e01 	vmlsldav.s32	r4, r7, q1, q0
[^>]*> eeb3 4e21 	vmlsldava.s32	r4, r7, q1, q0
[^>]*> eeb3 5e01 	vmlsldavx.s32	r4, r7, q1, q0
[^>]*> eeb3 5e21 	vmlsldavax.s32	r4, r7, q1, q0
[^>]*> eeb3 4e03 	vmlsldav.s32	r4, r7, q1, q1
[^>]*> eeb3 4e23 	vmlsldava.s32	r4, r7, q1, q1
[^>]*> eeb3 5e03 	vmlsldavx.s32	r4, r7, q1, q1
[^>]*> eeb3 5e23 	vmlsldavax.s32	r4, r7, q1, q1
[^>]*> eeb3 4e05 	vmlsldav.s32	r4, r7, q1, q2
[^>]*> eeb3 4e25 	vmlsldava.s32	r4, r7, q1, q2
[^>]*> eeb3 5e05 	vmlsldavx.s32	r4, r7, q1, q2
[^>]*> eeb3 5e25 	vmlsldavax.s32	r4, r7, q1, q2
[^>]*> eeb3 4e09 	vmlsldav.s32	r4, r7, q1, q4
[^>]*> eeb3 4e29 	vmlsldava.s32	r4, r7, q1, q4
[^>]*> eeb3 5e09 	vmlsldavx.s32	r4, r7, q1, q4
[^>]*> eeb3 5e29 	vmlsldavax.s32	r4, r7, q1, q4
[^>]*> eeb3 4e0f 	vmlsldav.s32	r4, r7, q1, q7
[^>]*> eeb3 4e2f 	vmlsldava.s32	r4, r7, q1, q7
[^>]*> eeb3 5e0f 	vmlsldavx.s32	r4, r7, q1, q7
[^>]*> eeb3 5e2f 	vmlsldavax.s32	r4, r7, q1, q7
[^>]*> eeb5 4e01 	vmlsldav.s32	r4, r7, q2, q0
[^>]*> eeb5 4e21 	vmlsldava.s32	r4, r7, q2, q0
[^>]*> eeb5 5e01 	vmlsldavx.s32	r4, r7, q2, q0
[^>]*> eeb5 5e21 	vmlsldavax.s32	r4, r7, q2, q0
[^>]*> eeb5 4e03 	vmlsldav.s32	r4, r7, q2, q1
[^>]*> eeb5 4e23 	vmlsldava.s32	r4, r7, q2, q1
[^>]*> eeb5 5e03 	vmlsldavx.s32	r4, r7, q2, q1
[^>]*> eeb5 5e23 	vmlsldavax.s32	r4, r7, q2, q1
[^>]*> eeb5 4e05 	vmlsldav.s32	r4, r7, q2, q2
[^>]*> eeb5 4e25 	vmlsldava.s32	r4, r7, q2, q2
[^>]*> eeb5 5e05 	vmlsldavx.s32	r4, r7, q2, q2
[^>]*> eeb5 5e25 	vmlsldavax.s32	r4, r7, q2, q2
[^>]*> eeb5 4e09 	vmlsldav.s32	r4, r7, q2, q4
[^>]*> eeb5 4e29 	vmlsldava.s32	r4, r7, q2, q4
[^>]*> eeb5 5e09 	vmlsldavx.s32	r4, r7, q2, q4
[^>]*> eeb5 5e29 	vmlsldavax.s32	r4, r7, q2, q4
[^>]*> eeb5 4e0f 	vmlsldav.s32	r4, r7, q2, q7
[^>]*> eeb5 4e2f 	vmlsldava.s32	r4, r7, q2, q7
[^>]*> eeb5 5e0f 	vmlsldavx.s32	r4, r7, q2, q7
[^>]*> eeb5 5e2f 	vmlsldavax.s32	r4, r7, q2, q7
[^>]*> eeb9 4e01 	vmlsldav.s32	r4, r7, q4, q0
[^>]*> eeb9 4e21 	vmlsldava.s32	r4, r7, q4, q0
[^>]*> eeb9 5e01 	vmlsldavx.s32	r4, r7, q4, q0
[^>]*> eeb9 5e21 	vmlsldavax.s32	r4, r7, q4, q0
[^>]*> eeb9 4e03 	vmlsldav.s32	r4, r7, q4, q1
[^>]*> eeb9 4e23 	vmlsldava.s32	r4, r7, q4, q1
[^>]*> eeb9 5e03 	vmlsldavx.s32	r4, r7, q4, q1
[^>]*> eeb9 5e23 	vmlsldavax.s32	r4, r7, q4, q1
[^>]*> eeb9 4e05 	vmlsldav.s32	r4, r7, q4, q2
[^>]*> eeb9 4e25 	vmlsldava.s32	r4, r7, q4, q2
[^>]*> eeb9 5e05 	vmlsldavx.s32	r4, r7, q4, q2
[^>]*> eeb9 5e25 	vmlsldavax.s32	r4, r7, q4, q2
[^>]*> eeb9 4e09 	vmlsldav.s32	r4, r7, q4, q4
[^>]*> eeb9 4e29 	vmlsldava.s32	r4, r7, q4, q4
[^>]*> eeb9 5e09 	vmlsldavx.s32	r4, r7, q4, q4
[^>]*> eeb9 5e29 	vmlsldavax.s32	r4, r7, q4, q4
[^>]*> eeb9 4e0f 	vmlsldav.s32	r4, r7, q4, q7
[^>]*> eeb9 4e2f 	vmlsldava.s32	r4, r7, q4, q7
[^>]*> eeb9 5e0f 	vmlsldavx.s32	r4, r7, q4, q7
[^>]*> eeb9 5e2f 	vmlsldavax.s32	r4, r7, q4, q7
[^>]*> eebf 4e01 	vmlsldav.s32	r4, r7, q7, q0
[^>]*> eebf 4e21 	vmlsldava.s32	r4, r7, q7, q0
[^>]*> eebf 5e01 	vmlsldavx.s32	r4, r7, q7, q0
[^>]*> eebf 5e21 	vmlsldavax.s32	r4, r7, q7, q0
[^>]*> eebf 4e03 	vmlsldav.s32	r4, r7, q7, q1
[^>]*> eebf 4e23 	vmlsldava.s32	r4, r7, q7, q1
[^>]*> eebf 5e03 	vmlsldavx.s32	r4, r7, q7, q1
[^>]*> eebf 5e23 	vmlsldavax.s32	r4, r7, q7, q1
[^>]*> eebf 4e05 	vmlsldav.s32	r4, r7, q7, q2
[^>]*> eebf 4e25 	vmlsldava.s32	r4, r7, q7, q2
[^>]*> eebf 5e05 	vmlsldavx.s32	r4, r7, q7, q2
[^>]*> eebf 5e25 	vmlsldavax.s32	r4, r7, q7, q2
[^>]*> eebf 4e09 	vmlsldav.s32	r4, r7, q7, q4
[^>]*> eebf 4e29 	vmlsldava.s32	r4, r7, q7, q4
[^>]*> eebf 5e09 	vmlsldavx.s32	r4, r7, q7, q4
[^>]*> eebf 5e29 	vmlsldavax.s32	r4, r7, q7, q4
[^>]*> eebf 4e0f 	vmlsldav.s32	r4, r7, q7, q7
[^>]*> eebf 4e2f 	vmlsldava.s32	r4, r7, q7, q7
[^>]*> eebf 5e0f 	vmlsldavx.s32	r4, r7, q7, q7
[^>]*> eebf 5e2f 	vmlsldavax.s32	r4, r7, q7, q7
[^>]*> eec1 4e01 	vmlsldav.s32	r4, r9, q0, q0
[^>]*> eec1 4e21 	vmlsldava.s32	r4, r9, q0, q0
[^>]*> eec1 5e01 	vmlsldavx.s32	r4, r9, q0, q0
[^>]*> eec1 5e21 	vmlsldavax.s32	r4, r9, q0, q0
[^>]*> eec1 4e03 	vmlsldav.s32	r4, r9, q0, q1
[^>]*> eec1 4e23 	vmlsldava.s32	r4, r9, q0, q1
[^>]*> eec1 5e03 	vmlsldavx.s32	r4, r9, q0, q1
[^>]*> eec1 5e23 	vmlsldavax.s32	r4, r9, q0, q1
[^>]*> eec1 4e05 	vmlsldav.s32	r4, r9, q0, q2
[^>]*> eec1 4e25 	vmlsldava.s32	r4, r9, q0, q2
[^>]*> eec1 5e05 	vmlsldavx.s32	r4, r9, q0, q2
[^>]*> eec1 5e25 	vmlsldavax.s32	r4, r9, q0, q2
[^>]*> eec1 4e09 	vmlsldav.s32	r4, r9, q0, q4
[^>]*> eec1 4e29 	vmlsldava.s32	r4, r9, q0, q4
[^>]*> eec1 5e09 	vmlsldavx.s32	r4, r9, q0, q4
[^>]*> eec1 5e29 	vmlsldavax.s32	r4, r9, q0, q4
[^>]*> eec1 4e0f 	vmlsldav.s32	r4, r9, q0, q7
[^>]*> eec1 4e2f 	vmlsldava.s32	r4, r9, q0, q7
[^>]*> eec1 5e0f 	vmlsldavx.s32	r4, r9, q0, q7
[^>]*> eec1 5e2f 	vmlsldavax.s32	r4, r9, q0, q7
[^>]*> eec3 4e01 	vmlsldav.s32	r4, r9, q1, q0
[^>]*> eec3 4e21 	vmlsldava.s32	r4, r9, q1, q0
[^>]*> eec3 5e01 	vmlsldavx.s32	r4, r9, q1, q0
[^>]*> eec3 5e21 	vmlsldavax.s32	r4, r9, q1, q0
[^>]*> eec3 4e03 	vmlsldav.s32	r4, r9, q1, q1
[^>]*> eec3 4e23 	vmlsldava.s32	r4, r9, q1, q1
[^>]*> eec3 5e03 	vmlsldavx.s32	r4, r9, q1, q1
[^>]*> eec3 5e23 	vmlsldavax.s32	r4, r9, q1, q1
[^>]*> eec3 4e05 	vmlsldav.s32	r4, r9, q1, q2
[^>]*> eec3 4e25 	vmlsldava.s32	r4, r9, q1, q2
[^>]*> eec3 5e05 	vmlsldavx.s32	r4, r9, q1, q2
[^>]*> eec3 5e25 	vmlsldavax.s32	r4, r9, q1, q2
[^>]*> eec3 4e09 	vmlsldav.s32	r4, r9, q1, q4
[^>]*> eec3 4e29 	vmlsldava.s32	r4, r9, q1, q4
[^>]*> eec3 5e09 	vmlsldavx.s32	r4, r9, q1, q4
[^>]*> eec3 5e29 	vmlsldavax.s32	r4, r9, q1, q4
[^>]*> eec3 4e0f 	vmlsldav.s32	r4, r9, q1, q7
[^>]*> eec3 4e2f 	vmlsldava.s32	r4, r9, q1, q7
[^>]*> eec3 5e0f 	vmlsldavx.s32	r4, r9, q1, q7
[^>]*> eec3 5e2f 	vmlsldavax.s32	r4, r9, q1, q7
[^>]*> eec5 4e01 	vmlsldav.s32	r4, r9, q2, q0
[^>]*> eec5 4e21 	vmlsldava.s32	r4, r9, q2, q0
[^>]*> eec5 5e01 	vmlsldavx.s32	r4, r9, q2, q0
[^>]*> eec5 5e21 	vmlsldavax.s32	r4, r9, q2, q0
[^>]*> eec5 4e03 	vmlsldav.s32	r4, r9, q2, q1
[^>]*> eec5 4e23 	vmlsldava.s32	r4, r9, q2, q1
[^>]*> eec5 5e03 	vmlsldavx.s32	r4, r9, q2, q1
[^>]*> eec5 5e23 	vmlsldavax.s32	r4, r9, q2, q1
[^>]*> eec5 4e05 	vmlsldav.s32	r4, r9, q2, q2
[^>]*> eec5 4e25 	vmlsldava.s32	r4, r9, q2, q2
[^>]*> eec5 5e05 	vmlsldavx.s32	r4, r9, q2, q2
[^>]*> eec5 5e25 	vmlsldavax.s32	r4, r9, q2, q2
[^>]*> eec5 4e09 	vmlsldav.s32	r4, r9, q2, q4
[^>]*> eec5 4e29 	vmlsldava.s32	r4, r9, q2, q4
[^>]*> eec5 5e09 	vmlsldavx.s32	r4, r9, q2, q4
[^>]*> eec5 5e29 	vmlsldavax.s32	r4, r9, q2, q4
[^>]*> eec5 4e0f 	vmlsldav.s32	r4, r9, q2, q7
[^>]*> eec5 4e2f 	vmlsldava.s32	r4, r9, q2, q7
[^>]*> eec5 5e0f 	vmlsldavx.s32	r4, r9, q2, q7
[^>]*> eec5 5e2f 	vmlsldavax.s32	r4, r9, q2, q7
[^>]*> eec9 4e01 	vmlsldav.s32	r4, r9, q4, q0
[^>]*> eec9 4e21 	vmlsldava.s32	r4, r9, q4, q0
[^>]*> eec9 5e01 	vmlsldavx.s32	r4, r9, q4, q0
[^>]*> eec9 5e21 	vmlsldavax.s32	r4, r9, q4, q0
[^>]*> eec9 4e03 	vmlsldav.s32	r4, r9, q4, q1
[^>]*> eec9 4e23 	vmlsldava.s32	r4, r9, q4, q1
[^>]*> eec9 5e03 	vmlsldavx.s32	r4, r9, q4, q1
[^>]*> eec9 5e23 	vmlsldavax.s32	r4, r9, q4, q1
[^>]*> eec9 4e05 	vmlsldav.s32	r4, r9, q4, q2
[^>]*> eec9 4e25 	vmlsldava.s32	r4, r9, q4, q2
[^>]*> eec9 5e05 	vmlsldavx.s32	r4, r9, q4, q2
[^>]*> eec9 5e25 	vmlsldavax.s32	r4, r9, q4, q2
[^>]*> eec9 4e09 	vmlsldav.s32	r4, r9, q4, q4
[^>]*> eec9 4e29 	vmlsldava.s32	r4, r9, q4, q4
[^>]*> eec9 5e09 	vmlsldavx.s32	r4, r9, q4, q4
[^>]*> eec9 5e29 	vmlsldavax.s32	r4, r9, q4, q4
[^>]*> eec9 4e0f 	vmlsldav.s32	r4, r9, q4, q7
[^>]*> eec9 4e2f 	vmlsldava.s32	r4, r9, q4, q7
[^>]*> eec9 5e0f 	vmlsldavx.s32	r4, r9, q4, q7
[^>]*> eec9 5e2f 	vmlsldavax.s32	r4, r9, q4, q7
[^>]*> eecf 4e01 	vmlsldav.s32	r4, r9, q7, q0
[^>]*> eecf 4e21 	vmlsldava.s32	r4, r9, q7, q0
[^>]*> eecf 5e01 	vmlsldavx.s32	r4, r9, q7, q0
[^>]*> eecf 5e21 	vmlsldavax.s32	r4, r9, q7, q0
[^>]*> eecf 4e03 	vmlsldav.s32	r4, r9, q7, q1
[^>]*> eecf 4e23 	vmlsldava.s32	r4, r9, q7, q1
[^>]*> eecf 5e03 	vmlsldavx.s32	r4, r9, q7, q1
[^>]*> eecf 5e23 	vmlsldavax.s32	r4, r9, q7, q1
[^>]*> eecf 4e05 	vmlsldav.s32	r4, r9, q7, q2
[^>]*> eecf 4e25 	vmlsldava.s32	r4, r9, q7, q2
[^>]*> eecf 5e05 	vmlsldavx.s32	r4, r9, q7, q2
[^>]*> eecf 5e25 	vmlsldavax.s32	r4, r9, q7, q2
[^>]*> eecf 4e09 	vmlsldav.s32	r4, r9, q7, q4
[^>]*> eecf 4e29 	vmlsldava.s32	r4, r9, q7, q4
[^>]*> eecf 5e09 	vmlsldavx.s32	r4, r9, q7, q4
[^>]*> eecf 5e29 	vmlsldavax.s32	r4, r9, q7, q4
[^>]*> eecf 4e0f 	vmlsldav.s32	r4, r9, q7, q7
[^>]*> eecf 4e2f 	vmlsldava.s32	r4, r9, q7, q7
[^>]*> eecf 5e0f 	vmlsldavx.s32	r4, r9, q7, q7
[^>]*> eecf 5e2f 	vmlsldavax.s32	r4, r9, q7, q7
[^>]*> eed1 4e01 	vmlsldav.s32	r4, fp, q0, q0
[^>]*> eed1 4e21 	vmlsldava.s32	r4, fp, q0, q0
[^>]*> eed1 5e01 	vmlsldavx.s32	r4, fp, q0, q0
[^>]*> eed1 5e21 	vmlsldavax.s32	r4, fp, q0, q0
[^>]*> eed1 4e03 	vmlsldav.s32	r4, fp, q0, q1
[^>]*> eed1 4e23 	vmlsldava.s32	r4, fp, q0, q1
[^>]*> eed1 5e03 	vmlsldavx.s32	r4, fp, q0, q1
[^>]*> eed1 5e23 	vmlsldavax.s32	r4, fp, q0, q1
[^>]*> eed1 4e05 	vmlsldav.s32	r4, fp, q0, q2
[^>]*> eed1 4e25 	vmlsldava.s32	r4, fp, q0, q2
[^>]*> eed1 5e05 	vmlsldavx.s32	r4, fp, q0, q2
[^>]*> eed1 5e25 	vmlsldavax.s32	r4, fp, q0, q2
[^>]*> eed1 4e09 	vmlsldav.s32	r4, fp, q0, q4
[^>]*> eed1 4e29 	vmlsldava.s32	r4, fp, q0, q4
[^>]*> eed1 5e09 	vmlsldavx.s32	r4, fp, q0, q4
[^>]*> eed1 5e29 	vmlsldavax.s32	r4, fp, q0, q4
[^>]*> eed1 4e0f 	vmlsldav.s32	r4, fp, q0, q7
[^>]*> eed1 4e2f 	vmlsldava.s32	r4, fp, q0, q7
[^>]*> eed1 5e0f 	vmlsldavx.s32	r4, fp, q0, q7
[^>]*> eed1 5e2f 	vmlsldavax.s32	r4, fp, q0, q7
[^>]*> eed3 4e01 	vmlsldav.s32	r4, fp, q1, q0
[^>]*> eed3 4e21 	vmlsldava.s32	r4, fp, q1, q0
[^>]*> eed3 5e01 	vmlsldavx.s32	r4, fp, q1, q0
[^>]*> eed3 5e21 	vmlsldavax.s32	r4, fp, q1, q0
[^>]*> eed3 4e03 	vmlsldav.s32	r4, fp, q1, q1
[^>]*> eed3 4e23 	vmlsldava.s32	r4, fp, q1, q1
[^>]*> eed3 5e03 	vmlsldavx.s32	r4, fp, q1, q1
[^>]*> eed3 5e23 	vmlsldavax.s32	r4, fp, q1, q1
[^>]*> eed3 4e05 	vmlsldav.s32	r4, fp, q1, q2
[^>]*> eed3 4e25 	vmlsldava.s32	r4, fp, q1, q2
[^>]*> eed3 5e05 	vmlsldavx.s32	r4, fp, q1, q2
[^>]*> eed3 5e25 	vmlsldavax.s32	r4, fp, q1, q2
[^>]*> eed3 4e09 	vmlsldav.s32	r4, fp, q1, q4
[^>]*> eed3 4e29 	vmlsldava.s32	r4, fp, q1, q4
[^>]*> eed3 5e09 	vmlsldavx.s32	r4, fp, q1, q4
[^>]*> eed3 5e29 	vmlsldavax.s32	r4, fp, q1, q4
[^>]*> eed3 4e0f 	vmlsldav.s32	r4, fp, q1, q7
[^>]*> eed3 4e2f 	vmlsldava.s32	r4, fp, q1, q7
[^>]*> eed3 5e0f 	vmlsldavx.s32	r4, fp, q1, q7
[^>]*> eed3 5e2f 	vmlsldavax.s32	r4, fp, q1, q7
[^>]*> eed5 4e01 	vmlsldav.s32	r4, fp, q2, q0
[^>]*> eed5 4e21 	vmlsldava.s32	r4, fp, q2, q0
[^>]*> eed5 5e01 	vmlsldavx.s32	r4, fp, q2, q0
[^>]*> eed5 5e21 	vmlsldavax.s32	r4, fp, q2, q0
[^>]*> eed5 4e03 	vmlsldav.s32	r4, fp, q2, q1
[^>]*> eed5 4e23 	vmlsldava.s32	r4, fp, q2, q1
[^>]*> eed5 5e03 	vmlsldavx.s32	r4, fp, q2, q1
[^>]*> eed5 5e23 	vmlsldavax.s32	r4, fp, q2, q1
[^>]*> eed5 4e05 	vmlsldav.s32	r4, fp, q2, q2
[^>]*> eed5 4e25 	vmlsldava.s32	r4, fp, q2, q2
[^>]*> eed5 5e05 	vmlsldavx.s32	r4, fp, q2, q2
[^>]*> eed5 5e25 	vmlsldavax.s32	r4, fp, q2, q2
[^>]*> eed5 4e09 	vmlsldav.s32	r4, fp, q2, q4
[^>]*> eed5 4e29 	vmlsldava.s32	r4, fp, q2, q4
[^>]*> eed5 5e09 	vmlsldavx.s32	r4, fp, q2, q4
[^>]*> eed5 5e29 	vmlsldavax.s32	r4, fp, q2, q4
[^>]*> eed5 4e0f 	vmlsldav.s32	r4, fp, q2, q7
[^>]*> eed5 4e2f 	vmlsldava.s32	r4, fp, q2, q7
[^>]*> eed5 5e0f 	vmlsldavx.s32	r4, fp, q2, q7
[^>]*> eed5 5e2f 	vmlsldavax.s32	r4, fp, q2, q7
[^>]*> eed9 4e01 	vmlsldav.s32	r4, fp, q4, q0
[^>]*> eed9 4e21 	vmlsldava.s32	r4, fp, q4, q0
[^>]*> eed9 5e01 	vmlsldavx.s32	r4, fp, q4, q0
[^>]*> eed9 5e21 	vmlsldavax.s32	r4, fp, q4, q0
[^>]*> eed9 4e03 	vmlsldav.s32	r4, fp, q4, q1
[^>]*> eed9 4e23 	vmlsldava.s32	r4, fp, q4, q1
[^>]*> eed9 5e03 	vmlsldavx.s32	r4, fp, q4, q1
[^>]*> eed9 5e23 	vmlsldavax.s32	r4, fp, q4, q1
[^>]*> eed9 4e05 	vmlsldav.s32	r4, fp, q4, q2
[^>]*> eed9 4e25 	vmlsldava.s32	r4, fp, q4, q2
[^>]*> eed9 5e05 	vmlsldavx.s32	r4, fp, q4, q2
[^>]*> eed9 5e25 	vmlsldavax.s32	r4, fp, q4, q2
[^>]*> eed9 4e09 	vmlsldav.s32	r4, fp, q4, q4
[^>]*> eed9 4e29 	vmlsldava.s32	r4, fp, q4, q4
[^>]*> eed9 5e09 	vmlsldavx.s32	r4, fp, q4, q4
[^>]*> eed9 5e29 	vmlsldavax.s32	r4, fp, q4, q4
[^>]*> eed9 4e0f 	vmlsldav.s32	r4, fp, q4, q7
[^>]*> eed9 4e2f 	vmlsldava.s32	r4, fp, q4, q7
[^>]*> eed9 5e0f 	vmlsldavx.s32	r4, fp, q4, q7
[^>]*> eed9 5e2f 	vmlsldavax.s32	r4, fp, q4, q7
[^>]*> eedf 4e01 	vmlsldav.s32	r4, fp, q7, q0
[^>]*> eedf 4e21 	vmlsldava.s32	r4, fp, q7, q0
[^>]*> eedf 5e01 	vmlsldavx.s32	r4, fp, q7, q0
[^>]*> eedf 5e21 	vmlsldavax.s32	r4, fp, q7, q0
[^>]*> eedf 4e03 	vmlsldav.s32	r4, fp, q7, q1
[^>]*> eedf 4e23 	vmlsldava.s32	r4, fp, q7, q1
[^>]*> eedf 5e03 	vmlsldavx.s32	r4, fp, q7, q1
[^>]*> eedf 5e23 	vmlsldavax.s32	r4, fp, q7, q1
[^>]*> eedf 4e05 	vmlsldav.s32	r4, fp, q7, q2
[^>]*> eedf 4e25 	vmlsldava.s32	r4, fp, q7, q2
[^>]*> eedf 5e05 	vmlsldavx.s32	r4, fp, q7, q2
[^>]*> eedf 5e25 	vmlsldavax.s32	r4, fp, q7, q2
[^>]*> eedf 4e09 	vmlsldav.s32	r4, fp, q7, q4
[^>]*> eedf 4e29 	vmlsldava.s32	r4, fp, q7, q4
[^>]*> eedf 5e09 	vmlsldavx.s32	r4, fp, q7, q4
[^>]*> eedf 5e29 	vmlsldavax.s32	r4, fp, q7, q4
[^>]*> eedf 4e0f 	vmlsldav.s32	r4, fp, q7, q7
[^>]*> eedf 4e2f 	vmlsldava.s32	r4, fp, q7, q7
[^>]*> eedf 5e0f 	vmlsldavx.s32	r4, fp, q7, q7
[^>]*> eedf 5e2f 	vmlsldavax.s32	r4, fp, q7, q7
[^>]*> ee81 8e01 	vmlsldav.s32	r8, r1, q0, q0
[^>]*> ee81 8e21 	vmlsldava.s32	r8, r1, q0, q0
[^>]*> ee81 9e01 	vmlsldavx.s32	r8, r1, q0, q0
[^>]*> ee81 9e21 	vmlsldavax.s32	r8, r1, q0, q0
[^>]*> ee81 8e03 	vmlsldav.s32	r8, r1, q0, q1
[^>]*> ee81 8e23 	vmlsldava.s32	r8, r1, q0, q1
[^>]*> ee81 9e03 	vmlsldavx.s32	r8, r1, q0, q1
[^>]*> ee81 9e23 	vmlsldavax.s32	r8, r1, q0, q1
[^>]*> ee81 8e05 	vmlsldav.s32	r8, r1, q0, q2
[^>]*> ee81 8e25 	vmlsldava.s32	r8, r1, q0, q2
[^>]*> ee81 9e05 	vmlsldavx.s32	r8, r1, q0, q2
[^>]*> ee81 9e25 	vmlsldavax.s32	r8, r1, q0, q2
[^>]*> ee81 8e09 	vmlsldav.s32	r8, r1, q0, q4
[^>]*> ee81 8e29 	vmlsldava.s32	r8, r1, q0, q4
[^>]*> ee81 9e09 	vmlsldavx.s32	r8, r1, q0, q4
[^>]*> ee81 9e29 	vmlsldavax.s32	r8, r1, q0, q4
[^>]*> ee81 8e0f 	vmlsldav.s32	r8, r1, q0, q7
[^>]*> ee81 8e2f 	vmlsldava.s32	r8, r1, q0, q7
[^>]*> ee81 9e0f 	vmlsldavx.s32	r8, r1, q0, q7
[^>]*> ee81 9e2f 	vmlsldavax.s32	r8, r1, q0, q7
[^>]*> ee83 8e01 	vmlsldav.s32	r8, r1, q1, q0
[^>]*> ee83 8e21 	vmlsldava.s32	r8, r1, q1, q0
[^>]*> ee83 9e01 	vmlsldavx.s32	r8, r1, q1, q0
[^>]*> ee83 9e21 	vmlsldavax.s32	r8, r1, q1, q0
[^>]*> ee83 8e03 	vmlsldav.s32	r8, r1, q1, q1
[^>]*> ee83 8e23 	vmlsldava.s32	r8, r1, q1, q1
[^>]*> ee83 9e03 	vmlsldavx.s32	r8, r1, q1, q1
[^>]*> ee83 9e23 	vmlsldavax.s32	r8, r1, q1, q1
[^>]*> ee83 8e05 	vmlsldav.s32	r8, r1, q1, q2
[^>]*> ee83 8e25 	vmlsldava.s32	r8, r1, q1, q2
[^>]*> ee83 9e05 	vmlsldavx.s32	r8, r1, q1, q2
[^>]*> ee83 9e25 	vmlsldavax.s32	r8, r1, q1, q2
[^>]*> ee83 8e09 	vmlsldav.s32	r8, r1, q1, q4
[^>]*> ee83 8e29 	vmlsldava.s32	r8, r1, q1, q4
[^>]*> ee83 9e09 	vmlsldavx.s32	r8, r1, q1, q4
[^>]*> ee83 9e29 	vmlsldavax.s32	r8, r1, q1, q4
[^>]*> ee83 8e0f 	vmlsldav.s32	r8, r1, q1, q7
[^>]*> ee83 8e2f 	vmlsldava.s32	r8, r1, q1, q7
[^>]*> ee83 9e0f 	vmlsldavx.s32	r8, r1, q1, q7
[^>]*> ee83 9e2f 	vmlsldavax.s32	r8, r1, q1, q7
[^>]*> ee85 8e01 	vmlsldav.s32	r8, r1, q2, q0
[^>]*> ee85 8e21 	vmlsldava.s32	r8, r1, q2, q0
[^>]*> ee85 9e01 	vmlsldavx.s32	r8, r1, q2, q0
[^>]*> ee85 9e21 	vmlsldavax.s32	r8, r1, q2, q0
[^>]*> ee85 8e03 	vmlsldav.s32	r8, r1, q2, q1
[^>]*> ee85 8e23 	vmlsldava.s32	r8, r1, q2, q1
[^>]*> ee85 9e03 	vmlsldavx.s32	r8, r1, q2, q1
[^>]*> ee85 9e23 	vmlsldavax.s32	r8, r1, q2, q1
[^>]*> ee85 8e05 	vmlsldav.s32	r8, r1, q2, q2
[^>]*> ee85 8e25 	vmlsldava.s32	r8, r1, q2, q2
[^>]*> ee85 9e05 	vmlsldavx.s32	r8, r1, q2, q2
[^>]*> ee85 9e25 	vmlsldavax.s32	r8, r1, q2, q2
[^>]*> ee85 8e09 	vmlsldav.s32	r8, r1, q2, q4
[^>]*> ee85 8e29 	vmlsldava.s32	r8, r1, q2, q4
[^>]*> ee85 9e09 	vmlsldavx.s32	r8, r1, q2, q4
[^>]*> ee85 9e29 	vmlsldavax.s32	r8, r1, q2, q4
[^>]*> ee85 8e0f 	vmlsldav.s32	r8, r1, q2, q7
[^>]*> ee85 8e2f 	vmlsldava.s32	r8, r1, q2, q7
[^>]*> ee85 9e0f 	vmlsldavx.s32	r8, r1, q2, q7
[^>]*> ee85 9e2f 	vmlsldavax.s32	r8, r1, q2, q7
[^>]*> ee89 8e01 	vmlsldav.s32	r8, r1, q4, q0
[^>]*> ee89 8e21 	vmlsldava.s32	r8, r1, q4, q0
[^>]*> ee89 9e01 	vmlsldavx.s32	r8, r1, q4, q0
[^>]*> ee89 9e21 	vmlsldavax.s32	r8, r1, q4, q0
[^>]*> ee89 8e03 	vmlsldav.s32	r8, r1, q4, q1
[^>]*> ee89 8e23 	vmlsldava.s32	r8, r1, q4, q1
[^>]*> ee89 9e03 	vmlsldavx.s32	r8, r1, q4, q1
[^>]*> ee89 9e23 	vmlsldavax.s32	r8, r1, q4, q1
[^>]*> ee89 8e05 	vmlsldav.s32	r8, r1, q4, q2
[^>]*> ee89 8e25 	vmlsldava.s32	r8, r1, q4, q2
[^>]*> ee89 9e05 	vmlsldavx.s32	r8, r1, q4, q2
[^>]*> ee89 9e25 	vmlsldavax.s32	r8, r1, q4, q2
[^>]*> ee89 8e09 	vmlsldav.s32	r8, r1, q4, q4
[^>]*> ee89 8e29 	vmlsldava.s32	r8, r1, q4, q4
[^>]*> ee89 9e09 	vmlsldavx.s32	r8, r1, q4, q4
[^>]*> ee89 9e29 	vmlsldavax.s32	r8, r1, q4, q4
[^>]*> ee89 8e0f 	vmlsldav.s32	r8, r1, q4, q7
[^>]*> ee89 8e2f 	vmlsldava.s32	r8, r1, q4, q7
[^>]*> ee89 9e0f 	vmlsldavx.s32	r8, r1, q4, q7
[^>]*> ee89 9e2f 	vmlsldavax.s32	r8, r1, q4, q7
[^>]*> ee8f 8e01 	vmlsldav.s32	r8, r1, q7, q0
[^>]*> ee8f 8e21 	vmlsldava.s32	r8, r1, q7, q0
[^>]*> ee8f 9e01 	vmlsldavx.s32	r8, r1, q7, q0
[^>]*> ee8f 9e21 	vmlsldavax.s32	r8, r1, q7, q0
[^>]*> ee8f 8e03 	vmlsldav.s32	r8, r1, q7, q1
[^>]*> ee8f 8e23 	vmlsldava.s32	r8, r1, q7, q1
[^>]*> ee8f 9e03 	vmlsldavx.s32	r8, r1, q7, q1
[^>]*> ee8f 9e23 	vmlsldavax.s32	r8, r1, q7, q1
[^>]*> ee8f 8e05 	vmlsldav.s32	r8, r1, q7, q2
[^>]*> ee8f 8e25 	vmlsldava.s32	r8, r1, q7, q2
[^>]*> ee8f 9e05 	vmlsldavx.s32	r8, r1, q7, q2
[^>]*> ee8f 9e25 	vmlsldavax.s32	r8, r1, q7, q2
[^>]*> ee8f 8e09 	vmlsldav.s32	r8, r1, q7, q4
[^>]*> ee8f 8e29 	vmlsldava.s32	r8, r1, q7, q4
[^>]*> ee8f 9e09 	vmlsldavx.s32	r8, r1, q7, q4
[^>]*> ee8f 9e29 	vmlsldavax.s32	r8, r1, q7, q4
[^>]*> ee8f 8e0f 	vmlsldav.s32	r8, r1, q7, q7
[^>]*> ee8f 8e2f 	vmlsldava.s32	r8, r1, q7, q7
[^>]*> ee8f 9e0f 	vmlsldavx.s32	r8, r1, q7, q7
[^>]*> ee8f 9e2f 	vmlsldavax.s32	r8, r1, q7, q7
[^>]*> ee91 8e01 	vmlsldav.s32	r8, r3, q0, q0
[^>]*> ee91 8e21 	vmlsldava.s32	r8, r3, q0, q0
[^>]*> ee91 9e01 	vmlsldavx.s32	r8, r3, q0, q0
[^>]*> ee91 9e21 	vmlsldavax.s32	r8, r3, q0, q0
[^>]*> ee91 8e03 	vmlsldav.s32	r8, r3, q0, q1
[^>]*> ee91 8e23 	vmlsldava.s32	r8, r3, q0, q1
[^>]*> ee91 9e03 	vmlsldavx.s32	r8, r3, q0, q1
[^>]*> ee91 9e23 	vmlsldavax.s32	r8, r3, q0, q1
[^>]*> ee91 8e05 	vmlsldav.s32	r8, r3, q0, q2
[^>]*> ee91 8e25 	vmlsldava.s32	r8, r3, q0, q2
[^>]*> ee91 9e05 	vmlsldavx.s32	r8, r3, q0, q2
[^>]*> ee91 9e25 	vmlsldavax.s32	r8, r3, q0, q2
[^>]*> ee91 8e09 	vmlsldav.s32	r8, r3, q0, q4
[^>]*> ee91 8e29 	vmlsldava.s32	r8, r3, q0, q4
[^>]*> ee91 9e09 	vmlsldavx.s32	r8, r3, q0, q4
[^>]*> ee91 9e29 	vmlsldavax.s32	r8, r3, q0, q4
[^>]*> ee91 8e0f 	vmlsldav.s32	r8, r3, q0, q7
[^>]*> ee91 8e2f 	vmlsldava.s32	r8, r3, q0, q7
[^>]*> ee91 9e0f 	vmlsldavx.s32	r8, r3, q0, q7
[^>]*> ee91 9e2f 	vmlsldavax.s32	r8, r3, q0, q7
[^>]*> ee93 8e01 	vmlsldav.s32	r8, r3, q1, q0
[^>]*> ee93 8e21 	vmlsldava.s32	r8, r3, q1, q0
[^>]*> ee93 9e01 	vmlsldavx.s32	r8, r3, q1, q0
[^>]*> ee93 9e21 	vmlsldavax.s32	r8, r3, q1, q0
[^>]*> ee93 8e03 	vmlsldav.s32	r8, r3, q1, q1
[^>]*> ee93 8e23 	vmlsldava.s32	r8, r3, q1, q1
[^>]*> ee93 9e03 	vmlsldavx.s32	r8, r3, q1, q1
[^>]*> ee93 9e23 	vmlsldavax.s32	r8, r3, q1, q1
[^>]*> ee93 8e05 	vmlsldav.s32	r8, r3, q1, q2
[^>]*> ee93 8e25 	vmlsldava.s32	r8, r3, q1, q2
[^>]*> ee93 9e05 	vmlsldavx.s32	r8, r3, q1, q2
[^>]*> ee93 9e25 	vmlsldavax.s32	r8, r3, q1, q2
[^>]*> ee93 8e09 	vmlsldav.s32	r8, r3, q1, q4
[^>]*> ee93 8e29 	vmlsldava.s32	r8, r3, q1, q4
[^>]*> ee93 9e09 	vmlsldavx.s32	r8, r3, q1, q4
[^>]*> ee93 9e29 	vmlsldavax.s32	r8, r3, q1, q4
[^>]*> ee93 8e0f 	vmlsldav.s32	r8, r3, q1, q7
[^>]*> ee93 8e2f 	vmlsldava.s32	r8, r3, q1, q7
[^>]*> ee93 9e0f 	vmlsldavx.s32	r8, r3, q1, q7
[^>]*> ee93 9e2f 	vmlsldavax.s32	r8, r3, q1, q7
[^>]*> ee95 8e01 	vmlsldav.s32	r8, r3, q2, q0
[^>]*> ee95 8e21 	vmlsldava.s32	r8, r3, q2, q0
[^>]*> ee95 9e01 	vmlsldavx.s32	r8, r3, q2, q0
[^>]*> ee95 9e21 	vmlsldavax.s32	r8, r3, q2, q0
[^>]*> ee95 8e03 	vmlsldav.s32	r8, r3, q2, q1
[^>]*> ee95 8e23 	vmlsldava.s32	r8, r3, q2, q1
[^>]*> ee95 9e03 	vmlsldavx.s32	r8, r3, q2, q1
[^>]*> ee95 9e23 	vmlsldavax.s32	r8, r3, q2, q1
[^>]*> ee95 8e05 	vmlsldav.s32	r8, r3, q2, q2
[^>]*> ee95 8e25 	vmlsldava.s32	r8, r3, q2, q2
[^>]*> ee95 9e05 	vmlsldavx.s32	r8, r3, q2, q2
[^>]*> ee95 9e25 	vmlsldavax.s32	r8, r3, q2, q2
[^>]*> ee95 8e09 	vmlsldav.s32	r8, r3, q2, q4
[^>]*> ee95 8e29 	vmlsldava.s32	r8, r3, q2, q4
[^>]*> ee95 9e09 	vmlsldavx.s32	r8, r3, q2, q4
[^>]*> ee95 9e29 	vmlsldavax.s32	r8, r3, q2, q4
[^>]*> ee95 8e0f 	vmlsldav.s32	r8, r3, q2, q7
[^>]*> ee95 8e2f 	vmlsldava.s32	r8, r3, q2, q7
[^>]*> ee95 9e0f 	vmlsldavx.s32	r8, r3, q2, q7
[^>]*> ee95 9e2f 	vmlsldavax.s32	r8, r3, q2, q7
[^>]*> ee99 8e01 	vmlsldav.s32	r8, r3, q4, q0
[^>]*> ee99 8e21 	vmlsldava.s32	r8, r3, q4, q0
[^>]*> ee99 9e01 	vmlsldavx.s32	r8, r3, q4, q0
[^>]*> ee99 9e21 	vmlsldavax.s32	r8, r3, q4, q0
[^>]*> ee99 8e03 	vmlsldav.s32	r8, r3, q4, q1
[^>]*> ee99 8e23 	vmlsldava.s32	r8, r3, q4, q1
[^>]*> ee99 9e03 	vmlsldavx.s32	r8, r3, q4, q1
[^>]*> ee99 9e23 	vmlsldavax.s32	r8, r3, q4, q1
[^>]*> ee99 8e05 	vmlsldav.s32	r8, r3, q4, q2
[^>]*> ee99 8e25 	vmlsldava.s32	r8, r3, q4, q2
[^>]*> ee99 9e05 	vmlsldavx.s32	r8, r3, q4, q2
[^>]*> ee99 9e25 	vmlsldavax.s32	r8, r3, q4, q2
[^>]*> ee99 8e09 	vmlsldav.s32	r8, r3, q4, q4
[^>]*> ee99 8e29 	vmlsldava.s32	r8, r3, q4, q4
[^>]*> ee99 9e09 	vmlsldavx.s32	r8, r3, q4, q4
[^>]*> ee99 9e29 	vmlsldavax.s32	r8, r3, q4, q4
[^>]*> ee99 8e0f 	vmlsldav.s32	r8, r3, q4, q7
[^>]*> ee99 8e2f 	vmlsldava.s32	r8, r3, q4, q7
[^>]*> ee99 9e0f 	vmlsldavx.s32	r8, r3, q4, q7
[^>]*> ee99 9e2f 	vmlsldavax.s32	r8, r3, q4, q7
[^>]*> ee9f 8e01 	vmlsldav.s32	r8, r3, q7, q0
[^>]*> ee9f 8e21 	vmlsldava.s32	r8, r3, q7, q0
[^>]*> ee9f 9e01 	vmlsldavx.s32	r8, r3, q7, q0
[^>]*> ee9f 9e21 	vmlsldavax.s32	r8, r3, q7, q0
[^>]*> ee9f 8e03 	vmlsldav.s32	r8, r3, q7, q1
[^>]*> ee9f 8e23 	vmlsldava.s32	r8, r3, q7, q1
[^>]*> ee9f 9e03 	vmlsldavx.s32	r8, r3, q7, q1
[^>]*> ee9f 9e23 	vmlsldavax.s32	r8, r3, q7, q1
[^>]*> ee9f 8e05 	vmlsldav.s32	r8, r3, q7, q2
[^>]*> ee9f 8e25 	vmlsldava.s32	r8, r3, q7, q2
[^>]*> ee9f 9e05 	vmlsldavx.s32	r8, r3, q7, q2
[^>]*> ee9f 9e25 	vmlsldavax.s32	r8, r3, q7, q2
[^>]*> ee9f 8e09 	vmlsldav.s32	r8, r3, q7, q4
[^>]*> ee9f 8e29 	vmlsldava.s32	r8, r3, q7, q4
[^>]*> ee9f 9e09 	vmlsldavx.s32	r8, r3, q7, q4
[^>]*> ee9f 9e29 	vmlsldavax.s32	r8, r3, q7, q4
[^>]*> ee9f 8e0f 	vmlsldav.s32	r8, r3, q7, q7
[^>]*> ee9f 8e2f 	vmlsldava.s32	r8, r3, q7, q7
[^>]*> ee9f 9e0f 	vmlsldavx.s32	r8, r3, q7, q7
[^>]*> ee9f 9e2f 	vmlsldavax.s32	r8, r3, q7, q7
[^>]*> eea1 8e01 	vmlsldav.s32	r8, r5, q0, q0
[^>]*> eea1 8e21 	vmlsldava.s32	r8, r5, q0, q0
[^>]*> eea1 9e01 	vmlsldavx.s32	r8, r5, q0, q0
[^>]*> eea1 9e21 	vmlsldavax.s32	r8, r5, q0, q0
[^>]*> eea1 8e03 	vmlsldav.s32	r8, r5, q0, q1
[^>]*> eea1 8e23 	vmlsldava.s32	r8, r5, q0, q1
[^>]*> eea1 9e03 	vmlsldavx.s32	r8, r5, q0, q1
[^>]*> eea1 9e23 	vmlsldavax.s32	r8, r5, q0, q1
[^>]*> eea1 8e05 	vmlsldav.s32	r8, r5, q0, q2
[^>]*> eea1 8e25 	vmlsldava.s32	r8, r5, q0, q2
[^>]*> eea1 9e05 	vmlsldavx.s32	r8, r5, q0, q2
[^>]*> eea1 9e25 	vmlsldavax.s32	r8, r5, q0, q2
[^>]*> eea1 8e09 	vmlsldav.s32	r8, r5, q0, q4
[^>]*> eea1 8e29 	vmlsldava.s32	r8, r5, q0, q4
[^>]*> eea1 9e09 	vmlsldavx.s32	r8, r5, q0, q4
[^>]*> eea1 9e29 	vmlsldavax.s32	r8, r5, q0, q4
[^>]*> eea1 8e0f 	vmlsldav.s32	r8, r5, q0, q7
[^>]*> eea1 8e2f 	vmlsldava.s32	r8, r5, q0, q7
[^>]*> eea1 9e0f 	vmlsldavx.s32	r8, r5, q0, q7
[^>]*> eea1 9e2f 	vmlsldavax.s32	r8, r5, q0, q7
[^>]*> eea3 8e01 	vmlsldav.s32	r8, r5, q1, q0
[^>]*> eea3 8e21 	vmlsldava.s32	r8, r5, q1, q0
[^>]*> eea3 9e01 	vmlsldavx.s32	r8, r5, q1, q0
[^>]*> eea3 9e21 	vmlsldavax.s32	r8, r5, q1, q0
[^>]*> eea3 8e03 	vmlsldav.s32	r8, r5, q1, q1
[^>]*> eea3 8e23 	vmlsldava.s32	r8, r5, q1, q1
[^>]*> eea3 9e03 	vmlsldavx.s32	r8, r5, q1, q1
[^>]*> eea3 9e23 	vmlsldavax.s32	r8, r5, q1, q1
[^>]*> eea3 8e05 	vmlsldav.s32	r8, r5, q1, q2
[^>]*> eea3 8e25 	vmlsldava.s32	r8, r5, q1, q2
[^>]*> eea3 9e05 	vmlsldavx.s32	r8, r5, q1, q2
[^>]*> eea3 9e25 	vmlsldavax.s32	r8, r5, q1, q2
[^>]*> eea3 8e09 	vmlsldav.s32	r8, r5, q1, q4
[^>]*> eea3 8e29 	vmlsldava.s32	r8, r5, q1, q4
[^>]*> eea3 9e09 	vmlsldavx.s32	r8, r5, q1, q4
[^>]*> eea3 9e29 	vmlsldavax.s32	r8, r5, q1, q4
[^>]*> eea3 8e0f 	vmlsldav.s32	r8, r5, q1, q7
[^>]*> eea3 8e2f 	vmlsldava.s32	r8, r5, q1, q7
[^>]*> eea3 9e0f 	vmlsldavx.s32	r8, r5, q1, q7
[^>]*> eea3 9e2f 	vmlsldavax.s32	r8, r5, q1, q7
[^>]*> eea5 8e01 	vmlsldav.s32	r8, r5, q2, q0
[^>]*> eea5 8e21 	vmlsldava.s32	r8, r5, q2, q0
[^>]*> eea5 9e01 	vmlsldavx.s32	r8, r5, q2, q0
[^>]*> eea5 9e21 	vmlsldavax.s32	r8, r5, q2, q0
[^>]*> eea5 8e03 	vmlsldav.s32	r8, r5, q2, q1
[^>]*> eea5 8e23 	vmlsldava.s32	r8, r5, q2, q1
[^>]*> eea5 9e03 	vmlsldavx.s32	r8, r5, q2, q1
[^>]*> eea5 9e23 	vmlsldavax.s32	r8, r5, q2, q1
[^>]*> eea5 8e05 	vmlsldav.s32	r8, r5, q2, q2
[^>]*> eea5 8e25 	vmlsldava.s32	r8, r5, q2, q2
[^>]*> eea5 9e05 	vmlsldavx.s32	r8, r5, q2, q2
[^>]*> eea5 9e25 	vmlsldavax.s32	r8, r5, q2, q2
[^>]*> eea5 8e09 	vmlsldav.s32	r8, r5, q2, q4
[^>]*> eea5 8e29 	vmlsldava.s32	r8, r5, q2, q4
[^>]*> eea5 9e09 	vmlsldavx.s32	r8, r5, q2, q4
[^>]*> eea5 9e29 	vmlsldavax.s32	r8, r5, q2, q4
[^>]*> eea5 8e0f 	vmlsldav.s32	r8, r5, q2, q7
[^>]*> eea5 8e2f 	vmlsldava.s32	r8, r5, q2, q7
[^>]*> eea5 9e0f 	vmlsldavx.s32	r8, r5, q2, q7
[^>]*> eea5 9e2f 	vmlsldavax.s32	r8, r5, q2, q7
[^>]*> eea9 8e01 	vmlsldav.s32	r8, r5, q4, q0
[^>]*> eea9 8e21 	vmlsldava.s32	r8, r5, q4, q0
[^>]*> eea9 9e01 	vmlsldavx.s32	r8, r5, q4, q0
[^>]*> eea9 9e21 	vmlsldavax.s32	r8, r5, q4, q0
[^>]*> eea9 8e03 	vmlsldav.s32	r8, r5, q4, q1
[^>]*> eea9 8e23 	vmlsldava.s32	r8, r5, q4, q1
[^>]*> eea9 9e03 	vmlsldavx.s32	r8, r5, q4, q1
[^>]*> eea9 9e23 	vmlsldavax.s32	r8, r5, q4, q1
[^>]*> eea9 8e05 	vmlsldav.s32	r8, r5, q4, q2
[^>]*> eea9 8e25 	vmlsldava.s32	r8, r5, q4, q2
[^>]*> eea9 9e05 	vmlsldavx.s32	r8, r5, q4, q2
[^>]*> eea9 9e25 	vmlsldavax.s32	r8, r5, q4, q2
[^>]*> eea9 8e09 	vmlsldav.s32	r8, r5, q4, q4
[^>]*> eea9 8e29 	vmlsldava.s32	r8, r5, q4, q4
[^>]*> eea9 9e09 	vmlsldavx.s32	r8, r5, q4, q4
[^>]*> eea9 9e29 	vmlsldavax.s32	r8, r5, q4, q4
[^>]*> eea9 8e0f 	vmlsldav.s32	r8, r5, q4, q7
[^>]*> eea9 8e2f 	vmlsldava.s32	r8, r5, q4, q7
[^>]*> eea9 9e0f 	vmlsldavx.s32	r8, r5, q4, q7
[^>]*> eea9 9e2f 	vmlsldavax.s32	r8, r5, q4, q7
[^>]*> eeaf 8e01 	vmlsldav.s32	r8, r5, q7, q0
[^>]*> eeaf 8e21 	vmlsldava.s32	r8, r5, q7, q0
[^>]*> eeaf 9e01 	vmlsldavx.s32	r8, r5, q7, q0
[^>]*> eeaf 9e21 	vmlsldavax.s32	r8, r5, q7, q0
[^>]*> eeaf 8e03 	vmlsldav.s32	r8, r5, q7, q1
[^>]*> eeaf 8e23 	vmlsldava.s32	r8, r5, q7, q1
[^>]*> eeaf 9e03 	vmlsldavx.s32	r8, r5, q7, q1
[^>]*> eeaf 9e23 	vmlsldavax.s32	r8, r5, q7, q1
[^>]*> eeaf 8e05 	vmlsldav.s32	r8, r5, q7, q2
[^>]*> eeaf 8e25 	vmlsldava.s32	r8, r5, q7, q2
[^>]*> eeaf 9e05 	vmlsldavx.s32	r8, r5, q7, q2
[^>]*> eeaf 9e25 	vmlsldavax.s32	r8, r5, q7, q2
[^>]*> eeaf 8e09 	vmlsldav.s32	r8, r5, q7, q4
[^>]*> eeaf 8e29 	vmlsldava.s32	r8, r5, q7, q4
[^>]*> eeaf 9e09 	vmlsldavx.s32	r8, r5, q7, q4
[^>]*> eeaf 9e29 	vmlsldavax.s32	r8, r5, q7, q4
[^>]*> eeaf 8e0f 	vmlsldav.s32	r8, r5, q7, q7
[^>]*> eeaf 8e2f 	vmlsldava.s32	r8, r5, q7, q7
[^>]*> eeaf 9e0f 	vmlsldavx.s32	r8, r5, q7, q7
[^>]*> eeaf 9e2f 	vmlsldavax.s32	r8, r5, q7, q7
[^>]*> eeb1 8e01 	vmlsldav.s32	r8, r7, q0, q0
[^>]*> eeb1 8e21 	vmlsldava.s32	r8, r7, q0, q0
[^>]*> eeb1 9e01 	vmlsldavx.s32	r8, r7, q0, q0
[^>]*> eeb1 9e21 	vmlsldavax.s32	r8, r7, q0, q0
[^>]*> eeb1 8e03 	vmlsldav.s32	r8, r7, q0, q1
[^>]*> eeb1 8e23 	vmlsldava.s32	r8, r7, q0, q1
[^>]*> eeb1 9e03 	vmlsldavx.s32	r8, r7, q0, q1
[^>]*> eeb1 9e23 	vmlsldavax.s32	r8, r7, q0, q1
[^>]*> eeb1 8e05 	vmlsldav.s32	r8, r7, q0, q2
[^>]*> eeb1 8e25 	vmlsldava.s32	r8, r7, q0, q2
[^>]*> eeb1 9e05 	vmlsldavx.s32	r8, r7, q0, q2
[^>]*> eeb1 9e25 	vmlsldavax.s32	r8, r7, q0, q2
[^>]*> eeb1 8e09 	vmlsldav.s32	r8, r7, q0, q4
[^>]*> eeb1 8e29 	vmlsldava.s32	r8, r7, q0, q4
[^>]*> eeb1 9e09 	vmlsldavx.s32	r8, r7, q0, q4
[^>]*> eeb1 9e29 	vmlsldavax.s32	r8, r7, q0, q4
[^>]*> eeb1 8e0f 	vmlsldav.s32	r8, r7, q0, q7
[^>]*> eeb1 8e2f 	vmlsldava.s32	r8, r7, q0, q7
[^>]*> eeb1 9e0f 	vmlsldavx.s32	r8, r7, q0, q7
[^>]*> eeb1 9e2f 	vmlsldavax.s32	r8, r7, q0, q7
[^>]*> eeb3 8e01 	vmlsldav.s32	r8, r7, q1, q0
[^>]*> eeb3 8e21 	vmlsldava.s32	r8, r7, q1, q0
[^>]*> eeb3 9e01 	vmlsldavx.s32	r8, r7, q1, q0
[^>]*> eeb3 9e21 	vmlsldavax.s32	r8, r7, q1, q0
[^>]*> eeb3 8e03 	vmlsldav.s32	r8, r7, q1, q1
[^>]*> eeb3 8e23 	vmlsldava.s32	r8, r7, q1, q1
[^>]*> eeb3 9e03 	vmlsldavx.s32	r8, r7, q1, q1
[^>]*> eeb3 9e23 	vmlsldavax.s32	r8, r7, q1, q1
[^>]*> eeb3 8e05 	vmlsldav.s32	r8, r7, q1, q2
[^>]*> eeb3 8e25 	vmlsldava.s32	r8, r7, q1, q2
[^>]*> eeb3 9e05 	vmlsldavx.s32	r8, r7, q1, q2
[^>]*> eeb3 9e25 	vmlsldavax.s32	r8, r7, q1, q2
[^>]*> eeb3 8e09 	vmlsldav.s32	r8, r7, q1, q4
[^>]*> eeb3 8e29 	vmlsldava.s32	r8, r7, q1, q4
[^>]*> eeb3 9e09 	vmlsldavx.s32	r8, r7, q1, q4
[^>]*> eeb3 9e29 	vmlsldavax.s32	r8, r7, q1, q4
[^>]*> eeb3 8e0f 	vmlsldav.s32	r8, r7, q1, q7
[^>]*> eeb3 8e2f 	vmlsldava.s32	r8, r7, q1, q7
[^>]*> eeb3 9e0f 	vmlsldavx.s32	r8, r7, q1, q7
[^>]*> eeb3 9e2f 	vmlsldavax.s32	r8, r7, q1, q7
[^>]*> eeb5 8e01 	vmlsldav.s32	r8, r7, q2, q0
[^>]*> eeb5 8e21 	vmlsldava.s32	r8, r7, q2, q0
[^>]*> eeb5 9e01 	vmlsldavx.s32	r8, r7, q2, q0
[^>]*> eeb5 9e21 	vmlsldavax.s32	r8, r7, q2, q0
[^>]*> eeb5 8e03 	vmlsldav.s32	r8, r7, q2, q1
[^>]*> eeb5 8e23 	vmlsldava.s32	r8, r7, q2, q1
[^>]*> eeb5 9e03 	vmlsldavx.s32	r8, r7, q2, q1
[^>]*> eeb5 9e23 	vmlsldavax.s32	r8, r7, q2, q1
[^>]*> eeb5 8e05 	vmlsldav.s32	r8, r7, q2, q2
[^>]*> eeb5 8e25 	vmlsldava.s32	r8, r7, q2, q2
[^>]*> eeb5 9e05 	vmlsldavx.s32	r8, r7, q2, q2
[^>]*> eeb5 9e25 	vmlsldavax.s32	r8, r7, q2, q2
[^>]*> eeb5 8e09 	vmlsldav.s32	r8, r7, q2, q4
[^>]*> eeb5 8e29 	vmlsldava.s32	r8, r7, q2, q4
[^>]*> eeb5 9e09 	vmlsldavx.s32	r8, r7, q2, q4
[^>]*> eeb5 9e29 	vmlsldavax.s32	r8, r7, q2, q4
[^>]*> eeb5 8e0f 	vmlsldav.s32	r8, r7, q2, q7
[^>]*> eeb5 8e2f 	vmlsldava.s32	r8, r7, q2, q7
[^>]*> eeb5 9e0f 	vmlsldavx.s32	r8, r7, q2, q7
[^>]*> eeb5 9e2f 	vmlsldavax.s32	r8, r7, q2, q7
[^>]*> eeb9 8e01 	vmlsldav.s32	r8, r7, q4, q0
[^>]*> eeb9 8e21 	vmlsldava.s32	r8, r7, q4, q0
[^>]*> eeb9 9e01 	vmlsldavx.s32	r8, r7, q4, q0
[^>]*> eeb9 9e21 	vmlsldavax.s32	r8, r7, q4, q0
[^>]*> eeb9 8e03 	vmlsldav.s32	r8, r7, q4, q1
[^>]*> eeb9 8e23 	vmlsldava.s32	r8, r7, q4, q1
[^>]*> eeb9 9e03 	vmlsldavx.s32	r8, r7, q4, q1
[^>]*> eeb9 9e23 	vmlsldavax.s32	r8, r7, q4, q1
[^>]*> eeb9 8e05 	vmlsldav.s32	r8, r7, q4, q2
[^>]*> eeb9 8e25 	vmlsldava.s32	r8, r7, q4, q2
[^>]*> eeb9 9e05 	vmlsldavx.s32	r8, r7, q4, q2
[^>]*> eeb9 9e25 	vmlsldavax.s32	r8, r7, q4, q2
[^>]*> eeb9 8e09 	vmlsldav.s32	r8, r7, q4, q4
[^>]*> eeb9 8e29 	vmlsldava.s32	r8, r7, q4, q4
[^>]*> eeb9 9e09 	vmlsldavx.s32	r8, r7, q4, q4
[^>]*> eeb9 9e29 	vmlsldavax.s32	r8, r7, q4, q4
[^>]*> eeb9 8e0f 	vmlsldav.s32	r8, r7, q4, q7
[^>]*> eeb9 8e2f 	vmlsldava.s32	r8, r7, q4, q7
[^>]*> eeb9 9e0f 	vmlsldavx.s32	r8, r7, q4, q7
[^>]*> eeb9 9e2f 	vmlsldavax.s32	r8, r7, q4, q7
[^>]*> eebf 8e01 	vmlsldav.s32	r8, r7, q7, q0
[^>]*> eebf 8e21 	vmlsldava.s32	r8, r7, q7, q0
[^>]*> eebf 9e01 	vmlsldavx.s32	r8, r7, q7, q0
[^>]*> eebf 9e21 	vmlsldavax.s32	r8, r7, q7, q0
[^>]*> eebf 8e03 	vmlsldav.s32	r8, r7, q7, q1
[^>]*> eebf 8e23 	vmlsldava.s32	r8, r7, q7, q1
[^>]*> eebf 9e03 	vmlsldavx.s32	r8, r7, q7, q1
[^>]*> eebf 9e23 	vmlsldavax.s32	r8, r7, q7, q1
[^>]*> eebf 8e05 	vmlsldav.s32	r8, r7, q7, q2
[^>]*> eebf 8e25 	vmlsldava.s32	r8, r7, q7, q2
[^>]*> eebf 9e05 	vmlsldavx.s32	r8, r7, q7, q2
[^>]*> eebf 9e25 	vmlsldavax.s32	r8, r7, q7, q2
[^>]*> eebf 8e09 	vmlsldav.s32	r8, r7, q7, q4
[^>]*> eebf 8e29 	vmlsldava.s32	r8, r7, q7, q4
[^>]*> eebf 9e09 	vmlsldavx.s32	r8, r7, q7, q4
[^>]*> eebf 9e29 	vmlsldavax.s32	r8, r7, q7, q4
[^>]*> eebf 8e0f 	vmlsldav.s32	r8, r7, q7, q7
[^>]*> eebf 8e2f 	vmlsldava.s32	r8, r7, q7, q7
[^>]*> eebf 9e0f 	vmlsldavx.s32	r8, r7, q7, q7
[^>]*> eebf 9e2f 	vmlsldavax.s32	r8, r7, q7, q7
[^>]*> eec1 8e01 	vmlsldav.s32	r8, r9, q0, q0
[^>]*> eec1 8e21 	vmlsldava.s32	r8, r9, q0, q0
[^>]*> eec1 9e01 	vmlsldavx.s32	r8, r9, q0, q0
[^>]*> eec1 9e21 	vmlsldavax.s32	r8, r9, q0, q0
[^>]*> eec1 8e03 	vmlsldav.s32	r8, r9, q0, q1
[^>]*> eec1 8e23 	vmlsldava.s32	r8, r9, q0, q1
[^>]*> eec1 9e03 	vmlsldavx.s32	r8, r9, q0, q1
[^>]*> eec1 9e23 	vmlsldavax.s32	r8, r9, q0, q1
[^>]*> eec1 8e05 	vmlsldav.s32	r8, r9, q0, q2
[^>]*> eec1 8e25 	vmlsldava.s32	r8, r9, q0, q2
[^>]*> eec1 9e05 	vmlsldavx.s32	r8, r9, q0, q2
[^>]*> eec1 9e25 	vmlsldavax.s32	r8, r9, q0, q2
[^>]*> eec1 8e09 	vmlsldav.s32	r8, r9, q0, q4
[^>]*> eec1 8e29 	vmlsldava.s32	r8, r9, q0, q4
[^>]*> eec1 9e09 	vmlsldavx.s32	r8, r9, q0, q4
[^>]*> eec1 9e29 	vmlsldavax.s32	r8, r9, q0, q4
[^>]*> eec1 8e0f 	vmlsldav.s32	r8, r9, q0, q7
[^>]*> eec1 8e2f 	vmlsldava.s32	r8, r9, q0, q7
[^>]*> eec1 9e0f 	vmlsldavx.s32	r8, r9, q0, q7
[^>]*> eec1 9e2f 	vmlsldavax.s32	r8, r9, q0, q7
[^>]*> eec3 8e01 	vmlsldav.s32	r8, r9, q1, q0
[^>]*> eec3 8e21 	vmlsldava.s32	r8, r9, q1, q0
[^>]*> eec3 9e01 	vmlsldavx.s32	r8, r9, q1, q0
[^>]*> eec3 9e21 	vmlsldavax.s32	r8, r9, q1, q0
[^>]*> eec3 8e03 	vmlsldav.s32	r8, r9, q1, q1
[^>]*> eec3 8e23 	vmlsldava.s32	r8, r9, q1, q1
[^>]*> eec3 9e03 	vmlsldavx.s32	r8, r9, q1, q1
[^>]*> eec3 9e23 	vmlsldavax.s32	r8, r9, q1, q1
[^>]*> eec3 8e05 	vmlsldav.s32	r8, r9, q1, q2
[^>]*> eec3 8e25 	vmlsldava.s32	r8, r9, q1, q2
[^>]*> eec3 9e05 	vmlsldavx.s32	r8, r9, q1, q2
[^>]*> eec3 9e25 	vmlsldavax.s32	r8, r9, q1, q2
[^>]*> eec3 8e09 	vmlsldav.s32	r8, r9, q1, q4
[^>]*> eec3 8e29 	vmlsldava.s32	r8, r9, q1, q4
[^>]*> eec3 9e09 	vmlsldavx.s32	r8, r9, q1, q4
[^>]*> eec3 9e29 	vmlsldavax.s32	r8, r9, q1, q4
[^>]*> eec3 8e0f 	vmlsldav.s32	r8, r9, q1, q7
[^>]*> eec3 8e2f 	vmlsldava.s32	r8, r9, q1, q7
[^>]*> eec3 9e0f 	vmlsldavx.s32	r8, r9, q1, q7
[^>]*> eec3 9e2f 	vmlsldavax.s32	r8, r9, q1, q7
[^>]*> eec5 8e01 	vmlsldav.s32	r8, r9, q2, q0
[^>]*> eec5 8e21 	vmlsldava.s32	r8, r9, q2, q0
[^>]*> eec5 9e01 	vmlsldavx.s32	r8, r9, q2, q0
[^>]*> eec5 9e21 	vmlsldavax.s32	r8, r9, q2, q0
[^>]*> eec5 8e03 	vmlsldav.s32	r8, r9, q2, q1
[^>]*> eec5 8e23 	vmlsldava.s32	r8, r9, q2, q1
[^>]*> eec5 9e03 	vmlsldavx.s32	r8, r9, q2, q1
[^>]*> eec5 9e23 	vmlsldavax.s32	r8, r9, q2, q1
[^>]*> eec5 8e05 	vmlsldav.s32	r8, r9, q2, q2
[^>]*> eec5 8e25 	vmlsldava.s32	r8, r9, q2, q2
[^>]*> eec5 9e05 	vmlsldavx.s32	r8, r9, q2, q2
[^>]*> eec5 9e25 	vmlsldavax.s32	r8, r9, q2, q2
[^>]*> eec5 8e09 	vmlsldav.s32	r8, r9, q2, q4
[^>]*> eec5 8e29 	vmlsldava.s32	r8, r9, q2, q4
[^>]*> eec5 9e09 	vmlsldavx.s32	r8, r9, q2, q4
[^>]*> eec5 9e29 	vmlsldavax.s32	r8, r9, q2, q4
[^>]*> eec5 8e0f 	vmlsldav.s32	r8, r9, q2, q7
[^>]*> eec5 8e2f 	vmlsldava.s32	r8, r9, q2, q7
[^>]*> eec5 9e0f 	vmlsldavx.s32	r8, r9, q2, q7
[^>]*> eec5 9e2f 	vmlsldavax.s32	r8, r9, q2, q7
[^>]*> eec9 8e01 	vmlsldav.s32	r8, r9, q4, q0
[^>]*> eec9 8e21 	vmlsldava.s32	r8, r9, q4, q0
[^>]*> eec9 9e01 	vmlsldavx.s32	r8, r9, q4, q0
[^>]*> eec9 9e21 	vmlsldavax.s32	r8, r9, q4, q0
[^>]*> eec9 8e03 	vmlsldav.s32	r8, r9, q4, q1
[^>]*> eec9 8e23 	vmlsldava.s32	r8, r9, q4, q1
[^>]*> eec9 9e03 	vmlsldavx.s32	r8, r9, q4, q1
[^>]*> eec9 9e23 	vmlsldavax.s32	r8, r9, q4, q1
[^>]*> eec9 8e05 	vmlsldav.s32	r8, r9, q4, q2
[^>]*> eec9 8e25 	vmlsldava.s32	r8, r9, q4, q2
[^>]*> eec9 9e05 	vmlsldavx.s32	r8, r9, q4, q2
[^>]*> eec9 9e25 	vmlsldavax.s32	r8, r9, q4, q2
[^>]*> eec9 8e09 	vmlsldav.s32	r8, r9, q4, q4
[^>]*> eec9 8e29 	vmlsldava.s32	r8, r9, q4, q4
[^>]*> eec9 9e09 	vmlsldavx.s32	r8, r9, q4, q4
[^>]*> eec9 9e29 	vmlsldavax.s32	r8, r9, q4, q4
[^>]*> eec9 8e0f 	vmlsldav.s32	r8, r9, q4, q7
[^>]*> eec9 8e2f 	vmlsldava.s32	r8, r9, q4, q7
[^>]*> eec9 9e0f 	vmlsldavx.s32	r8, r9, q4, q7
[^>]*> eec9 9e2f 	vmlsldavax.s32	r8, r9, q4, q7
[^>]*> eecf 8e01 	vmlsldav.s32	r8, r9, q7, q0
[^>]*> eecf 8e21 	vmlsldava.s32	r8, r9, q7, q0
[^>]*> eecf 9e01 	vmlsldavx.s32	r8, r9, q7, q0
[^>]*> eecf 9e21 	vmlsldavax.s32	r8, r9, q7, q0
[^>]*> eecf 8e03 	vmlsldav.s32	r8, r9, q7, q1
[^>]*> eecf 8e23 	vmlsldava.s32	r8, r9, q7, q1
[^>]*> eecf 9e03 	vmlsldavx.s32	r8, r9, q7, q1
[^>]*> eecf 9e23 	vmlsldavax.s32	r8, r9, q7, q1
[^>]*> eecf 8e05 	vmlsldav.s32	r8, r9, q7, q2
[^>]*> eecf 8e25 	vmlsldava.s32	r8, r9, q7, q2
[^>]*> eecf 9e05 	vmlsldavx.s32	r8, r9, q7, q2
[^>]*> eecf 9e25 	vmlsldavax.s32	r8, r9, q7, q2
[^>]*> eecf 8e09 	vmlsldav.s32	r8, r9, q7, q4
[^>]*> eecf 8e29 	vmlsldava.s32	r8, r9, q7, q4
[^>]*> eecf 9e09 	vmlsldavx.s32	r8, r9, q7, q4
[^>]*> eecf 9e29 	vmlsldavax.s32	r8, r9, q7, q4
[^>]*> eecf 8e0f 	vmlsldav.s32	r8, r9, q7, q7
[^>]*> eecf 8e2f 	vmlsldava.s32	r8, r9, q7, q7
[^>]*> eecf 9e0f 	vmlsldavx.s32	r8, r9, q7, q7
[^>]*> eecf 9e2f 	vmlsldavax.s32	r8, r9, q7, q7
[^>]*> eed1 8e01 	vmlsldav.s32	r8, fp, q0, q0
[^>]*> eed1 8e21 	vmlsldava.s32	r8, fp, q0, q0
[^>]*> eed1 9e01 	vmlsldavx.s32	r8, fp, q0, q0
[^>]*> eed1 9e21 	vmlsldavax.s32	r8, fp, q0, q0
[^>]*> eed1 8e03 	vmlsldav.s32	r8, fp, q0, q1
[^>]*> eed1 8e23 	vmlsldava.s32	r8, fp, q0, q1
[^>]*> eed1 9e03 	vmlsldavx.s32	r8, fp, q0, q1
[^>]*> eed1 9e23 	vmlsldavax.s32	r8, fp, q0, q1
[^>]*> eed1 8e05 	vmlsldav.s32	r8, fp, q0, q2
[^>]*> eed1 8e25 	vmlsldava.s32	r8, fp, q0, q2
[^>]*> eed1 9e05 	vmlsldavx.s32	r8, fp, q0, q2
[^>]*> eed1 9e25 	vmlsldavax.s32	r8, fp, q0, q2
[^>]*> eed1 8e09 	vmlsldav.s32	r8, fp, q0, q4
[^>]*> eed1 8e29 	vmlsldava.s32	r8, fp, q0, q4
[^>]*> eed1 9e09 	vmlsldavx.s32	r8, fp, q0, q4
[^>]*> eed1 9e29 	vmlsldavax.s32	r8, fp, q0, q4
[^>]*> eed1 8e0f 	vmlsldav.s32	r8, fp, q0, q7
[^>]*> eed1 8e2f 	vmlsldava.s32	r8, fp, q0, q7
[^>]*> eed1 9e0f 	vmlsldavx.s32	r8, fp, q0, q7
[^>]*> eed1 9e2f 	vmlsldavax.s32	r8, fp, q0, q7
[^>]*> eed3 8e01 	vmlsldav.s32	r8, fp, q1, q0
[^>]*> eed3 8e21 	vmlsldava.s32	r8, fp, q1, q0
[^>]*> eed3 9e01 	vmlsldavx.s32	r8, fp, q1, q0
[^>]*> eed3 9e21 	vmlsldavax.s32	r8, fp, q1, q0
[^>]*> eed3 8e03 	vmlsldav.s32	r8, fp, q1, q1
[^>]*> eed3 8e23 	vmlsldava.s32	r8, fp, q1, q1
[^>]*> eed3 9e03 	vmlsldavx.s32	r8, fp, q1, q1
[^>]*> eed3 9e23 	vmlsldavax.s32	r8, fp, q1, q1
[^>]*> eed3 8e05 	vmlsldav.s32	r8, fp, q1, q2
[^>]*> eed3 8e25 	vmlsldava.s32	r8, fp, q1, q2
[^>]*> eed3 9e05 	vmlsldavx.s32	r8, fp, q1, q2
[^>]*> eed3 9e25 	vmlsldavax.s32	r8, fp, q1, q2
[^>]*> eed3 8e09 	vmlsldav.s32	r8, fp, q1, q4
[^>]*> eed3 8e29 	vmlsldava.s32	r8, fp, q1, q4
[^>]*> eed3 9e09 	vmlsldavx.s32	r8, fp, q1, q4
[^>]*> eed3 9e29 	vmlsldavax.s32	r8, fp, q1, q4
[^>]*> eed3 8e0f 	vmlsldav.s32	r8, fp, q1, q7
[^>]*> eed3 8e2f 	vmlsldava.s32	r8, fp, q1, q7
[^>]*> eed3 9e0f 	vmlsldavx.s32	r8, fp, q1, q7
[^>]*> eed3 9e2f 	vmlsldavax.s32	r8, fp, q1, q7
[^>]*> eed5 8e01 	vmlsldav.s32	r8, fp, q2, q0
[^>]*> eed5 8e21 	vmlsldava.s32	r8, fp, q2, q0
[^>]*> eed5 9e01 	vmlsldavx.s32	r8, fp, q2, q0
[^>]*> eed5 9e21 	vmlsldavax.s32	r8, fp, q2, q0
[^>]*> eed5 8e03 	vmlsldav.s32	r8, fp, q2, q1
[^>]*> eed5 8e23 	vmlsldava.s32	r8, fp, q2, q1
[^>]*> eed5 9e03 	vmlsldavx.s32	r8, fp, q2, q1
[^>]*> eed5 9e23 	vmlsldavax.s32	r8, fp, q2, q1
[^>]*> eed5 8e05 	vmlsldav.s32	r8, fp, q2, q2
[^>]*> eed5 8e25 	vmlsldava.s32	r8, fp, q2, q2
[^>]*> eed5 9e05 	vmlsldavx.s32	r8, fp, q2, q2
[^>]*> eed5 9e25 	vmlsldavax.s32	r8, fp, q2, q2
[^>]*> eed5 8e09 	vmlsldav.s32	r8, fp, q2, q4
[^>]*> eed5 8e29 	vmlsldava.s32	r8, fp, q2, q4
[^>]*> eed5 9e09 	vmlsldavx.s32	r8, fp, q2, q4
[^>]*> eed5 9e29 	vmlsldavax.s32	r8, fp, q2, q4
[^>]*> eed5 8e0f 	vmlsldav.s32	r8, fp, q2, q7
[^>]*> eed5 8e2f 	vmlsldava.s32	r8, fp, q2, q7
[^>]*> eed5 9e0f 	vmlsldavx.s32	r8, fp, q2, q7
[^>]*> eed5 9e2f 	vmlsldavax.s32	r8, fp, q2, q7
[^>]*> eed9 8e01 	vmlsldav.s32	r8, fp, q4, q0
[^>]*> eed9 8e21 	vmlsldava.s32	r8, fp, q4, q0
[^>]*> eed9 9e01 	vmlsldavx.s32	r8, fp, q4, q0
[^>]*> eed9 9e21 	vmlsldavax.s32	r8, fp, q4, q0
[^>]*> eed9 8e03 	vmlsldav.s32	r8, fp, q4, q1
[^>]*> eed9 8e23 	vmlsldava.s32	r8, fp, q4, q1
[^>]*> eed9 9e03 	vmlsldavx.s32	r8, fp, q4, q1
[^>]*> eed9 9e23 	vmlsldavax.s32	r8, fp, q4, q1
[^>]*> eed9 8e05 	vmlsldav.s32	r8, fp, q4, q2
[^>]*> eed9 8e25 	vmlsldava.s32	r8, fp, q4, q2
[^>]*> eed9 9e05 	vmlsldavx.s32	r8, fp, q4, q2
[^>]*> eed9 9e25 	vmlsldavax.s32	r8, fp, q4, q2
[^>]*> eed9 8e09 	vmlsldav.s32	r8, fp, q4, q4
[^>]*> eed9 8e29 	vmlsldava.s32	r8, fp, q4, q4
[^>]*> eed9 9e09 	vmlsldavx.s32	r8, fp, q4, q4
[^>]*> eed9 9e29 	vmlsldavax.s32	r8, fp, q4, q4
[^>]*> eed9 8e0f 	vmlsldav.s32	r8, fp, q4, q7
[^>]*> eed9 8e2f 	vmlsldava.s32	r8, fp, q4, q7
[^>]*> eed9 9e0f 	vmlsldavx.s32	r8, fp, q4, q7
[^>]*> eed9 9e2f 	vmlsldavax.s32	r8, fp, q4, q7
[^>]*> eedf 8e01 	vmlsldav.s32	r8, fp, q7, q0
[^>]*> eedf 8e21 	vmlsldava.s32	r8, fp, q7, q0
[^>]*> eedf 9e01 	vmlsldavx.s32	r8, fp, q7, q0
[^>]*> eedf 9e21 	vmlsldavax.s32	r8, fp, q7, q0
[^>]*> eedf 8e03 	vmlsldav.s32	r8, fp, q7, q1
[^>]*> eedf 8e23 	vmlsldava.s32	r8, fp, q7, q1
[^>]*> eedf 9e03 	vmlsldavx.s32	r8, fp, q7, q1
[^>]*> eedf 9e23 	vmlsldavax.s32	r8, fp, q7, q1
[^>]*> eedf 8e05 	vmlsldav.s32	r8, fp, q7, q2
[^>]*> eedf 8e25 	vmlsldava.s32	r8, fp, q7, q2
[^>]*> eedf 9e05 	vmlsldavx.s32	r8, fp, q7, q2
[^>]*> eedf 9e25 	vmlsldavax.s32	r8, fp, q7, q2
[^>]*> eedf 8e09 	vmlsldav.s32	r8, fp, q7, q4
[^>]*> eedf 8e29 	vmlsldava.s32	r8, fp, q7, q4
[^>]*> eedf 9e09 	vmlsldavx.s32	r8, fp, q7, q4
[^>]*> eedf 9e29 	vmlsldavax.s32	r8, fp, q7, q4
[^>]*> eedf 8e0f 	vmlsldav.s32	r8, fp, q7, q7
[^>]*> eedf 8e2f 	vmlsldava.s32	r8, fp, q7, q7
[^>]*> eedf 9e0f 	vmlsldavx.s32	r8, fp, q7, q7
[^>]*> eedf 9e2f 	vmlsldavax.s32	r8, fp, q7, q7
[^>]*> ee81 ae01 	vmlsldav.s32	sl, r1, q0, q0
[^>]*> ee81 ae21 	vmlsldava.s32	sl, r1, q0, q0
[^>]*> ee81 be01 	vmlsldavx.s32	sl, r1, q0, q0
[^>]*> ee81 be21 	vmlsldavax.s32	sl, r1, q0, q0
[^>]*> ee81 ae03 	vmlsldav.s32	sl, r1, q0, q1
[^>]*> ee81 ae23 	vmlsldava.s32	sl, r1, q0, q1
[^>]*> ee81 be03 	vmlsldavx.s32	sl, r1, q0, q1
[^>]*> ee81 be23 	vmlsldavax.s32	sl, r1, q0, q1
[^>]*> ee81 ae05 	vmlsldav.s32	sl, r1, q0, q2
[^>]*> ee81 ae25 	vmlsldava.s32	sl, r1, q0, q2
[^>]*> ee81 be05 	vmlsldavx.s32	sl, r1, q0, q2
[^>]*> ee81 be25 	vmlsldavax.s32	sl, r1, q0, q2
[^>]*> ee81 ae09 	vmlsldav.s32	sl, r1, q0, q4
[^>]*> ee81 ae29 	vmlsldava.s32	sl, r1, q0, q4
[^>]*> ee81 be09 	vmlsldavx.s32	sl, r1, q0, q4
[^>]*> ee81 be29 	vmlsldavax.s32	sl, r1, q0, q4
[^>]*> ee81 ae0f 	vmlsldav.s32	sl, r1, q0, q7
[^>]*> ee81 ae2f 	vmlsldava.s32	sl, r1, q0, q7
[^>]*> ee81 be0f 	vmlsldavx.s32	sl, r1, q0, q7
[^>]*> ee81 be2f 	vmlsldavax.s32	sl, r1, q0, q7
[^>]*> ee83 ae01 	vmlsldav.s32	sl, r1, q1, q0
[^>]*> ee83 ae21 	vmlsldava.s32	sl, r1, q1, q0
[^>]*> ee83 be01 	vmlsldavx.s32	sl, r1, q1, q0
[^>]*> ee83 be21 	vmlsldavax.s32	sl, r1, q1, q0
[^>]*> ee83 ae03 	vmlsldav.s32	sl, r1, q1, q1
[^>]*> ee83 ae23 	vmlsldava.s32	sl, r1, q1, q1
[^>]*> ee83 be03 	vmlsldavx.s32	sl, r1, q1, q1
[^>]*> ee83 be23 	vmlsldavax.s32	sl, r1, q1, q1
[^>]*> ee83 ae05 	vmlsldav.s32	sl, r1, q1, q2
[^>]*> ee83 ae25 	vmlsldava.s32	sl, r1, q1, q2
[^>]*> ee83 be05 	vmlsldavx.s32	sl, r1, q1, q2
[^>]*> ee83 be25 	vmlsldavax.s32	sl, r1, q1, q2
[^>]*> ee83 ae09 	vmlsldav.s32	sl, r1, q1, q4
[^>]*> ee83 ae29 	vmlsldava.s32	sl, r1, q1, q4
[^>]*> ee83 be09 	vmlsldavx.s32	sl, r1, q1, q4
[^>]*> ee83 be29 	vmlsldavax.s32	sl, r1, q1, q4
[^>]*> ee83 ae0f 	vmlsldav.s32	sl, r1, q1, q7
[^>]*> ee83 ae2f 	vmlsldava.s32	sl, r1, q1, q7
[^>]*> ee83 be0f 	vmlsldavx.s32	sl, r1, q1, q7
[^>]*> ee83 be2f 	vmlsldavax.s32	sl, r1, q1, q7
[^>]*> ee85 ae01 	vmlsldav.s32	sl, r1, q2, q0
[^>]*> ee85 ae21 	vmlsldava.s32	sl, r1, q2, q0
[^>]*> ee85 be01 	vmlsldavx.s32	sl, r1, q2, q0
[^>]*> ee85 be21 	vmlsldavax.s32	sl, r1, q2, q0
[^>]*> ee85 ae03 	vmlsldav.s32	sl, r1, q2, q1
[^>]*> ee85 ae23 	vmlsldava.s32	sl, r1, q2, q1
[^>]*> ee85 be03 	vmlsldavx.s32	sl, r1, q2, q1
[^>]*> ee85 be23 	vmlsldavax.s32	sl, r1, q2, q1
[^>]*> ee85 ae05 	vmlsldav.s32	sl, r1, q2, q2
[^>]*> ee85 ae25 	vmlsldava.s32	sl, r1, q2, q2
[^>]*> ee85 be05 	vmlsldavx.s32	sl, r1, q2, q2
[^>]*> ee85 be25 	vmlsldavax.s32	sl, r1, q2, q2
[^>]*> ee85 ae09 	vmlsldav.s32	sl, r1, q2, q4
[^>]*> ee85 ae29 	vmlsldava.s32	sl, r1, q2, q4
[^>]*> ee85 be09 	vmlsldavx.s32	sl, r1, q2, q4
[^>]*> ee85 be29 	vmlsldavax.s32	sl, r1, q2, q4
[^>]*> ee85 ae0f 	vmlsldav.s32	sl, r1, q2, q7
[^>]*> ee85 ae2f 	vmlsldava.s32	sl, r1, q2, q7
[^>]*> ee85 be0f 	vmlsldavx.s32	sl, r1, q2, q7
[^>]*> ee85 be2f 	vmlsldavax.s32	sl, r1, q2, q7
[^>]*> ee89 ae01 	vmlsldav.s32	sl, r1, q4, q0
[^>]*> ee89 ae21 	vmlsldava.s32	sl, r1, q4, q0
[^>]*> ee89 be01 	vmlsldavx.s32	sl, r1, q4, q0
[^>]*> ee89 be21 	vmlsldavax.s32	sl, r1, q4, q0
[^>]*> ee89 ae03 	vmlsldav.s32	sl, r1, q4, q1
[^>]*> ee89 ae23 	vmlsldava.s32	sl, r1, q4, q1
[^>]*> ee89 be03 	vmlsldavx.s32	sl, r1, q4, q1
[^>]*> ee89 be23 	vmlsldavax.s32	sl, r1, q4, q1
[^>]*> ee89 ae05 	vmlsldav.s32	sl, r1, q4, q2
[^>]*> ee89 ae25 	vmlsldava.s32	sl, r1, q4, q2
[^>]*> ee89 be05 	vmlsldavx.s32	sl, r1, q4, q2
[^>]*> ee89 be25 	vmlsldavax.s32	sl, r1, q4, q2
[^>]*> ee89 ae09 	vmlsldav.s32	sl, r1, q4, q4
[^>]*> ee89 ae29 	vmlsldava.s32	sl, r1, q4, q4
[^>]*> ee89 be09 	vmlsldavx.s32	sl, r1, q4, q4
[^>]*> ee89 be29 	vmlsldavax.s32	sl, r1, q4, q4
[^>]*> ee89 ae0f 	vmlsldav.s32	sl, r1, q4, q7
[^>]*> ee89 ae2f 	vmlsldava.s32	sl, r1, q4, q7
[^>]*> ee89 be0f 	vmlsldavx.s32	sl, r1, q4, q7
[^>]*> ee89 be2f 	vmlsldavax.s32	sl, r1, q4, q7
[^>]*> ee8f ae01 	vmlsldav.s32	sl, r1, q7, q0
[^>]*> ee8f ae21 	vmlsldava.s32	sl, r1, q7, q0
[^>]*> ee8f be01 	vmlsldavx.s32	sl, r1, q7, q0
[^>]*> ee8f be21 	vmlsldavax.s32	sl, r1, q7, q0
[^>]*> ee8f ae03 	vmlsldav.s32	sl, r1, q7, q1
[^>]*> ee8f ae23 	vmlsldava.s32	sl, r1, q7, q1
[^>]*> ee8f be03 	vmlsldavx.s32	sl, r1, q7, q1
[^>]*> ee8f be23 	vmlsldavax.s32	sl, r1, q7, q1
[^>]*> ee8f ae05 	vmlsldav.s32	sl, r1, q7, q2
[^>]*> ee8f ae25 	vmlsldava.s32	sl, r1, q7, q2
[^>]*> ee8f be05 	vmlsldavx.s32	sl, r1, q7, q2
[^>]*> ee8f be25 	vmlsldavax.s32	sl, r1, q7, q2
[^>]*> ee8f ae09 	vmlsldav.s32	sl, r1, q7, q4
[^>]*> ee8f ae29 	vmlsldava.s32	sl, r1, q7, q4
[^>]*> ee8f be09 	vmlsldavx.s32	sl, r1, q7, q4
[^>]*> ee8f be29 	vmlsldavax.s32	sl, r1, q7, q4
[^>]*> ee8f ae0f 	vmlsldav.s32	sl, r1, q7, q7
[^>]*> ee8f ae2f 	vmlsldava.s32	sl, r1, q7, q7
[^>]*> ee8f be0f 	vmlsldavx.s32	sl, r1, q7, q7
[^>]*> ee8f be2f 	vmlsldavax.s32	sl, r1, q7, q7
[^>]*> ee91 ae01 	vmlsldav.s32	sl, r3, q0, q0
[^>]*> ee91 ae21 	vmlsldava.s32	sl, r3, q0, q0
[^>]*> ee91 be01 	vmlsldavx.s32	sl, r3, q0, q0
[^>]*> ee91 be21 	vmlsldavax.s32	sl, r3, q0, q0
[^>]*> ee91 ae03 	vmlsldav.s32	sl, r3, q0, q1
[^>]*> ee91 ae23 	vmlsldava.s32	sl, r3, q0, q1
[^>]*> ee91 be03 	vmlsldavx.s32	sl, r3, q0, q1
[^>]*> ee91 be23 	vmlsldavax.s32	sl, r3, q0, q1
[^>]*> ee91 ae05 	vmlsldav.s32	sl, r3, q0, q2
[^>]*> ee91 ae25 	vmlsldava.s32	sl, r3, q0, q2
[^>]*> ee91 be05 	vmlsldavx.s32	sl, r3, q0, q2
[^>]*> ee91 be25 	vmlsldavax.s32	sl, r3, q0, q2
[^>]*> ee91 ae09 	vmlsldav.s32	sl, r3, q0, q4
[^>]*> ee91 ae29 	vmlsldava.s32	sl, r3, q0, q4
[^>]*> ee91 be09 	vmlsldavx.s32	sl, r3, q0, q4
[^>]*> ee91 be29 	vmlsldavax.s32	sl, r3, q0, q4
[^>]*> ee91 ae0f 	vmlsldav.s32	sl, r3, q0, q7
[^>]*> ee91 ae2f 	vmlsldava.s32	sl, r3, q0, q7
[^>]*> ee91 be0f 	vmlsldavx.s32	sl, r3, q0, q7
[^>]*> ee91 be2f 	vmlsldavax.s32	sl, r3, q0, q7
[^>]*> ee93 ae01 	vmlsldav.s32	sl, r3, q1, q0
[^>]*> ee93 ae21 	vmlsldava.s32	sl, r3, q1, q0
[^>]*> ee93 be01 	vmlsldavx.s32	sl, r3, q1, q0
[^>]*> ee93 be21 	vmlsldavax.s32	sl, r3, q1, q0
[^>]*> ee93 ae03 	vmlsldav.s32	sl, r3, q1, q1
[^>]*> ee93 ae23 	vmlsldava.s32	sl, r3, q1, q1
[^>]*> ee93 be03 	vmlsldavx.s32	sl, r3, q1, q1
[^>]*> ee93 be23 	vmlsldavax.s32	sl, r3, q1, q1
[^>]*> ee93 ae05 	vmlsldav.s32	sl, r3, q1, q2
[^>]*> ee93 ae25 	vmlsldava.s32	sl, r3, q1, q2
[^>]*> ee93 be05 	vmlsldavx.s32	sl, r3, q1, q2
[^>]*> ee93 be25 	vmlsldavax.s32	sl, r3, q1, q2
[^>]*> ee93 ae09 	vmlsldav.s32	sl, r3, q1, q4
[^>]*> ee93 ae29 	vmlsldava.s32	sl, r3, q1, q4
[^>]*> ee93 be09 	vmlsldavx.s32	sl, r3, q1, q4
[^>]*> ee93 be29 	vmlsldavax.s32	sl, r3, q1, q4
[^>]*> ee93 ae0f 	vmlsldav.s32	sl, r3, q1, q7
[^>]*> ee93 ae2f 	vmlsldava.s32	sl, r3, q1, q7
[^>]*> ee93 be0f 	vmlsldavx.s32	sl, r3, q1, q7
[^>]*> ee93 be2f 	vmlsldavax.s32	sl, r3, q1, q7
[^>]*> ee95 ae01 	vmlsldav.s32	sl, r3, q2, q0
[^>]*> ee95 ae21 	vmlsldava.s32	sl, r3, q2, q0
[^>]*> ee95 be01 	vmlsldavx.s32	sl, r3, q2, q0
[^>]*> ee95 be21 	vmlsldavax.s32	sl, r3, q2, q0
[^>]*> ee95 ae03 	vmlsldav.s32	sl, r3, q2, q1
[^>]*> ee95 ae23 	vmlsldava.s32	sl, r3, q2, q1
[^>]*> ee95 be03 	vmlsldavx.s32	sl, r3, q2, q1
[^>]*> ee95 be23 	vmlsldavax.s32	sl, r3, q2, q1
[^>]*> ee95 ae05 	vmlsldav.s32	sl, r3, q2, q2
[^>]*> ee95 ae25 	vmlsldava.s32	sl, r3, q2, q2
[^>]*> ee95 be05 	vmlsldavx.s32	sl, r3, q2, q2
[^>]*> ee95 be25 	vmlsldavax.s32	sl, r3, q2, q2
[^>]*> ee95 ae09 	vmlsldav.s32	sl, r3, q2, q4
[^>]*> ee95 ae29 	vmlsldava.s32	sl, r3, q2, q4
[^>]*> ee95 be09 	vmlsldavx.s32	sl, r3, q2, q4
[^>]*> ee95 be29 	vmlsldavax.s32	sl, r3, q2, q4
[^>]*> ee95 ae0f 	vmlsldav.s32	sl, r3, q2, q7
[^>]*> ee95 ae2f 	vmlsldava.s32	sl, r3, q2, q7
[^>]*> ee95 be0f 	vmlsldavx.s32	sl, r3, q2, q7
[^>]*> ee95 be2f 	vmlsldavax.s32	sl, r3, q2, q7
[^>]*> ee99 ae01 	vmlsldav.s32	sl, r3, q4, q0
[^>]*> ee99 ae21 	vmlsldava.s32	sl, r3, q4, q0
[^>]*> ee99 be01 	vmlsldavx.s32	sl, r3, q4, q0
[^>]*> ee99 be21 	vmlsldavax.s32	sl, r3, q4, q0
[^>]*> ee99 ae03 	vmlsldav.s32	sl, r3, q4, q1
[^>]*> ee99 ae23 	vmlsldava.s32	sl, r3, q4, q1
[^>]*> ee99 be03 	vmlsldavx.s32	sl, r3, q4, q1
[^>]*> ee99 be23 	vmlsldavax.s32	sl, r3, q4, q1
[^>]*> ee99 ae05 	vmlsldav.s32	sl, r3, q4, q2
[^>]*> ee99 ae25 	vmlsldava.s32	sl, r3, q4, q2
[^>]*> ee99 be05 	vmlsldavx.s32	sl, r3, q4, q2
[^>]*> ee99 be25 	vmlsldavax.s32	sl, r3, q4, q2
[^>]*> ee99 ae09 	vmlsldav.s32	sl, r3, q4, q4
[^>]*> ee99 ae29 	vmlsldava.s32	sl, r3, q4, q4
[^>]*> ee99 be09 	vmlsldavx.s32	sl, r3, q4, q4
[^>]*> ee99 be29 	vmlsldavax.s32	sl, r3, q4, q4
[^>]*> ee99 ae0f 	vmlsldav.s32	sl, r3, q4, q7
[^>]*> ee99 ae2f 	vmlsldava.s32	sl, r3, q4, q7
[^>]*> ee99 be0f 	vmlsldavx.s32	sl, r3, q4, q7
[^>]*> ee99 be2f 	vmlsldavax.s32	sl, r3, q4, q7
[^>]*> ee9f ae01 	vmlsldav.s32	sl, r3, q7, q0
[^>]*> ee9f ae21 	vmlsldava.s32	sl, r3, q7, q0
[^>]*> ee9f be01 	vmlsldavx.s32	sl, r3, q7, q0
[^>]*> ee9f be21 	vmlsldavax.s32	sl, r3, q7, q0
[^>]*> ee9f ae03 	vmlsldav.s32	sl, r3, q7, q1
[^>]*> ee9f ae23 	vmlsldava.s32	sl, r3, q7, q1
[^>]*> ee9f be03 	vmlsldavx.s32	sl, r3, q7, q1
[^>]*> ee9f be23 	vmlsldavax.s32	sl, r3, q7, q1
[^>]*> ee9f ae05 	vmlsldav.s32	sl, r3, q7, q2
[^>]*> ee9f ae25 	vmlsldava.s32	sl, r3, q7, q2
[^>]*> ee9f be05 	vmlsldavx.s32	sl, r3, q7, q2
[^>]*> ee9f be25 	vmlsldavax.s32	sl, r3, q7, q2
[^>]*> ee9f ae09 	vmlsldav.s32	sl, r3, q7, q4
[^>]*> ee9f ae29 	vmlsldava.s32	sl, r3, q7, q4
[^>]*> ee9f be09 	vmlsldavx.s32	sl, r3, q7, q4
[^>]*> ee9f be29 	vmlsldavax.s32	sl, r3, q7, q4
[^>]*> ee9f ae0f 	vmlsldav.s32	sl, r3, q7, q7
[^>]*> ee9f ae2f 	vmlsldava.s32	sl, r3, q7, q7
[^>]*> ee9f be0f 	vmlsldavx.s32	sl, r3, q7, q7
[^>]*> ee9f be2f 	vmlsldavax.s32	sl, r3, q7, q7
[^>]*> eea1 ae01 	vmlsldav.s32	sl, r5, q0, q0
[^>]*> eea1 ae21 	vmlsldava.s32	sl, r5, q0, q0
[^>]*> eea1 be01 	vmlsldavx.s32	sl, r5, q0, q0
[^>]*> eea1 be21 	vmlsldavax.s32	sl, r5, q0, q0
[^>]*> eea1 ae03 	vmlsldav.s32	sl, r5, q0, q1
[^>]*> eea1 ae23 	vmlsldava.s32	sl, r5, q0, q1
[^>]*> eea1 be03 	vmlsldavx.s32	sl, r5, q0, q1
[^>]*> eea1 be23 	vmlsldavax.s32	sl, r5, q0, q1
[^>]*> eea1 ae05 	vmlsldav.s32	sl, r5, q0, q2
[^>]*> eea1 ae25 	vmlsldava.s32	sl, r5, q0, q2
[^>]*> eea1 be05 	vmlsldavx.s32	sl, r5, q0, q2
[^>]*> eea1 be25 	vmlsldavax.s32	sl, r5, q0, q2
[^>]*> eea1 ae09 	vmlsldav.s32	sl, r5, q0, q4
[^>]*> eea1 ae29 	vmlsldava.s32	sl, r5, q0, q4
[^>]*> eea1 be09 	vmlsldavx.s32	sl, r5, q0, q4
[^>]*> eea1 be29 	vmlsldavax.s32	sl, r5, q0, q4
[^>]*> eea1 ae0f 	vmlsldav.s32	sl, r5, q0, q7
[^>]*> eea1 ae2f 	vmlsldava.s32	sl, r5, q0, q7
[^>]*> eea1 be0f 	vmlsldavx.s32	sl, r5, q0, q7
[^>]*> eea1 be2f 	vmlsldavax.s32	sl, r5, q0, q7
[^>]*> eea3 ae01 	vmlsldav.s32	sl, r5, q1, q0
[^>]*> eea3 ae21 	vmlsldava.s32	sl, r5, q1, q0
[^>]*> eea3 be01 	vmlsldavx.s32	sl, r5, q1, q0
[^>]*> eea3 be21 	vmlsldavax.s32	sl, r5, q1, q0
[^>]*> eea3 ae03 	vmlsldav.s32	sl, r5, q1, q1
[^>]*> eea3 ae23 	vmlsldava.s32	sl, r5, q1, q1
[^>]*> eea3 be03 	vmlsldavx.s32	sl, r5, q1, q1
[^>]*> eea3 be23 	vmlsldavax.s32	sl, r5, q1, q1
[^>]*> eea3 ae05 	vmlsldav.s32	sl, r5, q1, q2
[^>]*> eea3 ae25 	vmlsldava.s32	sl, r5, q1, q2
[^>]*> eea3 be05 	vmlsldavx.s32	sl, r5, q1, q2
[^>]*> eea3 be25 	vmlsldavax.s32	sl, r5, q1, q2
[^>]*> eea3 ae09 	vmlsldav.s32	sl, r5, q1, q4
[^>]*> eea3 ae29 	vmlsldava.s32	sl, r5, q1, q4
[^>]*> eea3 be09 	vmlsldavx.s32	sl, r5, q1, q4
[^>]*> eea3 be29 	vmlsldavax.s32	sl, r5, q1, q4
[^>]*> eea3 ae0f 	vmlsldav.s32	sl, r5, q1, q7
[^>]*> eea3 ae2f 	vmlsldava.s32	sl, r5, q1, q7
[^>]*> eea3 be0f 	vmlsldavx.s32	sl, r5, q1, q7
[^>]*> eea3 be2f 	vmlsldavax.s32	sl, r5, q1, q7
[^>]*> eea5 ae01 	vmlsldav.s32	sl, r5, q2, q0
[^>]*> eea5 ae21 	vmlsldava.s32	sl, r5, q2, q0
[^>]*> eea5 be01 	vmlsldavx.s32	sl, r5, q2, q0
[^>]*> eea5 be21 	vmlsldavax.s32	sl, r5, q2, q0
[^>]*> eea5 ae03 	vmlsldav.s32	sl, r5, q2, q1
[^>]*> eea5 ae23 	vmlsldava.s32	sl, r5, q2, q1
[^>]*> eea5 be03 	vmlsldavx.s32	sl, r5, q2, q1
[^>]*> eea5 be23 	vmlsldavax.s32	sl, r5, q2, q1
[^>]*> eea5 ae05 	vmlsldav.s32	sl, r5, q2, q2
[^>]*> eea5 ae25 	vmlsldava.s32	sl, r5, q2, q2
[^>]*> eea5 be05 	vmlsldavx.s32	sl, r5, q2, q2
[^>]*> eea5 be25 	vmlsldavax.s32	sl, r5, q2, q2
[^>]*> eea5 ae09 	vmlsldav.s32	sl, r5, q2, q4
[^>]*> eea5 ae29 	vmlsldava.s32	sl, r5, q2, q4
[^>]*> eea5 be09 	vmlsldavx.s32	sl, r5, q2, q4
[^>]*> eea5 be29 	vmlsldavax.s32	sl, r5, q2, q4
[^>]*> eea5 ae0f 	vmlsldav.s32	sl, r5, q2, q7
[^>]*> eea5 ae2f 	vmlsldava.s32	sl, r5, q2, q7
[^>]*> eea5 be0f 	vmlsldavx.s32	sl, r5, q2, q7
[^>]*> eea5 be2f 	vmlsldavax.s32	sl, r5, q2, q7
[^>]*> eea9 ae01 	vmlsldav.s32	sl, r5, q4, q0
[^>]*> eea9 ae21 	vmlsldava.s32	sl, r5, q4, q0
[^>]*> eea9 be01 	vmlsldavx.s32	sl, r5, q4, q0
[^>]*> eea9 be21 	vmlsldavax.s32	sl, r5, q4, q0
[^>]*> eea9 ae03 	vmlsldav.s32	sl, r5, q4, q1
[^>]*> eea9 ae23 	vmlsldava.s32	sl, r5, q4, q1
[^>]*> eea9 be03 	vmlsldavx.s32	sl, r5, q4, q1
[^>]*> eea9 be23 	vmlsldavax.s32	sl, r5, q4, q1
[^>]*> eea9 ae05 	vmlsldav.s32	sl, r5, q4, q2
[^>]*> eea9 ae25 	vmlsldava.s32	sl, r5, q4, q2
[^>]*> eea9 be05 	vmlsldavx.s32	sl, r5, q4, q2
[^>]*> eea9 be25 	vmlsldavax.s32	sl, r5, q4, q2
[^>]*> eea9 ae09 	vmlsldav.s32	sl, r5, q4, q4
[^>]*> eea9 ae29 	vmlsldava.s32	sl, r5, q4, q4
[^>]*> eea9 be09 	vmlsldavx.s32	sl, r5, q4, q4
[^>]*> eea9 be29 	vmlsldavax.s32	sl, r5, q4, q4
[^>]*> eea9 ae0f 	vmlsldav.s32	sl, r5, q4, q7
[^>]*> eea9 ae2f 	vmlsldava.s32	sl, r5, q4, q7
[^>]*> eea9 be0f 	vmlsldavx.s32	sl, r5, q4, q7
[^>]*> eea9 be2f 	vmlsldavax.s32	sl, r5, q4, q7
[^>]*> eeaf ae01 	vmlsldav.s32	sl, r5, q7, q0
[^>]*> eeaf ae21 	vmlsldava.s32	sl, r5, q7, q0
[^>]*> eeaf be01 	vmlsldavx.s32	sl, r5, q7, q0
[^>]*> eeaf be21 	vmlsldavax.s32	sl, r5, q7, q0
[^>]*> eeaf ae03 	vmlsldav.s32	sl, r5, q7, q1
[^>]*> eeaf ae23 	vmlsldava.s32	sl, r5, q7, q1
[^>]*> eeaf be03 	vmlsldavx.s32	sl, r5, q7, q1
[^>]*> eeaf be23 	vmlsldavax.s32	sl, r5, q7, q1
[^>]*> eeaf ae05 	vmlsldav.s32	sl, r5, q7, q2
[^>]*> eeaf ae25 	vmlsldava.s32	sl, r5, q7, q2
[^>]*> eeaf be05 	vmlsldavx.s32	sl, r5, q7, q2
[^>]*> eeaf be25 	vmlsldavax.s32	sl, r5, q7, q2
[^>]*> eeaf ae09 	vmlsldav.s32	sl, r5, q7, q4
[^>]*> eeaf ae29 	vmlsldava.s32	sl, r5, q7, q4
[^>]*> eeaf be09 	vmlsldavx.s32	sl, r5, q7, q4
[^>]*> eeaf be29 	vmlsldavax.s32	sl, r5, q7, q4
[^>]*> eeaf ae0f 	vmlsldav.s32	sl, r5, q7, q7
[^>]*> eeaf ae2f 	vmlsldava.s32	sl, r5, q7, q7
[^>]*> eeaf be0f 	vmlsldavx.s32	sl, r5, q7, q7
[^>]*> eeaf be2f 	vmlsldavax.s32	sl, r5, q7, q7
[^>]*> eeb1 ae01 	vmlsldav.s32	sl, r7, q0, q0
[^>]*> eeb1 ae21 	vmlsldava.s32	sl, r7, q0, q0
[^>]*> eeb1 be01 	vmlsldavx.s32	sl, r7, q0, q0
[^>]*> eeb1 be21 	vmlsldavax.s32	sl, r7, q0, q0
[^>]*> eeb1 ae03 	vmlsldav.s32	sl, r7, q0, q1
[^>]*> eeb1 ae23 	vmlsldava.s32	sl, r7, q0, q1
[^>]*> eeb1 be03 	vmlsldavx.s32	sl, r7, q0, q1
[^>]*> eeb1 be23 	vmlsldavax.s32	sl, r7, q0, q1
[^>]*> eeb1 ae05 	vmlsldav.s32	sl, r7, q0, q2
[^>]*> eeb1 ae25 	vmlsldava.s32	sl, r7, q0, q2
[^>]*> eeb1 be05 	vmlsldavx.s32	sl, r7, q0, q2
[^>]*> eeb1 be25 	vmlsldavax.s32	sl, r7, q0, q2
[^>]*> eeb1 ae09 	vmlsldav.s32	sl, r7, q0, q4
[^>]*> eeb1 ae29 	vmlsldava.s32	sl, r7, q0, q4
[^>]*> eeb1 be09 	vmlsldavx.s32	sl, r7, q0, q4
[^>]*> eeb1 be29 	vmlsldavax.s32	sl, r7, q0, q4
[^>]*> eeb1 ae0f 	vmlsldav.s32	sl, r7, q0, q7
[^>]*> eeb1 ae2f 	vmlsldava.s32	sl, r7, q0, q7
[^>]*> eeb1 be0f 	vmlsldavx.s32	sl, r7, q0, q7
[^>]*> eeb1 be2f 	vmlsldavax.s32	sl, r7, q0, q7
[^>]*> eeb3 ae01 	vmlsldav.s32	sl, r7, q1, q0
[^>]*> eeb3 ae21 	vmlsldava.s32	sl, r7, q1, q0
[^>]*> eeb3 be01 	vmlsldavx.s32	sl, r7, q1, q0
[^>]*> eeb3 be21 	vmlsldavax.s32	sl, r7, q1, q0
[^>]*> eeb3 ae03 	vmlsldav.s32	sl, r7, q1, q1
[^>]*> eeb3 ae23 	vmlsldava.s32	sl, r7, q1, q1
[^>]*> eeb3 be03 	vmlsldavx.s32	sl, r7, q1, q1
[^>]*> eeb3 be23 	vmlsldavax.s32	sl, r7, q1, q1
[^>]*> eeb3 ae05 	vmlsldav.s32	sl, r7, q1, q2
[^>]*> eeb3 ae25 	vmlsldava.s32	sl, r7, q1, q2
[^>]*> eeb3 be05 	vmlsldavx.s32	sl, r7, q1, q2
[^>]*> eeb3 be25 	vmlsldavax.s32	sl, r7, q1, q2
[^>]*> eeb3 ae09 	vmlsldav.s32	sl, r7, q1, q4
[^>]*> eeb3 ae29 	vmlsldava.s32	sl, r7, q1, q4
[^>]*> eeb3 be09 	vmlsldavx.s32	sl, r7, q1, q4
[^>]*> eeb3 be29 	vmlsldavax.s32	sl, r7, q1, q4
[^>]*> eeb3 ae0f 	vmlsldav.s32	sl, r7, q1, q7
[^>]*> eeb3 ae2f 	vmlsldava.s32	sl, r7, q1, q7
[^>]*> eeb3 be0f 	vmlsldavx.s32	sl, r7, q1, q7
[^>]*> eeb3 be2f 	vmlsldavax.s32	sl, r7, q1, q7
[^>]*> eeb5 ae01 	vmlsldav.s32	sl, r7, q2, q0
[^>]*> eeb5 ae21 	vmlsldava.s32	sl, r7, q2, q0
[^>]*> eeb5 be01 	vmlsldavx.s32	sl, r7, q2, q0
[^>]*> eeb5 be21 	vmlsldavax.s32	sl, r7, q2, q0
[^>]*> eeb5 ae03 	vmlsldav.s32	sl, r7, q2, q1
[^>]*> eeb5 ae23 	vmlsldava.s32	sl, r7, q2, q1
[^>]*> eeb5 be03 	vmlsldavx.s32	sl, r7, q2, q1
[^>]*> eeb5 be23 	vmlsldavax.s32	sl, r7, q2, q1
[^>]*> eeb5 ae05 	vmlsldav.s32	sl, r7, q2, q2
[^>]*> eeb5 ae25 	vmlsldava.s32	sl, r7, q2, q2
[^>]*> eeb5 be05 	vmlsldavx.s32	sl, r7, q2, q2
[^>]*> eeb5 be25 	vmlsldavax.s32	sl, r7, q2, q2
[^>]*> eeb5 ae09 	vmlsldav.s32	sl, r7, q2, q4
[^>]*> eeb5 ae29 	vmlsldava.s32	sl, r7, q2, q4
[^>]*> eeb5 be09 	vmlsldavx.s32	sl, r7, q2, q4
[^>]*> eeb5 be29 	vmlsldavax.s32	sl, r7, q2, q4
[^>]*> eeb5 ae0f 	vmlsldav.s32	sl, r7, q2, q7
[^>]*> eeb5 ae2f 	vmlsldava.s32	sl, r7, q2, q7
[^>]*> eeb5 be0f 	vmlsldavx.s32	sl, r7, q2, q7
[^>]*> eeb5 be2f 	vmlsldavax.s32	sl, r7, q2, q7
[^>]*> eeb9 ae01 	vmlsldav.s32	sl, r7, q4, q0
[^>]*> eeb9 ae21 	vmlsldava.s32	sl, r7, q4, q0
[^>]*> eeb9 be01 	vmlsldavx.s32	sl, r7, q4, q0
[^>]*> eeb9 be21 	vmlsldavax.s32	sl, r7, q4, q0
[^>]*> eeb9 ae03 	vmlsldav.s32	sl, r7, q4, q1
[^>]*> eeb9 ae23 	vmlsldava.s32	sl, r7, q4, q1
[^>]*> eeb9 be03 	vmlsldavx.s32	sl, r7, q4, q1
[^>]*> eeb9 be23 	vmlsldavax.s32	sl, r7, q4, q1
[^>]*> eeb9 ae05 	vmlsldav.s32	sl, r7, q4, q2
[^>]*> eeb9 ae25 	vmlsldava.s32	sl, r7, q4, q2
[^>]*> eeb9 be05 	vmlsldavx.s32	sl, r7, q4, q2
[^>]*> eeb9 be25 	vmlsldavax.s32	sl, r7, q4, q2
[^>]*> eeb9 ae09 	vmlsldav.s32	sl, r7, q4, q4
[^>]*> eeb9 ae29 	vmlsldava.s32	sl, r7, q4, q4
[^>]*> eeb9 be09 	vmlsldavx.s32	sl, r7, q4, q4
[^>]*> eeb9 be29 	vmlsldavax.s32	sl, r7, q4, q4
[^>]*> eeb9 ae0f 	vmlsldav.s32	sl, r7, q4, q7
[^>]*> eeb9 ae2f 	vmlsldava.s32	sl, r7, q4, q7
[^>]*> eeb9 be0f 	vmlsldavx.s32	sl, r7, q4, q7
[^>]*> eeb9 be2f 	vmlsldavax.s32	sl, r7, q4, q7
[^>]*> eebf ae01 	vmlsldav.s32	sl, r7, q7, q0
[^>]*> eebf ae21 	vmlsldava.s32	sl, r7, q7, q0
[^>]*> eebf be01 	vmlsldavx.s32	sl, r7, q7, q0
[^>]*> eebf be21 	vmlsldavax.s32	sl, r7, q7, q0
[^>]*> eebf ae03 	vmlsldav.s32	sl, r7, q7, q1
[^>]*> eebf ae23 	vmlsldava.s32	sl, r7, q7, q1
[^>]*> eebf be03 	vmlsldavx.s32	sl, r7, q7, q1
[^>]*> eebf be23 	vmlsldavax.s32	sl, r7, q7, q1
[^>]*> eebf ae05 	vmlsldav.s32	sl, r7, q7, q2
[^>]*> eebf ae25 	vmlsldava.s32	sl, r7, q7, q2
[^>]*> eebf be05 	vmlsldavx.s32	sl, r7, q7, q2
[^>]*> eebf be25 	vmlsldavax.s32	sl, r7, q7, q2
[^>]*> eebf ae09 	vmlsldav.s32	sl, r7, q7, q4
[^>]*> eebf ae29 	vmlsldava.s32	sl, r7, q7, q4
[^>]*> eebf be09 	vmlsldavx.s32	sl, r7, q7, q4
[^>]*> eebf be29 	vmlsldavax.s32	sl, r7, q7, q4
[^>]*> eebf ae0f 	vmlsldav.s32	sl, r7, q7, q7
[^>]*> eebf ae2f 	vmlsldava.s32	sl, r7, q7, q7
[^>]*> eebf be0f 	vmlsldavx.s32	sl, r7, q7, q7
[^>]*> eebf be2f 	vmlsldavax.s32	sl, r7, q7, q7
[^>]*> eec1 ae01 	vmlsldav.s32	sl, r9, q0, q0
[^>]*> eec1 ae21 	vmlsldava.s32	sl, r9, q0, q0
[^>]*> eec1 be01 	vmlsldavx.s32	sl, r9, q0, q0
[^>]*> eec1 be21 	vmlsldavax.s32	sl, r9, q0, q0
[^>]*> eec1 ae03 	vmlsldav.s32	sl, r9, q0, q1
[^>]*> eec1 ae23 	vmlsldava.s32	sl, r9, q0, q1
[^>]*> eec1 be03 	vmlsldavx.s32	sl, r9, q0, q1
[^>]*> eec1 be23 	vmlsldavax.s32	sl, r9, q0, q1
[^>]*> eec1 ae05 	vmlsldav.s32	sl, r9, q0, q2
[^>]*> eec1 ae25 	vmlsldava.s32	sl, r9, q0, q2
[^>]*> eec1 be05 	vmlsldavx.s32	sl, r9, q0, q2
[^>]*> eec1 be25 	vmlsldavax.s32	sl, r9, q0, q2
[^>]*> eec1 ae09 	vmlsldav.s32	sl, r9, q0, q4
[^>]*> eec1 ae29 	vmlsldava.s32	sl, r9, q0, q4
[^>]*> eec1 be09 	vmlsldavx.s32	sl, r9, q0, q4
[^>]*> eec1 be29 	vmlsldavax.s32	sl, r9, q0, q4
[^>]*> eec1 ae0f 	vmlsldav.s32	sl, r9, q0, q7
[^>]*> eec1 ae2f 	vmlsldava.s32	sl, r9, q0, q7
[^>]*> eec1 be0f 	vmlsldavx.s32	sl, r9, q0, q7
[^>]*> eec1 be2f 	vmlsldavax.s32	sl, r9, q0, q7
[^>]*> eec3 ae01 	vmlsldav.s32	sl, r9, q1, q0
[^>]*> eec3 ae21 	vmlsldava.s32	sl, r9, q1, q0
[^>]*> eec3 be01 	vmlsldavx.s32	sl, r9, q1, q0
[^>]*> eec3 be21 	vmlsldavax.s32	sl, r9, q1, q0
[^>]*> eec3 ae03 	vmlsldav.s32	sl, r9, q1, q1
[^>]*> eec3 ae23 	vmlsldava.s32	sl, r9, q1, q1
[^>]*> eec3 be03 	vmlsldavx.s32	sl, r9, q1, q1
[^>]*> eec3 be23 	vmlsldavax.s32	sl, r9, q1, q1
[^>]*> eec3 ae05 	vmlsldav.s32	sl, r9, q1, q2
[^>]*> eec3 ae25 	vmlsldava.s32	sl, r9, q1, q2
[^>]*> eec3 be05 	vmlsldavx.s32	sl, r9, q1, q2
[^>]*> eec3 be25 	vmlsldavax.s32	sl, r9, q1, q2
[^>]*> eec3 ae09 	vmlsldav.s32	sl, r9, q1, q4
[^>]*> eec3 ae29 	vmlsldava.s32	sl, r9, q1, q4
[^>]*> eec3 be09 	vmlsldavx.s32	sl, r9, q1, q4
[^>]*> eec3 be29 	vmlsldavax.s32	sl, r9, q1, q4
[^>]*> eec3 ae0f 	vmlsldav.s32	sl, r9, q1, q7
[^>]*> eec3 ae2f 	vmlsldava.s32	sl, r9, q1, q7
[^>]*> eec3 be0f 	vmlsldavx.s32	sl, r9, q1, q7
[^>]*> eec3 be2f 	vmlsldavax.s32	sl, r9, q1, q7
[^>]*> eec5 ae01 	vmlsldav.s32	sl, r9, q2, q0
[^>]*> eec5 ae21 	vmlsldava.s32	sl, r9, q2, q0
[^>]*> eec5 be01 	vmlsldavx.s32	sl, r9, q2, q0
[^>]*> eec5 be21 	vmlsldavax.s32	sl, r9, q2, q0
[^>]*> eec5 ae03 	vmlsldav.s32	sl, r9, q2, q1
[^>]*> eec5 ae23 	vmlsldava.s32	sl, r9, q2, q1
[^>]*> eec5 be03 	vmlsldavx.s32	sl, r9, q2, q1
[^>]*> eec5 be23 	vmlsldavax.s32	sl, r9, q2, q1
[^>]*> eec5 ae05 	vmlsldav.s32	sl, r9, q2, q2
[^>]*> eec5 ae25 	vmlsldava.s32	sl, r9, q2, q2
[^>]*> eec5 be05 	vmlsldavx.s32	sl, r9, q2, q2
[^>]*> eec5 be25 	vmlsldavax.s32	sl, r9, q2, q2
[^>]*> eec5 ae09 	vmlsldav.s32	sl, r9, q2, q4
[^>]*> eec5 ae29 	vmlsldava.s32	sl, r9, q2, q4
[^>]*> eec5 be09 	vmlsldavx.s32	sl, r9, q2, q4
[^>]*> eec5 be29 	vmlsldavax.s32	sl, r9, q2, q4
[^>]*> eec5 ae0f 	vmlsldav.s32	sl, r9, q2, q7
[^>]*> eec5 ae2f 	vmlsldava.s32	sl, r9, q2, q7
[^>]*> eec5 be0f 	vmlsldavx.s32	sl, r9, q2, q7
[^>]*> eec5 be2f 	vmlsldavax.s32	sl, r9, q2, q7
[^>]*> eec9 ae01 	vmlsldav.s32	sl, r9, q4, q0
[^>]*> eec9 ae21 	vmlsldava.s32	sl, r9, q4, q0
[^>]*> eec9 be01 	vmlsldavx.s32	sl, r9, q4, q0
[^>]*> eec9 be21 	vmlsldavax.s32	sl, r9, q4, q0
[^>]*> eec9 ae03 	vmlsldav.s32	sl, r9, q4, q1
[^>]*> eec9 ae23 	vmlsldava.s32	sl, r9, q4, q1
[^>]*> eec9 be03 	vmlsldavx.s32	sl, r9, q4, q1
[^>]*> eec9 be23 	vmlsldavax.s32	sl, r9, q4, q1
[^>]*> eec9 ae05 	vmlsldav.s32	sl, r9, q4, q2
[^>]*> eec9 ae25 	vmlsldava.s32	sl, r9, q4, q2
[^>]*> eec9 be05 	vmlsldavx.s32	sl, r9, q4, q2
[^>]*> eec9 be25 	vmlsldavax.s32	sl, r9, q4, q2
[^>]*> eec9 ae09 	vmlsldav.s32	sl, r9, q4, q4
[^>]*> eec9 ae29 	vmlsldava.s32	sl, r9, q4, q4
[^>]*> eec9 be09 	vmlsldavx.s32	sl, r9, q4, q4
[^>]*> eec9 be29 	vmlsldavax.s32	sl, r9, q4, q4
[^>]*> eec9 ae0f 	vmlsldav.s32	sl, r9, q4, q7
[^>]*> eec9 ae2f 	vmlsldava.s32	sl, r9, q4, q7
[^>]*> eec9 be0f 	vmlsldavx.s32	sl, r9, q4, q7
[^>]*> eec9 be2f 	vmlsldavax.s32	sl, r9, q4, q7
[^>]*> eecf ae01 	vmlsldav.s32	sl, r9, q7, q0
[^>]*> eecf ae21 	vmlsldava.s32	sl, r9, q7, q0
[^>]*> eecf be01 	vmlsldavx.s32	sl, r9, q7, q0
[^>]*> eecf be21 	vmlsldavax.s32	sl, r9, q7, q0
[^>]*> eecf ae03 	vmlsldav.s32	sl, r9, q7, q1
[^>]*> eecf ae23 	vmlsldava.s32	sl, r9, q7, q1
[^>]*> eecf be03 	vmlsldavx.s32	sl, r9, q7, q1
[^>]*> eecf be23 	vmlsldavax.s32	sl, r9, q7, q1
[^>]*> eecf ae05 	vmlsldav.s32	sl, r9, q7, q2
[^>]*> eecf ae25 	vmlsldava.s32	sl, r9, q7, q2
[^>]*> eecf be05 	vmlsldavx.s32	sl, r9, q7, q2
[^>]*> eecf be25 	vmlsldavax.s32	sl, r9, q7, q2
[^>]*> eecf ae09 	vmlsldav.s32	sl, r9, q7, q4
[^>]*> eecf ae29 	vmlsldava.s32	sl, r9, q7, q4
[^>]*> eecf be09 	vmlsldavx.s32	sl, r9, q7, q4
[^>]*> eecf be29 	vmlsldavax.s32	sl, r9, q7, q4
[^>]*> eecf ae0f 	vmlsldav.s32	sl, r9, q7, q7
[^>]*> eecf ae2f 	vmlsldava.s32	sl, r9, q7, q7
[^>]*> eecf be0f 	vmlsldavx.s32	sl, r9, q7, q7
[^>]*> eecf be2f 	vmlsldavax.s32	sl, r9, q7, q7
[^>]*> eed1 ae01 	vmlsldav.s32	sl, fp, q0, q0
[^>]*> eed1 ae21 	vmlsldava.s32	sl, fp, q0, q0
[^>]*> eed1 be01 	vmlsldavx.s32	sl, fp, q0, q0
[^>]*> eed1 be21 	vmlsldavax.s32	sl, fp, q0, q0
[^>]*> eed1 ae03 	vmlsldav.s32	sl, fp, q0, q1
[^>]*> eed1 ae23 	vmlsldava.s32	sl, fp, q0, q1
[^>]*> eed1 be03 	vmlsldavx.s32	sl, fp, q0, q1
[^>]*> eed1 be23 	vmlsldavax.s32	sl, fp, q0, q1
[^>]*> eed1 ae05 	vmlsldav.s32	sl, fp, q0, q2
[^>]*> eed1 ae25 	vmlsldava.s32	sl, fp, q0, q2
[^>]*> eed1 be05 	vmlsldavx.s32	sl, fp, q0, q2
[^>]*> eed1 be25 	vmlsldavax.s32	sl, fp, q0, q2
[^>]*> eed1 ae09 	vmlsldav.s32	sl, fp, q0, q4
[^>]*> eed1 ae29 	vmlsldava.s32	sl, fp, q0, q4
[^>]*> eed1 be09 	vmlsldavx.s32	sl, fp, q0, q4
[^>]*> eed1 be29 	vmlsldavax.s32	sl, fp, q0, q4
[^>]*> eed1 ae0f 	vmlsldav.s32	sl, fp, q0, q7
[^>]*> eed1 ae2f 	vmlsldava.s32	sl, fp, q0, q7
[^>]*> eed1 be0f 	vmlsldavx.s32	sl, fp, q0, q7
[^>]*> eed1 be2f 	vmlsldavax.s32	sl, fp, q0, q7
[^>]*> eed3 ae01 	vmlsldav.s32	sl, fp, q1, q0
[^>]*> eed3 ae21 	vmlsldava.s32	sl, fp, q1, q0
[^>]*> eed3 be01 	vmlsldavx.s32	sl, fp, q1, q0
[^>]*> eed3 be21 	vmlsldavax.s32	sl, fp, q1, q0
[^>]*> eed3 ae03 	vmlsldav.s32	sl, fp, q1, q1
[^>]*> eed3 ae23 	vmlsldava.s32	sl, fp, q1, q1
[^>]*> eed3 be03 	vmlsldavx.s32	sl, fp, q1, q1
[^>]*> eed3 be23 	vmlsldavax.s32	sl, fp, q1, q1
[^>]*> eed3 ae05 	vmlsldav.s32	sl, fp, q1, q2
[^>]*> eed3 ae25 	vmlsldava.s32	sl, fp, q1, q2
[^>]*> eed3 be05 	vmlsldavx.s32	sl, fp, q1, q2
[^>]*> eed3 be25 	vmlsldavax.s32	sl, fp, q1, q2
[^>]*> eed3 ae09 	vmlsldav.s32	sl, fp, q1, q4
[^>]*> eed3 ae29 	vmlsldava.s32	sl, fp, q1, q4
[^>]*> eed3 be09 	vmlsldavx.s32	sl, fp, q1, q4
[^>]*> eed3 be29 	vmlsldavax.s32	sl, fp, q1, q4
[^>]*> eed3 ae0f 	vmlsldav.s32	sl, fp, q1, q7
[^>]*> eed3 ae2f 	vmlsldava.s32	sl, fp, q1, q7
[^>]*> eed3 be0f 	vmlsldavx.s32	sl, fp, q1, q7
[^>]*> eed3 be2f 	vmlsldavax.s32	sl, fp, q1, q7
[^>]*> eed5 ae01 	vmlsldav.s32	sl, fp, q2, q0
[^>]*> eed5 ae21 	vmlsldava.s32	sl, fp, q2, q0
[^>]*> eed5 be01 	vmlsldavx.s32	sl, fp, q2, q0
[^>]*> eed5 be21 	vmlsldavax.s32	sl, fp, q2, q0
[^>]*> eed5 ae03 	vmlsldav.s32	sl, fp, q2, q1
[^>]*> eed5 ae23 	vmlsldava.s32	sl, fp, q2, q1
[^>]*> eed5 be03 	vmlsldavx.s32	sl, fp, q2, q1
[^>]*> eed5 be23 	vmlsldavax.s32	sl, fp, q2, q1
[^>]*> eed5 ae05 	vmlsldav.s32	sl, fp, q2, q2
[^>]*> eed5 ae25 	vmlsldava.s32	sl, fp, q2, q2
[^>]*> eed5 be05 	vmlsldavx.s32	sl, fp, q2, q2
[^>]*> eed5 be25 	vmlsldavax.s32	sl, fp, q2, q2
[^>]*> eed5 ae09 	vmlsldav.s32	sl, fp, q2, q4
[^>]*> eed5 ae29 	vmlsldava.s32	sl, fp, q2, q4
[^>]*> eed5 be09 	vmlsldavx.s32	sl, fp, q2, q4
[^>]*> eed5 be29 	vmlsldavax.s32	sl, fp, q2, q4
[^>]*> eed5 ae0f 	vmlsldav.s32	sl, fp, q2, q7
[^>]*> eed5 ae2f 	vmlsldava.s32	sl, fp, q2, q7
[^>]*> eed5 be0f 	vmlsldavx.s32	sl, fp, q2, q7
[^>]*> eed5 be2f 	vmlsldavax.s32	sl, fp, q2, q7
[^>]*> eed9 ae01 	vmlsldav.s32	sl, fp, q4, q0
[^>]*> eed9 ae21 	vmlsldava.s32	sl, fp, q4, q0
[^>]*> eed9 be01 	vmlsldavx.s32	sl, fp, q4, q0
[^>]*> eed9 be21 	vmlsldavax.s32	sl, fp, q4, q0
[^>]*> eed9 ae03 	vmlsldav.s32	sl, fp, q4, q1
[^>]*> eed9 ae23 	vmlsldava.s32	sl, fp, q4, q1
[^>]*> eed9 be03 	vmlsldavx.s32	sl, fp, q4, q1
[^>]*> eed9 be23 	vmlsldavax.s32	sl, fp, q4, q1
[^>]*> eed9 ae05 	vmlsldav.s32	sl, fp, q4, q2
[^>]*> eed9 ae25 	vmlsldava.s32	sl, fp, q4, q2
[^>]*> eed9 be05 	vmlsldavx.s32	sl, fp, q4, q2
[^>]*> eed9 be25 	vmlsldavax.s32	sl, fp, q4, q2
[^>]*> eed9 ae09 	vmlsldav.s32	sl, fp, q4, q4
[^>]*> eed9 ae29 	vmlsldava.s32	sl, fp, q4, q4
[^>]*> eed9 be09 	vmlsldavx.s32	sl, fp, q4, q4
[^>]*> eed9 be29 	vmlsldavax.s32	sl, fp, q4, q4
[^>]*> eed9 ae0f 	vmlsldav.s32	sl, fp, q4, q7
[^>]*> eed9 ae2f 	vmlsldava.s32	sl, fp, q4, q7
[^>]*> eed9 be0f 	vmlsldavx.s32	sl, fp, q4, q7
[^>]*> eed9 be2f 	vmlsldavax.s32	sl, fp, q4, q7
[^>]*> eedf ae01 	vmlsldav.s32	sl, fp, q7, q0
[^>]*> eedf ae21 	vmlsldava.s32	sl, fp, q7, q0
[^>]*> eedf be01 	vmlsldavx.s32	sl, fp, q7, q0
[^>]*> eedf be21 	vmlsldavax.s32	sl, fp, q7, q0
[^>]*> eedf ae03 	vmlsldav.s32	sl, fp, q7, q1
[^>]*> eedf ae23 	vmlsldava.s32	sl, fp, q7, q1
[^>]*> eedf be03 	vmlsldavx.s32	sl, fp, q7, q1
[^>]*> eedf be23 	vmlsldavax.s32	sl, fp, q7, q1
[^>]*> eedf ae05 	vmlsldav.s32	sl, fp, q7, q2
[^>]*> eedf ae25 	vmlsldava.s32	sl, fp, q7, q2
[^>]*> eedf be05 	vmlsldavx.s32	sl, fp, q7, q2
[^>]*> eedf be25 	vmlsldavax.s32	sl, fp, q7, q2
[^>]*> eedf ae09 	vmlsldav.s32	sl, fp, q7, q4
[^>]*> eedf ae29 	vmlsldava.s32	sl, fp, q7, q4
[^>]*> eedf be09 	vmlsldavx.s32	sl, fp, q7, q4
[^>]*> eedf be29 	vmlsldavax.s32	sl, fp, q7, q4
[^>]*> eedf ae0f 	vmlsldav.s32	sl, fp, q7, q7
[^>]*> eedf ae2f 	vmlsldava.s32	sl, fp, q7, q7
[^>]*> eedf be0f 	vmlsldavx.s32	sl, fp, q7, q7
[^>]*> eedf be2f 	vmlsldavax.s32	sl, fp, q7, q7
[^>]*> ee81 ce01 	vmlsldav.s32	ip, r1, q0, q0
[^>]*> ee81 ce21 	vmlsldava.s32	ip, r1, q0, q0
[^>]*> ee81 de01 	vmlsldavx.s32	ip, r1, q0, q0
[^>]*> ee81 de21 	vmlsldavax.s32	ip, r1, q0, q0
[^>]*> ee81 ce03 	vmlsldav.s32	ip, r1, q0, q1
[^>]*> ee81 ce23 	vmlsldava.s32	ip, r1, q0, q1
[^>]*> ee81 de03 	vmlsldavx.s32	ip, r1, q0, q1
[^>]*> ee81 de23 	vmlsldavax.s32	ip, r1, q0, q1
[^>]*> ee81 ce05 	vmlsldav.s32	ip, r1, q0, q2
[^>]*> ee81 ce25 	vmlsldava.s32	ip, r1, q0, q2
[^>]*> ee81 de05 	vmlsldavx.s32	ip, r1, q0, q2
[^>]*> ee81 de25 	vmlsldavax.s32	ip, r1, q0, q2
[^>]*> ee81 ce09 	vmlsldav.s32	ip, r1, q0, q4
[^>]*> ee81 ce29 	vmlsldava.s32	ip, r1, q0, q4
[^>]*> ee81 de09 	vmlsldavx.s32	ip, r1, q0, q4
[^>]*> ee81 de29 	vmlsldavax.s32	ip, r1, q0, q4
[^>]*> ee81 ce0f 	vmlsldav.s32	ip, r1, q0, q7
[^>]*> ee81 ce2f 	vmlsldava.s32	ip, r1, q0, q7
[^>]*> ee81 de0f 	vmlsldavx.s32	ip, r1, q0, q7
[^>]*> ee81 de2f 	vmlsldavax.s32	ip, r1, q0, q7
[^>]*> ee83 ce01 	vmlsldav.s32	ip, r1, q1, q0
[^>]*> ee83 ce21 	vmlsldava.s32	ip, r1, q1, q0
[^>]*> ee83 de01 	vmlsldavx.s32	ip, r1, q1, q0
[^>]*> ee83 de21 	vmlsldavax.s32	ip, r1, q1, q0
[^>]*> ee83 ce03 	vmlsldav.s32	ip, r1, q1, q1
[^>]*> ee83 ce23 	vmlsldava.s32	ip, r1, q1, q1
[^>]*> ee83 de03 	vmlsldavx.s32	ip, r1, q1, q1
[^>]*> ee83 de23 	vmlsldavax.s32	ip, r1, q1, q1
[^>]*> ee83 ce05 	vmlsldav.s32	ip, r1, q1, q2
[^>]*> ee83 ce25 	vmlsldava.s32	ip, r1, q1, q2
[^>]*> ee83 de05 	vmlsldavx.s32	ip, r1, q1, q2
[^>]*> ee83 de25 	vmlsldavax.s32	ip, r1, q1, q2
[^>]*> ee83 ce09 	vmlsldav.s32	ip, r1, q1, q4
[^>]*> ee83 ce29 	vmlsldava.s32	ip, r1, q1, q4
[^>]*> ee83 de09 	vmlsldavx.s32	ip, r1, q1, q4
[^>]*> ee83 de29 	vmlsldavax.s32	ip, r1, q1, q4
[^>]*> ee83 ce0f 	vmlsldav.s32	ip, r1, q1, q7
[^>]*> ee83 ce2f 	vmlsldava.s32	ip, r1, q1, q7
[^>]*> ee83 de0f 	vmlsldavx.s32	ip, r1, q1, q7
[^>]*> ee83 de2f 	vmlsldavax.s32	ip, r1, q1, q7
[^>]*> ee85 ce01 	vmlsldav.s32	ip, r1, q2, q0
[^>]*> ee85 ce21 	vmlsldava.s32	ip, r1, q2, q0
[^>]*> ee85 de01 	vmlsldavx.s32	ip, r1, q2, q0
[^>]*> ee85 de21 	vmlsldavax.s32	ip, r1, q2, q0
[^>]*> ee85 ce03 	vmlsldav.s32	ip, r1, q2, q1
[^>]*> ee85 ce23 	vmlsldava.s32	ip, r1, q2, q1
[^>]*> ee85 de03 	vmlsldavx.s32	ip, r1, q2, q1
[^>]*> ee85 de23 	vmlsldavax.s32	ip, r1, q2, q1
[^>]*> ee85 ce05 	vmlsldav.s32	ip, r1, q2, q2
[^>]*> ee85 ce25 	vmlsldava.s32	ip, r1, q2, q2
[^>]*> ee85 de05 	vmlsldavx.s32	ip, r1, q2, q2
[^>]*> ee85 de25 	vmlsldavax.s32	ip, r1, q2, q2
[^>]*> ee85 ce09 	vmlsldav.s32	ip, r1, q2, q4
[^>]*> ee85 ce29 	vmlsldava.s32	ip, r1, q2, q4
[^>]*> ee85 de09 	vmlsldavx.s32	ip, r1, q2, q4
[^>]*> ee85 de29 	vmlsldavax.s32	ip, r1, q2, q4
[^>]*> ee85 ce0f 	vmlsldav.s32	ip, r1, q2, q7
[^>]*> ee85 ce2f 	vmlsldava.s32	ip, r1, q2, q7
[^>]*> ee85 de0f 	vmlsldavx.s32	ip, r1, q2, q7
[^>]*> ee85 de2f 	vmlsldavax.s32	ip, r1, q2, q7
[^>]*> ee89 ce01 	vmlsldav.s32	ip, r1, q4, q0
[^>]*> ee89 ce21 	vmlsldava.s32	ip, r1, q4, q0
[^>]*> ee89 de01 	vmlsldavx.s32	ip, r1, q4, q0
[^>]*> ee89 de21 	vmlsldavax.s32	ip, r1, q4, q0
[^>]*> ee89 ce03 	vmlsldav.s32	ip, r1, q4, q1
[^>]*> ee89 ce23 	vmlsldava.s32	ip, r1, q4, q1
[^>]*> ee89 de03 	vmlsldavx.s32	ip, r1, q4, q1
[^>]*> ee89 de23 	vmlsldavax.s32	ip, r1, q4, q1
[^>]*> ee89 ce05 	vmlsldav.s32	ip, r1, q4, q2
[^>]*> ee89 ce25 	vmlsldava.s32	ip, r1, q4, q2
[^>]*> ee89 de05 	vmlsldavx.s32	ip, r1, q4, q2
[^>]*> ee89 de25 	vmlsldavax.s32	ip, r1, q4, q2
[^>]*> ee89 ce09 	vmlsldav.s32	ip, r1, q4, q4
[^>]*> ee89 ce29 	vmlsldava.s32	ip, r1, q4, q4
[^>]*> ee89 de09 	vmlsldavx.s32	ip, r1, q4, q4
[^>]*> ee89 de29 	vmlsldavax.s32	ip, r1, q4, q4
[^>]*> ee89 ce0f 	vmlsldav.s32	ip, r1, q4, q7
[^>]*> ee89 ce2f 	vmlsldava.s32	ip, r1, q4, q7
[^>]*> ee89 de0f 	vmlsldavx.s32	ip, r1, q4, q7
[^>]*> ee89 de2f 	vmlsldavax.s32	ip, r1, q4, q7
[^>]*> ee8f ce01 	vmlsldav.s32	ip, r1, q7, q0
[^>]*> ee8f ce21 	vmlsldava.s32	ip, r1, q7, q0
[^>]*> ee8f de01 	vmlsldavx.s32	ip, r1, q7, q0
[^>]*> ee8f de21 	vmlsldavax.s32	ip, r1, q7, q0
[^>]*> ee8f ce03 	vmlsldav.s32	ip, r1, q7, q1
[^>]*> ee8f ce23 	vmlsldava.s32	ip, r1, q7, q1
[^>]*> ee8f de03 	vmlsldavx.s32	ip, r1, q7, q1
[^>]*> ee8f de23 	vmlsldavax.s32	ip, r1, q7, q1
[^>]*> ee8f ce05 	vmlsldav.s32	ip, r1, q7, q2
[^>]*> ee8f ce25 	vmlsldava.s32	ip, r1, q7, q2
[^>]*> ee8f de05 	vmlsldavx.s32	ip, r1, q7, q2
[^>]*> ee8f de25 	vmlsldavax.s32	ip, r1, q7, q2
[^>]*> ee8f ce09 	vmlsldav.s32	ip, r1, q7, q4
[^>]*> ee8f ce29 	vmlsldava.s32	ip, r1, q7, q4
[^>]*> ee8f de09 	vmlsldavx.s32	ip, r1, q7, q4
[^>]*> ee8f de29 	vmlsldavax.s32	ip, r1, q7, q4
[^>]*> ee8f ce0f 	vmlsldav.s32	ip, r1, q7, q7
[^>]*> ee8f ce2f 	vmlsldava.s32	ip, r1, q7, q7
[^>]*> ee8f de0f 	vmlsldavx.s32	ip, r1, q7, q7
[^>]*> ee8f de2f 	vmlsldavax.s32	ip, r1, q7, q7
[^>]*> ee91 ce01 	vmlsldav.s32	ip, r3, q0, q0
[^>]*> ee91 ce21 	vmlsldava.s32	ip, r3, q0, q0
[^>]*> ee91 de01 	vmlsldavx.s32	ip, r3, q0, q0
[^>]*> ee91 de21 	vmlsldavax.s32	ip, r3, q0, q0
[^>]*> ee91 ce03 	vmlsldav.s32	ip, r3, q0, q1
[^>]*> ee91 ce23 	vmlsldava.s32	ip, r3, q0, q1
[^>]*> ee91 de03 	vmlsldavx.s32	ip, r3, q0, q1
[^>]*> ee91 de23 	vmlsldavax.s32	ip, r3, q0, q1
[^>]*> ee91 ce05 	vmlsldav.s32	ip, r3, q0, q2
[^>]*> ee91 ce25 	vmlsldava.s32	ip, r3, q0, q2
[^>]*> ee91 de05 	vmlsldavx.s32	ip, r3, q0, q2
[^>]*> ee91 de25 	vmlsldavax.s32	ip, r3, q0, q2
[^>]*> ee91 ce09 	vmlsldav.s32	ip, r3, q0, q4
[^>]*> ee91 ce29 	vmlsldava.s32	ip, r3, q0, q4
[^>]*> ee91 de09 	vmlsldavx.s32	ip, r3, q0, q4
[^>]*> ee91 de29 	vmlsldavax.s32	ip, r3, q0, q4
[^>]*> ee91 ce0f 	vmlsldav.s32	ip, r3, q0, q7
[^>]*> ee91 ce2f 	vmlsldava.s32	ip, r3, q0, q7
[^>]*> ee91 de0f 	vmlsldavx.s32	ip, r3, q0, q7
[^>]*> ee91 de2f 	vmlsldavax.s32	ip, r3, q0, q7
[^>]*> ee93 ce01 	vmlsldav.s32	ip, r3, q1, q0
[^>]*> ee93 ce21 	vmlsldava.s32	ip, r3, q1, q0
[^>]*> ee93 de01 	vmlsldavx.s32	ip, r3, q1, q0
[^>]*> ee93 de21 	vmlsldavax.s32	ip, r3, q1, q0
[^>]*> ee93 ce03 	vmlsldav.s32	ip, r3, q1, q1
[^>]*> ee93 ce23 	vmlsldava.s32	ip, r3, q1, q1
[^>]*> ee93 de03 	vmlsldavx.s32	ip, r3, q1, q1
[^>]*> ee93 de23 	vmlsldavax.s32	ip, r3, q1, q1
[^>]*> ee93 ce05 	vmlsldav.s32	ip, r3, q1, q2
[^>]*> ee93 ce25 	vmlsldava.s32	ip, r3, q1, q2
[^>]*> ee93 de05 	vmlsldavx.s32	ip, r3, q1, q2
[^>]*> ee93 de25 	vmlsldavax.s32	ip, r3, q1, q2
[^>]*> ee93 ce09 	vmlsldav.s32	ip, r3, q1, q4
[^>]*> ee93 ce29 	vmlsldava.s32	ip, r3, q1, q4
[^>]*> ee93 de09 	vmlsldavx.s32	ip, r3, q1, q4
[^>]*> ee93 de29 	vmlsldavax.s32	ip, r3, q1, q4
[^>]*> ee93 ce0f 	vmlsldav.s32	ip, r3, q1, q7
[^>]*> ee93 ce2f 	vmlsldava.s32	ip, r3, q1, q7
[^>]*> ee93 de0f 	vmlsldavx.s32	ip, r3, q1, q7
[^>]*> ee93 de2f 	vmlsldavax.s32	ip, r3, q1, q7
[^>]*> ee95 ce01 	vmlsldav.s32	ip, r3, q2, q0
[^>]*> ee95 ce21 	vmlsldava.s32	ip, r3, q2, q0
[^>]*> ee95 de01 	vmlsldavx.s32	ip, r3, q2, q0
[^>]*> ee95 de21 	vmlsldavax.s32	ip, r3, q2, q0
[^>]*> ee95 ce03 	vmlsldav.s32	ip, r3, q2, q1
[^>]*> ee95 ce23 	vmlsldava.s32	ip, r3, q2, q1
[^>]*> ee95 de03 	vmlsldavx.s32	ip, r3, q2, q1
[^>]*> ee95 de23 	vmlsldavax.s32	ip, r3, q2, q1
[^>]*> ee95 ce05 	vmlsldav.s32	ip, r3, q2, q2
[^>]*> ee95 ce25 	vmlsldava.s32	ip, r3, q2, q2
[^>]*> ee95 de05 	vmlsldavx.s32	ip, r3, q2, q2
[^>]*> ee95 de25 	vmlsldavax.s32	ip, r3, q2, q2
[^>]*> ee95 ce09 	vmlsldav.s32	ip, r3, q2, q4
[^>]*> ee95 ce29 	vmlsldava.s32	ip, r3, q2, q4
[^>]*> ee95 de09 	vmlsldavx.s32	ip, r3, q2, q4
[^>]*> ee95 de29 	vmlsldavax.s32	ip, r3, q2, q4
[^>]*> ee95 ce0f 	vmlsldav.s32	ip, r3, q2, q7
[^>]*> ee95 ce2f 	vmlsldava.s32	ip, r3, q2, q7
[^>]*> ee95 de0f 	vmlsldavx.s32	ip, r3, q2, q7
[^>]*> ee95 de2f 	vmlsldavax.s32	ip, r3, q2, q7
[^>]*> ee99 ce01 	vmlsldav.s32	ip, r3, q4, q0
[^>]*> ee99 ce21 	vmlsldava.s32	ip, r3, q4, q0
[^>]*> ee99 de01 	vmlsldavx.s32	ip, r3, q4, q0
[^>]*> ee99 de21 	vmlsldavax.s32	ip, r3, q4, q0
[^>]*> ee99 ce03 	vmlsldav.s32	ip, r3, q4, q1
[^>]*> ee99 ce23 	vmlsldava.s32	ip, r3, q4, q1
[^>]*> ee99 de03 	vmlsldavx.s32	ip, r3, q4, q1
[^>]*> ee99 de23 	vmlsldavax.s32	ip, r3, q4, q1
[^>]*> ee99 ce05 	vmlsldav.s32	ip, r3, q4, q2
[^>]*> ee99 ce25 	vmlsldava.s32	ip, r3, q4, q2
[^>]*> ee99 de05 	vmlsldavx.s32	ip, r3, q4, q2
[^>]*> ee99 de25 	vmlsldavax.s32	ip, r3, q4, q2
[^>]*> ee99 ce09 	vmlsldav.s32	ip, r3, q4, q4
[^>]*> ee99 ce29 	vmlsldava.s32	ip, r3, q4, q4
[^>]*> ee99 de09 	vmlsldavx.s32	ip, r3, q4, q4
[^>]*> ee99 de29 	vmlsldavax.s32	ip, r3, q4, q4
[^>]*> ee99 ce0f 	vmlsldav.s32	ip, r3, q4, q7
[^>]*> ee99 ce2f 	vmlsldava.s32	ip, r3, q4, q7
[^>]*> ee99 de0f 	vmlsldavx.s32	ip, r3, q4, q7
[^>]*> ee99 de2f 	vmlsldavax.s32	ip, r3, q4, q7
[^>]*> ee9f ce01 	vmlsldav.s32	ip, r3, q7, q0
[^>]*> ee9f ce21 	vmlsldava.s32	ip, r3, q7, q0
[^>]*> ee9f de01 	vmlsldavx.s32	ip, r3, q7, q0
[^>]*> ee9f de21 	vmlsldavax.s32	ip, r3, q7, q0
[^>]*> ee9f ce03 	vmlsldav.s32	ip, r3, q7, q1
[^>]*> ee9f ce23 	vmlsldava.s32	ip, r3, q7, q1
[^>]*> ee9f de03 	vmlsldavx.s32	ip, r3, q7, q1
[^>]*> ee9f de23 	vmlsldavax.s32	ip, r3, q7, q1
[^>]*> ee9f ce05 	vmlsldav.s32	ip, r3, q7, q2
[^>]*> ee9f ce25 	vmlsldava.s32	ip, r3, q7, q2
[^>]*> ee9f de05 	vmlsldavx.s32	ip, r3, q7, q2
[^>]*> ee9f de25 	vmlsldavax.s32	ip, r3, q7, q2
[^>]*> ee9f ce09 	vmlsldav.s32	ip, r3, q7, q4
[^>]*> ee9f ce29 	vmlsldava.s32	ip, r3, q7, q4
[^>]*> ee9f de09 	vmlsldavx.s32	ip, r3, q7, q4
[^>]*> ee9f de29 	vmlsldavax.s32	ip, r3, q7, q4
[^>]*> ee9f ce0f 	vmlsldav.s32	ip, r3, q7, q7
[^>]*> ee9f ce2f 	vmlsldava.s32	ip, r3, q7, q7
[^>]*> ee9f de0f 	vmlsldavx.s32	ip, r3, q7, q7
[^>]*> ee9f de2f 	vmlsldavax.s32	ip, r3, q7, q7
[^>]*> eea1 ce01 	vmlsldav.s32	ip, r5, q0, q0
[^>]*> eea1 ce21 	vmlsldava.s32	ip, r5, q0, q0
[^>]*> eea1 de01 	vmlsldavx.s32	ip, r5, q0, q0
[^>]*> eea1 de21 	vmlsldavax.s32	ip, r5, q0, q0
[^>]*> eea1 ce03 	vmlsldav.s32	ip, r5, q0, q1
[^>]*> eea1 ce23 	vmlsldava.s32	ip, r5, q0, q1
[^>]*> eea1 de03 	vmlsldavx.s32	ip, r5, q0, q1
[^>]*> eea1 de23 	vmlsldavax.s32	ip, r5, q0, q1
[^>]*> eea1 ce05 	vmlsldav.s32	ip, r5, q0, q2
[^>]*> eea1 ce25 	vmlsldava.s32	ip, r5, q0, q2
[^>]*> eea1 de05 	vmlsldavx.s32	ip, r5, q0, q2
[^>]*> eea1 de25 	vmlsldavax.s32	ip, r5, q0, q2
[^>]*> eea1 ce09 	vmlsldav.s32	ip, r5, q0, q4
[^>]*> eea1 ce29 	vmlsldava.s32	ip, r5, q0, q4
[^>]*> eea1 de09 	vmlsldavx.s32	ip, r5, q0, q4
[^>]*> eea1 de29 	vmlsldavax.s32	ip, r5, q0, q4
[^>]*> eea1 ce0f 	vmlsldav.s32	ip, r5, q0, q7
[^>]*> eea1 ce2f 	vmlsldava.s32	ip, r5, q0, q7
[^>]*> eea1 de0f 	vmlsldavx.s32	ip, r5, q0, q7
[^>]*> eea1 de2f 	vmlsldavax.s32	ip, r5, q0, q7
[^>]*> eea3 ce01 	vmlsldav.s32	ip, r5, q1, q0
[^>]*> eea3 ce21 	vmlsldava.s32	ip, r5, q1, q0
[^>]*> eea3 de01 	vmlsldavx.s32	ip, r5, q1, q0
[^>]*> eea3 de21 	vmlsldavax.s32	ip, r5, q1, q0
[^>]*> eea3 ce03 	vmlsldav.s32	ip, r5, q1, q1
[^>]*> eea3 ce23 	vmlsldava.s32	ip, r5, q1, q1
[^>]*> eea3 de03 	vmlsldavx.s32	ip, r5, q1, q1
[^>]*> eea3 de23 	vmlsldavax.s32	ip, r5, q1, q1
[^>]*> eea3 ce05 	vmlsldav.s32	ip, r5, q1, q2
[^>]*> eea3 ce25 	vmlsldava.s32	ip, r5, q1, q2
[^>]*> eea3 de05 	vmlsldavx.s32	ip, r5, q1, q2
[^>]*> eea3 de25 	vmlsldavax.s32	ip, r5, q1, q2
[^>]*> eea3 ce09 	vmlsldav.s32	ip, r5, q1, q4
[^>]*> eea3 ce29 	vmlsldava.s32	ip, r5, q1, q4
[^>]*> eea3 de09 	vmlsldavx.s32	ip, r5, q1, q4
[^>]*> eea3 de29 	vmlsldavax.s32	ip, r5, q1, q4
[^>]*> eea3 ce0f 	vmlsldav.s32	ip, r5, q1, q7
[^>]*> eea3 ce2f 	vmlsldava.s32	ip, r5, q1, q7
[^>]*> eea3 de0f 	vmlsldavx.s32	ip, r5, q1, q7
[^>]*> eea3 de2f 	vmlsldavax.s32	ip, r5, q1, q7
[^>]*> eea5 ce01 	vmlsldav.s32	ip, r5, q2, q0
[^>]*> eea5 ce21 	vmlsldava.s32	ip, r5, q2, q0
[^>]*> eea5 de01 	vmlsldavx.s32	ip, r5, q2, q0
[^>]*> eea5 de21 	vmlsldavax.s32	ip, r5, q2, q0
[^>]*> eea5 ce03 	vmlsldav.s32	ip, r5, q2, q1
[^>]*> eea5 ce23 	vmlsldava.s32	ip, r5, q2, q1
[^>]*> eea5 de03 	vmlsldavx.s32	ip, r5, q2, q1
[^>]*> eea5 de23 	vmlsldavax.s32	ip, r5, q2, q1
[^>]*> eea5 ce05 	vmlsldav.s32	ip, r5, q2, q2
[^>]*> eea5 ce25 	vmlsldava.s32	ip, r5, q2, q2
[^>]*> eea5 de05 	vmlsldavx.s32	ip, r5, q2, q2
[^>]*> eea5 de25 	vmlsldavax.s32	ip, r5, q2, q2
[^>]*> eea5 ce09 	vmlsldav.s32	ip, r5, q2, q4
[^>]*> eea5 ce29 	vmlsldava.s32	ip, r5, q2, q4
[^>]*> eea5 de09 	vmlsldavx.s32	ip, r5, q2, q4
[^>]*> eea5 de29 	vmlsldavax.s32	ip, r5, q2, q4
[^>]*> eea5 ce0f 	vmlsldav.s32	ip, r5, q2, q7
[^>]*> eea5 ce2f 	vmlsldava.s32	ip, r5, q2, q7
[^>]*> eea5 de0f 	vmlsldavx.s32	ip, r5, q2, q7
[^>]*> eea5 de2f 	vmlsldavax.s32	ip, r5, q2, q7
[^>]*> eea9 ce01 	vmlsldav.s32	ip, r5, q4, q0
[^>]*> eea9 ce21 	vmlsldava.s32	ip, r5, q4, q0
[^>]*> eea9 de01 	vmlsldavx.s32	ip, r5, q4, q0
[^>]*> eea9 de21 	vmlsldavax.s32	ip, r5, q4, q0
[^>]*> eea9 ce03 	vmlsldav.s32	ip, r5, q4, q1
[^>]*> eea9 ce23 	vmlsldava.s32	ip, r5, q4, q1
[^>]*> eea9 de03 	vmlsldavx.s32	ip, r5, q4, q1
[^>]*> eea9 de23 	vmlsldavax.s32	ip, r5, q4, q1
[^>]*> eea9 ce05 	vmlsldav.s32	ip, r5, q4, q2
[^>]*> eea9 ce25 	vmlsldava.s32	ip, r5, q4, q2
[^>]*> eea9 de05 	vmlsldavx.s32	ip, r5, q4, q2
[^>]*> eea9 de25 	vmlsldavax.s32	ip, r5, q4, q2
[^>]*> eea9 ce09 	vmlsldav.s32	ip, r5, q4, q4
[^>]*> eea9 ce29 	vmlsldava.s32	ip, r5, q4, q4
[^>]*> eea9 de09 	vmlsldavx.s32	ip, r5, q4, q4
[^>]*> eea9 de29 	vmlsldavax.s32	ip, r5, q4, q4
[^>]*> eea9 ce0f 	vmlsldav.s32	ip, r5, q4, q7
[^>]*> eea9 ce2f 	vmlsldava.s32	ip, r5, q4, q7
[^>]*> eea9 de0f 	vmlsldavx.s32	ip, r5, q4, q7
[^>]*> eea9 de2f 	vmlsldavax.s32	ip, r5, q4, q7
[^>]*> eeaf ce01 	vmlsldav.s32	ip, r5, q7, q0
[^>]*> eeaf ce21 	vmlsldava.s32	ip, r5, q7, q0
[^>]*> eeaf de01 	vmlsldavx.s32	ip, r5, q7, q0
[^>]*> eeaf de21 	vmlsldavax.s32	ip, r5, q7, q0
[^>]*> eeaf ce03 	vmlsldav.s32	ip, r5, q7, q1
[^>]*> eeaf ce23 	vmlsldava.s32	ip, r5, q7, q1
[^>]*> eeaf de03 	vmlsldavx.s32	ip, r5, q7, q1
[^>]*> eeaf de23 	vmlsldavax.s32	ip, r5, q7, q1
[^>]*> eeaf ce05 	vmlsldav.s32	ip, r5, q7, q2
[^>]*> eeaf ce25 	vmlsldava.s32	ip, r5, q7, q2
[^>]*> eeaf de05 	vmlsldavx.s32	ip, r5, q7, q2
[^>]*> eeaf de25 	vmlsldavax.s32	ip, r5, q7, q2
[^>]*> eeaf ce09 	vmlsldav.s32	ip, r5, q7, q4
[^>]*> eeaf ce29 	vmlsldava.s32	ip, r5, q7, q4
[^>]*> eeaf de09 	vmlsldavx.s32	ip, r5, q7, q4
[^>]*> eeaf de29 	vmlsldavax.s32	ip, r5, q7, q4
[^>]*> eeaf ce0f 	vmlsldav.s32	ip, r5, q7, q7
[^>]*> eeaf ce2f 	vmlsldava.s32	ip, r5, q7, q7
[^>]*> eeaf de0f 	vmlsldavx.s32	ip, r5, q7, q7
[^>]*> eeaf de2f 	vmlsldavax.s32	ip, r5, q7, q7
[^>]*> eeb1 ce01 	vmlsldav.s32	ip, r7, q0, q0
[^>]*> eeb1 ce21 	vmlsldava.s32	ip, r7, q0, q0
[^>]*> eeb1 de01 	vmlsldavx.s32	ip, r7, q0, q0
[^>]*> eeb1 de21 	vmlsldavax.s32	ip, r7, q0, q0
[^>]*> eeb1 ce03 	vmlsldav.s32	ip, r7, q0, q1
[^>]*> eeb1 ce23 	vmlsldava.s32	ip, r7, q0, q1
[^>]*> eeb1 de03 	vmlsldavx.s32	ip, r7, q0, q1
[^>]*> eeb1 de23 	vmlsldavax.s32	ip, r7, q0, q1
[^>]*> eeb1 ce05 	vmlsldav.s32	ip, r7, q0, q2
[^>]*> eeb1 ce25 	vmlsldava.s32	ip, r7, q0, q2
[^>]*> eeb1 de05 	vmlsldavx.s32	ip, r7, q0, q2
[^>]*> eeb1 de25 	vmlsldavax.s32	ip, r7, q0, q2
[^>]*> eeb1 ce09 	vmlsldav.s32	ip, r7, q0, q4
[^>]*> eeb1 ce29 	vmlsldava.s32	ip, r7, q0, q4
[^>]*> eeb1 de09 	vmlsldavx.s32	ip, r7, q0, q4
[^>]*> eeb1 de29 	vmlsldavax.s32	ip, r7, q0, q4
[^>]*> eeb1 ce0f 	vmlsldav.s32	ip, r7, q0, q7
[^>]*> eeb1 ce2f 	vmlsldava.s32	ip, r7, q0, q7
[^>]*> eeb1 de0f 	vmlsldavx.s32	ip, r7, q0, q7
[^>]*> eeb1 de2f 	vmlsldavax.s32	ip, r7, q0, q7
[^>]*> eeb3 ce01 	vmlsldav.s32	ip, r7, q1, q0
[^>]*> eeb3 ce21 	vmlsldava.s32	ip, r7, q1, q0
[^>]*> eeb3 de01 	vmlsldavx.s32	ip, r7, q1, q0
[^>]*> eeb3 de21 	vmlsldavax.s32	ip, r7, q1, q0
[^>]*> eeb3 ce03 	vmlsldav.s32	ip, r7, q1, q1
[^>]*> eeb3 ce23 	vmlsldava.s32	ip, r7, q1, q1
[^>]*> eeb3 de03 	vmlsldavx.s32	ip, r7, q1, q1
[^>]*> eeb3 de23 	vmlsldavax.s32	ip, r7, q1, q1
[^>]*> eeb3 ce05 	vmlsldav.s32	ip, r7, q1, q2
[^>]*> eeb3 ce25 	vmlsldava.s32	ip, r7, q1, q2
[^>]*> eeb3 de05 	vmlsldavx.s32	ip, r7, q1, q2
[^>]*> eeb3 de25 	vmlsldavax.s32	ip, r7, q1, q2
[^>]*> eeb3 ce09 	vmlsldav.s32	ip, r7, q1, q4
[^>]*> eeb3 ce29 	vmlsldava.s32	ip, r7, q1, q4
[^>]*> eeb3 de09 	vmlsldavx.s32	ip, r7, q1, q4
[^>]*> eeb3 de29 	vmlsldavax.s32	ip, r7, q1, q4
[^>]*> eeb3 ce0f 	vmlsldav.s32	ip, r7, q1, q7
[^>]*> eeb3 ce2f 	vmlsldava.s32	ip, r7, q1, q7
[^>]*> eeb3 de0f 	vmlsldavx.s32	ip, r7, q1, q7
[^>]*> eeb3 de2f 	vmlsldavax.s32	ip, r7, q1, q7
[^>]*> eeb5 ce01 	vmlsldav.s32	ip, r7, q2, q0
[^>]*> eeb5 ce21 	vmlsldava.s32	ip, r7, q2, q0
[^>]*> eeb5 de01 	vmlsldavx.s32	ip, r7, q2, q0
[^>]*> eeb5 de21 	vmlsldavax.s32	ip, r7, q2, q0
[^>]*> eeb5 ce03 	vmlsldav.s32	ip, r7, q2, q1
[^>]*> eeb5 ce23 	vmlsldava.s32	ip, r7, q2, q1
[^>]*> eeb5 de03 	vmlsldavx.s32	ip, r7, q2, q1
[^>]*> eeb5 de23 	vmlsldavax.s32	ip, r7, q2, q1
[^>]*> eeb5 ce05 	vmlsldav.s32	ip, r7, q2, q2
[^>]*> eeb5 ce25 	vmlsldava.s32	ip, r7, q2, q2
[^>]*> eeb5 de05 	vmlsldavx.s32	ip, r7, q2, q2
[^>]*> eeb5 de25 	vmlsldavax.s32	ip, r7, q2, q2
[^>]*> eeb5 ce09 	vmlsldav.s32	ip, r7, q2, q4
[^>]*> eeb5 ce29 	vmlsldava.s32	ip, r7, q2, q4
[^>]*> eeb5 de09 	vmlsldavx.s32	ip, r7, q2, q4
[^>]*> eeb5 de29 	vmlsldavax.s32	ip, r7, q2, q4
[^>]*> eeb5 ce0f 	vmlsldav.s32	ip, r7, q2, q7
[^>]*> eeb5 ce2f 	vmlsldava.s32	ip, r7, q2, q7
[^>]*> eeb5 de0f 	vmlsldavx.s32	ip, r7, q2, q7
[^>]*> eeb5 de2f 	vmlsldavax.s32	ip, r7, q2, q7
[^>]*> eeb9 ce01 	vmlsldav.s32	ip, r7, q4, q0
[^>]*> eeb9 ce21 	vmlsldava.s32	ip, r7, q4, q0
[^>]*> eeb9 de01 	vmlsldavx.s32	ip, r7, q4, q0
[^>]*> eeb9 de21 	vmlsldavax.s32	ip, r7, q4, q0
[^>]*> eeb9 ce03 	vmlsldav.s32	ip, r7, q4, q1
[^>]*> eeb9 ce23 	vmlsldava.s32	ip, r7, q4, q1
[^>]*> eeb9 de03 	vmlsldavx.s32	ip, r7, q4, q1
[^>]*> eeb9 de23 	vmlsldavax.s32	ip, r7, q4, q1
[^>]*> eeb9 ce05 	vmlsldav.s32	ip, r7, q4, q2
[^>]*> eeb9 ce25 	vmlsldava.s32	ip, r7, q4, q2
[^>]*> eeb9 de05 	vmlsldavx.s32	ip, r7, q4, q2
[^>]*> eeb9 de25 	vmlsldavax.s32	ip, r7, q4, q2
[^>]*> eeb9 ce09 	vmlsldav.s32	ip, r7, q4, q4
[^>]*> eeb9 ce29 	vmlsldava.s32	ip, r7, q4, q4
[^>]*> eeb9 de09 	vmlsldavx.s32	ip, r7, q4, q4
[^>]*> eeb9 de29 	vmlsldavax.s32	ip, r7, q4, q4
[^>]*> eeb9 ce0f 	vmlsldav.s32	ip, r7, q4, q7
[^>]*> eeb9 ce2f 	vmlsldava.s32	ip, r7, q4, q7
[^>]*> eeb9 de0f 	vmlsldavx.s32	ip, r7, q4, q7
[^>]*> eeb9 de2f 	vmlsldavax.s32	ip, r7, q4, q7
[^>]*> eebf ce01 	vmlsldav.s32	ip, r7, q7, q0
[^>]*> eebf ce21 	vmlsldava.s32	ip, r7, q7, q0
[^>]*> eebf de01 	vmlsldavx.s32	ip, r7, q7, q0
[^>]*> eebf de21 	vmlsldavax.s32	ip, r7, q7, q0
[^>]*> eebf ce03 	vmlsldav.s32	ip, r7, q7, q1
[^>]*> eebf ce23 	vmlsldava.s32	ip, r7, q7, q1
[^>]*> eebf de03 	vmlsldavx.s32	ip, r7, q7, q1
[^>]*> eebf de23 	vmlsldavax.s32	ip, r7, q7, q1
[^>]*> eebf ce05 	vmlsldav.s32	ip, r7, q7, q2
[^>]*> eebf ce25 	vmlsldava.s32	ip, r7, q7, q2
[^>]*> eebf de05 	vmlsldavx.s32	ip, r7, q7, q2
[^>]*> eebf de25 	vmlsldavax.s32	ip, r7, q7, q2
[^>]*> eebf ce09 	vmlsldav.s32	ip, r7, q7, q4
[^>]*> eebf ce29 	vmlsldava.s32	ip, r7, q7, q4
[^>]*> eebf de09 	vmlsldavx.s32	ip, r7, q7, q4
[^>]*> eebf de29 	vmlsldavax.s32	ip, r7, q7, q4
[^>]*> eebf ce0f 	vmlsldav.s32	ip, r7, q7, q7
[^>]*> eebf ce2f 	vmlsldava.s32	ip, r7, q7, q7
[^>]*> eebf de0f 	vmlsldavx.s32	ip, r7, q7, q7
[^>]*> eebf de2f 	vmlsldavax.s32	ip, r7, q7, q7
[^>]*> eec1 ce01 	vmlsldav.s32	ip, r9, q0, q0
[^>]*> eec1 ce21 	vmlsldava.s32	ip, r9, q0, q0
[^>]*> eec1 de01 	vmlsldavx.s32	ip, r9, q0, q0
[^>]*> eec1 de21 	vmlsldavax.s32	ip, r9, q0, q0
[^>]*> eec1 ce03 	vmlsldav.s32	ip, r9, q0, q1
[^>]*> eec1 ce23 	vmlsldava.s32	ip, r9, q0, q1
[^>]*> eec1 de03 	vmlsldavx.s32	ip, r9, q0, q1
[^>]*> eec1 de23 	vmlsldavax.s32	ip, r9, q0, q1
[^>]*> eec1 ce05 	vmlsldav.s32	ip, r9, q0, q2
[^>]*> eec1 ce25 	vmlsldava.s32	ip, r9, q0, q2
[^>]*> eec1 de05 	vmlsldavx.s32	ip, r9, q0, q2
[^>]*> eec1 de25 	vmlsldavax.s32	ip, r9, q0, q2
[^>]*> eec1 ce09 	vmlsldav.s32	ip, r9, q0, q4
[^>]*> eec1 ce29 	vmlsldava.s32	ip, r9, q0, q4
[^>]*> eec1 de09 	vmlsldavx.s32	ip, r9, q0, q4
[^>]*> eec1 de29 	vmlsldavax.s32	ip, r9, q0, q4
[^>]*> eec1 ce0f 	vmlsldav.s32	ip, r9, q0, q7
[^>]*> eec1 ce2f 	vmlsldava.s32	ip, r9, q0, q7
[^>]*> eec1 de0f 	vmlsldavx.s32	ip, r9, q0, q7
[^>]*> eec1 de2f 	vmlsldavax.s32	ip, r9, q0, q7
[^>]*> eec3 ce01 	vmlsldav.s32	ip, r9, q1, q0
[^>]*> eec3 ce21 	vmlsldava.s32	ip, r9, q1, q0
[^>]*> eec3 de01 	vmlsldavx.s32	ip, r9, q1, q0
[^>]*> eec3 de21 	vmlsldavax.s32	ip, r9, q1, q0
[^>]*> eec3 ce03 	vmlsldav.s32	ip, r9, q1, q1
[^>]*> eec3 ce23 	vmlsldava.s32	ip, r9, q1, q1
[^>]*> eec3 de03 	vmlsldavx.s32	ip, r9, q1, q1
[^>]*> eec3 de23 	vmlsldavax.s32	ip, r9, q1, q1
[^>]*> eec3 ce05 	vmlsldav.s32	ip, r9, q1, q2
[^>]*> eec3 ce25 	vmlsldava.s32	ip, r9, q1, q2
[^>]*> eec3 de05 	vmlsldavx.s32	ip, r9, q1, q2
[^>]*> eec3 de25 	vmlsldavax.s32	ip, r9, q1, q2
[^>]*> eec3 ce09 	vmlsldav.s32	ip, r9, q1, q4
[^>]*> eec3 ce29 	vmlsldava.s32	ip, r9, q1, q4
[^>]*> eec3 de09 	vmlsldavx.s32	ip, r9, q1, q4
[^>]*> eec3 de29 	vmlsldavax.s32	ip, r9, q1, q4
[^>]*> eec3 ce0f 	vmlsldav.s32	ip, r9, q1, q7
[^>]*> eec3 ce2f 	vmlsldava.s32	ip, r9, q1, q7
[^>]*> eec3 de0f 	vmlsldavx.s32	ip, r9, q1, q7
[^>]*> eec3 de2f 	vmlsldavax.s32	ip, r9, q1, q7
[^>]*> eec5 ce01 	vmlsldav.s32	ip, r9, q2, q0
[^>]*> eec5 ce21 	vmlsldava.s32	ip, r9, q2, q0
[^>]*> eec5 de01 	vmlsldavx.s32	ip, r9, q2, q0
[^>]*> eec5 de21 	vmlsldavax.s32	ip, r9, q2, q0
[^>]*> eec5 ce03 	vmlsldav.s32	ip, r9, q2, q1
[^>]*> eec5 ce23 	vmlsldava.s32	ip, r9, q2, q1
[^>]*> eec5 de03 	vmlsldavx.s32	ip, r9, q2, q1
[^>]*> eec5 de23 	vmlsldavax.s32	ip, r9, q2, q1
[^>]*> eec5 ce05 	vmlsldav.s32	ip, r9, q2, q2
[^>]*> eec5 ce25 	vmlsldava.s32	ip, r9, q2, q2
[^>]*> eec5 de05 	vmlsldavx.s32	ip, r9, q2, q2
[^>]*> eec5 de25 	vmlsldavax.s32	ip, r9, q2, q2
[^>]*> eec5 ce09 	vmlsldav.s32	ip, r9, q2, q4
[^>]*> eec5 ce29 	vmlsldava.s32	ip, r9, q2, q4
[^>]*> eec5 de09 	vmlsldavx.s32	ip, r9, q2, q4
[^>]*> eec5 de29 	vmlsldavax.s32	ip, r9, q2, q4
[^>]*> eec5 ce0f 	vmlsldav.s32	ip, r9, q2, q7
[^>]*> eec5 ce2f 	vmlsldava.s32	ip, r9, q2, q7
[^>]*> eec5 de0f 	vmlsldavx.s32	ip, r9, q2, q7
[^>]*> eec5 de2f 	vmlsldavax.s32	ip, r9, q2, q7
[^>]*> eec9 ce01 	vmlsldav.s32	ip, r9, q4, q0
[^>]*> eec9 ce21 	vmlsldava.s32	ip, r9, q4, q0
[^>]*> eec9 de01 	vmlsldavx.s32	ip, r9, q4, q0
[^>]*> eec9 de21 	vmlsldavax.s32	ip, r9, q4, q0
[^>]*> eec9 ce03 	vmlsldav.s32	ip, r9, q4, q1
[^>]*> eec9 ce23 	vmlsldava.s32	ip, r9, q4, q1
[^>]*> eec9 de03 	vmlsldavx.s32	ip, r9, q4, q1
[^>]*> eec9 de23 	vmlsldavax.s32	ip, r9, q4, q1
[^>]*> eec9 ce05 	vmlsldav.s32	ip, r9, q4, q2
[^>]*> eec9 ce25 	vmlsldava.s32	ip, r9, q4, q2
[^>]*> eec9 de05 	vmlsldavx.s32	ip, r9, q4, q2
[^>]*> eec9 de25 	vmlsldavax.s32	ip, r9, q4, q2
[^>]*> eec9 ce09 	vmlsldav.s32	ip, r9, q4, q4
[^>]*> eec9 ce29 	vmlsldava.s32	ip, r9, q4, q4
[^>]*> eec9 de09 	vmlsldavx.s32	ip, r9, q4, q4
[^>]*> eec9 de29 	vmlsldavax.s32	ip, r9, q4, q4
[^>]*> eec9 ce0f 	vmlsldav.s32	ip, r9, q4, q7
[^>]*> eec9 ce2f 	vmlsldava.s32	ip, r9, q4, q7
[^>]*> eec9 de0f 	vmlsldavx.s32	ip, r9, q4, q7
[^>]*> eec9 de2f 	vmlsldavax.s32	ip, r9, q4, q7
[^>]*> eecf ce01 	vmlsldav.s32	ip, r9, q7, q0
[^>]*> eecf ce21 	vmlsldava.s32	ip, r9, q7, q0
[^>]*> eecf de01 	vmlsldavx.s32	ip, r9, q7, q0
[^>]*> eecf de21 	vmlsldavax.s32	ip, r9, q7, q0
[^>]*> eecf ce03 	vmlsldav.s32	ip, r9, q7, q1
[^>]*> eecf ce23 	vmlsldava.s32	ip, r9, q7, q1
[^>]*> eecf de03 	vmlsldavx.s32	ip, r9, q7, q1
[^>]*> eecf de23 	vmlsldavax.s32	ip, r9, q7, q1
[^>]*> eecf ce05 	vmlsldav.s32	ip, r9, q7, q2
[^>]*> eecf ce25 	vmlsldava.s32	ip, r9, q7, q2
[^>]*> eecf de05 	vmlsldavx.s32	ip, r9, q7, q2
[^>]*> eecf de25 	vmlsldavax.s32	ip, r9, q7, q2
[^>]*> eecf ce09 	vmlsldav.s32	ip, r9, q7, q4
[^>]*> eecf ce29 	vmlsldava.s32	ip, r9, q7, q4
[^>]*> eecf de09 	vmlsldavx.s32	ip, r9, q7, q4
[^>]*> eecf de29 	vmlsldavax.s32	ip, r9, q7, q4
[^>]*> eecf ce0f 	vmlsldav.s32	ip, r9, q7, q7
[^>]*> eecf ce2f 	vmlsldava.s32	ip, r9, q7, q7
[^>]*> eecf de0f 	vmlsldavx.s32	ip, r9, q7, q7
[^>]*> eecf de2f 	vmlsldavax.s32	ip, r9, q7, q7
[^>]*> eed1 ce01 	vmlsldav.s32	ip, fp, q0, q0
[^>]*> eed1 ce21 	vmlsldava.s32	ip, fp, q0, q0
[^>]*> eed1 de01 	vmlsldavx.s32	ip, fp, q0, q0
[^>]*> eed1 de21 	vmlsldavax.s32	ip, fp, q0, q0
[^>]*> eed1 ce03 	vmlsldav.s32	ip, fp, q0, q1
[^>]*> eed1 ce23 	vmlsldava.s32	ip, fp, q0, q1
[^>]*> eed1 de03 	vmlsldavx.s32	ip, fp, q0, q1
[^>]*> eed1 de23 	vmlsldavax.s32	ip, fp, q0, q1
[^>]*> eed1 ce05 	vmlsldav.s32	ip, fp, q0, q2
[^>]*> eed1 ce25 	vmlsldava.s32	ip, fp, q0, q2
[^>]*> eed1 de05 	vmlsldavx.s32	ip, fp, q0, q2
[^>]*> eed1 de25 	vmlsldavax.s32	ip, fp, q0, q2
[^>]*> eed1 ce09 	vmlsldav.s32	ip, fp, q0, q4
[^>]*> eed1 ce29 	vmlsldava.s32	ip, fp, q0, q4
[^>]*> eed1 de09 	vmlsldavx.s32	ip, fp, q0, q4
[^>]*> eed1 de29 	vmlsldavax.s32	ip, fp, q0, q4
[^>]*> eed1 ce0f 	vmlsldav.s32	ip, fp, q0, q7
[^>]*> eed1 ce2f 	vmlsldava.s32	ip, fp, q0, q7
[^>]*> eed1 de0f 	vmlsldavx.s32	ip, fp, q0, q7
[^>]*> eed1 de2f 	vmlsldavax.s32	ip, fp, q0, q7
[^>]*> eed3 ce01 	vmlsldav.s32	ip, fp, q1, q0
[^>]*> eed3 ce21 	vmlsldava.s32	ip, fp, q1, q0
[^>]*> eed3 de01 	vmlsldavx.s32	ip, fp, q1, q0
[^>]*> eed3 de21 	vmlsldavax.s32	ip, fp, q1, q0
[^>]*> eed3 ce03 	vmlsldav.s32	ip, fp, q1, q1
[^>]*> eed3 ce23 	vmlsldava.s32	ip, fp, q1, q1
[^>]*> eed3 de03 	vmlsldavx.s32	ip, fp, q1, q1
[^>]*> eed3 de23 	vmlsldavax.s32	ip, fp, q1, q1
[^>]*> eed3 ce05 	vmlsldav.s32	ip, fp, q1, q2
[^>]*> eed3 ce25 	vmlsldava.s32	ip, fp, q1, q2
[^>]*> eed3 de05 	vmlsldavx.s32	ip, fp, q1, q2
[^>]*> eed3 de25 	vmlsldavax.s32	ip, fp, q1, q2
[^>]*> eed3 ce09 	vmlsldav.s32	ip, fp, q1, q4
[^>]*> eed3 ce29 	vmlsldava.s32	ip, fp, q1, q4
[^>]*> eed3 de09 	vmlsldavx.s32	ip, fp, q1, q4
[^>]*> eed3 de29 	vmlsldavax.s32	ip, fp, q1, q4
[^>]*> eed3 ce0f 	vmlsldav.s32	ip, fp, q1, q7
[^>]*> eed3 ce2f 	vmlsldava.s32	ip, fp, q1, q7
[^>]*> eed3 de0f 	vmlsldavx.s32	ip, fp, q1, q7
[^>]*> eed3 de2f 	vmlsldavax.s32	ip, fp, q1, q7
[^>]*> eed5 ce01 	vmlsldav.s32	ip, fp, q2, q0
[^>]*> eed5 ce21 	vmlsldava.s32	ip, fp, q2, q0
[^>]*> eed5 de01 	vmlsldavx.s32	ip, fp, q2, q0
[^>]*> eed5 de21 	vmlsldavax.s32	ip, fp, q2, q0
[^>]*> eed5 ce03 	vmlsldav.s32	ip, fp, q2, q1
[^>]*> eed5 ce23 	vmlsldava.s32	ip, fp, q2, q1
[^>]*> eed5 de03 	vmlsldavx.s32	ip, fp, q2, q1
[^>]*> eed5 de23 	vmlsldavax.s32	ip, fp, q2, q1
[^>]*> eed5 ce05 	vmlsldav.s32	ip, fp, q2, q2
[^>]*> eed5 ce25 	vmlsldava.s32	ip, fp, q2, q2
[^>]*> eed5 de05 	vmlsldavx.s32	ip, fp, q2, q2
[^>]*> eed5 de25 	vmlsldavax.s32	ip, fp, q2, q2
[^>]*> eed5 ce09 	vmlsldav.s32	ip, fp, q2, q4
[^>]*> eed5 ce29 	vmlsldava.s32	ip, fp, q2, q4
[^>]*> eed5 de09 	vmlsldavx.s32	ip, fp, q2, q4
[^>]*> eed5 de29 	vmlsldavax.s32	ip, fp, q2, q4
[^>]*> eed5 ce0f 	vmlsldav.s32	ip, fp, q2, q7
[^>]*> eed5 ce2f 	vmlsldava.s32	ip, fp, q2, q7
[^>]*> eed5 de0f 	vmlsldavx.s32	ip, fp, q2, q7
[^>]*> eed5 de2f 	vmlsldavax.s32	ip, fp, q2, q7
[^>]*> eed9 ce01 	vmlsldav.s32	ip, fp, q4, q0
[^>]*> eed9 ce21 	vmlsldava.s32	ip, fp, q4, q0
[^>]*> eed9 de01 	vmlsldavx.s32	ip, fp, q4, q0
[^>]*> eed9 de21 	vmlsldavax.s32	ip, fp, q4, q0
[^>]*> eed9 ce03 	vmlsldav.s32	ip, fp, q4, q1
[^>]*> eed9 ce23 	vmlsldava.s32	ip, fp, q4, q1
[^>]*> eed9 de03 	vmlsldavx.s32	ip, fp, q4, q1
[^>]*> eed9 de23 	vmlsldavax.s32	ip, fp, q4, q1
[^>]*> eed9 ce05 	vmlsldav.s32	ip, fp, q4, q2
[^>]*> eed9 ce25 	vmlsldava.s32	ip, fp, q4, q2
[^>]*> eed9 de05 	vmlsldavx.s32	ip, fp, q4, q2
[^>]*> eed9 de25 	vmlsldavax.s32	ip, fp, q4, q2
[^>]*> eed9 ce09 	vmlsldav.s32	ip, fp, q4, q4
[^>]*> eed9 ce29 	vmlsldava.s32	ip, fp, q4, q4
[^>]*> eed9 de09 	vmlsldavx.s32	ip, fp, q4, q4
[^>]*> eed9 de29 	vmlsldavax.s32	ip, fp, q4, q4
[^>]*> eed9 ce0f 	vmlsldav.s32	ip, fp, q4, q7
[^>]*> eed9 ce2f 	vmlsldava.s32	ip, fp, q4, q7
[^>]*> eed9 de0f 	vmlsldavx.s32	ip, fp, q4, q7
[^>]*> eed9 de2f 	vmlsldavax.s32	ip, fp, q4, q7
[^>]*> eedf ce01 	vmlsldav.s32	ip, fp, q7, q0
[^>]*> eedf ce21 	vmlsldava.s32	ip, fp, q7, q0
[^>]*> eedf de01 	vmlsldavx.s32	ip, fp, q7, q0
[^>]*> eedf de21 	vmlsldavax.s32	ip, fp, q7, q0
[^>]*> eedf ce03 	vmlsldav.s32	ip, fp, q7, q1
[^>]*> eedf ce23 	vmlsldava.s32	ip, fp, q7, q1
[^>]*> eedf de03 	vmlsldavx.s32	ip, fp, q7, q1
[^>]*> eedf de23 	vmlsldavax.s32	ip, fp, q7, q1
[^>]*> eedf ce05 	vmlsldav.s32	ip, fp, q7, q2
[^>]*> eedf ce25 	vmlsldava.s32	ip, fp, q7, q2
[^>]*> eedf de05 	vmlsldavx.s32	ip, fp, q7, q2
[^>]*> eedf de25 	vmlsldavax.s32	ip, fp, q7, q2
[^>]*> eedf ce09 	vmlsldav.s32	ip, fp, q7, q4
[^>]*> eedf ce29 	vmlsldava.s32	ip, fp, q7, q4
[^>]*> eedf de09 	vmlsldavx.s32	ip, fp, q7, q4
[^>]*> eedf de29 	vmlsldavax.s32	ip, fp, q7, q4
[^>]*> eedf ce0f 	vmlsldav.s32	ip, fp, q7, q7
[^>]*> eedf ce2f 	vmlsldava.s32	ip, fp, q7, q7
[^>]*> eedf de0f 	vmlsldavx.s32	ip, fp, q7, q7
[^>]*> eedf de2f 	vmlsldavax.s32	ip, fp, q7, q7
[^>]*> ee81 ee01 	vmlsldav.s32	lr, r1, q0, q0
[^>]*> ee81 ee21 	vmlsldava.s32	lr, r1, q0, q0
[^>]*> ee81 fe01 	vmlsldavx.s32	lr, r1, q0, q0
[^>]*> ee81 fe21 	vmlsldavax.s32	lr, r1, q0, q0
[^>]*> ee81 ee03 	vmlsldav.s32	lr, r1, q0, q1
[^>]*> ee81 ee23 	vmlsldava.s32	lr, r1, q0, q1
[^>]*> ee81 fe03 	vmlsldavx.s32	lr, r1, q0, q1
[^>]*> ee81 fe23 	vmlsldavax.s32	lr, r1, q0, q1
[^>]*> ee81 ee05 	vmlsldav.s32	lr, r1, q0, q2
[^>]*> ee81 ee25 	vmlsldava.s32	lr, r1, q0, q2
[^>]*> ee81 fe05 	vmlsldavx.s32	lr, r1, q0, q2
[^>]*> ee81 fe25 	vmlsldavax.s32	lr, r1, q0, q2
[^>]*> ee81 ee09 	vmlsldav.s32	lr, r1, q0, q4
[^>]*> ee81 ee29 	vmlsldava.s32	lr, r1, q0, q4
[^>]*> ee81 fe09 	vmlsldavx.s32	lr, r1, q0, q4
[^>]*> ee81 fe29 	vmlsldavax.s32	lr, r1, q0, q4
[^>]*> ee81 ee0f 	vmlsldav.s32	lr, r1, q0, q7
[^>]*> ee81 ee2f 	vmlsldava.s32	lr, r1, q0, q7
[^>]*> ee81 fe0f 	vmlsldavx.s32	lr, r1, q0, q7
[^>]*> ee81 fe2f 	vmlsldavax.s32	lr, r1, q0, q7
[^>]*> ee83 ee01 	vmlsldav.s32	lr, r1, q1, q0
[^>]*> ee83 ee21 	vmlsldava.s32	lr, r1, q1, q0
[^>]*> ee83 fe01 	vmlsldavx.s32	lr, r1, q1, q0
[^>]*> ee83 fe21 	vmlsldavax.s32	lr, r1, q1, q0
[^>]*> ee83 ee03 	vmlsldav.s32	lr, r1, q1, q1
[^>]*> ee83 ee23 	vmlsldava.s32	lr, r1, q1, q1
[^>]*> ee83 fe03 	vmlsldavx.s32	lr, r1, q1, q1
[^>]*> ee83 fe23 	vmlsldavax.s32	lr, r1, q1, q1
[^>]*> ee83 ee05 	vmlsldav.s32	lr, r1, q1, q2
[^>]*> ee83 ee25 	vmlsldava.s32	lr, r1, q1, q2
[^>]*> ee83 fe05 	vmlsldavx.s32	lr, r1, q1, q2
[^>]*> ee83 fe25 	vmlsldavax.s32	lr, r1, q1, q2
[^>]*> ee83 ee09 	vmlsldav.s32	lr, r1, q1, q4
[^>]*> ee83 ee29 	vmlsldava.s32	lr, r1, q1, q4
[^>]*> ee83 fe09 	vmlsldavx.s32	lr, r1, q1, q4
[^>]*> ee83 fe29 	vmlsldavax.s32	lr, r1, q1, q4
[^>]*> ee83 ee0f 	vmlsldav.s32	lr, r1, q1, q7
[^>]*> ee83 ee2f 	vmlsldava.s32	lr, r1, q1, q7
[^>]*> ee83 fe0f 	vmlsldavx.s32	lr, r1, q1, q7
[^>]*> ee83 fe2f 	vmlsldavax.s32	lr, r1, q1, q7
[^>]*> ee85 ee01 	vmlsldav.s32	lr, r1, q2, q0
[^>]*> ee85 ee21 	vmlsldava.s32	lr, r1, q2, q0
[^>]*> ee85 fe01 	vmlsldavx.s32	lr, r1, q2, q0
[^>]*> ee85 fe21 	vmlsldavax.s32	lr, r1, q2, q0
[^>]*> ee85 ee03 	vmlsldav.s32	lr, r1, q2, q1
[^>]*> ee85 ee23 	vmlsldava.s32	lr, r1, q2, q1
[^>]*> ee85 fe03 	vmlsldavx.s32	lr, r1, q2, q1
[^>]*> ee85 fe23 	vmlsldavax.s32	lr, r1, q2, q1
[^>]*> ee85 ee05 	vmlsldav.s32	lr, r1, q2, q2
[^>]*> ee85 ee25 	vmlsldava.s32	lr, r1, q2, q2
[^>]*> ee85 fe05 	vmlsldavx.s32	lr, r1, q2, q2
[^>]*> ee85 fe25 	vmlsldavax.s32	lr, r1, q2, q2
[^>]*> ee85 ee09 	vmlsldav.s32	lr, r1, q2, q4
[^>]*> ee85 ee29 	vmlsldava.s32	lr, r1, q2, q4
[^>]*> ee85 fe09 	vmlsldavx.s32	lr, r1, q2, q4
[^>]*> ee85 fe29 	vmlsldavax.s32	lr, r1, q2, q4
[^>]*> ee85 ee0f 	vmlsldav.s32	lr, r1, q2, q7
[^>]*> ee85 ee2f 	vmlsldava.s32	lr, r1, q2, q7
[^>]*> ee85 fe0f 	vmlsldavx.s32	lr, r1, q2, q7
[^>]*> ee85 fe2f 	vmlsldavax.s32	lr, r1, q2, q7
[^>]*> ee89 ee01 	vmlsldav.s32	lr, r1, q4, q0
[^>]*> ee89 ee21 	vmlsldava.s32	lr, r1, q4, q0
[^>]*> ee89 fe01 	vmlsldavx.s32	lr, r1, q4, q0
[^>]*> ee89 fe21 	vmlsldavax.s32	lr, r1, q4, q0
[^>]*> ee89 ee03 	vmlsldav.s32	lr, r1, q4, q1
[^>]*> ee89 ee23 	vmlsldava.s32	lr, r1, q4, q1
[^>]*> ee89 fe03 	vmlsldavx.s32	lr, r1, q4, q1
[^>]*> ee89 fe23 	vmlsldavax.s32	lr, r1, q4, q1
[^>]*> ee89 ee05 	vmlsldav.s32	lr, r1, q4, q2
[^>]*> ee89 ee25 	vmlsldava.s32	lr, r1, q4, q2
[^>]*> ee89 fe05 	vmlsldavx.s32	lr, r1, q4, q2
[^>]*> ee89 fe25 	vmlsldavax.s32	lr, r1, q4, q2
[^>]*> ee89 ee09 	vmlsldav.s32	lr, r1, q4, q4
[^>]*> ee89 ee29 	vmlsldava.s32	lr, r1, q4, q4
[^>]*> ee89 fe09 	vmlsldavx.s32	lr, r1, q4, q4
[^>]*> ee89 fe29 	vmlsldavax.s32	lr, r1, q4, q4
[^>]*> ee89 ee0f 	vmlsldav.s32	lr, r1, q4, q7
[^>]*> ee89 ee2f 	vmlsldava.s32	lr, r1, q4, q7
[^>]*> ee89 fe0f 	vmlsldavx.s32	lr, r1, q4, q7
[^>]*> ee89 fe2f 	vmlsldavax.s32	lr, r1, q4, q7
[^>]*> ee8f ee01 	vmlsldav.s32	lr, r1, q7, q0
[^>]*> ee8f ee21 	vmlsldava.s32	lr, r1, q7, q0
[^>]*> ee8f fe01 	vmlsldavx.s32	lr, r1, q7, q0
[^>]*> ee8f fe21 	vmlsldavax.s32	lr, r1, q7, q0
[^>]*> ee8f ee03 	vmlsldav.s32	lr, r1, q7, q1
[^>]*> ee8f ee23 	vmlsldava.s32	lr, r1, q7, q1
[^>]*> ee8f fe03 	vmlsldavx.s32	lr, r1, q7, q1
[^>]*> ee8f fe23 	vmlsldavax.s32	lr, r1, q7, q1
[^>]*> ee8f ee05 	vmlsldav.s32	lr, r1, q7, q2
[^>]*> ee8f ee25 	vmlsldava.s32	lr, r1, q7, q2
[^>]*> ee8f fe05 	vmlsldavx.s32	lr, r1, q7, q2
[^>]*> ee8f fe25 	vmlsldavax.s32	lr, r1, q7, q2
[^>]*> ee8f ee09 	vmlsldav.s32	lr, r1, q7, q4
[^>]*> ee8f ee29 	vmlsldava.s32	lr, r1, q7, q4
[^>]*> ee8f fe09 	vmlsldavx.s32	lr, r1, q7, q4
[^>]*> ee8f fe29 	vmlsldavax.s32	lr, r1, q7, q4
[^>]*> ee8f ee0f 	vmlsldav.s32	lr, r1, q7, q7
[^>]*> ee8f ee2f 	vmlsldava.s32	lr, r1, q7, q7
[^>]*> ee8f fe0f 	vmlsldavx.s32	lr, r1, q7, q7
[^>]*> ee8f fe2f 	vmlsldavax.s32	lr, r1, q7, q7
[^>]*> ee91 ee01 	vmlsldav.s32	lr, r3, q0, q0
[^>]*> ee91 ee21 	vmlsldava.s32	lr, r3, q0, q0
[^>]*> ee91 fe01 	vmlsldavx.s32	lr, r3, q0, q0
[^>]*> ee91 fe21 	vmlsldavax.s32	lr, r3, q0, q0
[^>]*> ee91 ee03 	vmlsldav.s32	lr, r3, q0, q1
[^>]*> ee91 ee23 	vmlsldava.s32	lr, r3, q0, q1
[^>]*> ee91 fe03 	vmlsldavx.s32	lr, r3, q0, q1
[^>]*> ee91 fe23 	vmlsldavax.s32	lr, r3, q0, q1
[^>]*> ee91 ee05 	vmlsldav.s32	lr, r3, q0, q2
[^>]*> ee91 ee25 	vmlsldava.s32	lr, r3, q0, q2
[^>]*> ee91 fe05 	vmlsldavx.s32	lr, r3, q0, q2
[^>]*> ee91 fe25 	vmlsldavax.s32	lr, r3, q0, q2
[^>]*> ee91 ee09 	vmlsldav.s32	lr, r3, q0, q4
[^>]*> ee91 ee29 	vmlsldava.s32	lr, r3, q0, q4
[^>]*> ee91 fe09 	vmlsldavx.s32	lr, r3, q0, q4
[^>]*> ee91 fe29 	vmlsldavax.s32	lr, r3, q0, q4
[^>]*> ee91 ee0f 	vmlsldav.s32	lr, r3, q0, q7
[^>]*> ee91 ee2f 	vmlsldava.s32	lr, r3, q0, q7
[^>]*> ee91 fe0f 	vmlsldavx.s32	lr, r3, q0, q7
[^>]*> ee91 fe2f 	vmlsldavax.s32	lr, r3, q0, q7
[^>]*> ee93 ee01 	vmlsldav.s32	lr, r3, q1, q0
[^>]*> ee93 ee21 	vmlsldava.s32	lr, r3, q1, q0
[^>]*> ee93 fe01 	vmlsldavx.s32	lr, r3, q1, q0
[^>]*> ee93 fe21 	vmlsldavax.s32	lr, r3, q1, q0
[^>]*> ee93 ee03 	vmlsldav.s32	lr, r3, q1, q1
[^>]*> ee93 ee23 	vmlsldava.s32	lr, r3, q1, q1
[^>]*> ee93 fe03 	vmlsldavx.s32	lr, r3, q1, q1
[^>]*> ee93 fe23 	vmlsldavax.s32	lr, r3, q1, q1
[^>]*> ee93 ee05 	vmlsldav.s32	lr, r3, q1, q2
[^>]*> ee93 ee25 	vmlsldava.s32	lr, r3, q1, q2
[^>]*> ee93 fe05 	vmlsldavx.s32	lr, r3, q1, q2
[^>]*> ee93 fe25 	vmlsldavax.s32	lr, r3, q1, q2
[^>]*> ee93 ee09 	vmlsldav.s32	lr, r3, q1, q4
[^>]*> ee93 ee29 	vmlsldava.s32	lr, r3, q1, q4
[^>]*> ee93 fe09 	vmlsldavx.s32	lr, r3, q1, q4
[^>]*> ee93 fe29 	vmlsldavax.s32	lr, r3, q1, q4
[^>]*> ee93 ee0f 	vmlsldav.s32	lr, r3, q1, q7
[^>]*> ee93 ee2f 	vmlsldava.s32	lr, r3, q1, q7
[^>]*> ee93 fe0f 	vmlsldavx.s32	lr, r3, q1, q7
[^>]*> ee93 fe2f 	vmlsldavax.s32	lr, r3, q1, q7
[^>]*> ee95 ee01 	vmlsldav.s32	lr, r3, q2, q0
[^>]*> ee95 ee21 	vmlsldava.s32	lr, r3, q2, q0
[^>]*> ee95 fe01 	vmlsldavx.s32	lr, r3, q2, q0
[^>]*> ee95 fe21 	vmlsldavax.s32	lr, r3, q2, q0
[^>]*> ee95 ee03 	vmlsldav.s32	lr, r3, q2, q1
[^>]*> ee95 ee23 	vmlsldava.s32	lr, r3, q2, q1
[^>]*> ee95 fe03 	vmlsldavx.s32	lr, r3, q2, q1
[^>]*> ee95 fe23 	vmlsldavax.s32	lr, r3, q2, q1
[^>]*> ee95 ee05 	vmlsldav.s32	lr, r3, q2, q2
[^>]*> ee95 ee25 	vmlsldava.s32	lr, r3, q2, q2
[^>]*> ee95 fe05 	vmlsldavx.s32	lr, r3, q2, q2
[^>]*> ee95 fe25 	vmlsldavax.s32	lr, r3, q2, q2
[^>]*> ee95 ee09 	vmlsldav.s32	lr, r3, q2, q4
[^>]*> ee95 ee29 	vmlsldava.s32	lr, r3, q2, q4
[^>]*> ee95 fe09 	vmlsldavx.s32	lr, r3, q2, q4
[^>]*> ee95 fe29 	vmlsldavax.s32	lr, r3, q2, q4
[^>]*> ee95 ee0f 	vmlsldav.s32	lr, r3, q2, q7
[^>]*> ee95 ee2f 	vmlsldava.s32	lr, r3, q2, q7
[^>]*> ee95 fe0f 	vmlsldavx.s32	lr, r3, q2, q7
[^>]*> ee95 fe2f 	vmlsldavax.s32	lr, r3, q2, q7
[^>]*> ee99 ee01 	vmlsldav.s32	lr, r3, q4, q0
[^>]*> ee99 ee21 	vmlsldava.s32	lr, r3, q4, q0
[^>]*> ee99 fe01 	vmlsldavx.s32	lr, r3, q4, q0
[^>]*> ee99 fe21 	vmlsldavax.s32	lr, r3, q4, q0
[^>]*> ee99 ee03 	vmlsldav.s32	lr, r3, q4, q1
[^>]*> ee99 ee23 	vmlsldava.s32	lr, r3, q4, q1
[^>]*> ee99 fe03 	vmlsldavx.s32	lr, r3, q4, q1
[^>]*> ee99 fe23 	vmlsldavax.s32	lr, r3, q4, q1
[^>]*> ee99 ee05 	vmlsldav.s32	lr, r3, q4, q2
[^>]*> ee99 ee25 	vmlsldava.s32	lr, r3, q4, q2
[^>]*> ee99 fe05 	vmlsldavx.s32	lr, r3, q4, q2
[^>]*> ee99 fe25 	vmlsldavax.s32	lr, r3, q4, q2
[^>]*> ee99 ee09 	vmlsldav.s32	lr, r3, q4, q4
[^>]*> ee99 ee29 	vmlsldava.s32	lr, r3, q4, q4
[^>]*> ee99 fe09 	vmlsldavx.s32	lr, r3, q4, q4
[^>]*> ee99 fe29 	vmlsldavax.s32	lr, r3, q4, q4
[^>]*> ee99 ee0f 	vmlsldav.s32	lr, r3, q4, q7
[^>]*> ee99 ee2f 	vmlsldava.s32	lr, r3, q4, q7
[^>]*> ee99 fe0f 	vmlsldavx.s32	lr, r3, q4, q7
[^>]*> ee99 fe2f 	vmlsldavax.s32	lr, r3, q4, q7
[^>]*> ee9f ee01 	vmlsldav.s32	lr, r3, q7, q0
[^>]*> ee9f ee21 	vmlsldava.s32	lr, r3, q7, q0
[^>]*> ee9f fe01 	vmlsldavx.s32	lr, r3, q7, q0
[^>]*> ee9f fe21 	vmlsldavax.s32	lr, r3, q7, q0
[^>]*> ee9f ee03 	vmlsldav.s32	lr, r3, q7, q1
[^>]*> ee9f ee23 	vmlsldava.s32	lr, r3, q7, q1
[^>]*> ee9f fe03 	vmlsldavx.s32	lr, r3, q7, q1
[^>]*> ee9f fe23 	vmlsldavax.s32	lr, r3, q7, q1
[^>]*> ee9f ee05 	vmlsldav.s32	lr, r3, q7, q2
[^>]*> ee9f ee25 	vmlsldava.s32	lr, r3, q7, q2
[^>]*> ee9f fe05 	vmlsldavx.s32	lr, r3, q7, q2
[^>]*> ee9f fe25 	vmlsldavax.s32	lr, r3, q7, q2
[^>]*> ee9f ee09 	vmlsldav.s32	lr, r3, q7, q4
[^>]*> ee9f ee29 	vmlsldava.s32	lr, r3, q7, q4
[^>]*> ee9f fe09 	vmlsldavx.s32	lr, r3, q7, q4
[^>]*> ee9f fe29 	vmlsldavax.s32	lr, r3, q7, q4
[^>]*> ee9f ee0f 	vmlsldav.s32	lr, r3, q7, q7
[^>]*> ee9f ee2f 	vmlsldava.s32	lr, r3, q7, q7
[^>]*> ee9f fe0f 	vmlsldavx.s32	lr, r3, q7, q7
[^>]*> ee9f fe2f 	vmlsldavax.s32	lr, r3, q7, q7
[^>]*> eea1 ee01 	vmlsldav.s32	lr, r5, q0, q0
[^>]*> eea1 ee21 	vmlsldava.s32	lr, r5, q0, q0
[^>]*> eea1 fe01 	vmlsldavx.s32	lr, r5, q0, q0
[^>]*> eea1 fe21 	vmlsldavax.s32	lr, r5, q0, q0
[^>]*> eea1 ee03 	vmlsldav.s32	lr, r5, q0, q1
[^>]*> eea1 ee23 	vmlsldava.s32	lr, r5, q0, q1
[^>]*> eea1 fe03 	vmlsldavx.s32	lr, r5, q0, q1
[^>]*> eea1 fe23 	vmlsldavax.s32	lr, r5, q0, q1
[^>]*> eea1 ee05 	vmlsldav.s32	lr, r5, q0, q2
[^>]*> eea1 ee25 	vmlsldava.s32	lr, r5, q0, q2
[^>]*> eea1 fe05 	vmlsldavx.s32	lr, r5, q0, q2
[^>]*> eea1 fe25 	vmlsldavax.s32	lr, r5, q0, q2
[^>]*> eea1 ee09 	vmlsldav.s32	lr, r5, q0, q4
[^>]*> eea1 ee29 	vmlsldava.s32	lr, r5, q0, q4
[^>]*> eea1 fe09 	vmlsldavx.s32	lr, r5, q0, q4
[^>]*> eea1 fe29 	vmlsldavax.s32	lr, r5, q0, q4
[^>]*> eea1 ee0f 	vmlsldav.s32	lr, r5, q0, q7
[^>]*> eea1 ee2f 	vmlsldava.s32	lr, r5, q0, q7
[^>]*> eea1 fe0f 	vmlsldavx.s32	lr, r5, q0, q7
[^>]*> eea1 fe2f 	vmlsldavax.s32	lr, r5, q0, q7
[^>]*> eea3 ee01 	vmlsldav.s32	lr, r5, q1, q0
[^>]*> eea3 ee21 	vmlsldava.s32	lr, r5, q1, q0
[^>]*> eea3 fe01 	vmlsldavx.s32	lr, r5, q1, q0
[^>]*> eea3 fe21 	vmlsldavax.s32	lr, r5, q1, q0
[^>]*> eea3 ee03 	vmlsldav.s32	lr, r5, q1, q1
[^>]*> eea3 ee23 	vmlsldava.s32	lr, r5, q1, q1
[^>]*> eea3 fe03 	vmlsldavx.s32	lr, r5, q1, q1
[^>]*> eea3 fe23 	vmlsldavax.s32	lr, r5, q1, q1
[^>]*> eea3 ee05 	vmlsldav.s32	lr, r5, q1, q2
[^>]*> eea3 ee25 	vmlsldava.s32	lr, r5, q1, q2
[^>]*> eea3 fe05 	vmlsldavx.s32	lr, r5, q1, q2
[^>]*> eea3 fe25 	vmlsldavax.s32	lr, r5, q1, q2
[^>]*> eea3 ee09 	vmlsldav.s32	lr, r5, q1, q4
[^>]*> eea3 ee29 	vmlsldava.s32	lr, r5, q1, q4
[^>]*> eea3 fe09 	vmlsldavx.s32	lr, r5, q1, q4
[^>]*> eea3 fe29 	vmlsldavax.s32	lr, r5, q1, q4
[^>]*> eea3 ee0f 	vmlsldav.s32	lr, r5, q1, q7
[^>]*> eea3 ee2f 	vmlsldava.s32	lr, r5, q1, q7
[^>]*> eea3 fe0f 	vmlsldavx.s32	lr, r5, q1, q7
[^>]*> eea3 fe2f 	vmlsldavax.s32	lr, r5, q1, q7
[^>]*> eea5 ee01 	vmlsldav.s32	lr, r5, q2, q0
[^>]*> eea5 ee21 	vmlsldava.s32	lr, r5, q2, q0
[^>]*> eea5 fe01 	vmlsldavx.s32	lr, r5, q2, q0
[^>]*> eea5 fe21 	vmlsldavax.s32	lr, r5, q2, q0
[^>]*> eea5 ee03 	vmlsldav.s32	lr, r5, q2, q1
[^>]*> eea5 ee23 	vmlsldava.s32	lr, r5, q2, q1
[^>]*> eea5 fe03 	vmlsldavx.s32	lr, r5, q2, q1
[^>]*> eea5 fe23 	vmlsldavax.s32	lr, r5, q2, q1
[^>]*> eea5 ee05 	vmlsldav.s32	lr, r5, q2, q2
[^>]*> eea5 ee25 	vmlsldava.s32	lr, r5, q2, q2
[^>]*> eea5 fe05 	vmlsldavx.s32	lr, r5, q2, q2
[^>]*> eea5 fe25 	vmlsldavax.s32	lr, r5, q2, q2
[^>]*> eea5 ee09 	vmlsldav.s32	lr, r5, q2, q4
[^>]*> eea5 ee29 	vmlsldava.s32	lr, r5, q2, q4
[^>]*> eea5 fe09 	vmlsldavx.s32	lr, r5, q2, q4
[^>]*> eea5 fe29 	vmlsldavax.s32	lr, r5, q2, q4
[^>]*> eea5 ee0f 	vmlsldav.s32	lr, r5, q2, q7
[^>]*> eea5 ee2f 	vmlsldava.s32	lr, r5, q2, q7
[^>]*> eea5 fe0f 	vmlsldavx.s32	lr, r5, q2, q7
[^>]*> eea5 fe2f 	vmlsldavax.s32	lr, r5, q2, q7
[^>]*> eea9 ee01 	vmlsldav.s32	lr, r5, q4, q0
[^>]*> eea9 ee21 	vmlsldava.s32	lr, r5, q4, q0
[^>]*> eea9 fe01 	vmlsldavx.s32	lr, r5, q4, q0
[^>]*> eea9 fe21 	vmlsldavax.s32	lr, r5, q4, q0
[^>]*> eea9 ee03 	vmlsldav.s32	lr, r5, q4, q1
[^>]*> eea9 ee23 	vmlsldava.s32	lr, r5, q4, q1
[^>]*> eea9 fe03 	vmlsldavx.s32	lr, r5, q4, q1
[^>]*> eea9 fe23 	vmlsldavax.s32	lr, r5, q4, q1
[^>]*> eea9 ee05 	vmlsldav.s32	lr, r5, q4, q2
[^>]*> eea9 ee25 	vmlsldava.s32	lr, r5, q4, q2
[^>]*> eea9 fe05 	vmlsldavx.s32	lr, r5, q4, q2
[^>]*> eea9 fe25 	vmlsldavax.s32	lr, r5, q4, q2
[^>]*> eea9 ee09 	vmlsldav.s32	lr, r5, q4, q4
[^>]*> eea9 ee29 	vmlsldava.s32	lr, r5, q4, q4
[^>]*> eea9 fe09 	vmlsldavx.s32	lr, r5, q4, q4
[^>]*> eea9 fe29 	vmlsldavax.s32	lr, r5, q4, q4
[^>]*> eea9 ee0f 	vmlsldav.s32	lr, r5, q4, q7
[^>]*> eea9 ee2f 	vmlsldava.s32	lr, r5, q4, q7
[^>]*> eea9 fe0f 	vmlsldavx.s32	lr, r5, q4, q7
[^>]*> eea9 fe2f 	vmlsldavax.s32	lr, r5, q4, q7
[^>]*> eeaf ee01 	vmlsldav.s32	lr, r5, q7, q0
[^>]*> eeaf ee21 	vmlsldava.s32	lr, r5, q7, q0
[^>]*> eeaf fe01 	vmlsldavx.s32	lr, r5, q7, q0
[^>]*> eeaf fe21 	vmlsldavax.s32	lr, r5, q7, q0
[^>]*> eeaf ee03 	vmlsldav.s32	lr, r5, q7, q1
[^>]*> eeaf ee23 	vmlsldava.s32	lr, r5, q7, q1
[^>]*> eeaf fe03 	vmlsldavx.s32	lr, r5, q7, q1
[^>]*> eeaf fe23 	vmlsldavax.s32	lr, r5, q7, q1
[^>]*> eeaf ee05 	vmlsldav.s32	lr, r5, q7, q2
[^>]*> eeaf ee25 	vmlsldava.s32	lr, r5, q7, q2
[^>]*> eeaf fe05 	vmlsldavx.s32	lr, r5, q7, q2
[^>]*> eeaf fe25 	vmlsldavax.s32	lr, r5, q7, q2
[^>]*> eeaf ee09 	vmlsldav.s32	lr, r5, q7, q4
[^>]*> eeaf ee29 	vmlsldava.s32	lr, r5, q7, q4
[^>]*> eeaf fe09 	vmlsldavx.s32	lr, r5, q7, q4
[^>]*> eeaf fe29 	vmlsldavax.s32	lr, r5, q7, q4
[^>]*> eeaf ee0f 	vmlsldav.s32	lr, r5, q7, q7
[^>]*> eeaf ee2f 	vmlsldava.s32	lr, r5, q7, q7
[^>]*> eeaf fe0f 	vmlsldavx.s32	lr, r5, q7, q7
[^>]*> eeaf fe2f 	vmlsldavax.s32	lr, r5, q7, q7
[^>]*> eeb1 ee01 	vmlsldav.s32	lr, r7, q0, q0
[^>]*> eeb1 ee21 	vmlsldava.s32	lr, r7, q0, q0
[^>]*> eeb1 fe01 	vmlsldavx.s32	lr, r7, q0, q0
[^>]*> eeb1 fe21 	vmlsldavax.s32	lr, r7, q0, q0
[^>]*> eeb1 ee03 	vmlsldav.s32	lr, r7, q0, q1
[^>]*> eeb1 ee23 	vmlsldava.s32	lr, r7, q0, q1
[^>]*> eeb1 fe03 	vmlsldavx.s32	lr, r7, q0, q1
[^>]*> eeb1 fe23 	vmlsldavax.s32	lr, r7, q0, q1
[^>]*> eeb1 ee05 	vmlsldav.s32	lr, r7, q0, q2
[^>]*> eeb1 ee25 	vmlsldava.s32	lr, r7, q0, q2
[^>]*> eeb1 fe05 	vmlsldavx.s32	lr, r7, q0, q2
[^>]*> eeb1 fe25 	vmlsldavax.s32	lr, r7, q0, q2
[^>]*> eeb1 ee09 	vmlsldav.s32	lr, r7, q0, q4
[^>]*> eeb1 ee29 	vmlsldava.s32	lr, r7, q0, q4
[^>]*> eeb1 fe09 	vmlsldavx.s32	lr, r7, q0, q4
[^>]*> eeb1 fe29 	vmlsldavax.s32	lr, r7, q0, q4
[^>]*> eeb1 ee0f 	vmlsldav.s32	lr, r7, q0, q7
[^>]*> eeb1 ee2f 	vmlsldava.s32	lr, r7, q0, q7
[^>]*> eeb1 fe0f 	vmlsldavx.s32	lr, r7, q0, q7
[^>]*> eeb1 fe2f 	vmlsldavax.s32	lr, r7, q0, q7
[^>]*> eeb3 ee01 	vmlsldav.s32	lr, r7, q1, q0
[^>]*> eeb3 ee21 	vmlsldava.s32	lr, r7, q1, q0
[^>]*> eeb3 fe01 	vmlsldavx.s32	lr, r7, q1, q0
[^>]*> eeb3 fe21 	vmlsldavax.s32	lr, r7, q1, q0
[^>]*> eeb3 ee03 	vmlsldav.s32	lr, r7, q1, q1
[^>]*> eeb3 ee23 	vmlsldava.s32	lr, r7, q1, q1
[^>]*> eeb3 fe03 	vmlsldavx.s32	lr, r7, q1, q1
[^>]*> eeb3 fe23 	vmlsldavax.s32	lr, r7, q1, q1
[^>]*> eeb3 ee05 	vmlsldav.s32	lr, r7, q1, q2
[^>]*> eeb3 ee25 	vmlsldava.s32	lr, r7, q1, q2
[^>]*> eeb3 fe05 	vmlsldavx.s32	lr, r7, q1, q2
[^>]*> eeb3 fe25 	vmlsldavax.s32	lr, r7, q1, q2
[^>]*> eeb3 ee09 	vmlsldav.s32	lr, r7, q1, q4
[^>]*> eeb3 ee29 	vmlsldava.s32	lr, r7, q1, q4
[^>]*> eeb3 fe09 	vmlsldavx.s32	lr, r7, q1, q4
[^>]*> eeb3 fe29 	vmlsldavax.s32	lr, r7, q1, q4
[^>]*> eeb3 ee0f 	vmlsldav.s32	lr, r7, q1, q7
[^>]*> eeb3 ee2f 	vmlsldava.s32	lr, r7, q1, q7
[^>]*> eeb3 fe0f 	vmlsldavx.s32	lr, r7, q1, q7
[^>]*> eeb3 fe2f 	vmlsldavax.s32	lr, r7, q1, q7
[^>]*> eeb5 ee01 	vmlsldav.s32	lr, r7, q2, q0
[^>]*> eeb5 ee21 	vmlsldava.s32	lr, r7, q2, q0
[^>]*> eeb5 fe01 	vmlsldavx.s32	lr, r7, q2, q0
[^>]*> eeb5 fe21 	vmlsldavax.s32	lr, r7, q2, q0
[^>]*> eeb5 ee03 	vmlsldav.s32	lr, r7, q2, q1
[^>]*> eeb5 ee23 	vmlsldava.s32	lr, r7, q2, q1
[^>]*> eeb5 fe03 	vmlsldavx.s32	lr, r7, q2, q1
[^>]*> eeb5 fe23 	vmlsldavax.s32	lr, r7, q2, q1
[^>]*> eeb5 ee05 	vmlsldav.s32	lr, r7, q2, q2
[^>]*> eeb5 ee25 	vmlsldava.s32	lr, r7, q2, q2
[^>]*> eeb5 fe05 	vmlsldavx.s32	lr, r7, q2, q2
[^>]*> eeb5 fe25 	vmlsldavax.s32	lr, r7, q2, q2
[^>]*> eeb5 ee09 	vmlsldav.s32	lr, r7, q2, q4
[^>]*> eeb5 ee29 	vmlsldava.s32	lr, r7, q2, q4
[^>]*> eeb5 fe09 	vmlsldavx.s32	lr, r7, q2, q4
[^>]*> eeb5 fe29 	vmlsldavax.s32	lr, r7, q2, q4
[^>]*> eeb5 ee0f 	vmlsldav.s32	lr, r7, q2, q7
[^>]*> eeb5 ee2f 	vmlsldava.s32	lr, r7, q2, q7
[^>]*> eeb5 fe0f 	vmlsldavx.s32	lr, r7, q2, q7
[^>]*> eeb5 fe2f 	vmlsldavax.s32	lr, r7, q2, q7
[^>]*> eeb9 ee01 	vmlsldav.s32	lr, r7, q4, q0
[^>]*> eeb9 ee21 	vmlsldava.s32	lr, r7, q4, q0
[^>]*> eeb9 fe01 	vmlsldavx.s32	lr, r7, q4, q0
[^>]*> eeb9 fe21 	vmlsldavax.s32	lr, r7, q4, q0
[^>]*> eeb9 ee03 	vmlsldav.s32	lr, r7, q4, q1
[^>]*> eeb9 ee23 	vmlsldava.s32	lr, r7, q4, q1
[^>]*> eeb9 fe03 	vmlsldavx.s32	lr, r7, q4, q1
[^>]*> eeb9 fe23 	vmlsldavax.s32	lr, r7, q4, q1
[^>]*> eeb9 ee05 	vmlsldav.s32	lr, r7, q4, q2
[^>]*> eeb9 ee25 	vmlsldava.s32	lr, r7, q4, q2
[^>]*> eeb9 fe05 	vmlsldavx.s32	lr, r7, q4, q2
[^>]*> eeb9 fe25 	vmlsldavax.s32	lr, r7, q4, q2
[^>]*> eeb9 ee09 	vmlsldav.s32	lr, r7, q4, q4
[^>]*> eeb9 ee29 	vmlsldava.s32	lr, r7, q4, q4
[^>]*> eeb9 fe09 	vmlsldavx.s32	lr, r7, q4, q4
[^>]*> eeb9 fe29 	vmlsldavax.s32	lr, r7, q4, q4
[^>]*> eeb9 ee0f 	vmlsldav.s32	lr, r7, q4, q7
[^>]*> eeb9 ee2f 	vmlsldava.s32	lr, r7, q4, q7
[^>]*> eeb9 fe0f 	vmlsldavx.s32	lr, r7, q4, q7
[^>]*> eeb9 fe2f 	vmlsldavax.s32	lr, r7, q4, q7
[^>]*> eebf ee01 	vmlsldav.s32	lr, r7, q7, q0
[^>]*> eebf ee21 	vmlsldava.s32	lr, r7, q7, q0
[^>]*> eebf fe01 	vmlsldavx.s32	lr, r7, q7, q0
[^>]*> eebf fe21 	vmlsldavax.s32	lr, r7, q7, q0
[^>]*> eebf ee03 	vmlsldav.s32	lr, r7, q7, q1
[^>]*> eebf ee23 	vmlsldava.s32	lr, r7, q7, q1
[^>]*> eebf fe03 	vmlsldavx.s32	lr, r7, q7, q1
[^>]*> eebf fe23 	vmlsldavax.s32	lr, r7, q7, q1
[^>]*> eebf ee05 	vmlsldav.s32	lr, r7, q7, q2
[^>]*> eebf ee25 	vmlsldava.s32	lr, r7, q7, q2
[^>]*> eebf fe05 	vmlsldavx.s32	lr, r7, q7, q2
[^>]*> eebf fe25 	vmlsldavax.s32	lr, r7, q7, q2
[^>]*> eebf ee09 	vmlsldav.s32	lr, r7, q7, q4
[^>]*> eebf ee29 	vmlsldava.s32	lr, r7, q7, q4
[^>]*> eebf fe09 	vmlsldavx.s32	lr, r7, q7, q4
[^>]*> eebf fe29 	vmlsldavax.s32	lr, r7, q7, q4
[^>]*> eebf ee0f 	vmlsldav.s32	lr, r7, q7, q7
[^>]*> eebf ee2f 	vmlsldava.s32	lr, r7, q7, q7
[^>]*> eebf fe0f 	vmlsldavx.s32	lr, r7, q7, q7
[^>]*> eebf fe2f 	vmlsldavax.s32	lr, r7, q7, q7
[^>]*> eec1 ee01 	vmlsldav.s32	lr, r9, q0, q0
[^>]*> eec1 ee21 	vmlsldava.s32	lr, r9, q0, q0
[^>]*> eec1 fe01 	vmlsldavx.s32	lr, r9, q0, q0
[^>]*> eec1 fe21 	vmlsldavax.s32	lr, r9, q0, q0
[^>]*> eec1 ee03 	vmlsldav.s32	lr, r9, q0, q1
[^>]*> eec1 ee23 	vmlsldava.s32	lr, r9, q0, q1
[^>]*> eec1 fe03 	vmlsldavx.s32	lr, r9, q0, q1
[^>]*> eec1 fe23 	vmlsldavax.s32	lr, r9, q0, q1
[^>]*> eec1 ee05 	vmlsldav.s32	lr, r9, q0, q2
[^>]*> eec1 ee25 	vmlsldava.s32	lr, r9, q0, q2
[^>]*> eec1 fe05 	vmlsldavx.s32	lr, r9, q0, q2
[^>]*> eec1 fe25 	vmlsldavax.s32	lr, r9, q0, q2
[^>]*> eec1 ee09 	vmlsldav.s32	lr, r9, q0, q4
[^>]*> eec1 ee29 	vmlsldava.s32	lr, r9, q0, q4
[^>]*> eec1 fe09 	vmlsldavx.s32	lr, r9, q0, q4
[^>]*> eec1 fe29 	vmlsldavax.s32	lr, r9, q0, q4
[^>]*> eec1 ee0f 	vmlsldav.s32	lr, r9, q0, q7
[^>]*> eec1 ee2f 	vmlsldava.s32	lr, r9, q0, q7
[^>]*> eec1 fe0f 	vmlsldavx.s32	lr, r9, q0, q7
[^>]*> eec1 fe2f 	vmlsldavax.s32	lr, r9, q0, q7
[^>]*> eec3 ee01 	vmlsldav.s32	lr, r9, q1, q0
[^>]*> eec3 ee21 	vmlsldava.s32	lr, r9, q1, q0
[^>]*> eec3 fe01 	vmlsldavx.s32	lr, r9, q1, q0
[^>]*> eec3 fe21 	vmlsldavax.s32	lr, r9, q1, q0
[^>]*> eec3 ee03 	vmlsldav.s32	lr, r9, q1, q1
[^>]*> eec3 ee23 	vmlsldava.s32	lr, r9, q1, q1
[^>]*> eec3 fe03 	vmlsldavx.s32	lr, r9, q1, q1
[^>]*> eec3 fe23 	vmlsldavax.s32	lr, r9, q1, q1
[^>]*> eec3 ee05 	vmlsldav.s32	lr, r9, q1, q2
[^>]*> eec3 ee25 	vmlsldava.s32	lr, r9, q1, q2
[^>]*> eec3 fe05 	vmlsldavx.s32	lr, r9, q1, q2
[^>]*> eec3 fe25 	vmlsldavax.s32	lr, r9, q1, q2
[^>]*> eec3 ee09 	vmlsldav.s32	lr, r9, q1, q4
[^>]*> eec3 ee29 	vmlsldava.s32	lr, r9, q1, q4
[^>]*> eec3 fe09 	vmlsldavx.s32	lr, r9, q1, q4
[^>]*> eec3 fe29 	vmlsldavax.s32	lr, r9, q1, q4
[^>]*> eec3 ee0f 	vmlsldav.s32	lr, r9, q1, q7
[^>]*> eec3 ee2f 	vmlsldava.s32	lr, r9, q1, q7
[^>]*> eec3 fe0f 	vmlsldavx.s32	lr, r9, q1, q7
[^>]*> eec3 fe2f 	vmlsldavax.s32	lr, r9, q1, q7
[^>]*> eec5 ee01 	vmlsldav.s32	lr, r9, q2, q0
[^>]*> eec5 ee21 	vmlsldava.s32	lr, r9, q2, q0
[^>]*> eec5 fe01 	vmlsldavx.s32	lr, r9, q2, q0
[^>]*> eec5 fe21 	vmlsldavax.s32	lr, r9, q2, q0
[^>]*> eec5 ee03 	vmlsldav.s32	lr, r9, q2, q1
[^>]*> eec5 ee23 	vmlsldava.s32	lr, r9, q2, q1
[^>]*> eec5 fe03 	vmlsldavx.s32	lr, r9, q2, q1
[^>]*> eec5 fe23 	vmlsldavax.s32	lr, r9, q2, q1
[^>]*> eec5 ee05 	vmlsldav.s32	lr, r9, q2, q2
[^>]*> eec5 ee25 	vmlsldava.s32	lr, r9, q2, q2
[^>]*> eec5 fe05 	vmlsldavx.s32	lr, r9, q2, q2
[^>]*> eec5 fe25 	vmlsldavax.s32	lr, r9, q2, q2
[^>]*> eec5 ee09 	vmlsldav.s32	lr, r9, q2, q4
[^>]*> eec5 ee29 	vmlsldava.s32	lr, r9, q2, q4
[^>]*> eec5 fe09 	vmlsldavx.s32	lr, r9, q2, q4
[^>]*> eec5 fe29 	vmlsldavax.s32	lr, r9, q2, q4
[^>]*> eec5 ee0f 	vmlsldav.s32	lr, r9, q2, q7
[^>]*> eec5 ee2f 	vmlsldava.s32	lr, r9, q2, q7
[^>]*> eec5 fe0f 	vmlsldavx.s32	lr, r9, q2, q7
[^>]*> eec5 fe2f 	vmlsldavax.s32	lr, r9, q2, q7
[^>]*> eec9 ee01 	vmlsldav.s32	lr, r9, q4, q0
[^>]*> eec9 ee21 	vmlsldava.s32	lr, r9, q4, q0
[^>]*> eec9 fe01 	vmlsldavx.s32	lr, r9, q4, q0
[^>]*> eec9 fe21 	vmlsldavax.s32	lr, r9, q4, q0
[^>]*> eec9 ee03 	vmlsldav.s32	lr, r9, q4, q1
[^>]*> eec9 ee23 	vmlsldava.s32	lr, r9, q4, q1
[^>]*> eec9 fe03 	vmlsldavx.s32	lr, r9, q4, q1
[^>]*> eec9 fe23 	vmlsldavax.s32	lr, r9, q4, q1
[^>]*> eec9 ee05 	vmlsldav.s32	lr, r9, q4, q2
[^>]*> eec9 ee25 	vmlsldava.s32	lr, r9, q4, q2
[^>]*> eec9 fe05 	vmlsldavx.s32	lr, r9, q4, q2
[^>]*> eec9 fe25 	vmlsldavax.s32	lr, r9, q4, q2
[^>]*> eec9 ee09 	vmlsldav.s32	lr, r9, q4, q4
[^>]*> eec9 ee29 	vmlsldava.s32	lr, r9, q4, q4
[^>]*> eec9 fe09 	vmlsldavx.s32	lr, r9, q4, q4
[^>]*> eec9 fe29 	vmlsldavax.s32	lr, r9, q4, q4
[^>]*> eec9 ee0f 	vmlsldav.s32	lr, r9, q4, q7
[^>]*> eec9 ee2f 	vmlsldava.s32	lr, r9, q4, q7
[^>]*> eec9 fe0f 	vmlsldavx.s32	lr, r9, q4, q7
[^>]*> eec9 fe2f 	vmlsldavax.s32	lr, r9, q4, q7
[^>]*> eecf ee01 	vmlsldav.s32	lr, r9, q7, q0
[^>]*> eecf ee21 	vmlsldava.s32	lr, r9, q7, q0
[^>]*> eecf fe01 	vmlsldavx.s32	lr, r9, q7, q0
[^>]*> eecf fe21 	vmlsldavax.s32	lr, r9, q7, q0
[^>]*> eecf ee03 	vmlsldav.s32	lr, r9, q7, q1
[^>]*> eecf ee23 	vmlsldava.s32	lr, r9, q7, q1
[^>]*> eecf fe03 	vmlsldavx.s32	lr, r9, q7, q1
[^>]*> eecf fe23 	vmlsldavax.s32	lr, r9, q7, q1
[^>]*> eecf ee05 	vmlsldav.s32	lr, r9, q7, q2
[^>]*> eecf ee25 	vmlsldava.s32	lr, r9, q7, q2
[^>]*> eecf fe05 	vmlsldavx.s32	lr, r9, q7, q2
[^>]*> eecf fe25 	vmlsldavax.s32	lr, r9, q7, q2
[^>]*> eecf ee09 	vmlsldav.s32	lr, r9, q7, q4
[^>]*> eecf ee29 	vmlsldava.s32	lr, r9, q7, q4
[^>]*> eecf fe09 	vmlsldavx.s32	lr, r9, q7, q4
[^>]*> eecf fe29 	vmlsldavax.s32	lr, r9, q7, q4
[^>]*> eecf ee0f 	vmlsldav.s32	lr, r9, q7, q7
[^>]*> eecf ee2f 	vmlsldava.s32	lr, r9, q7, q7
[^>]*> eecf fe0f 	vmlsldavx.s32	lr, r9, q7, q7
[^>]*> eecf fe2f 	vmlsldavax.s32	lr, r9, q7, q7
[^>]*> eed1 ee01 	vmlsldav.s32	lr, fp, q0, q0
[^>]*> eed1 ee21 	vmlsldava.s32	lr, fp, q0, q0
[^>]*> eed1 fe01 	vmlsldavx.s32	lr, fp, q0, q0
[^>]*> eed1 fe21 	vmlsldavax.s32	lr, fp, q0, q0
[^>]*> eed1 ee03 	vmlsldav.s32	lr, fp, q0, q1
[^>]*> eed1 ee23 	vmlsldava.s32	lr, fp, q0, q1
[^>]*> eed1 fe03 	vmlsldavx.s32	lr, fp, q0, q1
[^>]*> eed1 fe23 	vmlsldavax.s32	lr, fp, q0, q1
[^>]*> eed1 ee05 	vmlsldav.s32	lr, fp, q0, q2
[^>]*> eed1 ee25 	vmlsldava.s32	lr, fp, q0, q2
[^>]*> eed1 fe05 	vmlsldavx.s32	lr, fp, q0, q2
[^>]*> eed1 fe25 	vmlsldavax.s32	lr, fp, q0, q2
[^>]*> eed1 ee09 	vmlsldav.s32	lr, fp, q0, q4
[^>]*> eed1 ee29 	vmlsldava.s32	lr, fp, q0, q4
[^>]*> eed1 fe09 	vmlsldavx.s32	lr, fp, q0, q4
[^>]*> eed1 fe29 	vmlsldavax.s32	lr, fp, q0, q4
[^>]*> eed1 ee0f 	vmlsldav.s32	lr, fp, q0, q7
[^>]*> eed1 ee2f 	vmlsldava.s32	lr, fp, q0, q7
[^>]*> eed1 fe0f 	vmlsldavx.s32	lr, fp, q0, q7
[^>]*> eed1 fe2f 	vmlsldavax.s32	lr, fp, q0, q7
[^>]*> eed3 ee01 	vmlsldav.s32	lr, fp, q1, q0
[^>]*> eed3 ee21 	vmlsldava.s32	lr, fp, q1, q0
[^>]*> eed3 fe01 	vmlsldavx.s32	lr, fp, q1, q0
[^>]*> eed3 fe21 	vmlsldavax.s32	lr, fp, q1, q0
[^>]*> eed3 ee03 	vmlsldav.s32	lr, fp, q1, q1
[^>]*> eed3 ee23 	vmlsldava.s32	lr, fp, q1, q1
[^>]*> eed3 fe03 	vmlsldavx.s32	lr, fp, q1, q1
[^>]*> eed3 fe23 	vmlsldavax.s32	lr, fp, q1, q1
[^>]*> eed3 ee05 	vmlsldav.s32	lr, fp, q1, q2
[^>]*> eed3 ee25 	vmlsldava.s32	lr, fp, q1, q2
[^>]*> eed3 fe05 	vmlsldavx.s32	lr, fp, q1, q2
[^>]*> eed3 fe25 	vmlsldavax.s32	lr, fp, q1, q2
[^>]*> eed3 ee09 	vmlsldav.s32	lr, fp, q1, q4
[^>]*> eed3 ee29 	vmlsldava.s32	lr, fp, q1, q4
[^>]*> eed3 fe09 	vmlsldavx.s32	lr, fp, q1, q4
[^>]*> eed3 fe29 	vmlsldavax.s32	lr, fp, q1, q4
[^>]*> eed3 ee0f 	vmlsldav.s32	lr, fp, q1, q7
[^>]*> eed3 ee2f 	vmlsldava.s32	lr, fp, q1, q7
[^>]*> eed3 fe0f 	vmlsldavx.s32	lr, fp, q1, q7
[^>]*> eed3 fe2f 	vmlsldavax.s32	lr, fp, q1, q7
[^>]*> eed5 ee01 	vmlsldav.s32	lr, fp, q2, q0
[^>]*> eed5 ee21 	vmlsldava.s32	lr, fp, q2, q0
[^>]*> eed5 fe01 	vmlsldavx.s32	lr, fp, q2, q0
[^>]*> eed5 fe21 	vmlsldavax.s32	lr, fp, q2, q0
[^>]*> eed5 ee03 	vmlsldav.s32	lr, fp, q2, q1
[^>]*> eed5 ee23 	vmlsldava.s32	lr, fp, q2, q1
[^>]*> eed5 fe03 	vmlsldavx.s32	lr, fp, q2, q1
[^>]*> eed5 fe23 	vmlsldavax.s32	lr, fp, q2, q1
[^>]*> eed5 ee05 	vmlsldav.s32	lr, fp, q2, q2
[^>]*> eed5 ee25 	vmlsldava.s32	lr, fp, q2, q2
[^>]*> eed5 fe05 	vmlsldavx.s32	lr, fp, q2, q2
[^>]*> eed5 fe25 	vmlsldavax.s32	lr, fp, q2, q2
[^>]*> eed5 ee09 	vmlsldav.s32	lr, fp, q2, q4
[^>]*> eed5 ee29 	vmlsldava.s32	lr, fp, q2, q4
[^>]*> eed5 fe09 	vmlsldavx.s32	lr, fp, q2, q4
[^>]*> eed5 fe29 	vmlsldavax.s32	lr, fp, q2, q4
[^>]*> eed5 ee0f 	vmlsldav.s32	lr, fp, q2, q7
[^>]*> eed5 ee2f 	vmlsldava.s32	lr, fp, q2, q7
[^>]*> eed5 fe0f 	vmlsldavx.s32	lr, fp, q2, q7
[^>]*> eed5 fe2f 	vmlsldavax.s32	lr, fp, q2, q7
[^>]*> eed9 ee01 	vmlsldav.s32	lr, fp, q4, q0
[^>]*> eed9 ee21 	vmlsldava.s32	lr, fp, q4, q0
[^>]*> eed9 fe01 	vmlsldavx.s32	lr, fp, q4, q0
[^>]*> eed9 fe21 	vmlsldavax.s32	lr, fp, q4, q0
[^>]*> eed9 ee03 	vmlsldav.s32	lr, fp, q4, q1
[^>]*> eed9 ee23 	vmlsldava.s32	lr, fp, q4, q1
[^>]*> eed9 fe03 	vmlsldavx.s32	lr, fp, q4, q1
[^>]*> eed9 fe23 	vmlsldavax.s32	lr, fp, q4, q1
[^>]*> eed9 ee05 	vmlsldav.s32	lr, fp, q4, q2
[^>]*> eed9 ee25 	vmlsldava.s32	lr, fp, q4, q2
[^>]*> eed9 fe05 	vmlsldavx.s32	lr, fp, q4, q2
[^>]*> eed9 fe25 	vmlsldavax.s32	lr, fp, q4, q2
[^>]*> eed9 ee09 	vmlsldav.s32	lr, fp, q4, q4
[^>]*> eed9 ee29 	vmlsldava.s32	lr, fp, q4, q4
[^>]*> eed9 fe09 	vmlsldavx.s32	lr, fp, q4, q4
[^>]*> eed9 fe29 	vmlsldavax.s32	lr, fp, q4, q4
[^>]*> eed9 ee0f 	vmlsldav.s32	lr, fp, q4, q7
[^>]*> eed9 ee2f 	vmlsldava.s32	lr, fp, q4, q7
[^>]*> eed9 fe0f 	vmlsldavx.s32	lr, fp, q4, q7
[^>]*> eed9 fe2f 	vmlsldavax.s32	lr, fp, q4, q7
[^>]*> eedf ee01 	vmlsldav.s32	lr, fp, q7, q0
[^>]*> eedf ee21 	vmlsldava.s32	lr, fp, q7, q0
[^>]*> eedf fe01 	vmlsldavx.s32	lr, fp, q7, q0
[^>]*> eedf fe21 	vmlsldavax.s32	lr, fp, q7, q0
[^>]*> eedf ee03 	vmlsldav.s32	lr, fp, q7, q1
[^>]*> eedf ee23 	vmlsldava.s32	lr, fp, q7, q1
[^>]*> eedf fe03 	vmlsldavx.s32	lr, fp, q7, q1
[^>]*> eedf fe23 	vmlsldavax.s32	lr, fp, q7, q1
[^>]*> eedf ee05 	vmlsldav.s32	lr, fp, q7, q2
[^>]*> eedf ee25 	vmlsldava.s32	lr, fp, q7, q2
[^>]*> eedf fe05 	vmlsldavx.s32	lr, fp, q7, q2
[^>]*> eedf fe25 	vmlsldavax.s32	lr, fp, q7, q2
[^>]*> eedf ee09 	vmlsldav.s32	lr, fp, q7, q4
[^>]*> eedf ee29 	vmlsldava.s32	lr, fp, q7, q4
[^>]*> eedf fe09 	vmlsldavx.s32	lr, fp, q7, q4
[^>]*> eedf fe29 	vmlsldavax.s32	lr, fp, q7, q4
[^>]*> eedf ee0f 	vmlsldav.s32	lr, fp, q7, q7
[^>]*> eedf ee2f 	vmlsldava.s32	lr, fp, q7, q7
[^>]*> eedf fe0f 	vmlsldavx.s32	lr, fp, q7, q7
[^>]*> eedf fe2f 	vmlsldavax.s32	lr, fp, q7, q7
[^>]*> fe71 ef4d 	vpstete
[^>]*> ee84 0e07 	vmlsldavt.s16	r0, r1, q2, q3
[^>]*> eed8 ce27 	vmlsldavae.s16	ip, fp, q4, q3
[^>]*> eea3 5e0d 	vmlsldavxt.s32	r4, r5, q1, q6
[^>]*> eedf fe2f 	vmlsldavaxe.s32	lr, fp, q7, q7
