        .text
                  MOV       D0Re0,D0Re0
                  MOV       D0Re0,RD
                  ADD       D0Re0,D0.7,D1.7
                  ADD       D0.7,D0Re0,A1.7
                  ADD       D0.7,D0.7,D0Re0
                  ADD       D0.7,D0.7,A0.7
                  ADD       D1Re0,D1Re0,D0.7
                  ADD       D1Re0,D1.7,A1.7
                  ADD       D1.7,D1Re0,A1LbP
                  ADD       D1.7,D1Re0,A0FrP
                  ADD       D1.7,D1.7,RD
                  ADDT      D0Re0,D0Re0,#0x8000
                  MOV       D0Re0,#0xffff
                  ADDT      D0.7,D0.7,#0x8000
                  MOV       D0.7,#0xffff
                  ADDT      D1Re0,D1Re0,#0x8000
                  MOV       D1Re0,#0xffff
                  ADDT      D1.7,D1.7,#0x8000
                  MOV       D1.7,#0xffff
                  ADDLT     TXENABLE,D0Re0,D0Re0
                  ADDVS     D0Re0,D0Re0,A1LbP
                  ADDGE     D0Re0,D0Re0,A1.7
                  ADDVS     TTEXEC,D0Re0,A1.7
                  ADDGT     D0Re0,D0Re0,D1.7
                  ADDVS     PC,D0Re0,RD
                  ADDGE     TTEXEC,D0Re0,A0FrP
                  ADDMI     D0Re0,D0.7,D0Re0
                  ADDGE     PC,D0.7,A1LbP
                  ADDGE     D1Re0,D0.7,A1.7
                  ADDVS     D0Re0,D0.7,D1Re0
                  ADDVS     PC,D0.7,D1.7
                  ADDVS     TTEXEC,D0.7,RD
                  ADDGE     D0Re0,D0.7,A0.7
                  ADDCC     TTCTRL,D0Re0,D0Re0
                  ADDVS     A1LbP,D0Re0,A1.7
                  ADDNV     TTCTRL,D0Re0,D1Re0
                  ADDVS     TTCTRL,D0Re0,RD
                  ADDVS     TTCTRL,D0Re0,A0.7
                  ADDVS     TTCTRL,D0.7,A1LbP
                  ADDGE     TTCTRL,D0.7,A1.7
                  ADDGT     TTCTRL,D0.7,D1.7
                  ADDNV     TTCTRL,D0.7,A0FrP
                  ADDVS     TTMARK,D0Re0,A1.7
                  ADDCC     TTMARK,D0.7,D0.7
                  ADDMI     TTREC,D0Re0,D0Re0
                  ADDGT     TTREC,D0Re0,D1Re0
                  ADDGE     TTREC,D0Re0,A0.7
                  ADDGT     TTREC,D0.7,A1.7
                  ADDGT     TTREC,D0.7,A0FrP
                  ADDNV     GTEXEC,D0Re0,D1.7
                  ADDVS     GTEXEC,D0.7,D1Re0
                  ADDEQ     A1.7,D0Re0,D0Re0
                  ADDVS     D0.7,D0Re0,A1.7
                  ADDGE     TXGPIOO,D0Re0,A1.7
                  ADDVS     A0.7,D0Re0,D1.7
                  ADDGE     D0.7,D0Re0,A0FrP
                  ADDGT     A1.7,D0Re0,A0.7
                  ADDGT     D1.7,D0.7,A1LbP
                  ADDNE     A0.7,D0.7,D0.7
                  ADDVS     A0.7,D0.7,D1Re0
                  ADDNV     D0.7,D0.7,RD
                  ADDGT     A1.7,D0.7,A0FrP
                  ADDGE     RA,D0Re0,A1LbP
                  ADDCS     RA,D0.7,D0Re0
                  ADDGT     RA,D0.7,A0.7
                  ADDGT     RAM8X32,D0Re0,A0FrP
                  ADDVS     RAM8X32,D0.7,RD
                  ADDGE     RAM8X,D0Re0,D1.7
                  ADDGE     RAM8X,D0.7,D1Re0
                  ADDNV     RABZ,D0Re0,A1.7
                  ADDNE     RABZ,D0.7,D0.7
                  ADDGT     RAWX,D0Re0,A1LbP
                  ADDMI     RAWX,D0.7,D0Re0
                  ADDVS     RAWX,D0.7,A0.7
                  ADDNV     RAMX,D0Re0,A1.7
                  ADDGT     RAMX,D0Re0,A0FrP
                  ADDNV     TXIDLECYC,D0.7,A1.7
                  ADDVS     RAMX,D0.7,RD
                  ADDVC     TXENABLE,D1Re0,D1Re0
                  ADDCS     TTEXEC,D1Re0,D1Re0
                  ADDGT     TXENABLE,D1Re0,A1.7
                  ADDGE     TXSTAT,D1Re0,A1.7
                  ADDGT     TTEXEC,D1Re0,D0Re0
                  ADDVS     D0Re0,D1Re0,RD
                  ADDNV     PC,D1Re0,A0FrP
                  ADDNV     TTEXEC,D1Re0,A0.7
                  ADDVS     D0Re0,D1.7,A1LbP
                  ADDGT     D0Re0,D1.7,A1.7
                  ADDGE     TTEXEC,D1.7,A1.7
                  ADDNV     D0Re0,D1.7,D0.7
                  ADDGE     PC,D1.7,RD
                  ADDNV     TTEXEC,D1.7,A0FrP
                  ADDNE     A1LbP,D1Re0,D1Re0
                  ADDVS     A0FrP,D1Re0,A1.7
                  ADDGE     A1LbP,D1Re0,D0Re0
                  ADDGT     A1LbP,D1Re0,RD
                  ADDNV     A1LbP,D1Re0,A0.7
                  ADDGT     A1LbP,D1.7,A1LbP
                  ADDNV     PCX,D1.7,A1.7
                  ADDVS     A1LbP,D1.7,D0.7
                  ADDGE     A1LbP,D1.7,A0FrP
                  ADDGE     TTMARK,D1Re0,A1LbP
                  ADDCS     TTMARK,D1.7,D1Re0
                  ADDVS     TTMARK,D1.7,A0.7
                  ADDVS     TTREC,D1Re0,A1.7
                  ADDNV     TTREC,D1Re0,A0FrP
                  ADDNV     TXMASKI,D1.7,A1.7
                  ADDVS     TTREC,D1.7,RD
                  ADDVS     GTEXEC,D1Re0,A1.7
                  ADDCC     GTEXEC,D1.7,D1.7
                  ADDCS     D1.7,D1Re0,D1Re0
                  ADDGT     TXGPIOO,D1Re0,A1LbP
                  ADDGT     A1.7,D1Re0,A1.7
                  ADDGT     D0.7,D1Re0,D0.7
                  ADDNV     A1.7,D1Re0,RD
                  ADDVS     D1.7,D1Re0,A0.7
                  ADDNE     TXGPIOO,D1.7,D1Re0
                  ADDCS     D1.7,D1.7,D1.7
                  ADDGE     D0.7,D1.7,D0Re0
                  ADDGE     A1.7,D1.7,D0.7
                  ADDVS     D1.7,D1.7,A0FrP
                  ADDVS     TXGPIOO,D1.7,A0.7
                  ADDVS     RA,D1Re0,A0FrP
                  ADDGT     RA,D1.7,RD
                  ADDGE     RAM8X32,D1Re0,D0.7
                  ADDGE     RAM8X32,D1.7,D0Re0
                  ADDNV     RAM8X,D1Re0,A1.7
                  ADDNE     RAM8X,D1.7,D1.7
                  ADDGT     RABZ,D1Re0,A1LbP
                  ADDMI     RABZ,D1.7,D1Re0
                  ADDVS     RABZ,D1.7,A0.7
                  ADDGT     RAWX,D1Re0,A0FrP
                  ADDVS     RAWX,D1.7,RD
                  ADDGE     TXIDLECYC,D1Re0,A1.7
                  ADDGT     RAMX,D1Re0,RD
                  ADDVS     RAMX,D1.7,A1LbP
                  ADDNV     RAMX,D1.7,D0.7
                  ADDCC     D0Re0,D0Re0,#0x7f
                  ADD       PC,D0Re0,#0x7f
                  ADD       TTEXEC,D0Re0,#0x80
                  ADD       TXENABLE,D0.7,#0x7f
                  ADD       D0Re0,D0.7,#0x80
                  ADD       D1Re0,D0.7,#0xff
                  ADD       A0FrP,D0Re0,#0x80
                  ADD       A0FrP,D0.7,#0x7f
                  ADD       A0FrP,D0.7,#0xff
                  ADD       TTMARK,D0.7,#0x80
                  ADD       TXMASKI,D0.7,#0x7f
                  ADD       GTEXEC,D0Re0,#0xff
                  ADD       A1.7,D0Re0,#0x7f
                  ADDVS     D0.7,D0Re0,#0xff
                  ADD       A0.7,D0.7,#0x7f
                  ADDNV     D0.7,D0.7,#0xff
                  ADD       RA,D0.7,#0x7f
                  ADD       RAM8X32,D0.7,#0xff
                  ADD       RABZ,D0Re0,#0x80
                  ADD       RAWX,D0.7,#0x7f
                  ADD       RAMX,D0Re0,#0xff
                  ADDVC     D1Re0,D1Re0,#0x7f
                  ADD       TXENABLE,D1Re0,#0x80
                  ADD       PC,D1Re0,#0xff
                  ADD       TXSTAT,D1.7,#0x7f
                  ADD       TTEXEC,D1.7,#0x80
                  ADD       A0FrP,D1Re0,#0x7f
                  ADD       A0FrP,D1Re0,#0xff
                  ADD       A0FrP,D1.7,#0x80
                  ADD       TTMARK,D1Re0,#0x7f
                  ADD       TXMASKI,D1Re0,#0x80
                  ADD       TXMASKI,D1.7,#0xff
                  ADDNV     D1.7,D1Re0,#0x7f
                  ADD       D1.7,D1Re0,#0x80
                  ADD       A1.7,D1Re0,#0xff
                  ADD       D0.7,D1.7,#0x80
                  ADD       TXGPIOO,D1.7,#0xff
                  ADD       RAM8X32,D1Re0,#0x80
                  ADD       RAM8X,D1.7,#0x7f
                  ADD       RABZ,D1.7,#0xff
                  ADD       RAMX,D1Re0,#0x7f
                  ADD       RAMX,D1.7,#0x80
                  MOVS      D0Re0,D0.7
                  ADDS      D0Re0,D0.7,A1LbP
                  ADDS      D0.7,D0Re0,D0Re0
                  ADDS      D0.7,D0Re0,RD
                  ADDS      D0.7,D0.7,D1Re0
                  ADDS      D1Re0,D1Re0,D1.7
                  ADDS      D1Re0,D1Re0,A0.7
                  ADDS      D1Re0,D1.7,A0FrP
                  ADDS      D1.7,D1Re0,D0Re0
                  ADDS      D1.7,D1.7,D1.7
                  ADDST     D0Re0,D0Re0,#0x7fff
                  MOVS      D0Re0,#-0x8000
                  ADDST     D0.7,D0.7,#0x7fff
                  MOVS      D0.7,#-0x8000
                  ADDST     D1Re0,D1Re0,#0x7fff
                  MOVS      D1Re0,#-0x8000
                  ADDST     D1.7,D1.7,#0x7fff
                  MOVS      D1.7,#-0x8000
                  ADDSCC    TXENABLE,D0Re0,D0Re0
                  ADDSMI    PC,D0Re0,D0Re0
                  ADDSNV    TTEXEC,D0Re0,A1LbP
                  ADDSGT    PC,D0Re0,A1.7
                  ADDSVS    PC,D0Re0,D1Re0
                  ADDSGE    TTEXEC,D0Re0,D1.7
                  ADDSGT    D0Re0,D0Re0,A0FrP
                  ADDSVS    PC,D0Re0,A0.7
                  ADDSCC    TTEXEC,D0.7,D0Re0
                  ADDSNV    TXENABLE,D0.7,A1.7
                  ADDSGT    TXSTAT,D0.7,A1.7
                  ADDSNV    TTEXEC,D0.7,D1Re0
                  ADDSVS    D0Re0,D0.7,RD
                  ADDSVS    PC,D0.7,A0FrP
                  ADDSVS    TTEXEC,D0.7,A0.7
                  ADDSVS    TTCTRL,D0Re0,A1LbP
                  ADDSGE    TTCTRL,D0Re0,A1.7
                  ADDSGT    TTCTRL,D0Re0,D1.7
                  ADDSNV    TTCTRL,D0Re0,A0FrP
                  ADDSCC    TTCTRL,D0.7,D0Re0
                  ADDSVS    A1LbP,D0.7,A1.7
                  ADDSNV    TTCTRL,D0.7,D1Re0
                  ADDSVS    TTCTRL,D0.7,RD
                  ADDSVS    TTCTRL,D0.7,A0.7
                  ADDSNV    TTMARK,D0Re0,A0FrP
                  ADDSVS    TTMARK,D0.7,RD
                  ADDSVS    TXMASKI,D0Re0,A1.7
                  ADDSGE    TTREC,D0Re0,RD
                  ADDSVS    TTREC,D0.7,A1LbP
                  ADDSGE    TTREC,D0.7,D1.7
                  ADDSGE    GTEXEC,D0Re0,A1LbP
                  ADDSCS    GTEXEC,D0.7,D0Re0
                  ADDSVS    GTEXEC,D0.7,A0.7
                  ADDSVS    A0.7,D0Re0,A1LbP
                  ADDSNV    A0.7,D0Re0,A1.7
                  ADDSGE    A1.7,D0Re0,D1Re0
                  ADDSVS    D1.7,D0Re0,RD
                  ADDSGT    TXGPIOO,D0Re0,A0FrP
                  ADDSCC    A0.7,D0.7,D0Re0
                  ADDSCC    D0.7,D0.7,D0.7
                  ADDSMI    TXGPIOO,D0.7,D0.7
                  ADDSNV    D1.7,D0.7,D1.7
                  ADDSVS    TXGPIOO,D0.7,RD
                  ADDSGT    A0.7,D0.7,A0.7
                  ADDSVS    RA,D0Re0,D1.7
                  ADDSVS    RA,D0.7,D1Re0
                  ADDSNV    RAM8X32,D0Re0,A1.7
                  ADDSNE    RAM8X32,D0.7,D0.7
                  ADDSGT    RAM8X,D0Re0,A1LbP
                  ADDSMI    RAM8X,D0.7,D0Re0
                  ADDSVS    RAM8X,D0.7,A0.7
                  ADDSGT    RABZ,D0Re0,A0FrP
                  ADDSVS    RABZ,D0.7,RD
                  ADDSGE    RAWX,D0Re0,D1.7
                  ADDSGE    RAWX,D0.7,D1Re0
                  ADDSGT    RAMX,D0Re0,A1LbP
                  ADDSGE    RAMX,D0Re0,D1.7
                  ADDSMI    RAMX,D0.7,D0Re0
                  ADDSGE    RAMX,D0.7,D1Re0
                  ADDSVS    RAMX,D0.7,A0.7
                  ADDSCC    D0Re0,D1Re0,D1Re0
                  ADDSVS    PC,D1Re0,A1LbP
                  ADDSVS    D1Re0,D1Re0,A1.7
                  ADDSNV    D0Re0,D1Re0,D0Re0
                  ADDSNV    PC,D1Re0,D0.7
                  ADDSNV    TTEXEC,D1Re0,RD
                  ADDSVS    D0Re0,D1Re0,A0.7
                  ADDSEQ    PC,D1.7,D1Re0
                  ADDSVS    TTEXEC,D1.7,A1LbP
                  ADDSNV    PC,D1.7,A1.7
                  ADDSVS    PC,D1.7,D0Re0
                  ADDSGT    TTEXEC,D1.7,D0.7
                  ADDSNV    D0Re0,D1.7,A0FrP
                  ADDSGT    PC,D1.7,A0.7
                  ADDSGT    A1LbP,D1Re0,A1LbP
                  ADDSNV    PCX,D1Re0,A1.7
                  ADDSVS    A1LbP,D1Re0,D0.7
                  ADDSGE    A1LbP,D1Re0,A0FrP
                  ADDSNE    A1LbP,D1.7,D1Re0
                  ADDSVS    A0FrP,D1.7,A1.7
                  ADDSGE    A1LbP,D1.7,D0Re0
                  ADDSGT    A1LbP,D1.7,RD
                  ADDSNV    A1LbP,D1.7,A0.7
                  ADDSNV    TTMARK,D1Re0,D0.7
                  ADDSVS    TTMARK,D1.7,D0Re0
                  ADDSGE    TTREC,D1Re0,A1LbP
                  ADDSNV    TTREC,D1Re0,D0.7
                  ADDSCS    TTREC,D1.7,D1Re0
                  ADDSVS    TTREC,D1.7,D0Re0
                  ADDSVS    TTREC,D1.7,A0.7
                  ADDSNV    GTEXEC,D1Re0,A0FrP
                  ADDSVS    GTEXEC,D1.7,RD
                  ADDSGE    D0.7,D1Re0,A1LbP
                  ADDSVS    D1.7,D1Re0,A1.7
                  ADDSNV    D1.7,D1Re0,D0Re0
                  ADDSNV    TXGPIOO,D1Re0,D0.7
                  ADDSVS    A0.7,D1Re0,A0FrP
                  ADDSEQ    D0.7,D1.7,D1Re0
                  ADDSVS    A1.7,D1.7,A1LbP
                  ADDSEQ    A1.7,D1.7,D1.7
                  ADDSGT    TXGPIOO,D1.7,D0Re0
                  ADDSGE    A0.7,D1.7,RD
                  ADDSVS    D0.7,D1.7,A0.7
                  ADDSGT    RA,D1Re0,A1.7
                  ADDSMI    RA,D1.7,D1.7
                  ADDSGT    RAM8X32,D1Re0,A1LbP
                  ADDSMI    RAM8X32,D1.7,D1Re0
                  ADDSVS    RAM8X32,D1.7,A0.7
                  ADDSGT    RAM8X,D1Re0,A0FrP
                  ADDSVS    RAM8X,D1.7,RD
                  ADDSGE    RABZ,D1Re0,D0.7
                  ADDSGE    RABZ,D1.7,D0Re0
                  ADDSNV    RAWX,D1Re0,A1.7
                  ADDSNE    RAWX,D1.7,D1.7
                  ADDSCS    RAMX,D1Re0,D1Re0
                  ADDSVS    RAMX,D1Re0,D0Re0
                  ADDSGT    RAMX,D1Re0,A0.7
                  ADDSVS    RAMX,D1.7,A1.7
                  ADDSVS    RAMX,D1.7,A0FrP
                  ADDSLT    D0Re0,D0Re0,#0x7f
                  ADDS      TXENABLE,D0Re0,#0x80
                  ADDS      PC,D0Re0,#0xff
                  ADDS      TXSTAT,D0.7,#0x7f
                  ADDS      TTEXEC,D0.7,#0x80
                  ADDS      A0FrP,D0Re0,#0x7f
                  ADDS      A0FrP,D0Re0,#0xff
                  ADDS      A0FrP,D0.7,#0x80
                  ADDS      TTMARK,D0Re0,#0x7f
                  ADDS      TXMASKI,D0Re0,#0x80
                  ADDS      TXMASKI,D0.7,#0xff
                  ADDSGE    D0.7,D0Re0,#0x7f
                  ADDS      D1.7,D0Re0,#0x80
                  ADDS      A1.7,D0Re0,#0xff
                  ADDS      D1.7,D0.7,#0x80
                  ADDS      TXGPIOO,D0.7,#0xff
                  ADDS      RAM8X32,D0Re0,#0x80
                  ADDS      RAM8X,D0.7,#0x7f
                  ADDS      RABZ,D0.7,#0xff
                  ADDS      RAMX,D0Re0,#0x7f
                  ADDS      RAMX,D0.7,#0x80
                  ADDS      TXSTAT,D1Re0,#0x7f
                  ADDS      TTEXEC,D1Re0,#0x80
                  ADDS      TXENABLE,D1.7,#0x7f
                  ADDS      D0Re0,D1.7,#0x80
                  ADDS      D1Re0,D1.7,#0xff
                  ADDS      A0FrP,D1Re0,#0x80
                  ADDS      A0FrP,D1.7,#0x7f
                  ADDS      A0FrP,D1.7,#0xff
                  ADDS      TTMARK,D1.7,#0x80
                  ADDS      TXMASKI,D1.7,#0x7f
                  ADDS      GTEXEC,D1Re0,#0xff
                  ADDS      A1.7,D1Re0,#0x7f
                  ADDSGE    D1.7,D1Re0,#0xff
                  ADDS      A0.7,D1.7,#0x7f
                  ADDSVS    D1.7,D1.7,#0xff
                  ADDS      RA,D1.7,#0x7f
                  ADDS      RAM8X32,D1.7,#0xff
                  ADDS      RABZ,D1Re0,#0x80
                  ADDS      RAWX,D1.7,#0x7f
                  ADDS      RAMX,D1Re0,#0xff
                  NEG       D0Re0,D0Re0
                  NEG       D0Re0,D1Re0
                  NEG       D0Re0,A0.7
                  SUB       D0Re0,D0.7,A0FrP
                  NEG       D0.7,D0.7
                  SUB       D0.7,D0Re0,A0FrP
                  SUB       D0.7,D0.7,D1Re0
                  NEG       D1Re0,A1LbP
                  NEG       D1Re0,D0.7
                  SUB       D1Re0,D1.7,A1LbP
                  SUB       D1.7,D1Re0,D1Re0
                  SUB       D1.7,D1Re0,D0Re0
                  SUB       D1.7,D1Re0,A0.7
                  SUB       D1.7,D1.7,RD
                  SUB       D0Re0,D0Re0,#-0x8000
                  SUB       D0.7,D0.7,#0x7fff
                  SUB       D0.7,D0.7,#0xffff
                  SUB       D1Re0,D1Re0,#0x8000
                  NEG       D1Re0,#0xffff
                  NEG       D1.7,#0x8000
                  SUBCC     D0Re0,D0Re0,D0Re0
                  SUBVS     PC,D0Re0,A1LbP
                  SUBVS     D1Re0,D0Re0,A1.7
                  SUBNV     D0Re0,D0Re0,D1Re0
                  SUBNV     PC,D0Re0,D1.7
                  SUBNV     TTEXEC,D0Re0,RD
                  SUBVS     D0Re0,D0Re0,A0.7
                  SUBEQ     PC,D0.7,D0Re0
                  SUBVS     TTEXEC,D0.7,A1LbP
                  SUBNV     PC,D0.7,A1.7
                  SUBVS     PC,D0.7,D1Re0
                  SUBGT     TTEXEC,D0.7,D1.7
                  SUBNV     D0Re0,D0.7,A0FrP
                  SUBGT     PC,D0.7,A0.7
                  SUBGT     A1LbP,D0Re0,A1LbP
                  SUBNV     PCX,D0Re0,A1.7
                  SUBVS     A1LbP,D0Re0,D1.7
                  SUBGE     A1LbP,D0Re0,A0FrP
                  SUBNE     A1LbP,D0.7,D0Re0
                  SUBVS     A0FrP,D0.7,A1.7
                  SUBGE     A1LbP,D0.7,D1Re0
                  SUBGT     A1LbP,D0.7,RD
                  SUBNV     A1LbP,D0.7,A0.7
                  SUBNV     TTMARK,D0Re0,D1.7
                  SUBVS     TTMARK,D0.7,D1Re0
                  SUBGE     TTREC,D0Re0,A1LbP
                  SUBNV     TTREC,D0Re0,D1.7
                  SUBCS     TTREC,D0.7,D0Re0
                  SUBVS     TTREC,D0.7,D1Re0
                  SUBVS     TTREC,D0.7,A0.7
                  SUBNV     GTEXEC,D0Re0,A0FrP
                  SUBVS     GTEXEC,D0.7,RD
                  SUBGE     D0.7,D0Re0,A1LbP
                  SUBVS     D1.7,D0Re0,A1.7
                  SUBNV     D1.7,D0Re0,D1Re0
                  SUBNV     TXGPIOO,D0Re0,D1.7
                  SUBVS     A0.7,D0Re0,A0FrP
                  SUBEQ     D0.7,D0.7,D0Re0
                  SUBVS     A1.7,D0.7,A1LbP
                  SUBEQ     A1.7,D0.7,D0.7
                  SUBGT     TXGPIOO,D0.7,D1Re0
                  SUBGE     A0.7,D0.7,RD
                  SUBVS     D0.7,D0.7,A0.7
                  SUBGT     RA,D0Re0,A1.7
                  SUBMI     RA,D0.7,D0.7
                  SUBGT     RAM8X32,D0Re0,A1LbP
                  SUBMI     RAM8X32,D0.7,D0Re0
                  SUBVS     RAM8X32,D0.7,A0.7
                  SUBGT     RAM8X,D0Re0,A0FrP
                  SUBVS     RAM8X,D0.7,RD
                  SUBGE     RABZ,D0Re0,D1.7
                  SUBGE     RABZ,D0.7,D1Re0
                  SUBNV     RAWX,D0Re0,A1.7
                  SUBNE     RAWX,D0.7,D0.7
                  SUBCS     RAMX,D0Re0,D0Re0
                  SUBVS     RAMX,D0Re0,D1Re0
                  SUBGT     RAMX,D0Re0,A0.7
                  SUBVS     RAMX,D0.7,A1.7
                  SUBVS     RAMX,D0.7,A0FrP
                  SUBCC     TTEXEC,D1Re0,D1Re0
                  SUBNV     TXENABLE,D1Re0,A1.7
                  SUBGT     TXSTAT,D1Re0,A1.7
                  SUBNV     TTEXEC,D1Re0,D0Re0
                  SUBVS     D0Re0,D1Re0,RD
                  SUBVS     PC,D1Re0,A0FrP
                  SUBVS     TTEXEC,D1Re0,A0.7
                  SUBVS     D0Re0,D1.7,A1LbP
                  SUBGT     D0Re0,D1.7,A1.7
                  SUBGE     TTEXEC,D1.7,A1.7
                  SUBNV     D0Re0,D1.7,D0.7
                  SUBGE     PC,D1.7,RD
                  SUBNV     TTEXEC,D1.7,A0FrP
                  SUBNE     A1LbP,D1Re0,D1Re0
                  SUBVS     A0FrP,D1Re0,A1.7
                  SUBGE     A1LbP,D1Re0,D0Re0
                  SUBGT     A1LbP,D1Re0,RD
                  SUBNV     A1LbP,D1Re0,A0.7
                  SUBGT     A1LbP,D1.7,A1LbP
                  SUBNV     PCX,D1.7,A1.7
                  SUBVS     A1LbP,D1.7,D0.7
                  SUBGE     A1LbP,D1.7,A0FrP
                  SUBGE     TTMARK,D1Re0,A1LbP
                  SUBCS     TTMARK,D1.7,D1Re0
                  SUBVS     TTMARK,D1.7,A0.7
                  SUBVS     TTREC,D1Re0,A1.7
                  SUBNV     TTREC,D1Re0,A0FrP
                  SUBNV     TXMASKI,D1.7,A1.7
                  SUBVS     TTREC,D1.7,RD
                  SUBVS     GTEXEC,D1Re0,A1.7
                  SUBCC     GTEXEC,D1.7,D1.7
                  SUBCS     D1.7,D1Re0,D1Re0
                  SUBGT     TXGPIOO,D1Re0,A1LbP
                  SUBGT     A1.7,D1Re0,A1.7
                  SUBGT     D0.7,D1Re0,D0.7
                  SUBNV     A1.7,D1Re0,RD
                  SUBVS     D1.7,D1Re0,A0.7
                  SUBNE     TXGPIOO,D1.7,D1Re0
                  SUBCS     D1.7,D1.7,D1.7
                  SUBGE     D0.7,D1.7,D0Re0
                  SUBGE     A1.7,D1.7,D0.7
                  SUBVS     D1.7,D1.7,A0FrP
                  SUBVS     TXGPIOO,D1.7,A0.7
                  SUBVS     RA,D1Re0,A0FrP
                  SUBGT     RA,D1.7,RD
                  SUBGE     RAM8X32,D1Re0,D0.7
                  SUBGE     RAM8X32,D1.7,D0Re0
                  SUBNV     RAM8X,D1Re0,A1.7
                  SUBNE     RAM8X,D1.7,D1.7
                  SUBGT     RABZ,D1Re0,A1LbP
                  SUBMI     RABZ,D1.7,D1Re0
                  SUBVS     RABZ,D1.7,A0.7
                  SUBGT     RAWX,D1Re0,A0FrP
                  SUBVS     RAWX,D1.7,RD
                  SUBGE     TXIDLECYC,D1Re0,A1.7
                  SUBGT     RAMX,D1Re0,RD
                  SUBVS     RAMX,D1.7,A1LbP
                  SUBNV     RAMX,D1.7,D0.7
                  SUB       TXENABLE,D0Re0,#0x7f
                  SUB       PC,D0Re0,#0x80
                  SUB       TTEXEC,D0Re0,#0xff
                  SUBCC     D0Re0,D0.7,#0x80
                  SUB       TXENABLE,D0.7,#0xff
                  SUB       PCX,D0Re0,#0x7f
                  SUB       PCX,D0Re0,#0xff
                  SUB       PCX,D0.7,#0x80
                  SUB       TTMARK,D0Re0,#0xff
                  SUB       TXMASKI,D0Re0,#0xff
                  SUB       GTEXEC,D0Re0,#0x7f
                  SUB       D1.7,D0Re0,#0x7f
                  SUB       A1.7,D0Re0,#0x80
                  SUBGE     D0.7,D0.7,#0x7f
                  SUB       A1.7,D0.7,#0x80
                  SUB       RA,D0Re0,#0x80
                  SUB       RAM8X32,D0.7,#0x7f
                  SUB       RAM8X,D0.7,#0xff
                  SUB       RAWX,D0Re0,#0x80
                  SUB       RAMX,D0Re0,#0x80
                  SUB       RAMX,D0.7,#0xff
                  SUB       TXENABLE,D1Re0,#0x80
                  SUB       PC,D1Re0,#0xff
                  SUB       TXSTAT,D1.7,#0x7f
                  SUB       TTEXEC,D1.7,#0x80
                  SUB       A0FrP,D1Re0,#0x7f
                  SUB       A0FrP,D1Re0,#0xff
                  SUB       A0FrP,D1.7,#0x80
                  SUB       TTMARK,D1Re0,#0x7f
                  SUB       TXMASKI,D1Re0,#0x80
                  SUB       TXMASKI,D1.7,#0xff
                  SUBVS     D1.7,D1Re0,#0x7f
                  SUB       D1.7,D1Re0,#0x80
                  SUB       A1.7,D1Re0,#0xff
                  SUB       D0.7,D1.7,#0x80
                  SUB       TXGPIOO,D1.7,#0xff
                  SUB       RAM8X32,D1Re0,#0x80
                  SUB       RAM8X,D1.7,#0x7f
                  SUB       RABZ,D1.7,#0xff
                  SUB       RAMX,D1Re0,#0x7f
                  SUB       RAMX,D1.7,#0x80
                  SUBS      D0Re0,D0Re0,A1.7
                  NEGS      D0Re0,RD
                  SUBS      D0Re0,D0.7,A1.7
                  SUBS      D0.7,D0Re0,A1LbP
                  SUBS      D0.7,D0Re0,D1.7
                  SUBS      D0.7,D0.7,D0Re0
                  SUBS      D0.7,D0.7,A0.7
                  NEGS      D1Re0,A1.7
                  NEGS      D1Re0,A0FrP
                  SUBS      D1Re0,D1.7,D0.7
                  SUBS      D1.7,D1Re0,D1.7
                  SUBS      D1.7,D1Re0,RD
                  SUBS      D1.7,D1.7,D1.7
                  SUBST     D0Re0,D0Re0,#0x7fff
                  SUBST     D0Re0,D0Re0,#0xffff
                  SUBST     D0.7,D0.7,#0x8000
                  NEGS      D0.7,#-0x1
                  NEGS      D1Re0,#-0x8000
                  NEGS      D1.7,#0x7fff
                  SUBS      D1.7,D1.7,#-0x1
                  SUBSMI    TTEXEC,D0Re0,D0Re0
                  SUBSVS    TXENABLE,D0Re0,A1.7
                  SUBSNV    TXSTAT,D0Re0,A1.7
                  SUBSVS    TTEXEC,D0Re0,D1Re0
                  SUBSGE    D0Re0,D0Re0,RD
                  SUBSVS    PC,D0Re0,A0FrP
                  SUBSVS    TTEXEC,D0Re0,A0.7
                  SUBSVS    D0Re0,D0.7,A1LbP
                  SUBSGT    D0Re0,D0.7,A1.7
                  SUBSGE    TTEXEC,D0.7,A1.7
                  SUBSNV    D0Re0,D0.7,D1.7
                  SUBSGE    PC,D0.7,RD
                  SUBSNV    TTEXEC,D0.7,A0FrP
                  SUBSNE    A1LbP,D0Re0,D0Re0
                  SUBSVS    A0FrP,D0Re0,A1.7
                  SUBSGE    A1LbP,D0Re0,D1Re0
                  SUBSGT    A1LbP,D0Re0,RD
                  SUBSNV    A1LbP,D0Re0,A0.7
                  SUBSGT    A1LbP,D0.7,A1LbP
                  SUBSNV    PCX,D0.7,A1.7
                  SUBSVS    A1LbP,D0.7,D1.7
                  SUBSGE    A1LbP,D0.7,A0FrP
                  SUBSGE    TTMARK,D0Re0,A1LbP
                  SUBSCS    TTMARK,D0.7,D0Re0
                  SUBSVS    TTMARK,D0.7,A0.7
                  SUBSVS    TTREC,D0Re0,A1.7
                  SUBSNV    TTREC,D0Re0,A0FrP
                  SUBSNV    TXMASKI,D0.7,A1.7
                  SUBSVS    TTREC,D0.7,RD
                  SUBSVS    GTEXEC,D0Re0,A1.7
                  SUBSCC    GTEXEC,D0.7,D0.7
                  SUBSCS    D1.7,D0Re0,D0Re0
                  SUBSGT    TXGPIOO,D0Re0,A1LbP
                  SUBSGT    A1.7,D0Re0,A1.7
                  SUBSGT    D0.7,D0Re0,D1.7
                  SUBSNV    A1.7,D0Re0,RD
                  SUBSVS    D1.7,D0Re0,A0.7
                  SUBSNE    TXGPIOO,D0.7,D0Re0
                  SUBSCS    D1.7,D0.7,D0.7
                  SUBSGE    D0.7,D0.7,D1Re0
                  SUBSGE    A1.7,D0.7,D1.7
                  SUBSVS    D1.7,D0.7,A0FrP
                  SUBSVS    TXGPIOO,D0.7,A0.7
                  SUBSVS    RA,D0Re0,A0FrP
                  SUBSGT    RA,D0.7,RD
                  SUBSGE    RAM8X32,D0Re0,D1.7
                  SUBSGE    RAM8X32,D0.7,D1Re0
                  SUBSNV    RAM8X,D0Re0,A1.7
                  SUBSNE    RAM8X,D0.7,D0.7
                  SUBSGT    RABZ,D0Re0,A1LbP
                  SUBSMI    RABZ,D0.7,D0Re0
                  SUBSVS    RABZ,D0.7,A0.7
                  SUBSGT    RAWX,D0Re0,A0FrP
                  SUBSVS    RAWX,D0.7,RD
                  SUBSGE    TXIDLECYC,D0Re0,A1.7
                  SUBSGT    RAMX,D0Re0,RD
                  SUBSVS    RAMX,D0.7,A1LbP
                  SUBSNV    RAMX,D0.7,D1.7
                  SUBSMI    D0Re0,D1Re0,D1Re0
                  SUBSGE    PC,D1Re0,A1LbP
                  SUBSGE    D1Re0,D1Re0,A1.7
                  SUBSVS    D0Re0,D1Re0,D0Re0
                  SUBSVS    PC,D1Re0,D0.7
                  SUBSVS    TTEXEC,D1Re0,RD
                  SUBSGE    D0Re0,D1Re0,A0.7
                  SUBSEQ    PC,D1.7,D1Re0
                  SUBSVS    TTEXEC,D1.7,A1LbP
                  SUBSNV    PC,D1.7,A1.7
                  SUBSVS    PC,D1.7,D0Re0
                  SUBSGT    TTEXEC,D1.7,D0.7
                  SUBSNV    D0Re0,D1.7,A0FrP
                  SUBSGT    PC,D1.7,A0.7
                  SUBSGT    A1LbP,D1Re0,A1LbP
                  SUBSNV    PCX,D1Re0,A1.7
                  SUBSVS    A1LbP,D1Re0,D0.7
                  SUBSGE    A1LbP,D1Re0,A0FrP
                  SUBSNE    A1LbP,D1.7,D1Re0
                  SUBSVS    A0FrP,D1.7,A1.7
                  SUBSGE    A1LbP,D1.7,D0Re0
                  SUBSGT    A1LbP,D1.7,RD
                  SUBSNV    A1LbP,D1.7,A0.7
                  SUBSNV    TTMARK,D1Re0,D0.7
                  SUBSVS    TTMARK,D1.7,D0Re0
                  SUBSGE    TTREC,D1Re0,A1LbP
                  SUBSNV    TTREC,D1Re0,D0.7
                  SUBSCS    TTREC,D1.7,D1Re0
                  SUBSVS    TTREC,D1.7,D0Re0
                  SUBSVS    TTREC,D1.7,A0.7
                  SUBSNV    GTEXEC,D1Re0,A0FrP
                  SUBSVS    GTEXEC,D1.7,RD
                  SUBSGE    D0.7,D1Re0,A1LbP
                  SUBSVS    D1.7,D1Re0,A1.7
                  SUBSNV    D1.7,D1Re0,D0Re0
                  SUBSNV    TXGPIOO,D1Re0,D0.7
                  SUBSVS    A0.7,D1Re0,A0FrP
                  SUBSEQ    D0.7,D1.7,D1Re0
                  SUBSVS    A1.7,D1.7,A1LbP
                  SUBSEQ    A1.7,D1.7,D1.7
                  SUBSGT    TXGPIOO,D1.7,D0Re0
                  SUBSGE    A0.7,D1.7,RD
                  SUBSVS    D0.7,D1.7,A0.7
                  SUBSGT    RA,D1Re0,A1.7
                  SUBSMI    RA,D1.7,D1.7
                  SUBSGT    RAM8X32,D1Re0,A1LbP
                  SUBSMI    RAM8X32,D1.7,D1Re0
                  SUBSVS    RAM8X32,D1.7,A0.7
                  SUBSGT    RAM8X,D1Re0,A0FrP
                  SUBSVS    RAM8X,D1.7,RD
                  SUBSGE    RABZ,D1Re0,D0.7
                  SUBSGE    RABZ,D1.7,D0Re0
                  SUBSNV    RAWX,D1Re0,A1.7
                  SUBSNE    RAWX,D1.7,D1.7
                  SUBSCS    RAMX,D1Re0,D1Re0
                  SUBSVS    RAMX,D1Re0,D0Re0
                  SUBSGT    RAMX,D1Re0,A0.7
                  SUBSVS    RAMX,D1.7,A1.7
                  SUBSVS    RAMX,D1.7,A0FrP
                  SUBS      TTEXEC,D0Re0,#0x7f
                  SUBS      TXENABLE,D0Re0,#0xff
                  SUBS      D1Re0,D0.7,#0x7f
                  SUBS      PC,D0.7,#0x80
                  SUBS      TXSTAT,D0.7,#0xff
                  SUBS      PCX,D0Re0,#0x80
                  SUBS      PCX,D0.7,#0x7f
                  SUBS      PCX,D0.7,#0xff
                  SUBS      TXMASKI,D0Re0,#0x7f
                  SUBS      TXMASKI,D0.7,#0x80
                  SUBS      GTEXEC,D0.7,#0x80
                  SUBSCS    D0.7,D0Re0,#0x80
                  SUBS      D1.7,D0Re0,#0xff
                  SUBS      TXGPIOO,D0.7,#0x7f
                  SUBS      A0.7,D0.7,#0xff
                  SUBS      RA,D0.7,#0xff
                  SUBS      RAM8X,D0Re0,#0x80
                  SUBS      RABZ,D0.7,#0x7f
                  SUBS      RAWX,D0.7,#0xff
                  SUBS      RAMX,D0.7,#0x7f
                  SUBS      PC,D1Re0,#0x7f
                  SUBS      TTEXEC,D1Re0,#0x80
                  SUBS      TXENABLE,D1.7,#0x7f
                  SUBS      D0Re0,D1.7,#0x80
                  SUBS      D1Re0,D1.7,#0xff
                  SUBS      A0FrP,D1Re0,#0x80
                  SUBS      A0FrP,D1.7,#0x7f
                  SUBS      A0FrP,D1.7,#0xff
                  SUBS      TTMARK,D1.7,#0x80
                  SUBS      TXMASKI,D1.7,#0x7f
                  SUBS      GTEXEC,D1Re0,#0xff
                  SUBS      A1.7,D1Re0,#0x7f
                  SUBSNV    D1.7,D1Re0,#0xff
                  SUBS      A0.7,D1.7,#0x7f
                  SUBSGT    D1.7,D1.7,#0xff
                  SUBS      RA,D1.7,#0x7f
                  SUBS      RAM8X32,D1.7,#0xff
                  SUBS      RABZ,D1Re0,#0x80
                  SUBS      RAWX,D1.7,#0x7f
                  SUBS      RAMX,D1Re0,#0xff
                  AND       D0Re0,D0Re0,A1LbP
                  AND       D0Re0,D0.7,D0Re0
                  AND       D0Re0,D0.7,A0.7
                  AND       D0.7,D0Re0,A0FrP
                  AND       D0.7,D0.7,RD
                  AND       D1Re0,D1Re0,D0.7
                  AND       D1Re0,D1.7,D0Re0
                  AND       D1.7,D1Re0,A1.7
                  AND       D1.7,D1.7,D1.7
                  ANDT      D0Re0,D0Re0,#0x7fff
                  AND       D0Re0,D0Re0,#0xffff
                  ANDMT     D0.7,D0.7,#0x7fff
                  AND       D0.7,D0.7,#-0x1
                  ANDT      D1Re0,D1Re0,#0x8000
                  ANDMT     D1Re0,D1Re0,#0xffff
                  ANDMB     D1.7,D1.7,#0x8000
                  ANDEQ     D0Re0,D0Re0,D0Re0
                  ANDGT     PC,D0Re0,A1LbP
                  ANDGT     D1Re0,D0Re0,A1.7
                  ANDVS     D0Re0,D0Re0,D1Re0
                  ANDVS     PC,D0Re0,D1.7
                  ANDVS     TTEXEC,D0Re0,RD
                  ANDVS     D0Re0,D0Re0,A0.7
                  ANDEQ     PC,D0.7,D0Re0
                  ANDVS     TTEXEC,D0.7,A1LbP
                  ANDNV     PC,D0.7,A1.7
                  ANDVS     PC,D0.7,D1Re0
                  ANDGT     TTEXEC,D0.7,D1.7
                  ANDNV     D0Re0,D0.7,A0FrP
                  ANDGT     PC,D0.7,A0.7
                  ANDGT     A1LbP,D0Re0,A1LbP
                  ANDNV     PCX,D0Re0,A1.7
                  ANDVS     A1LbP,D0Re0,D1.7
                  ANDGE     A1LbP,D0Re0,A0FrP
                  ANDNE     A1LbP,D0.7,D0Re0
                  ANDVS     A0FrP,D0.7,A1.7
                  ANDGE     A1LbP,D0.7,D1Re0
                  ANDGT     A1LbP,D0.7,RD
                  ANDNV     A1LbP,D0.7,A0.7
                  ANDNV     TTMARK,D0Re0,D1.7
                  ANDVS     TTMARK,D0.7,D1Re0
                  ANDGE     TTREC,D0Re0,A1LbP
                  ANDNV     TTREC,D0Re0,D1.7
                  ANDCS     TTREC,D0.7,D0Re0
                  ANDVS     TTREC,D0.7,D1Re0
                  ANDVS     TTREC,D0.7,A0.7
                  ANDNV     GTEXEC,D0Re0,A0FrP
                  ANDVS     GTEXEC,D0.7,RD
                  ANDGE     D0.7,D0Re0,A1LbP
                  ANDVS     D1.7,D0Re0,A1.7
                  ANDNV     D1.7,D0Re0,D1Re0
                  ANDNV     TXGPIOO,D0Re0,D1.7
                  ANDVS     A0.7,D0Re0,A0FrP
                  ANDEQ     D0.7,D0.7,D0Re0
                  ANDVS     A1.7,D0.7,A1LbP
                  ANDEQ     A1.7,D0.7,D0.7
                  ANDGT     TXGPIOO,D0.7,D1Re0
                  ANDGE     A0.7,D0.7,RD
                  ANDVS     D0.7,D0.7,A0.7
                  ANDGT     RA,D0Re0,A1.7
                  ANDMI     RA,D0.7,D0.7
                  ANDGT     RAM8X32,D0Re0,A1LbP
                  ANDMI     RAM8X32,D0.7,D0Re0
                  ANDVS     RAM8X32,D0.7,A0.7
                  ANDGT     RAM8X,D0Re0,A0FrP
                  ANDVS     RAM8X,D0.7,RD
                  ANDGE     RABZ,D0Re0,D1.7
                  ANDGE     RABZ,D0.7,D1Re0
                  ANDNV     RAWX,D0Re0,A1.7
                  ANDNE     RAWX,D0.7,D0.7
                  ANDCS     RAMX,D0Re0,D0Re0
                  ANDVS     RAMX,D0Re0,D1Re0
                  ANDGT     RAMX,D0Re0,A0.7
                  ANDVS     RAMX,D0.7,A1.7
                  ANDVS     RAMX,D0.7,A0FrP
                  ANDCC     TTEXEC,D1Re0,D1Re0
                  ANDNV     TXENABLE,D1Re0,A1.7
                  ANDGT     TXSTAT,D1Re0,A1.7
                  ANDNV     TTEXEC,D1Re0,D0Re0
                  ANDVS     D0Re0,D1Re0,RD
                  ANDVS     PC,D1Re0,A0FrP
                  ANDVS     TTEXEC,D1Re0,A0.7
                  ANDVS     D0Re0,D1.7,A1LbP
                  ANDGT     D0Re0,D1.7,A1.7
                  ANDGE     TTEXEC,D1.7,A1.7
                  ANDNV     D0Re0,D1.7,D0.7
                  ANDGE     PC,D1.7,RD
                  ANDNV     TTEXEC,D1.7,A0FrP
                  ANDNE     A1LbP,D1Re0,D1Re0
                  ANDVS     A0FrP,D1Re0,A1.7
                  ANDGE     A1LbP,D1Re0,D0Re0
                  ANDGT     A1LbP,D1Re0,RD
                  ANDNV     A1LbP,D1Re0,A0.7
                  ANDGT     A1LbP,D1.7,A1LbP
                  ANDNV     PCX,D1.7,A1.7
                  ANDVS     A1LbP,D1.7,D0.7
                  ANDGE     A1LbP,D1.7,A0FrP
                  ANDGE     TTMARK,D1Re0,A1LbP
                  ANDCS     TTMARK,D1.7,D1Re0
                  ANDVS     TTMARK,D1.7,A0.7
                  ANDVS     TTREC,D1Re0,A1.7
                  ANDNV     TTREC,D1Re0,A0FrP
                  ANDNV     TXMASKI,D1.7,A1.7
                  ANDVS     TTREC,D1.7,RD
                  ANDVS     GTEXEC,D1Re0,A1.7
                  ANDCC     GTEXEC,D1.7,D1.7
                  ANDCS     D1.7,D1Re0,D1Re0
                  ANDGT     TXGPIOO,D1Re0,A1LbP
                  ANDGT     A1.7,D1Re0,A1.7
                  ANDGT     D0.7,D1Re0,D0.7
                  ANDNV     A1.7,D1Re0,RD
                  ANDVS     D1.7,D1Re0,A0.7
                  ANDNE     TXGPIOO,D1.7,D1Re0
                  ANDCS     D1.7,D1.7,D1.7
                  ANDGE     D0.7,D1.7,D0Re0
                  ANDGE     A1.7,D1.7,D0.7
                  ANDVS     D1.7,D1.7,A0FrP
                  ANDVS     TXGPIOO,D1.7,A0.7
                  ANDVS     RA,D1Re0,A0FrP
                  ANDGT     RA,D1.7,RD
                  ANDGE     RAM8X32,D1Re0,D0.7
                  ANDGE     RAM8X32,D1.7,D0Re0
                  ANDNV     RAM8X,D1Re0,A1.7
                  ANDNE     RAM8X,D1.7,D1.7
                  ANDGT     RABZ,D1Re0,A1LbP
                  ANDMI     RABZ,D1.7,D1Re0
                  ANDVS     RABZ,D1.7,A0.7
                  ANDGT     RAWX,D1Re0,A0FrP
                  ANDVS     RAWX,D1.7,RD
                  ANDGE     TXIDLECYC,D1Re0,A1.7
                  ANDGT     RAMX,D1Re0,RD
                  ANDVS     RAMX,D1.7,A1LbP
                  ANDNV     RAMX,D1.7,D0.7
                  AND       TXENABLE,D0Re0,#0x7f
                  AND       PC,D0Re0,#0x80
                  AND       TTEXEC,D0Re0,#0xff
                  ANDCC     D0Re0,D0.7,#0x80
                  AND       TXENABLE,D0.7,#0xff
                  AND       PCX,D0Re0,#0x7f
                  AND       PCX,D0Re0,#0xff
                  AND       PCX,D0.7,#0x80
                  AND       TTMARK,D0Re0,#0xff
                  AND       TXMASKI,D0Re0,#0xff
                  AND       GTEXEC,D0Re0,#0x7f
                  AND       D1.7,D0Re0,#0x7f
                  AND       A1.7,D0Re0,#0x80
                  ANDGE     D0.7,D0.7,#0x7f
                  AND       A1.7,D0.7,#0x80
                  AND       RA,D0Re0,#0x80
                  AND       RAM8X32,D0.7,#0x7f
                  AND       RAM8X,D0.7,#0xff
                  AND       RAWX,D0Re0,#0x80
                  AND       RAMX,D0Re0,#0x80
                  AND       RAMX,D0.7,#0xff
                  AND       TXENABLE,D1Re0,#0x80
                  AND       PC,D1Re0,#0xff
                  AND       TXSTAT,D1.7,#0x7f
                  AND       TTEXEC,D1.7,#0x80
                  AND       A0FrP,D1Re0,#0x7f
                  AND       A0FrP,D1Re0,#0xff
                  AND       A0FrP,D1.7,#0x80
                  AND       TTMARK,D1Re0,#0x7f
                  AND       TXMASKI,D1Re0,#0x80
                  AND       TXMASKI,D1.7,#0xff
                  ANDVS     D1.7,D1Re0,#0x7f
                  AND       D1.7,D1Re0,#0x80
                  AND       A1.7,D1Re0,#0xff
                  AND       D0.7,D1.7,#0x80
                  AND       TXGPIOO,D1.7,#0xff
                  AND       RAM8X32,D1Re0,#0x80
                  AND       RAM8X,D1.7,#0x7f
                  AND       RABZ,D1.7,#0xff
                  AND       RAMX,D1Re0,#0x7f
                  AND       RAMX,D1.7,#0x80
                  ANDS      D0Re0,D0Re0,D1.7
                  ANDS      D0Re0,D0.7,D1Re0
                  ANDS      D0.7,D0Re0,A1.7
                  ANDS      D0.7,D0.7,D0.7
                  ANDS      D1Re0,D1Re0,A1LbP
                  ANDS      D1Re0,D1.7,D1Re0
                  ANDS      D1Re0,D1.7,A0.7
                  ANDS      D1.7,D1Re0,A0FrP
                  ANDS      D1.7,D1.7,RD
                  ANDST     D0Re0,D0Re0,#0x8000
                  ANDSMT    D0Re0,D0Re0,#0xffff
                  ANDSMB    D0.7,D0.7,#0x8000
                  ANDST     D1Re0,D1Re0,#0x7fff
                  ANDS      D1Re0,D1Re0,#0xffff
                  ANDSMT    D1.7,D1.7,#0x7fff
                  ANDS      D1.7,D1.7,#-0x1
                  ANDSMI    TTEXEC,D0Re0,D0Re0
                  ANDSVS    TXENABLE,D0Re0,A1.7
                  ANDSNV    TXSTAT,D0Re0,A1.7
                  ANDSVS    TTEXEC,D0Re0,D1Re0
                  ANDSGE    D0Re0,D0Re0,RD
                  ANDSVS    PC,D0Re0,A0FrP
                  ANDSVS    TTEXEC,D0Re0,A0.7
                  ANDSVS    D0Re0,D0.7,A1LbP
                  ANDSGT    D0Re0,D0.7,A1.7
                  ANDSGE    TTEXEC,D0.7,A1.7
                  ANDSNV    D0Re0,D0.7,D1.7
                  ANDSGE    PC,D0.7,RD
                  ANDSNV    TTEXEC,D0.7,A0FrP
                  ANDSNE    A1LbP,D0Re0,D0Re0
                  ANDSVS    A0FrP,D0Re0,A1.7
                  ANDSGE    A1LbP,D0Re0,D1Re0
                  ANDSGT    A1LbP,D0Re0,RD
                  ANDSNV    A1LbP,D0Re0,A0.7
                  ANDSGT    A1LbP,D0.7,A1LbP
                  ANDSNV    PCX,D0.7,A1.7
                  ANDSVS    A1LbP,D0.7,D1.7
                  ANDSGE    A1LbP,D0.7,A0FrP
                  ANDSGE    TTMARK,D0Re0,A1LbP
                  ANDSCS    TTMARK,D0.7,D0Re0
                  ANDSVS    TTMARK,D0.7,A0.7
                  ANDSVS    TTREC,D0Re0,A1.7
                  ANDSNV    TTREC,D0Re0,A0FrP
                  ANDSNV    TXMASKI,D0.7,A1.7
                  ANDSVS    TTREC,D0.7,RD
                  ANDSVS    GTEXEC,D0Re0,A1.7
                  ANDSCC    GTEXEC,D0.7,D0.7
                  ANDSCS    D1.7,D0Re0,D0Re0
                  ANDSGT    TXGPIOO,D0Re0,A1LbP
                  ANDSGT    A1.7,D0Re0,A1.7
                  ANDSGT    D0.7,D0Re0,D1.7
                  ANDSNV    A1.7,D0Re0,RD
                  ANDSVS    D1.7,D0Re0,A0.7
                  ANDSNE    TXGPIOO,D0.7,D0Re0
                  ANDSCS    D1.7,D0.7,D0.7
                  ANDSGE    D0.7,D0.7,D1Re0
                  ANDSGE    A1.7,D0.7,D1.7
                  ANDSVS    D1.7,D0.7,A0FrP
                  ANDSVS    TXGPIOO,D0.7,A0.7
                  ANDSVS    RA,D0Re0,A0FrP
                  ANDSGT    RA,D0.7,RD
                  ANDSGE    RAM8X32,D0Re0,D1.7
                  ANDSGE    RAM8X32,D0.7,D1Re0
                  ANDSNV    RAM8X,D0Re0,A1.7
                  ANDSNE    RAM8X,D0.7,D0.7
                  ANDSGT    RABZ,D0Re0,A1LbP
                  ANDSMI    RABZ,D0.7,D0Re0
                  ANDSVS    RABZ,D0.7,A0.7
                  ANDSGT    RAWX,D0Re0,A0FrP
                  ANDSVS    RAWX,D0.7,RD
                  ANDSGE    TXIDLECYC,D0Re0,A1.7
                  ANDSGT    RAMX,D0Re0,RD
                  ANDSVS    RAMX,D0.7,A1LbP
                  ANDSNV    RAMX,D0.7,D1.7
                  ANDSMI    D0Re0,D1Re0,D1Re0
                  ANDSGE    PC,D1Re0,A1LbP
                  ANDSGE    D1Re0,D1Re0,A1.7
                  ANDSVS    D0Re0,D1Re0,D0Re0
                  ANDSVS    PC,D1Re0,D0.7
                  ANDSVS    TTEXEC,D1Re0,RD
                  ANDSGE    D0Re0,D1Re0,A0.7
                  ANDSEQ    PC,D1.7,D1Re0
                  ANDSVS    TTEXEC,D1.7,A1LbP
                  ANDSNV    PC,D1.7,A1.7
                  ANDSVS    PC,D1.7,D0Re0
                  ANDSGT    TTEXEC,D1.7,D0.7
                  ANDSNV    D0Re0,D1.7,A0FrP
                  ANDSGT    PC,D1.7,A0.7
                  ANDSGT    A1LbP,D1Re0,A1LbP
                  ANDSNV    PCX,D1Re0,A1.7
                  ANDSVS    A1LbP,D1Re0,D0.7
                  ANDSGE    A1LbP,D1Re0,A0FrP
                  ANDSNE    A1LbP,D1.7,D1Re0
                  ANDSVS    A0FrP,D1.7,A1.7
                  ANDSGE    A1LbP,D1.7,D0Re0
                  ANDSGT    A1LbP,D1.7,RD
                  ANDSNV    A1LbP,D1.7,A0.7
                  ANDSNV    TTMARK,D1Re0,D0.7
                  ANDSVS    TTMARK,D1.7,D0Re0
                  ANDSGE    TTREC,D1Re0,A1LbP
                  ANDSNV    TTREC,D1Re0,D0.7
                  ANDSCS    TTREC,D1.7,D1Re0
                  ANDSVS    TTREC,D1.7,D0Re0
                  ANDSVS    TTREC,D1.7,A0.7
                  ANDSNV    GTEXEC,D1Re0,A0FrP
                  ANDSVS    GTEXEC,D1.7,RD
                  ANDSGE    D0.7,D1Re0,A1LbP
                  ANDSVS    D1.7,D1Re0,A1.7
                  ANDSNV    D1.7,D1Re0,D0Re0
                  ANDSNV    TXGPIOO,D1Re0,D0.7
                  ANDSVS    A0.7,D1Re0,A0FrP
                  ANDSEQ    D0.7,D1.7,D1Re0
                  ANDSVS    A1.7,D1.7,A1LbP
                  ANDSEQ    A1.7,D1.7,D1.7
                  ANDSGT    TXGPIOO,D1.7,D0Re0
                  ANDSGE    A0.7,D1.7,RD
                  ANDSVS    D0.7,D1.7,A0.7
                  ANDSGT    RA,D1Re0,A1.7
                  ANDSMI    RA,D1.7,D1.7
                  ANDSGT    RAM8X32,D1Re0,A1LbP
                  ANDSMI    RAM8X32,D1.7,D1Re0
                  ANDSVS    RAM8X32,D1.7,A0.7
                  ANDSGT    RAM8X,D1Re0,A0FrP
                  ANDSVS    RAM8X,D1.7,RD
                  ANDSGE    RABZ,D1Re0,D0.7
                  ANDSGE    RABZ,D1.7,D0Re0
                  ANDSNV    RAWX,D1Re0,A1.7
                  ANDSNE    RAWX,D1.7,D1.7
                  ANDSCS    RAMX,D1Re0,D1Re0
                  ANDSVS    RAMX,D1Re0,D0Re0
                  ANDSGT    RAMX,D1Re0,A0.7
                  ANDSVS    RAMX,D1.7,A1.7
                  ANDSVS    RAMX,D1.7,A0FrP
                  ANDS      TTEXEC,D0Re0,#0x7f
                  ANDS      TXENABLE,D0Re0,#0xff
                  ANDS      D1Re0,D0.7,#0x7f
                  ANDS      PC,D0.7,#0x80
                  ANDS      TXSTAT,D0.7,#0xff
                  ANDS      PCX,D0Re0,#0x80
                  ANDS      PCX,D0.7,#0x7f
                  ANDS      PCX,D0.7,#0xff
                  ANDS      TXMASKI,D0Re0,#0x7f
                  ANDS      TXMASKI,D0.7,#0x80
                  ANDS      GTEXEC,D0.7,#0x80
                  ANDSCS    D0.7,D0Re0,#0x80
                  ANDS      D1.7,D0Re0,#0xff
                  ANDS      TXGPIOO,D0.7,#0x7f
                  ANDS      A0.7,D0.7,#0xff
                  ANDS      RA,D0.7,#0xff
                  ANDS      RAM8X,D0Re0,#0x80
                  ANDS      RABZ,D0.7,#0x7f
                  ANDS      RAWX,D0.7,#0xff
                  ANDS      RAMX,D0.7,#0x7f
                  ANDS      PC,D1Re0,#0x7f
                  ANDS      TTEXEC,D1Re0,#0x80
                  ANDS      TXENABLE,D1.7,#0x7f
                  ANDS      D0Re0,D1.7,#0x80
                  ANDS      D1Re0,D1.7,#0xff
                  ANDS      A0FrP,D1Re0,#0x80
                  ANDS      A0FrP,D1.7,#0x7f
                  ANDS      A0FrP,D1.7,#0xff
                  ANDS      TTMARK,D1.7,#0x80
                  ANDS      TXMASKI,D1.7,#0x7f
                  ANDS      GTEXEC,D1Re0,#0xff
                  ANDS      A1.7,D1Re0,#0x7f
                  ANDSNV    D1.7,D1Re0,#0xff
                  ANDS      A0.7,D1.7,#0x7f
                  ANDSGT    D1.7,D1.7,#0xff
                  ANDS      RA,D1.7,#0x7f
                  ANDS      RAM8X32,D1.7,#0xff
                  ANDS      RABZ,D1Re0,#0x80
                  ANDS      RAWX,D1.7,#0x7f
                  ANDS      RAMX,D1Re0,#0xff
                  OR        D0Re0,D0Re0,A1LbP
                  OR        D0Re0,D0.7,D0Re0
                  OR        D0Re0,D0.7,A0.7
                  OR        D0.7,D0Re0,A0FrP
                  OR        D0.7,D0.7,RD
                  OR        D1Re0,D1Re0,D0.7
                  OR        D1Re0,D1.7,D0Re0
                  OR        D1.7,D1Re0,A1.7
                  OR        D1.7,D1.7,D1.7
                  ORT       D0Re0,D0Re0,#0x7fff
                  OR        D0Re0,D0Re0,#0xffff
                  ORMT      D0.7,D0.7,#0x7fff
                  OR        D0.7,D0.7,#-0x1
                  ORT       D1Re0,D1Re0,#0x8000
                  ORMT      D1Re0,D1Re0,#0xffff
                  ORMB      D1.7,D1.7,#0x8000
                  OREQ      D0Re0,D0Re0,D0Re0
                  ORGT      PC,D0Re0,A1LbP
                  ORGT      D1Re0,D0Re0,A1.7
                  ORVS      D0Re0,D0Re0,D1Re0
                  ORVS      PC,D0Re0,D1.7
                  ORVS      TTEXEC,D0Re0,RD
                  ORVS      D0Re0,D0Re0,A0.7
                  OREQ      PC,D0.7,D0Re0
                  ORVS      TTEXEC,D0.7,A1LbP
                  ORNV      PC,D0.7,A1.7
                  ORVS      PC,D0.7,D1Re0
                  ORGT      TTEXEC,D0.7,D1.7
                  ORNV      D0Re0,D0.7,A0FrP
                  ORGT      PC,D0.7,A0.7
                  ORGT      A1LbP,D0Re0,A1LbP
                  ORNV      PCX,D0Re0,A1.7
                  ORVS      A1LbP,D0Re0,D1.7
                  ORGE      A1LbP,D0Re0,A0FrP
                  ORNE      A1LbP,D0.7,D0Re0
                  ORVS      A0FrP,D0.7,A1.7
                  ORGE      A1LbP,D0.7,D1Re0
                  ORGT      A1LbP,D0.7,RD
                  ORNV      A1LbP,D0.7,A0.7
                  ORNV      TTMARK,D0Re0,D1.7
                  ORVS      TTMARK,D0.7,D1Re0
                  ORGE      TTREC,D0Re0,A1LbP
                  ORNV      TTREC,D0Re0,D1.7
                  ORCS      TTREC,D0.7,D0Re0
                  ORVS      TTREC,D0.7,D1Re0
                  ORVS      TTREC,D0.7,A0.7
                  ORNV      GTEXEC,D0Re0,A0FrP
                  ORVS      GTEXEC,D0.7,RD
                  ORGE      D0.7,D0Re0,A1LbP
                  ORVS      D1.7,D0Re0,A1.7
                  ORNV      D1.7,D0Re0,D1Re0
                  ORNV      TXGPIOO,D0Re0,D1.7
                  ORVS      A0.7,D0Re0,A0FrP
                  OREQ      D0.7,D0.7,D0Re0
                  ORVS      A1.7,D0.7,A1LbP
                  OREQ      A1.7,D0.7,D0.7
                  ORGT      TXGPIOO,D0.7,D1Re0
                  ORGE      A0.7,D0.7,RD
                  ORVS      D0.7,D0.7,A0.7
                  ORGT      RA,D0Re0,A1.7
                  ORMI      RA,D0.7,D0.7
                  ORGT      RAM8X32,D0Re0,A1LbP
                  ORMI      RAM8X32,D0.7,D0Re0
                  ORVS      RAM8X32,D0.7,A0.7
                  ORGT      RAM8X,D0Re0,A0FrP
                  ORVS      RAM8X,D0.7,RD
                  ORGE      RABZ,D0Re0,D1.7
                  ORGE      RABZ,D0.7,D1Re0
                  ORNV      RAWX,D0Re0,A1.7
                  ORNE      RAWX,D0.7,D0.7
                  ORCS      RAMX,D0Re0,D0Re0
                  ORVS      RAMX,D0Re0,D1Re0
                  ORGT      RAMX,D0Re0,A0.7
                  ORVS      RAMX,D0.7,A1.7
                  ORVS      RAMX,D0.7,A0FrP
                  ORCC      TTEXEC,D1Re0,D1Re0
                  ORNV      TXENABLE,D1Re0,A1.7
                  ORGT      TXSTAT,D1Re0,A1.7
                  ORNV      TTEXEC,D1Re0,D0Re0
                  ORVS      D0Re0,D1Re0,RD
                  ORVS      PC,D1Re0,A0FrP
                  ORVS      TTEXEC,D1Re0,A0.7
                  ORVS      D0Re0,D1.7,A1LbP
                  ORGT      D0Re0,D1.7,A1.7
                  ORGE      TTEXEC,D1.7,A1.7
                  ORNV      D0Re0,D1.7,D0.7
                  ORGE      PC,D1.7,RD
                  ORNV      TTEXEC,D1.7,A0FrP
                  ORNE      A1LbP,D1Re0,D1Re0
                  ORVS      A0FrP,D1Re0,A1.7
                  ORGE      A1LbP,D1Re0,D0Re0
                  ORGT      A1LbP,D1Re0,RD
                  ORNV      A1LbP,D1Re0,A0.7
                  ORGT      A1LbP,D1.7,A1LbP
                  ORNV      PCX,D1.7,A1.7
                  ORVS      A1LbP,D1.7,D0.7
                  ORGE      A1LbP,D1.7,A0FrP
                  ORGE      TTMARK,D1Re0,A1LbP
                  ORCS      TTMARK,D1.7,D1Re0
                  ORVS      TTMARK,D1.7,A0.7
                  ORVS      TTREC,D1Re0,A1.7
                  ORNV      TTREC,D1Re0,A0FrP
                  ORNV      TXMASKI,D1.7,A1.7
                  ORVS      TTREC,D1.7,RD
                  ORVS      GTEXEC,D1Re0,A1.7
                  ORCC      GTEXEC,D1.7,D1.7
                  ORCS      D1.7,D1Re0,D1Re0
                  ORGT      TXGPIOO,D1Re0,A1LbP
                  ORGT      A1.7,D1Re0,A1.7
                  ORGT      D0.7,D1Re0,D0.7
                  ORNV      A1.7,D1Re0,RD
                  ORVS      D1.7,D1Re0,A0.7
                  ORNE      TXGPIOO,D1.7,D1Re0
                  ORCS      D1.7,D1.7,D1.7
                  ORGE      D0.7,D1.7,D0Re0
                  ORGE      A1.7,D1.7,D0.7
                  ORVS      D1.7,D1.7,A0FrP
                  ORVS      TXGPIOO,D1.7,A0.7
                  ORVS      RA,D1Re0,A0FrP
                  ORGT      RA,D1.7,RD
                  ORGE      RAM8X32,D1Re0,D0.7
                  ORGE      RAM8X32,D1.7,D0Re0
                  ORNV      RAM8X,D1Re0,A1.7
                  ORNE      RAM8X,D1.7,D1.7
                  ORGT      RABZ,D1Re0,A1LbP
                  ORMI      RABZ,D1.7,D1Re0
                  ORVS      RABZ,D1.7,A0.7
                  ORGT      RAWX,D1Re0,A0FrP
                  ORVS      RAWX,D1.7,RD
                  ORGE      TXIDLECYC,D1Re0,A1.7
                  ORGT      RAMX,D1Re0,RD
                  ORVS      RAMX,D1.7,A1LbP
                  ORNV      RAMX,D1.7,D0.7
                  OR        TXENABLE,D0Re0,#0x7f
                  OR        PC,D0Re0,#0x80
                  OR        TTEXEC,D0Re0,#0xff
                  ORCC      D0Re0,D0.7,#0x80
                  OR        TXENABLE,D0.7,#0xff
                  OR        PCX,D0Re0,#0x7f
                  OR        PCX,D0Re0,#0xff
                  OR        PCX,D0.7,#0x80
                  OR        TTMARK,D0Re0,#0xff
                  OR        TXMASKI,D0Re0,#0xff
                  OR        GTEXEC,D0Re0,#0x7f
                  OR        D1.7,D0Re0,#0x7f
                  OR        A1.7,D0Re0,#0x80
                  ORGE      D0.7,D0.7,#0x7f
                  OR        A1.7,D0.7,#0x80
                  OR        RA,D0Re0,#0x80
                  OR        RAM8X32,D0.7,#0x7f
                  OR        RAM8X,D0.7,#0xff
                  OR        RAWX,D0Re0,#0x80
                  OR        RAMX,D0Re0,#0x80
                  OR        RAMX,D0.7,#0xff
                  OR        TXENABLE,D1Re0,#0x80
                  OR        PC,D1Re0,#0xff
                  OR        TXSTAT,D1.7,#0x7f
                  OR        TTEXEC,D1.7,#0x80
                  OR        A0FrP,D1Re0,#0x7f
                  OR        A0FrP,D1Re0,#0xff
                  OR        A0FrP,D1.7,#0x80
                  OR        TTMARK,D1Re0,#0x7f
                  OR        TXMASKI,D1Re0,#0x80
                  OR        TXMASKI,D1.7,#0xff
                  ORVS      D1.7,D1Re0,#0x7f
                  OR        D1.7,D1Re0,#0x80
                  OR        A1.7,D1Re0,#0xff
                  OR        D0.7,D1.7,#0x80
                  OR        TXGPIOO,D1.7,#0xff
                  OR        RAM8X32,D1Re0,#0x80
                  OR        RAM8X,D1.7,#0x7f
                  OR        RABZ,D1.7,#0xff
                  OR        RAMX,D1Re0,#0x7f
                  OR        RAMX,D1.7,#0x80
                  ORS       D0Re0,D0Re0,D1.7
                  ORS       D0Re0,D0.7,D1Re0
                  ORS       D0.7,D0Re0,A1.7
                  ORS       D0.7,D0.7,D0.7
                  ORS       D1Re0,D1Re0,A1LbP
                  ORS       D1Re0,D1.7,D1Re0
                  ORS       D1Re0,D1.7,A0.7
                  ORS       D1.7,D1Re0,A0FrP
                  ORS       D1.7,D1.7,RD
                  ORST      D0Re0,D0Re0,#0x8000
                  ORSMT     D0Re0,D0Re0,#0xffff
                  ORSMB     D0.7,D0.7,#0x8000
                  ORST      D1Re0,D1Re0,#0x7fff
                  ORS       D1Re0,D1Re0,#0xffff
                  ORSMT     D1.7,D1.7,#0x7fff
                  ORS       D1.7,D1.7,#-0x1
                  ORSMI     TTEXEC,D0Re0,D0Re0
                  ORSVS     TXENABLE,D0Re0,A1.7
                  ORSNV     TXSTAT,D0Re0,A1.7
                  ORSVS     TTEXEC,D0Re0,D1Re0
                  ORSGE     D0Re0,D0Re0,RD
                  ORSVS     PC,D0Re0,A0FrP
                  ORSVS     TTEXEC,D0Re0,A0.7
                  ORSVS     D0Re0,D0.7,A1LbP
                  ORSGT     D0Re0,D0.7,A1.7
                  ORSGE     TTEXEC,D0.7,A1.7
                  ORSNV     D0Re0,D0.7,D1.7
                  ORSGE     PC,D0.7,RD
                  ORSNV     TTEXEC,D0.7,A0FrP
                  ORSNE     A1LbP,D0Re0,D0Re0
                  ORSVS     A0FrP,D0Re0,A1.7
                  ORSGE     A1LbP,D0Re0,D1Re0
                  ORSGT     A1LbP,D0Re0,RD
                  ORSNV     A1LbP,D0Re0,A0.7
                  ORSGT     A1LbP,D0.7,A1LbP
                  ORSNV     PCX,D0.7,A1.7
                  ORSVS     A1LbP,D0.7,D1.7
                  ORSGE     A1LbP,D0.7,A0FrP
                  ORSGE     TTMARK,D0Re0,A1LbP
                  ORSCS     TTMARK,D0.7,D0Re0
                  ORSVS     TTMARK,D0.7,A0.7
                  ORSVS     TTREC,D0Re0,A1.7
                  ORSNV     TTREC,D0Re0,A0FrP
                  ORSNV     TXMASKI,D0.7,A1.7
                  ORSVS     TTREC,D0.7,RD
                  ORSVS     GTEXEC,D0Re0,A1.7
                  ORSCC     GTEXEC,D0.7,D0.7
                  ORSCS     D1.7,D0Re0,D0Re0
                  ORSGT     TXGPIOO,D0Re0,A1LbP
                  ORSGT     A1.7,D0Re0,A1.7
                  ORSGT     D0.7,D0Re0,D1.7
                  ORSNV     A1.7,D0Re0,RD
                  ORSVS     D1.7,D0Re0,A0.7
                  ORSNE     TXGPIOO,D0.7,D0Re0
                  ORSCS     D1.7,D0.7,D0.7
                  ORSGE     D0.7,D0.7,D1Re0
                  ORSGE     A1.7,D0.7,D1.7
                  ORSVS     D1.7,D0.7,A0FrP
                  ORSVS     TXGPIOO,D0.7,A0.7
                  ORSVS     RA,D0Re0,A0FrP
                  ORSGT     RA,D0.7,RD
                  ORSGE     RAM8X32,D0Re0,D1.7
                  ORSGE     RAM8X32,D0.7,D1Re0
                  ORSNV     RAM8X,D0Re0,A1.7
                  ORSNE     RAM8X,D0.7,D0.7
                  ORSGT     RABZ,D0Re0,A1LbP
                  ORSMI     RABZ,D0.7,D0Re0
                  ORSVS     RABZ,D0.7,A0.7
                  ORSGT     RAWX,D0Re0,A0FrP
                  ORSVS     RAWX,D0.7,RD
                  ORSGE     TXIDLECYC,D0Re0,A1.7
                  ORSGT     RAMX,D0Re0,RD
                  ORSVS     RAMX,D0.7,A1LbP
                  ORSNV     RAMX,D0.7,D1.7
                  ORSMI     D0Re0,D1Re0,D1Re0
                  ORSGE     PC,D1Re0,A1LbP
                  ORSGE     D1Re0,D1Re0,A1.7
                  ORSVS     D0Re0,D1Re0,D0Re0
                  ORSVS     PC,D1Re0,D0.7
                  ORSVS     TTEXEC,D1Re0,RD
                  ORSGE     D0Re0,D1Re0,A0.7
                  ORSEQ     PC,D1.7,D1Re0
                  ORSVS     TTEXEC,D1.7,A1LbP
                  ORSNV     PC,D1.7,A1.7
                  ORSVS     PC,D1.7,D0Re0
                  ORSGT     TTEXEC,D1.7,D0.7
                  ORSNV     D0Re0,D1.7,A0FrP
                  ORSGT     PC,D1.7,A0.7
                  ORSGT     A1LbP,D1Re0,A1LbP
                  ORSNV     PCX,D1Re0,A1.7
                  ORSVS     A1LbP,D1Re0,D0.7
                  ORSGE     A1LbP,D1Re0,A0FrP
                  ORSNE     A1LbP,D1.7,D1Re0
                  ORSVS     A0FrP,D1.7,A1.7
                  ORSGE     A1LbP,D1.7,D0Re0
                  ORSGT     A1LbP,D1.7,RD
                  ORSNV     A1LbP,D1.7,A0.7
                  ORSNV     TTMARK,D1Re0,D0.7
                  ORSVS     TTMARK,D1.7,D0Re0
                  ORSGE     TTREC,D1Re0,A1LbP
                  ORSNV     TTREC,D1Re0,D0.7
                  ORSCS     TTREC,D1.7,D1Re0
                  ORSVS     TTREC,D1.7,D0Re0
                  ORSVS     TTREC,D1.7,A0.7
                  ORSNV     GTEXEC,D1Re0,A0FrP
                  ORSVS     GTEXEC,D1.7,RD
                  ORSGE     D0.7,D1Re0,A1LbP
                  ORSVS     D1.7,D1Re0,A1.7
                  ORSNV     D1.7,D1Re0,D0Re0
                  ORSNV     TXGPIOO,D1Re0,D0.7
                  ORSVS     A0.7,D1Re0,A0FrP
                  ORSEQ     D0.7,D1.7,D1Re0
                  ORSVS     A1.7,D1.7,A1LbP
                  ORSEQ     A1.7,D1.7,D1.7
                  ORSGT     TXGPIOO,D1.7,D0Re0
                  ORSGE     A0.7,D1.7,RD
                  ORSVS     D0.7,D1.7,A0.7
                  ORSGT     RA,D1Re0,A1.7
                  ORSMI     RA,D1.7,D1.7
                  ORSGT     RAM8X32,D1Re0,A1LbP
                  ORSMI     RAM8X32,D1.7,D1Re0
                  ORSVS     RAM8X32,D1.7,A0.7
                  ORSGT     RAM8X,D1Re0,A0FrP
                  ORSVS     RAM8X,D1.7,RD
                  ORSGE     RABZ,D1Re0,D0.7
                  ORSGE     RABZ,D1.7,D0Re0
                  ORSNV     RAWX,D1Re0,A1.7
                  ORSNE     RAWX,D1.7,D1.7
                  ORSCS     RAMX,D1Re0,D1Re0
                  ORSVS     RAMX,D1Re0,D0Re0
                  ORSGT     RAMX,D1Re0,A0.7
                  ORSVS     RAMX,D1.7,A1.7
                  ORSVS     RAMX,D1.7,A0FrP
                  ORS       TTEXEC,D0Re0,#0x7f
                  ORS       TXENABLE,D0Re0,#0xff
                  ORS       D1Re0,D0.7,#0x7f
                  ORS       PC,D0.7,#0x80
                  ORS       TXSTAT,D0.7,#0xff
                  ORS       PCX,D0Re0,#0x80
                  ORS       PCX,D0.7,#0x7f
                  ORS       PCX,D0.7,#0xff
                  ORS       TXMASKI,D0Re0,#0x7f
                  ORS       TXMASKI,D0.7,#0x80
                  ORS       GTEXEC,D0.7,#0x80
                  ORSCS     D0.7,D0Re0,#0x80
                  ORS       D1.7,D0Re0,#0xff
                  ORS       TXGPIOO,D0.7,#0x7f
                  ORS       A0.7,D0.7,#0xff
                  ORS       RA,D0.7,#0xff
                  ORS       RAM8X,D0Re0,#0x80
                  ORS       RABZ,D0.7,#0x7f
                  ORS       RAWX,D0.7,#0xff
                  ORS       RAMX,D0.7,#0x7f
                  ORS       PC,D1Re0,#0x7f
                  ORS       TTEXEC,D1Re0,#0x80
                  ORS       TXENABLE,D1.7,#0x7f
                  ORS       D0Re0,D1.7,#0x80
                  ORS       D1Re0,D1.7,#0xff
                  ORS       A0FrP,D1Re0,#0x80
                  ORS       A0FrP,D1.7,#0x7f
                  ORS       A0FrP,D1.7,#0xff
                  ORS       TTMARK,D1.7,#0x80
                  ORS       TXMASKI,D1.7,#0x7f
                  ORS       GTEXEC,D1Re0,#0xff
                  ORS       A1.7,D1Re0,#0x7f
                  ORSNV     D1.7,D1Re0,#0xff
                  ORS       A0.7,D1.7,#0x7f
                  ORSGT     D1.7,D1.7,#0xff
                  ORS       RA,D1.7,#0x7f
                  ORS       RAM8X32,D1.7,#0xff
                  ORS       RABZ,D1Re0,#0x80
                  ORS       RAWX,D1.7,#0x7f
                  ORS       RAMX,D1Re0,#0xff
                  XOR       D0Re0,D0Re0,A1LbP
                  XOR       D0Re0,D0.7,D0Re0
                  XOR       D0Re0,D0.7,A0.7
                  XOR       D0.7,D0Re0,A0FrP
                  XOR       D0.7,D0.7,RD
                  XOR       D1Re0,D1Re0,D0.7
                  XOR       D1Re0,D1.7,D0Re0
                  XOR       D1.7,D1Re0,A1.7
                  XOR       D1.7,D1.7,D1.7
                  XORT      D0Re0,D0Re0,#0x7fff
                  XOR       D0Re0,D0Re0,#0xffff
                  XORMT     D0.7,D0.7,#0x7fff
                  XOR       D0.7,D0.7,#-0x1
                  XORT      D1Re0,D1Re0,#0x8000
                  XORMT     D1Re0,D1Re0,#0xffff
                  XORMB     D1.7,D1.7,#0x8000
                  XOREQ     D0Re0,D0Re0,D0Re0
                  XORGT     PC,D0Re0,A1LbP
                  XORGT     D1Re0,D0Re0,A1.7
                  XORVS     D0Re0,D0Re0,D1Re0
                  XORVS     PC,D0Re0,D1.7
                  XORVS     TTEXEC,D0Re0,RD
                  XORVS     D0Re0,D0Re0,A0.7
                  XOREQ     PC,D0.7,D0Re0
                  XORVS     TTEXEC,D0.7,A1LbP
                  XORNV     PC,D0.7,A1.7
                  XORVS     PC,D0.7,D1Re0
                  XORGT     TTEXEC,D0.7,D1.7
                  XORNV     D0Re0,D0.7,A0FrP
                  XORGT     PC,D0.7,A0.7
                  XORGT     A1LbP,D0Re0,A1LbP
                  XORNV     PCX,D0Re0,A1.7
                  XORVS     A1LbP,D0Re0,D1.7
                  XORGE     A1LbP,D0Re0,A0FrP
                  XORNE     A1LbP,D0.7,D0Re0
                  XORVS     A0FrP,D0.7,A1.7
                  XORGE     A1LbP,D0.7,D1Re0
                  XORGT     A1LbP,D0.7,RD
                  XORNV     A1LbP,D0.7,A0.7
                  XORNV     TTMARK,D0Re0,D1.7
                  XORVS     TTMARK,D0.7,D1Re0
                  XORGE     TTREC,D0Re0,A1LbP
                  XORNV     TTREC,D0Re0,D1.7
                  XORCS     TTREC,D0.7,D0Re0
                  XORVS     TTREC,D0.7,D1Re0
                  XORVS     TTREC,D0.7,A0.7
                  XORNV     GTEXEC,D0Re0,A0FrP
                  XORVS     GTEXEC,D0.7,RD
                  XORGE     D0.7,D0Re0,A1LbP
                  XORVS     D1.7,D0Re0,A1.7
                  XORNV     D1.7,D0Re0,D1Re0
                  XORNV     TXGPIOO,D0Re0,D1.7
                  XORVS     A0.7,D0Re0,A0FrP
                  XOREQ     D0.7,D0.7,D0Re0
                  XORVS     A1.7,D0.7,A1LbP
                  XOREQ     A1.7,D0.7,D0.7
                  XORGT     TXGPIOO,D0.7,D1Re0
                  XORGE     A0.7,D0.7,RD
                  XORVS     D0.7,D0.7,A0.7
                  XORGT     RA,D0Re0,A1.7
                  XORMI     RA,D0.7,D0.7
                  XORGT     RAM8X32,D0Re0,A1LbP
                  XORMI     RAM8X32,D0.7,D0Re0
                  XORVS     RAM8X32,D0.7,A0.7
                  XORGT     RAM8X,D0Re0,A0FrP
                  XORVS     RAM8X,D0.7,RD
                  XORGE     RABZ,D0Re0,D1.7
                  XORGE     RABZ,D0.7,D1Re0
                  XORNV     RAWX,D0Re0,A1.7
                  XORNE     RAWX,D0.7,D0.7
                  XORCS     RAMX,D0Re0,D0Re0
                  XORVS     RAMX,D0Re0,D1Re0
                  XORGT     RAMX,D0Re0,A0.7
                  XORVS     RAMX,D0.7,A1.7
                  XORVS     RAMX,D0.7,A0FrP
                  XORCC     TTEXEC,D1Re0,D1Re0
                  XORNV     TXENABLE,D1Re0,A1.7
                  XORGT     TXSTAT,D1Re0,A1.7
                  XORNV     TTEXEC,D1Re0,D0Re0
                  XORVS     D0Re0,D1Re0,RD
                  XORVS     PC,D1Re0,A0FrP
                  XORVS     TTEXEC,D1Re0,A0.7
                  XORVS     D0Re0,D1.7,A1LbP
                  XORGT     D0Re0,D1.7,A1.7
                  XORGE     TTEXEC,D1.7,A1.7
                  XORNV     D0Re0,D1.7,D0.7
                  XORGE     PC,D1.7,RD
                  XORNV     TTEXEC,D1.7,A0FrP
                  XORNE     A1LbP,D1Re0,D1Re0
                  XORVS     A0FrP,D1Re0,A1.7
                  XORGE     A1LbP,D1Re0,D0Re0
                  XORGT     A1LbP,D1Re0,RD
                  XORNV     A1LbP,D1Re0,A0.7
                  XORGT     A1LbP,D1.7,A1LbP
                  XORNV     PCX,D1.7,A1.7
                  XORVS     A1LbP,D1.7,D0.7
                  XORGE     A1LbP,D1.7,A0FrP
                  XORGE     TTMARK,D1Re0,A1LbP
                  XORCS     TTMARK,D1.7,D1Re0
                  XORVS     TTMARK,D1.7,A0.7
                  XORVS     TTREC,D1Re0,A1.7
                  XORNV     TTREC,D1Re0,A0FrP
                  XORNV     TXMASKI,D1.7,A1.7
                  XORVS     TTREC,D1.7,RD
                  XORVS     GTEXEC,D1Re0,A1.7
                  XORCC     GTEXEC,D1.7,D1.7
                  XORCS     D1.7,D1Re0,D1Re0
                  XORGT     TXGPIOO,D1Re0,A1LbP
                  XORGT     A1.7,D1Re0,A1.7
                  XORGT     D0.7,D1Re0,D0.7
                  XORNV     A1.7,D1Re0,RD
                  XORVS     D1.7,D1Re0,A0.7
                  XORNE     TXGPIOO,D1.7,D1Re0
                  XORCS     D1.7,D1.7,D1.7
                  XORGE     D0.7,D1.7,D0Re0
                  XORGE     A1.7,D1.7,D0.7
                  XORVS     D1.7,D1.7,A0FrP
                  XORVS     TXGPIOO,D1.7,A0.7
                  XORVS     RA,D1Re0,A0FrP
                  XORGT     RA,D1.7,RD
                  XORGE     RAM8X32,D1Re0,D0.7
                  XORGE     RAM8X32,D1.7,D0Re0
                  XORNV     RAM8X,D1Re0,A1.7
                  XORNE     RAM8X,D1.7,D1.7
                  XORGT     RABZ,D1Re0,A1LbP
                  XORMI     RABZ,D1.7,D1Re0
                  XORVS     RABZ,D1.7,A0.7
                  XORGT     RAWX,D1Re0,A0FrP
                  XORVS     RAWX,D1.7,RD
                  XORGE     TXIDLECYC,D1Re0,A1.7
                  XORGT     RAMX,D1Re0,RD
                  XORVS     RAMX,D1.7,A1LbP
                  XORNV     RAMX,D1.7,D0.7
                  XOR       TXENABLE,D0Re0,#0x7f
                  XOR       PC,D0Re0,#0x80
                  XOR       TTEXEC,D0Re0,#0xff
                  XORCC     D0Re0,D0.7,#0x80
                  XOR       TXENABLE,D0.7,#0xff
                  XOR       PCX,D0Re0,#0x7f
                  XOR       PCX,D0Re0,#0xff
                  XOR       PCX,D0.7,#0x80
                  XOR       TTMARK,D0Re0,#0xff
                  XOR       TXMASKI,D0Re0,#0xff
                  XOR       GTEXEC,D0Re0,#0x7f
                  XOR       D1.7,D0Re0,#0x7f
                  XOR       A1.7,D0Re0,#0x80
                  XORGE     D0.7,D0.7,#0x7f
                  XOR       A1.7,D0.7,#0x80
                  XOR       RA,D0Re0,#0x80
                  XOR       RAM8X32,D0.7,#0x7f
                  XOR       RAM8X,D0.7,#0xff
                  XOR       RAWX,D0Re0,#0x80
                  XOR       RAMX,D0Re0,#0x80
                  XOR       RAMX,D0.7,#0xff
                  XOR       TXENABLE,D1Re0,#0x80
                  XOR       PC,D1Re0,#0xff
                  XOR       TXSTAT,D1.7,#0x7f
                  XOR       TTEXEC,D1.7,#0x80
                  XOR       A0FrP,D1Re0,#0x7f
                  XOR       A0FrP,D1Re0,#0xff
                  XOR       A0FrP,D1.7,#0x80
                  XOR       TTMARK,D1Re0,#0x7f
                  XOR       TXMASKI,D1Re0,#0x80
                  XOR       TXMASKI,D1.7,#0xff
                  XORVS     D1.7,D1Re0,#0x7f
                  XOR       D1.7,D1Re0,#0x80
                  XOR       A1.7,D1Re0,#0xff
                  XOR       D0.7,D1.7,#0x80
                  XOR       TXGPIOO,D1.7,#0xff
                  XOR       RAM8X32,D1Re0,#0x80
                  XOR       RAM8X,D1.7,#0x7f
                  XOR       RABZ,D1.7,#0xff
                  XOR       RAMX,D1Re0,#0x7f
                  XOR       RAMX,D1.7,#0x80
                  XORS      D0Re0,D0Re0,D1.7
                  XORS      D0Re0,D0.7,D1Re0
                  XORS      D0.7,D0Re0,A1.7
                  XORS      D0.7,D0.7,D0.7
                  XORS      D1Re0,D1Re0,A1LbP
                  XORS      D1Re0,D1.7,D1Re0
                  XORS      D1Re0,D1.7,A0.7
                  XORS      D1.7,D1Re0,A0FrP
                  XORS      D1.7,D1.7,RD
                  XORST     D0Re0,D0Re0,#0x8000
                  XORSMT    D0Re0,D0Re0,#0xffff
                  XORSMB    D0.7,D0.7,#0x8000
                  XORST     D1Re0,D1Re0,#0x7fff
                  XORS      D1Re0,D1Re0,#0xffff
                  XORSMT    D1.7,D1.7,#0x7fff
                  XORS      D1.7,D1.7,#-0x1
                  XORSMI    TTEXEC,D0Re0,D0Re0
                  XORSVS    TXENABLE,D0Re0,A1.7
                  XORSNV    TXSTAT,D0Re0,A1.7
                  XORSVS    TTEXEC,D0Re0,D1Re0
                  XORSGE    D0Re0,D0Re0,RD
                  XORSVS    PC,D0Re0,A0FrP
                  XORSVS    TTEXEC,D0Re0,A0.7
                  XORSVS    D0Re0,D0.7,A1LbP
                  XORSGT    D0Re0,D0.7,A1.7
                  XORSGE    TTEXEC,D0.7,A1.7
                  XORSNV    D0Re0,D0.7,D1.7
                  XORSGE    PC,D0.7,RD
                  XORSNV    TTEXEC,D0.7,A0FrP
                  XORSNE    A1LbP,D0Re0,D0Re0
                  XORSVS    A0FrP,D0Re0,A1.7
                  XORSGE    A1LbP,D0Re0,D1Re0
                  XORSGT    A1LbP,D0Re0,RD
                  XORSNV    A1LbP,D0Re0,A0.7
                  XORSGT    A1LbP,D0.7,A1LbP
                  XORSNV    PCX,D0.7,A1.7
                  XORSVS    A1LbP,D0.7,D1.7
                  XORSGE    A1LbP,D0.7,A0FrP
                  XORSGE    TTMARK,D0Re0,A1LbP
                  XORSCS    TTMARK,D0.7,D0Re0
                  XORSVS    TTMARK,D0.7,A0.7
                  XORSVS    TTREC,D0Re0,A1.7
                  XORSNV    TTREC,D0Re0,A0FrP
                  XORSNV    TXMASKI,D0.7,A1.7
                  XORSVS    TTREC,D0.7,RD
                  XORSVS    GTEXEC,D0Re0,A1.7
                  XORSCC    GTEXEC,D0.7,D0.7
                  XORSCS    D1.7,D0Re0,D0Re0
                  XORSGT    TXGPIOO,D0Re0,A1LbP
                  XORSGT    A1.7,D0Re0,A1.7
                  XORSGT    D0.7,D0Re0,D1.7
                  XORSNV    A1.7,D0Re0,RD
                  XORSVS    D1.7,D0Re0,A0.7
                  XORSNE    TXGPIOO,D0.7,D0Re0
                  XORSCS    D1.7,D0.7,D0.7
                  XORSGE    D0.7,D0.7,D1Re0
                  XORSGE    A1.7,D0.7,D1.7
                  XORSVS    D1.7,D0.7,A0FrP
                  XORSVS    TXGPIOO,D0.7,A0.7
                  XORSVS    RA,D0Re0,A0FrP
                  XORSGT    RA,D0.7,RD
                  XORSGE    RAM8X32,D0Re0,D1.7
                  XORSGE    RAM8X32,D0.7,D1Re0
                  XORSNV    RAM8X,D0Re0,A1.7
                  XORSNE    RAM8X,D0.7,D0.7
                  XORSGT    RABZ,D0Re0,A1LbP
                  XORSMI    RABZ,D0.7,D0Re0
                  XORSVS    RABZ,D0.7,A0.7
                  XORSGT    RAWX,D0Re0,A0FrP
                  XORSVS    RAWX,D0.7,RD
                  XORSGE    TXIDLECYC,D0Re0,A1.7
                  XORSGT    RAMX,D0Re0,RD
                  XORSVS    RAMX,D0.7,A1LbP
                  XORSNV    RAMX,D0.7,D1.7
                  XORSMI    D0Re0,D1Re0,D1Re0
                  XORSGE    PC,D1Re0,A1LbP
                  XORSGE    D1Re0,D1Re0,A1.7
                  XORSVS    D0Re0,D1Re0,D0Re0
                  XORSVS    PC,D1Re0,D0.7
                  XORSVS    TTEXEC,D1Re0,RD
                  XORSGE    D0Re0,D1Re0,A0.7
                  XORSEQ    PC,D1.7,D1Re0
                  XORSVS    TTEXEC,D1.7,A1LbP
                  XORSNV    PC,D1.7,A1.7
                  XORSVS    PC,D1.7,D0Re0
                  XORSGT    TTEXEC,D1.7,D0.7
                  XORSNV    D0Re0,D1.7,A0FrP
                  XORSGT    PC,D1.7,A0.7
                  XORSGT    A1LbP,D1Re0,A1LbP
                  XORSNV    PCX,D1Re0,A1.7
                  XORSVS    A1LbP,D1Re0,D0.7
                  XORSGE    A1LbP,D1Re0,A0FrP
                  XORSNE    A1LbP,D1.7,D1Re0
                  XORSVS    A0FrP,D1.7,A1.7
                  XORSGE    A1LbP,D1.7,D0Re0
                  XORSGT    A1LbP,D1.7,RD
                  XORSNV    A1LbP,D1.7,A0.7
                  XORSNV    TTMARK,D1Re0,D0.7
                  XORSVS    TTMARK,D1.7,D0Re0
                  XORSGE    TTREC,D1Re0,A1LbP
                  XORSNV    TTREC,D1Re0,D0.7
                  XORSCS    TTREC,D1.7,D1Re0
                  XORSVS    TTREC,D1.7,D0Re0
                  XORSVS    TTREC,D1.7,A0.7
                  XORSNV    GTEXEC,D1Re0,A0FrP
                  XORSVS    GTEXEC,D1.7,RD
                  XORSGE    D0.7,D1Re0,A1LbP
                  XORSVS    D1.7,D1Re0,A1.7
                  XORSNV    D1.7,D1Re0,D0Re0
                  XORSNV    TXGPIOO,D1Re0,D0.7
                  XORSVS    A0.7,D1Re0,A0FrP
                  XORSEQ    D0.7,D1.7,D1Re0
                  XORSVS    A1.7,D1.7,A1LbP
                  XORSEQ    A1.7,D1.7,D1.7
                  XORSGT    TXGPIOO,D1.7,D0Re0
                  XORSGE    A0.7,D1.7,RD
                  XORSVS    D0.7,D1.7,A0.7
                  XORSGT    RA,D1Re0,A1.7
                  XORSMI    RA,D1.7,D1.7
                  XORSGT    RAM8X32,D1Re0,A1LbP
                  XORSMI    RAM8X32,D1.7,D1Re0
                  XORSVS    RAM8X32,D1.7,A0.7
                  XORSGT    RAM8X,D1Re0,A0FrP
                  XORSVS    RAM8X,D1.7,RD
                  XORSGE    RABZ,D1Re0,D0.7
                  XORSGE    RABZ,D1.7,D0Re0
                  XORSNV    RAWX,D1Re0,A1.7
                  XORSNE    RAWX,D1.7,D1.7
                  XORSCS    RAMX,D1Re0,D1Re0
                  XORSVS    RAMX,D1Re0,D0Re0
                  XORSGT    RAMX,D1Re0,A0.7
                  XORSVS    RAMX,D1.7,A1.7
                  XORSVS    RAMX,D1.7,A0FrP
                  XORS      TTEXEC,D0Re0,#0x7f
                  XORS      TXENABLE,D0Re0,#0xff
                  XORS      D1Re0,D0.7,#0x7f
                  XORS      PC,D0.7,#0x80
                  XORS      TXSTAT,D0.7,#0xff
                  XORS      PCX,D0Re0,#0x80
                  XORS      PCX,D0.7,#0x7f
                  XORS      PCX,D0.7,#0xff
                  XORS      TXMASKI,D0Re0,#0x7f
                  XORS      TXMASKI,D0.7,#0x80
                  XORS      GTEXEC,D0.7,#0x80
                  XORSCS    D0.7,D0Re0,#0x80
                  XORS      D1.7,D0Re0,#0xff
                  XORS      TXGPIOO,D0.7,#0x7f
                  XORS      A0.7,D0.7,#0xff
                  XORS      RA,D0.7,#0xff
                  XORS      RAM8X,D0Re0,#0x80
                  XORS      RABZ,D0.7,#0x7f
                  XORS      RAWX,D0.7,#0xff
                  XORS      RAMX,D0.7,#0x7f
                  XORS      PC,D1Re0,#0x7f
                  XORS      TTEXEC,D1Re0,#0x80
                  XORS      TXENABLE,D1.7,#0x7f
                  XORS      D0Re0,D1.7,#0x80
                  XORS      D1Re0,D1.7,#0xff
                  XORS      A0FrP,D1Re0,#0x80
                  XORS      A0FrP,D1.7,#0x7f
                  XORS      A0FrP,D1.7,#0xff
                  XORS      TTMARK,D1.7,#0x80
                  XORS      TXMASKI,D1.7,#0x7f
                  XORS      GTEXEC,D1Re0,#0xff
                  XORS      A1.7,D1Re0,#0x7f
                  XORSNV    D1.7,D1Re0,#0xff
                  XORS      A0.7,D1.7,#0x7f
                  XORSGT    D1.7,D1.7,#0xff
                  XORS      RA,D1.7,#0x7f
                  XORS      RAM8X32,D1.7,#0xff
                  XORS      RABZ,D1Re0,#0x80
                  XORS      RAWX,D1.7,#0x7f
                  XORS      RAMX,D1Re0,#0xff
                  LSR       D0Re0,D0Re0,D0Re0
                  LSL       D0Re0,D0.7,D0.7
                  ASR       D0.7,D0Re0,D0.7
                  LSR       D1Re0,D1Re0,D1Re0
                  LSL       D1Re0,D1.7,D1.7
                  ASR       D1.7,D1Re0,D1.7
                  LSR       D0Re0,D0Re0,#0xf
                  LSL       D0Re0,D0.7,#0xf
                  ASR       D0Re0,D0.7,#0x1f
                  LSR       D0.7,D0Re0,#0x1f
                  LSL       D0.7,D0.7,#0x1f
                  ASR       D1Re0,D1Re0,#0x10
                  LSR       D1Re0,D1.7,#0x10
                  LSL       D1.7,D1Re0,#0x10
                  ASR       D1.7,D1.7,#0xf
                  LSLVC     D0Re0,D0Re0,D0Re0
                  LSL       TTEXEC,D0Re0,D0Re0
                  ASR       TXENABLE,D0Re0,D0Re0
                  LSL       PC,D0Re0,D0.7
                  LSR       D1Re0,D0Re0,D0.7
                  ASR       TXSTAT,D0Re0,D0.7
                  LSRNV     D0Re0,D0.7,D0Re0
                  ASRLE     D0Re0,D0.7,D0Re0
                  LSLLT     D0Re0,D0.7,D0.7
                  LSRLT     D0Re0,D0.7,D0.7
                  ASRNV     D0Re0,D0.7,D0.7
                  LSL       PCX,D0Re0,D0Re0
                  ASR       PCX,D0Re0,D0Re0
                  LSR       PCX,D0Re0,D0.7
                  LSL       PCX,D0.7,D0Re0
                  ASR       PCX,D0.7,D0Re0
                  LSR       PCX,D0.7,D0.7
                  ASR       TTMARK,D0Re0,D0Re0
                  LSR       TTMARK,D0.7,D0.7
                  LSL       TXMASKI,D0Re0,D0.7
                  LSR       TXMASKI,D0.7,D0Re0
                  ASR       TXMASKI,D0.7,D0.7
                  LSL       GTEXEC,D0.7,D0Re0
                  LSL       A0.7,D0Re0,D0Re0
                  ASRLT     D0.7,D0Re0,D0Re0
                  LSLLE     D0.7,D0Re0,D0.7
                  LSR       A0.7,D0Re0,D0.7
                  LSLHI     D0.7,D0.7,D0Re0
                  LSRNV     D0.7,D0.7,D0Re0
                  ASR       A1.7,D0.7,D0Re0
                  LSR       D1.7,D0.7,D0.7
                  ASR       D1.7,D0.7,D0.7
                  LSR       RA,D0Re0,D0.7
                  LSL       RAM8X32,D0Re0,D0Re0
                  ASR       RAM8X32,D0.7,D0Re0
                  LSR       RAM8X,D0Re0,D0.7
                  LSL       RABZ,D0Re0,D0Re0
                  ASR       RABZ,D0.7,D0Re0
                  LSR       RAWX,D0Re0,D0.7
                  LSL       TXIDLECYC,D0Re0,D0Re0
                  LSR       TXIDLECYC,D0Re0,D0.7
                  ASR       TXIDLECYC,D0.7,D0Re0
                  LSLNV     D1Re0,D1Re0,D1Re0
                  LSR       D0Re0,D1Re0,D1Re0
                  ASR       D0Re0,D1Re0,D1Re0
                  LSL       D0Re0,D1Re0,D1.7
                  LSR       TXSTAT,D1Re0,D1.7
                  LSLHI     D1Re0,D1.7,D1Re0
                  LSRLE     D1Re0,D1.7,D1Re0
                  ASR       TXENABLE,D1.7,D1Re0
                  LSL       PC,D1.7,D1.7
                  LSR       TTEXEC,D1.7,D1.7
                  ASR       TXSTAT,D1.7,D1.7
                  LSR       PCX,D1Re0,D1Re0
                  LSL       PCX,D1Re0,D1.7
                  ASR       PCX,D1Re0,D1.7
                  LSR       PCX,D1.7,D1Re0
                  LSL       PCX,D1.7,D1.7
                  ASR       PCX,D1.7,D1.7
                  LSL       TTMARK,D1.7,D1Re0
                  LSR       TXMASKI,D1Re0,D1Re0
                  ASR       TXMASKI,D1Re0,D1.7
                  LSL       TXMASKI,D1.7,D1.7
                  ASR       GTEXEC,D1Re0,D1Re0
                  LSR       GTEXEC,D1.7,D1.7
                  LSL       A1.7,D1Re0,D1Re0
                  LSR       TXGPIOO,D1Re0,D1Re0
                  LSL       A0.7,D1Re0,D1.7
                  ASRLT     D1.7,D1Re0,D1.7
                  LSLLE     D1.7,D1.7,D1Re0
                  LSR       A0.7,D1.7,D1Re0
                  LSLHI     D1.7,D1.7,D1.7
                  LSRNV     D1.7,D1.7,D1.7
                  ASR       A1.7,D1.7,D1.7
                  LSL       RA,D1.7,D1Re0
                  ASR       RAM8X32,D1Re0,D1Re0
                  LSR       RAM8X32,D1.7,D1.7
                  LSL       RAM8X,D1.7,D1Re0
                  ASR       RABZ,D1Re0,D1Re0
                  LSR       RABZ,D1.7,D1.7
                  LSL       RAWX,D1.7,D1Re0
                  LSR       TXIDLECYC,D1Re0,D1Re0
                  ASR       TXIDLECYC,D1Re0,D1.7
                  LSL       TXIDLECYC,D1.7,D1.7
                  LSLLE     D0Re0,D0Re0,#0xf
                  LSRLE     D0Re0,D0Re0,#0xf
                  ASR       TXENABLE,D0Re0,#0xf
                  LSL       PC,D0Re0,#0x10
                  LSR       D1Re0,D0Re0,#0x10
                  ASR       TXSTAT,D0Re0,#0x10
                  LSRHI     D0Re0,D0Re0,#0x1f
                  ASRNV     D0Re0,D0Re0,#0x1f
                  LSL       D1Re0,D0.7,#0xf
                  LSR       TXENABLE,D0.7,#0xf
                  ASR       PC,D0.7,#0xf
                  LSL       TTEXEC,D0.7,#0x10
                  ASRLE     D0Re0,D0.7,#0x10
                  LSL       TXENABLE,D0.7,#0x1f
                  LSR       PC,D0.7,#0x1f
                  ASR       D1Re0,D0.7,#0x1f
                  LSR       A0FrP,D0Re0,#0xf
                  LSL       A0FrP,D0Re0,#0x10
                  ASR       A0FrP,D0Re0,#0x10
                  LSR       A0FrP,D0Re0,#0x1f
                  LSL       A0FrP,D0.7,#0xf
                  ASR       A0FrP,D0.7,#0xf
                  LSR       A0FrP,D0.7,#0x10
                  LSL       A0FrP,D0.7,#0x1f
                  ASR       A0FrP,D0.7,#0x1f
                  LSR       TTMARK,D0Re0,#0x10
                  LSL       TTMARK,D0.7,#0x10
                  LSR       TXMASKI,D0Re0,#0xf
                  ASR       TXMASKI,D0Re0,#0x10
                  LSL       TXMASKI,D0.7,#0xf
                  LSR       TXMASKI,D0.7,#0x10
                  ASR       TXMASKI,D0.7,#0x1f
                  LSL       GTEXEC,D0Re0,#0x1f
                  ASR       GTEXEC,D0.7,#0x10
                  LSL       TXGPIOO,D0Re0,#0xf
                  ASRNV     D0.7,D0Re0,#0xf
                  LSL       A1.7,D0Re0,#0x10
                  ASRLT     D0.7,D0Re0,#0x10
                  LSLLE     D0.7,D0Re0,#0x1f
                  LSR       A0.7,D0Re0,#0x1f
                  LSLNV     D0.7,D0.7,#0xf
                  LSR       A1.7,D0.7,#0xf
                  ASR       A1.7,D0.7,#0xf
                  LSL       TXGPIOO,D0.7,#0x10
                  ASR       A0.7,D0.7,#0x10
                  LSL       A0.7,D0.7,#0x1f
                  LSR       A1.7,D0.7,#0x1f
                  LSR       RA,D0Re0,#0xf
                  LSL       RA,D0.7,#0xf
                  ASR       RA,D0.7,#0x1f
                  LSR       RAM8X32,D0Re0,#0x1f
                  LSL       RAM8X32,D0.7,#0x1f
                  ASR       RAM8X,D0Re0,#0x10
                  LSR       RAM8X,D0.7,#0x10
                  LSL       RABZ,D0Re0,#0x10
                  ASR       RABZ,D0.7,#0xf
                  LSR       RAWX,D0Re0,#0xf
                  LSL       RAWX,D0.7,#0xf
                  ASR       RAWX,D0.7,#0x1f
                  LSL       RAMX,D0Re0,#0x10
                  LSR       RAMX,D0Re0,#0x1f
                  ASR       RAMX,D0.7,#0xf
                  LSL       RAMX,D0.7,#0x1f
                  LSL       PC,D1Re0,#0xf
                  LSR       TTEXEC,D1Re0,#0xf
                  ASR       TTEXEC,D1Re0,#0xf
                  LSR       TXENABLE,D1Re0,#0x10
                  ASRNV     D1Re0,D1Re0,#0x10
                  LSLNV     D1Re0,D1Re0,#0x1f
                  LSR       D0Re0,D1Re0,#0x1f
                  ASR       TXSTAT,D1Re0,#0x1f
                  LSRNV     D1Re0,D1.7,#0xf
                  ASRLE     D1Re0,D1.7,#0xf
                  LSLLE     D1Re0,D1.7,#0x10
                  LSR       TXENABLE,D1.7,#0x10
                  ASR       PC,D1.7,#0x10
                  LSL       D0Re0,D1.7,#0x1f
                  LSR       D0Re0,D1.7,#0x1f
                  ASR       TXSTAT,D1.7,#0x1f
                  LSR       PCX,D1Re0,#0xf
                  LSL       PCX,D1Re0,#0x10
                  ASR       PCX,D1Re0,#0x10
                  LSR       PCX,D1Re0,#0x1f
                  LSL       PCX,D1.7,#0xf
                  ASR       PCX,D1.7,#0xf
                  LSR       PCX,D1.7,#0x10
                  LSL       PCX,D1.7,#0x1f
                  ASR       PCX,D1.7,#0x1f
                  LSL       TTMARK,D1Re0,#0x1f
                  ASR       TTMARK,D1.7,#0x10
                  ASR       TXMASKI,D1Re0,#0xf
                  LSL       TXMASKI,D1Re0,#0x1f
                  LSR       TXMASKI,D1.7,#0xf
                  ASR       TXMASKI,D1.7,#0x10
                  LSL       GTEXEC,D1Re0,#0xf
                  ASR       GTEXEC,D1Re0,#0x1f
                  LSR       GTEXEC,D1.7,#0x1f
                  LSL       TXGPIOO,D1Re0,#0xf
                  ASR       A0.7,D1Re0,#0xf
                  LSL       A0.7,D1Re0,#0x10
                  LSR       A1.7,D1Re0,#0x10
                  LSL       D0.7,D1Re0,#0x1f
                  LSR       D0.7,D1Re0,#0x1f
                  ASR       TXGPIOO,D1Re0,#0x1f
                  LSL       TXGPIOO,D1.7,#0xf
                  ASRNV     D1.7,D1.7,#0xf
                  LSL       A1.7,D1.7,#0x10
                  LSR       A1.7,D1.7,#0x10
                  LSL       D0.7,D1.7,#0x1f
                  LSR       TXGPIOO,D1.7,#0x1f
                  LSL       RA,D1Re0,#0xf
                  ASR       RA,D1Re0,#0x1f
                  LSR       RA,D1.7,#0x1f
                  LSL       RAM8X32,D1Re0,#0x1f
                  ASR       RAM8X32,D1.7,#0x10
                  LSR       RAM8X,D1Re0,#0x10
                  LSL       RAM8X,D1.7,#0x10
                  ASR       RABZ,D1Re0,#0xf
                  LSR       RABZ,D1.7,#0xf
                  LSL       RAWX,D1Re0,#0xf
                  ASR       RAWX,D1Re0,#0x1f
                  LSR       RAWX,D1.7,#0x1f
                  LSL       TXIDLECYC,D1Re0,#0x10
                  LSR       TXIDLECYC,D1Re0,#0x1f
                  ASR       TXIDLECYC,D1.7,#0xf
                  LSL       TXIDLECYC,D1.7,#0x1f
                  ASRS      D0Re0,D0Re0,D0Re0
                  LSRS      D0Re0,D0.7,D0.7
                  LSLS      D0.7,D0.7,D0Re0
                  ASRS      D1Re0,D1Re0,D1Re0
                  LSRS      D1Re0,D1.7,D1.7
                  LSLS      D1.7,D1.7,D1Re0
                  ASRS      D0Re0,D0Re0,#0xf
                  LSRS      D0Re0,D0.7,#0xf
                  LSLS      D0.7,D0Re0,#0xf
                  ASRS      D0.7,D0Re0,#0x1f
                  LSRS      D0.7,D0.7,#0x1f
                  LSLS      D1Re0,D1Re0,#0x1f
                  ASRS      D1Re0,D1.7,#0x10
                  LSRS      D1.7,D1Re0,#0x10
                  LSLS      D1.7,D1.7,#0x10
                  LSLSNV    D0Re0,D0Re0,D0Re0
                  LSRS      D1Re0,D0Re0,D0Re0
                  ASRS      TXSTAT,D0Re0,D0Re0
                  LSRSCS    D0Re0,D0Re0,D0.7
                  LSRS      TTEXEC,D0Re0,D0.7
                  LSLS      TXENABLE,D0.7,D0Re0
                  LSRS      PC,D0.7,D0Re0
                  ASRS      D1Re0,D0.7,D0Re0
                  LSLS      TXENABLE,D0.7,D0.7
                  LSRS      TXENABLE,D0.7,D0.7
                  ASRS      PC,D0.7,D0.7
                  LSRS      A1LbP,D0Re0,D0Re0
                  LSLS      A1LbP,D0Re0,D0.7
                  ASRS      A1LbP,D0Re0,D0.7
                  LSRS      A1LbP,D0.7,D0Re0
                  LSLS      A1LbP,D0.7,D0.7
                  ASRS      A1LbP,D0.7,D0.7
                  ASRS      TTMARK,D0Re0,D0.7
                  LSLS      TTREC,D0Re0,D0Re0
                  LSRS      TTREC,D0Re0,D0.7
                  ASRS      TTREC,D0.7,D0Re0
                  LSRS      GTEXEC,D0Re0,D0Re0
                  LSLS      GTEXEC,D0.7,D0.7
                  LSRSHI    D0.7,D0Re0,D0Re0
                  ASRS      D1.7,D0Re0,D0Re0
                  LSLS      A0.7,D0Re0,D0.7
                  ASRSHI    D0.7,D0Re0,D0.7
                  LSLS      A1.7,D0.7,D0Re0
                  LSRS      A1.7,D0.7,D0Re0
                  LSLS      D1.7,D0.7,D0.7
                  LSRS      TXGPIOO,D0.7,D0.7
                  ASRS      TXGPIOO,D0.7,D0.7
                  LSRS      RA,D0.7,D0Re0
                  LSLS      RAM8X32,D0Re0,D0.7
                  ASRS      RAM8X32,D0.7,D0.7
                  LSRS      RAM8X,D0.7,D0Re0
                  LSLS      RABZ,D0Re0,D0.7
                  ASRS      RABZ,D0.7,D0.7
                  LSRS      RAWX,D0.7,D0Re0
                  LSRS      RAMX,D0Re0,D0Re0
                  ASRS      RAMX,D0Re0,D0.7
                  LSLS      RAMX,D0.7,D0.7
                  LSLS      PC,D1Re0,D1Re0
                  LSRS      TTEXEC,D1Re0,D1Re0
                  ASRS      TTEXEC,D1Re0,D1Re0
                  LSLS      TTEXEC,D1Re0,D1.7
                  ASRS      TXENABLE,D1Re0,D1.7
                  LSLS      PC,D1.7,D1Re0
                  LSRS      D0Re0,D1.7,D1Re0
                  ASRS      TXSTAT,D1.7,D1Re0
                  LSRSNV    D1Re0,D1.7,D1.7
                  ASRSLE    D1Re0,D1.7,D1.7
                  LSLS      A1LbP,D1Re0,D1Re0
                  ASRS      A1LbP,D1Re0,D1Re0
                  LSRS      A1LbP,D1Re0,D1.7
                  LSLS      A1LbP,D1.7,D1Re0
                  ASRS      A1LbP,D1.7,D1Re0
                  LSRS      A1LbP,D1.7,D1.7
                  LSRS      TTMARK,D1Re0,D1Re0
                  LSLS      TTMARK,D1.7,D1.7
                  ASRS      TTREC,D1Re0,D1Re0
                  LSLS      TTREC,D1.7,D1Re0
                  LSRS      TTREC,D1.7,D1.7
                  ASRS      GTEXEC,D1Re0,D1.7
                  LSLSLT    D1.7,D1Re0,D1Re0
                  LSRSLE    D1.7,D1Re0,D1Re0
                  ASRS      A0.7,D1Re0,D1Re0
                  LSRSHI    D1.7,D1Re0,D1.7
                  ASRS      D0.7,D1Re0,D1.7
                  LSLS      A0.7,D1.7,D1Re0
                  ASRSHI    D1.7,D1.7,D1Re0
                  LSLS      A1.7,D1.7,D1.7
                  LSRS      A1.7,D1.7,D1.7
                  LSRS      RA,D1Re0,D1Re0
                  LSLS      RA,D1.7,D1.7
                  ASRS      RAM8X32,D1Re0,D1.7
                  LSRS      RAM8X,D1Re0,D1Re0
                  LSLS      RAM8X,D1.7,D1.7
                  ASRS      RABZ,D1Re0,D1.7
                  LSRS      RAWX,D1Re0,D1Re0
                  LSLS      RAWX,D1.7,D1.7
                  ASRS      RAMX,D1Re0,D1Re0
                  LSLS      RAMX,D1.7,D1Re0
                  LSRS      RAMX,D1.7,D1.7
                  LSLS      D1Re0,D0Re0,#0xf
                  LSRS      D1Re0,D0Re0,#0xf
                  ASRS      TXSTAT,D0Re0,#0xf
                  LSRSCS    D0Re0,D0Re0,#0x10
                  LSRS      TTEXEC,D0Re0,#0x10
                  LSLS      TXENABLE,D0Re0,#0x1f
                  LSRS      PC,D0Re0,#0x1f
                  ASRS      PC,D0Re0,#0x1f
                  LSLS      TTEXEC,D0.7,#0xf
                  LSRS      TXSTAT,D0.7,#0xf
                  LSLSNV    D0Re0,D0.7,#0x10
                  LSRS      D1Re0,D0.7,#0x10
                  ASRS      D1Re0,D0.7,#0x10
                  LSLS      TXSTAT,D0.7,#0x1f
                  ASRSCS    D0Re0,D0.7,#0x1f
                  ASRS      TTEXEC,D0.7,#0x1f
                  LSRS      TTCTRL,D0Re0,#0xf
                  LSLS      TTCTRL,D0Re0,#0x10
                  ASRS      TTCTRL,D0Re0,#0x10
                  LSRS      TTCTRL,D0Re0,#0x1f
                  LSLS      TTCTRL,D0.7,#0xf
                  ASRS      TTCTRL,D0.7,#0xf
                  LSRS      TTCTRL,D0.7,#0x10
                  LSLS      TTCTRL,D0.7,#0x1f
                  ASRS      TTCTRL,D0.7,#0x1f
                  LSRS      TTMARK,D0Re0,#0x1f
                  LSLS      TTMARK,D0.7,#0x1f
                  ASRS      TTREC,D0Re0,#0xf
                  LSLS      TTREC,D0Re0,#0x1f
                  LSRS      TTREC,D0.7,#0xf
                  ASRS      TTREC,D0.7,#0x10
                  LSRS      GTEXEC,D0Re0,#0xf
                  LSLS      GTEXEC,D0.7,#0xf
                  ASRS      GTEXEC,D0.7,#0x1f
                  LSRS      A0.7,D0Re0,#0xf
                  ASRS      A1.7,D0Re0,#0xf
                  LSRS      D1.7,D0Re0,#0x10
                  ASRS      D1.7,D0Re0,#0x10
                  LSLS      A0.7,D0Re0,#0x1f
                  ASRSHI    D0.7,D0Re0,#0x1f
                  LSLS      A1.7,D0.7,#0xf
                  ASRSLT    D0.7,D0.7,#0xf
                  LSLSLE    D0.7,D0.7,#0x10
                  LSRS      A0.7,D0.7,#0x10
                  LSLSGE    D0.7,D0.7,#0x1f
                  LSRSLT    D0.7,D0.7,#0x1f
                  ASRS      D1.7,D0.7,#0x1f
                  LSRS      RA,D0Re0,#0x10
                  LSLS      RA,D0.7,#0x10
                  ASRS      RAM8X32,D0Re0,#0xf
                  LSRS      RAM8X32,D0.7,#0xf
                  LSLS      RAM8X,D0Re0,#0xf
                  ASRS      RAM8X,D0Re0,#0x1f
                  LSRS      RAM8X,D0.7,#0x1f
                  LSLS      RABZ,D0Re0,#0x1f
                  ASRS      RABZ,D0.7,#0x10
                  LSRS      RAWX,D0Re0,#0x10
                  LSLS      RAWX,D0.7,#0x10
                  LSRS      TXIDLECYC,D0Re0,#0xf
                  ASRS      TXIDLECYC,D0Re0,#0x10
                  LSLS      TXIDLECYC,D0.7,#0xf
                  LSRS      TXIDLECYC,D0.7,#0x10
                  ASRS      TXIDLECYC,D0.7,#0x1f
                  LSRSHI    D1Re0,D1Re0,#0xf
                  ASRSNV    D1Re0,D1Re0,#0xf
                  LSLS      D0Re0,D1Re0,#0x10
                  LSRS      TXSTAT,D1Re0,#0x10
                  ASRS      PC,D1Re0,#0x10
                  LSLS      PC,D1Re0,#0x1f
                  LSRS      TTEXEC,D1Re0,#0x1f
                  LSLS      TXENABLE,D1.7,#0xf
                  LSRS      PC,D1.7,#0xf
                  ASRS      D0Re0,D1.7,#0xf
                  LSLS      D0Re0,D1.7,#0x10
                  LSRS      TXSTAT,D1.7,#0x10
                  LSLSGE    D1Re0,D1.7,#0x1f
                  LSLS      TTEXEC,D1.7,#0x1f
                  LSRS      TTEXEC,D1.7,#0x1f
                  LSLS      A1LbP,D1Re0,#0xf
                  ASRS      A1LbP,D1Re0,#0xf
                  LSRS      A1LbP,D1Re0,#0x10
                  LSLS      A1LbP,D1Re0,#0x1f
                  ASRS      A1LbP,D1Re0,#0x1f
                  LSRS      A1LbP,D1.7,#0xf
                  LSLS      A1LbP,D1.7,#0x10
                  ASRS      A1LbP,D1.7,#0x10
                  LSRS      A1LbP,D1.7,#0x1f
                  LSRS      TTMARK,D1Re0,#0xf
                  LSLS      TTMARK,D1.7,#0xf
                  ASRS      TTMARK,D1.7,#0x1f
                  LSLS      TTREC,D1Re0,#0x10
                  LSRS      TTREC,D1Re0,#0x1f
                  ASRS      TTREC,D1.7,#0xf
                  LSLS      TTREC,D1.7,#0x1f
                  LSLS      GTEXEC,D1Re0,#0x10
                  ASRS      GTEXEC,D1.7,#0xf
                  LSLSLE    D1.7,D1Re0,#0xf
                  LSRS      A0.7,D1Re0,#0xf
                  LSLSCS    D1.7,D1Re0,#0x10
                  LSRSLT    D1.7,D1Re0,#0x10
                  ASRS      D0.7,D1Re0,#0x10
                  LSLS      TXGPIOO,D1Re0,#0x1f
                  LSRS      TXGPIOO,D1Re0,#0x1f
                  LSLSLE    D1.7,D1.7,#0xf
                  LSRSNV    D1.7,D1.7,#0xf
                  ASRS      A1.7,D1.7,#0xf
                  LSRSLT    D1.7,D1.7,#0x10
                  ASRS      D0.7,D1.7,#0x10
                  LSLS      TXGPIOO,D1.7,#0x1f
                  ASRSNV    D1.7,D1.7,#0x1f
                  LSLS      RA,D1Re0,#0x10
                  ASRS      RA,D1.7,#0xf
                  LSRS      RAM8X32,D1Re0,#0xf
                  LSLS      RAM8X32,D1.7,#0xf
                  ASRS      RAM8X32,D1.7,#0x1f
                  LSRS      RAM8X,D1Re0,#0x1f
                  LSLS      RAM8X,D1.7,#0x1f
                  ASRS      RABZ,D1Re0,#0x10
                  LSRS      RABZ,D1.7,#0x10
                  LSLS      RAWX,D1Re0,#0x10
                  ASRS      RAWX,D1.7,#0xf
                  LSLS      RAMX,D1Re0,#0xf
                  LSRS      RAMX,D1Re0,#0x10
                  ASRS      RAMX,D1Re0,#0x1f
                  LSLS      RAMX,D1.7,#0x10
                  LSRS      RAMX,D1.7,#0x1f
                  MULW      D0Re0,D0Re0,A1.7
                  MULD      D0Re0,D0Re0,RD
                  MULD      D0Re0,D0.7,A1LbP
                  MULD      D0Re0,D0.7,D1.7
                  MULD      D0.7,D0Re0,D0Re0
                  MULD      D0.7,D0Re0,D1Re0
                  MULD      D0.7,D0Re0,A0.7
                  MULD      D0.7,D0.7,A1.7
                  MULD      D0.7,D0.7,A0FrP
                  MULW      D1Re0,D1Re0,A1.7
                  MULD      D1Re0,D1Re0,RD
                  MULD      D1Re0,D1.7,A1LbP
                  MULD      D1Re0,D1.7,D0.7
                  MULD      D1.7,D1Re0,D1Re0
                  MULD      D1.7,D1Re0,D0Re0
                  MULD      D1.7,D1Re0,A0.7
                  MULD      D1.7,D1.7,A1.7
                  MULD      D1.7,D1.7,A0FrP
                  MULWT     D0Re0,D0Re0,#0x8000
                  MULD      D0Re0,D0Re0,#0xffff
                  MULWT     D0.7,D0.7,#0x8000
                  MULD      D0.7,D0.7,#0xffff
                  MULWT     D1Re0,D1Re0,#0x8000
                  MULD      D1Re0,D1Re0,#0xffff
                  MULWT     D1.7,D1.7,#0x8000
                  MULD      D1.7,D1.7,#0xffff
                  MULW      D1Re0,D0Re0,A1LbP
                  MULDVS    D0Re0,D0Re0,A1.7
                  MULW      D1Re0,D0Re0,D1.7
                  MULW      D1Re0,D0Re0,A0FrP
                  MULW      D1Re0,D0.7,D0Re0
                  MULWVS    D0Re0,D0.7,A1.7
                  MULW      D1Re0,D0.7,D1Re0
                  MULW      D1Re0,D0.7,RD
                  MULW      D1Re0,D0.7,A0.7
                  MULW      A1LbP,D0Re0,A1LbP
                  MULD      A0FrP,D0Re0,A1.7
                  MULW      A1LbP,D0Re0,D1.7
                  MULW      A1LbP,D0Re0,A0FrP
                  MULW      A1LbP,D0.7,D0Re0
                  MULW      A0FrP,D0.7,A1.7
                  MULW      A1LbP,D0.7,D1Re0
                  MULW      A1LbP,D0.7,RD
                  MULW      A1LbP,D0.7,A0.7
                  MULD      D1.7,D0Re0,D0Re0
                  MULD      D1.7,D0Re0,A1LbP
                  MULW      A0.7,D0Re0,A1.7
                  MULD      A0.7,D0Re0,A1.7
                  MULD      D1.7,D0Re0,D1Re0
                  MULD      D1.7,D0Re0,D1.7
                  MULD      D1.7,D0Re0,RD
                  MULD      D1.7,D0Re0,A0FrP
                  MULD      D1.7,D0Re0,A0.7
                  MULD      D1.7,D0.7,D0Re0
                  MULD      D1.7,D0.7,A1LbP
                  MULW      A0.7,D0.7,A1.7
                  MULD      A0.7,D0.7,A1.7
                  MULD      D1.7,D0.7,D1Re0
                  MULD      D1.7,D0.7,D1.7
                  MULD      D1.7,D0.7,RD
                  MULD      D1.7,D0.7,A0FrP
                  MULD      D1.7,D0.7,A0.7
                  MULW      D0Re0,D1Re0,A1LbP
                  MULDVS    D1Re0,D1Re0,A1.7
                  MULW      D0Re0,D1Re0,D0.7
                  MULW      D0Re0,D1Re0,A0FrP
                  MULW      D0Re0,D1.7,D1Re0
                  MULWVS    D1Re0,D1.7,A1.7
                  MULW      D0Re0,D1.7,D0Re0
                  MULW      D0Re0,D1.7,RD
                  MULW      D0Re0,D1.7,A0.7
                  MULW      A1LbP,D1Re0,A1LbP
                  MULD      A0FrP,D1Re0,A1.7
                  MULW      A1LbP,D1Re0,D0.7
                  MULW      A1LbP,D1Re0,A0FrP
                  MULW      A1LbP,D1.7,D1Re0
                  MULW      A0FrP,D1.7,A1.7
                  MULW      A1LbP,D1.7,D0Re0
                  MULW      A1LbP,D1.7,RD
                  MULW      A1LbP,D1.7,A0.7
                  MULD      D0.7,D1Re0,D1Re0
                  MULD      D0.7,D1Re0,A1LbP
                  MULW      A0.7,D1Re0,A1.7
                  MULD      A0.7,D1Re0,A1.7
                  MULD      D0.7,D1Re0,D0Re0
                  MULD      D0.7,D1Re0,D0.7
                  MULD      D0.7,D1Re0,RD
                  MULD      D0.7,D1Re0,A0FrP
                  MULD      D0.7,D1Re0,A0.7
                  MULD      D0.7,D1.7,D1Re0
                  MULD      D0.7,D1.7,A1LbP
                  MULW      A0.7,D1.7,A1.7
                  MULD      A0.7,D1.7,A1.7
                  MULD      D0.7,D1.7,D0Re0
                  MULD      D0.7,D1.7,D0.7
                  MULD      D0.7,D1.7,RD
                  MULD      D0.7,D1.7,A0FrP
                  MULD      D0.7,D1.7,A0.7
                  MULDVS    D0Re0,D0Re0,#0x80
                  MULDVS    D0Re0,D0.7,#0x7f
                  MULD      D0Re0,D0.7,#0x80
                  MULD      D1Re0,D0.7,#0xff
                  MULD      A1LbP,D0Re0,#0x80
                  MULD      A1LbP,D0.7,#0x7f
                  MULD      A1LbP,D0.7,#0xff
                  MULD      A0.7,D0Re0,#0x7f
                  MULD      D1.7,D0Re0,#0x80
                  MULD      D0.7,D0Re0,#0xff
                  MULDGT    D0.7,D0.7,#0x7f
                  MULDGE    D0.7,D0.7,#0x80
                  MULDVS    D0.7,D0.7,#0xff
                  MULDNV    D1Re0,D1Re0,#0x7f
                  MULDGE    D1Re0,D1Re0,#0xff
                  MULD      D1Re0,D1.7,#0x7f
                  MULDVS    D1Re0,D1.7,#0xff
                  MULD      A1LbP,D1Re0,#0x7f
                  MULD      A1LbP,D1Re0,#0xff
                  MULD      A1LbP,D1.7,#0x80
                  MULD      D0.7,D1Re0,#0x7f
                  MULDVS    D1.7,D1Re0,#0x80
                  MULD      A1.7,D1Re0,#0x80
                  MULD      A0.7,D1Re0,#0xff
                  MULD      A0.7,D1.7,#0x7f
                  MULD      A0.7,D1.7,#0x80
                  MULD      A0.7,D1.7,#0xff
                  ABS       D0Re0,D0Re0
                  CMP       D0Re0,D1Re0
                  MIN       D0Re0,D0.7,D0Re0
                  MAX       D0Re0,D0.7,D0.7
                  NORM      D0.7,D0Re0
                  FFB       D0.7,D0.7
                  NMIN      D0.7,D0.7,D0.7
                  CMP       D1Re0,A1LbP
                  CMP       D1Re0,RD
                  ABS       D1Re0,D1.7
                  CMP       D1.7,D0Re0
                  MAX       D1.7,D1Re0,D1Re0
                  MIN       D1.7,D1.7,D1Re0
                  CMPT      D0Re0,#0x7fff
                  CMP       D0Re0,#0xffff
                  CMPMT     D0.7,#0x7fff
                  CMP       D0.7,#-0x1
                  CMPT      D1Re0,#0x8000
                  CMPMT     D1Re0,#0xffff
                  CMPMB     D1.7,#0x8000
                  CMPVS     D0Re0,A1LbP
                  CMPCC     D0.7,D0Re0
                  CMPGT     D0.7,A0.7
                  CMPGT     D1Re0,A0FrP
                  CMPNV     D1.7,RD
                  CMPNV     D0Re0,#0x80
                  CMPLT     D0.7,#0x80
                  CMPLT     D1Re0,#0x80
                  CMPNV     D1.7,#0xff
                  TST       D0Re0,A0FrP
                  TST       D0.7,RD
                  TST       D1Re0,D0.7
                  TST       D1.7,D0Re0
                  TSTMT     D0Re0,#0x7fff
                  TST       D0Re0,#-0x1
                  TSTT      D0.7,#0x8000
                  TSTMT     D0.7,#0xffff
                  TSTMB     D1Re0,#0x8000
                  TSTT      D1.7,#0x7fff
                  TST       D1.7,#0xffff
                  TSTNV     D0Re0,A1.7
                  TSTCC     D0.7,D0.7
                  TSTGE     D1Re0,A1LbP
                  TSTVS     D1.7,D1Re0
                  TSTVS     D1.7,A0.7
                  TSTLE     D0Re0,#0x80
                  TSTLE     D0.7,#0x80
                  TSTLE     D1Re0,#0x80
                  TSTNV     D1.7,#0x7f
                  MOV       A0FrP,RD
                  ADD       A0FrP,A0FrP,RD
                  ADD       A0FrP,A0.7,D0.7
                  ADD       A0FrP,CPC0,A1.7
                  MOV       A0.7,A0.7
                  ADD       A0.7,A0FrP,D0.7
                  ADD       A0.7,A0.7,A1.7
                  ADD       A0.7,CPC0,A1LbP
                  ADD       A0.7,CPC0,D1.7
                  ADD       A1LbP,A1LbP,D1.7
                  ADD       A1LbP,A1.7,A1LbP
                  ADD       A1LbP,A1.7,A0.7
                  ADD       A1LbP,CPC1,RD
                  ADD       A1.7,A1LbP,A1LbP
                  ADD       A1.7,A1LbP,A0.7
                  ADD       A1.7,A1.7,RD
                  ADD       A1.7,CPC1,D0.7
                  MOVT      A0FrP,#0x7fff
                  ADDT      A0FrP,A0FrP,#0xffff
                  MOVT      A0.7,#0x7fff
                  ADDT      A0.7,A0.7,#0xffff
                  ADDT      A0FrP,CPC0,#0x8000
                  ADDT      A0.7,CPC0,#0x8000
                  MOVT      A1LbP,#0x7fff
                  ADDT      A1LbP,A1LbP,#0xffff
                  MOVT      A1.7,#0x7fff
                  ADDT      A1.7,A1.7,#0xffff
                  ADDT      A1LbP,CPC1,#0x8000
                  ADDT      A1.7,CPC1,#0x8000
                  ADDGT     D0Re0,A0FrP,A1LbP
                  ADDGE     TTEXEC,A0FrP,A1LbP
                  ADDVS     PC,A0FrP,A1.7
                  ADDGT     PC,A0FrP,D0Re0
                  ADDVS     TTEXEC,A0FrP,D0.7
                  ADDNV     PC,A0FrP,RD
                  ADDLE     TXENABLE,A0FrP,D1Re0
                  ADDNV     TTEXEC,A0FrP,D1Re0
                  ADDNV     TXENABLE,A0.7,A1LbP
                  ADDGT     TXSTAT,A0.7,A1LbP
                  ADDNV     D1Re0,A0.7,A1.7
                  ADDGE     D0Re0,A0.7,D0Re0
                  ADDGE     PC,A0.7,D0.7
                  ADDGE     D1Re0,A0.7,RD
                  ADDVC     TXENABLE,A0.7,D1Re0
                  ADDNV     PC,A0.7,D1Re0
                  ADDHI     TTEXEC,A0.7,D1.7
                  ADDGT     PC,CPC0,A1LbP
                  ADDGE     D0Re0,CPC0,A1.7
                  ADDNV     TTEXEC,CPC0,A1.7
                  ADDVS     D0Re0,CPC0,D0.7
                  ADDGT     D0Re0,CPC0,RD
                  ADDGE     TTEXEC,CPC0,RD
                  ADDLT     PC,CPC0,D1Re0
                  ADDMI     PC,CPC0,D1.7
                  ADDNV     PCX,A0FrP,A1LbP
                  ADDVS     PCX,A0FrP,A1.7
                  ADDGT     A1LbP,A0FrP,D0.7
                  ADDNV     PCX,A0FrP,RD
                  ADDLT     PCX,A0FrP,D1Re0
                  ADDLT     A1LbP,A0FrP,D1.7
                  ADDVS     A1LbP,A0.7,A1LbP
                  ADDGE     A1LbP,A0.7,A1.7
                  ADDVS     TTCTRL,A0.7,D0Re0
                  ADDVS     A1LbP,A0.7,RD
                  ADDLE     A1LbP,A0.7,D1Re0
                  ADDLE     A0FrP,A0.7,D1.7
                  ADDVS     A0FrP,CPC0,A1LbP
                  ADDGT     PCX,CPC0,A1LbP
                  ADDLT     PCX,CPC0,A0.7
                  ADDNV     A0FrP,CPC0,D0.7
                  ADDMI     PCX,CPC0,CPC0
                  ADDNV     A1LbP,CPC0,D1Re0
                  ADDNV     A0FrP,CPC0,D1.7
                  ADDCS     TTMARK,A0FrP,A0.7
                  ADDLE     TTMARK,A0FrP,D1Re0
                  ADDVS     TTMARK,A0.7,D0.7
                  ADDCC     TTMARK,CPC0,A0FrP
                  ADDNV     TTMARK,CPC0,D1Re0
                  ADDCC     TTREC,A0FrP,A0.7
                  ADDEQ     TTREC,A0FrP,CPC0
                  ADDNE     TXMASKI,A0.7,A0FrP
                  ADDGE     TXMASKI,A0.7,D0Re0
                  ADDMI     TXMASKI,A0.7,D1Re0
                  ADDGE     TTREC,CPC0,A0FrP
                  ADDVS     TXMASKI,CPC0,D0.7
                  ADDLE     TXMASKI,CPC0,D1Re0
                  ADDLE     TTREC,CPC0,D1.7
                  ADDCC     GTEXEC,A0FrP,CPC0
                  ADDNV     GTEXEC,A0FrP,D1.7
                  ADDGT     GTEXEC,A0.7,RD
                  ADDCC     GTEXEC,CPC0,A0FrP
                  ADDNV     GTEXEC,CPC0,D1Re0
                  ADDMI     A1.7,A0FrP,A0FrP
                  ADDMI     A0.7,A0FrP,A0.7
                  ADDGT     A0.7,A0FrP,D0Re0
                  ADDCS     D0.7,A0FrP,CPC0
                  ADDCC     TXGPIOO,A0FrP,CPC0
                  ADDCS     TXGPIOO,A0FrP,D1Re0
                  ADDLE     A0.7,A0FrP,D1.7
                  ADDVS     D1.7,A0.7,A0FrP
                  ADDNE     D0.7,A0.7,A0.7
                  ADDCS     TXGPIOO,A0.7,A0.7
                  ADDGE     D1.7,A0.7,D0.7
                  ADDEQ     A0.7,A0.7,CPC0
                  ADDNV     D0.7,A0.7,D1Re0
                  ADDNV     D0.7,A0.7,D1.7
                  ADDNV     A1.7,A0.7,D1.7
                  ADDCC     A1.7,CPC0,A0FrP
                  ADDNV     D1.7,CPC0,A1.7
                  ADDVS     A0.7,CPC0,D0Re0
                  ADDEQ     D0.7,CPC0,CPC0
                  ADDNE     TXGPIOO,CPC0,CPC0
                  ADDLT     A0.7,CPC0,D1Re0
                  ADDMI     D1.7,CPC0,D1.7
                  ADDNV     RA,A0FrP,A1LbP
                  ADDCS     RA,A0FrP,D1.7
                  ADDVS     RA,A0.7,D0Re0
                  ADDNV     RA,A0.7,D1.7
                  ADDNV     RA,CPC0,RD
                  ADDCC     RAM8X32,A0FrP,A0.7
                  ADDVC     RAM8X32,A0.7,A0FrP
                  ADDHI     RAM8X32,A0.7,D1Re0
                  ADDCS     RAM8X32,CPC0,CPC0
                  ADDNV     RAM8X,A0FrP,D0Re0
                  ADDCC     RAM8X,A0.7,A0.7
                  ADDVC     RAM8X,CPC0,A0FrP
                  ADDHI     RAM8X,CPC0,D1Re0
                  ADDCS     RABZ,A0FrP,CPC0
                  ADDNV     RABZ,A0.7,D0Re0
                  ADDCC     RABZ,CPC0,A0.7
                  ADDVC     RAWX,A0FrP,A0FrP
                  ADDHI     RAWX,A0FrP,D1Re0
                  ADDCS     RAWX,A0.7,CPC0
                  ADDNV     RAWX,CPC0,D0Re0
                  ADDVC     RAMX,A0FrP,A0FrP
                  ADDNV     TXIDLECYC,A0FrP,D0.7
                  ADDGT     TXIDLECYC,A0FrP,D1Re0
                  ADDVC     RAMX,A0.7,A0FrP
                  ADDNV     TXIDLECYC,A0.7,D0.7
                  ADDGT     TXIDLECYC,A0.7,D1Re0
                  ADDVC     RAMX,CPC0,A0FrP
                  ADDNV     TXIDLECYC,CPC0,D0.7
                  ADDGT     TXIDLECYC,CPC0,D1Re0
                  ADDNV     D1Re0,A1LbP,D1Re0
                  ADDEQ     TXSTAT,A1LbP,A1LbP
                  ADDCC     PC,A1LbP,A1.7
                  ADDGT     D1Re0,A1LbP,D0Re0
                  ADDGT     TXSTAT,A1LbP,D0.7
                  ADDNE     PC,A1LbP,CPC1
                  ADDHI     D1Re0,A1LbP,A0FrP
                  ADDLT     D0Re0,A1LbP,A0.7
                  ADDLT     TXSTAT,A1LbP,A0.7
                  ADDNV     TXSTAT,A1.7,D1Re0
                  ADDCC     TXENABLE,A1.7,A1.7
                  ADDCS     TXSTAT,A1.7,A1.7
                  ADDNV     TXSTAT,A1.7,D0Re0
                  ADDNE     TXENABLE,A1.7,CPC1
                  ADDEQ     TXSTAT,A1.7,CPC1
                  ADDNV     TXSTAT,A1.7,A0FrP
                  ADDNV     D0Re0,A1.7,A0.7
                  ADDNV     TXSTAT,A1.7,A0.7
                  ADDVS     TXENABLE,CPC1,A1LbP
                  ADDCS     D0Re0,CPC1,A1.7
                  ADDNE     TTEXEC,CPC1,A1.7
                  ADDNV     TXENABLE,CPC1,D0.7
                  ADDEQ     D0Re0,CPC1,CPC1
                  ADDMI     TTEXEC,CPC1,CPC1
                  ADDLT     PC,CPC1,A0FrP
                  ADDHI     D0Re0,CPC1,A0.7
                  ADDNV     A0FrP,A1LbP,D1Re0
                  ADDCC     A0FrP,A1LbP,A1.7
                  ADDVS     A0FrP,A1LbP,D0Re0
                  ADDNE     A0FrP,A1LbP,CPC1
                  ADDMI     A0FrP,A1LbP,A0FrP
                  ADDLE     A0FrP,A1LbP,A0.7
                  ADDGT     A1LbP,A1.7,D1Re0
                  ADDGT     A0FrP,A1.7,D1.7
                  ADDNV     A1LbP,A1.7,D0Re0
                  ADDVS     A0FrP,A1.7,RD
                  ADDNV     A1LbP,A1.7,A0FrP
                  ADDNV     A0FrP,A1.7,A0.7
                  ADDGE     PCX,CPC1,D1Re0
                  ADDCS     A1LbP,CPC1,A1.7
                  ADDGT     PCX,CPC1,D0Re0
                  ADDEQ     A1LbP,CPC1,CPC1
                  ADDNV     A1LbP,CPC1,A0FrP
                  ADDGE     TTMARK,A1LbP,D1Re0
                  ADDCS     TTMARK,A1LbP,A0FrP
                  ADDGT     TTMARK,A1.7,D1.7
                  ADDNV     TTMARK,A1.7,A0FrP
                  ADDNE     TTMARK,CPC1,CPC1
                  ADDNV     TTREC,A1LbP,D1Re0
                  ADDNV     TTREC,A1LbP,D0Re0
                  ADDNV     TTREC,A1LbP,A0FrP
                  ADDMI     TXMASKI,A1.7,A1LbP
                  ADDVS     TXMASKI,A1.7,D0.7
                  ADDHI     TXMASKI,A1.7,A0.7
                  ADDCC     TTREC,CPC1,A1LbP
                  ADDVS     TTREC,CPC1,D0.7
                  ADDNV     TXMASKI,CPC1,A0FrP
                  ADDGE     GTEXEC,A1LbP,D1Re0
                  ADDCS     GTEXEC,A1LbP,A0FrP
                  ADDGT     GTEXEC,A1.7,D1.7
                  ADDNV     GTEXEC,A1.7,A0FrP
                  ADDNE     GTEXEC,CPC1,CPC1
                  ADDNV     D1.7,A1LbP,D1Re0
                  ADDCS     TXGPIOO,A1LbP,A1LbP
                  ADDGE     A1.7,A1LbP,D1.7
                  ADDGE     D0.7,A1LbP,D0.7
                  ADDVS     D1.7,A1LbP,RD
                  ADDHI     D1.7,A1LbP,A0FrP
                  ADDMI     TXGPIOO,A1LbP,A0FrP
                  ADDNV     A0.7,A1LbP,A0.7
                  ADDNE     D0.7,A1.7,A1LbP
                  ADDNV     D1.7,A1.7,D1.7
                  ADDGT     D1.7,A1.7,D0Re0
                  ADDGT     TXGPIOO,A1.7,D0.7
                  ADDGT     A1.7,A1.7,RD
                  ADDNV     A0.7,A1.7,A0FrP
                  ADDLE     D1.7,A1.7,A0.7
                  ADDNV     D1.7,CPC1,D1Re0
                  ADDCS     TXGPIOO,CPC1,A1LbP
                  ADDGE     A1.7,CPC1,D1.7
                  ADDGE     D0.7,CPC1,D0.7
                  ADDVS     D1.7,CPC1,RD
                  ADDNV     D1.7,CPC1,A0FrP
                  ADDHI     A1.7,CPC1,A0.7
                  ADDVS     RA,A1LbP,D1.7
                  ADDEQ     RA,A1.7,A1LbP
                  ADDNV     RA,A1.7,A0.7
                  ADDVS     RA,CPC1,RD
                  ADDNE     RAM8X32,A1LbP,A1.7
                  ADDNV     RAM8X32,A1.7,D1Re0
                  ADDHI     RAM8X32,A1.7,A0FrP
                  ADDNE     RAM8X32,CPC1,CPC1
                  ADDNE     RAM8X,A1LbP,A1LbP
                  ADDLT     RAM8X,A1LbP,A0FrP
                  ADDGT     RAM8X,A1.7,D0Re0
                  ADDHI     RAM8X,A1.7,A0.7
                  ADDVS     RAM8X,CPC1,RD
                  ADDNV     RABZ,A1LbP,D0.7
                  ADDVS     RABZ,A1.7,D1.7
                  ADDNE     RABZ,CPC1,A1LbP
                  ADDLT     RABZ,CPC1,A0FrP
                  ADDGE     RAWX,A1LbP,D0Re0
                  ADDNE     RAWX,A1.7,A1.7
                  ADDNV     RAWX,CPC1,D1Re0
                  ADDCS     RAWX,CPC1,A0FrP
                  ADDEQ     RAMX,A1LbP,A1LbP
                  ADDNV     RAMX,A1LbP,D0.7
                  ADDHI     RAMX,A1LbP,A0FrP
                  ADDCC     TXIDLECYC,A1.7,A1LbP
                  ADDGE     TXIDLECYC,A1.7,D0.7
                  ADDNV     TXIDLECYC,A1.7,A0FrP
                  ADDNV     RAMX,CPC1,D1Re0
                  ADDGT     RAMX,CPC1,D0Re0
                  ADDCS     RAMX,CPC1,A0FrP
                  ADD       TXENABLE,A0FrP,#0x7f
                  ADD       D1Re0,A0FrP,#0x80
                  ADD       TXSTAT,A0FrP,#0xff
                  ADD       TXENABLE,A0.7,#0x80
                  ADD       D1Re0,A0.7,#0xff
                  ADDCS     A0FrP,A0FrP,#0x80
                  ADDLE     A0FrP,A0FrP,#0xff
                  ADD       PCX,A0.7,#0x7f
                  ADD       A0FrP,A0.7,#0xff
                  ADDNV     A0FrP,CPC0,#0x80
                  ADD       TTMARK,A0.7,#0x80
                  ADD       TXMASKI,A0.7,#0x7f
                  ADD       GTEXEC,A0FrP,#0xff
                  ADD       D0.7,A0FrP,#0x7f
                  ADD       D0.7,A0FrP,#0x80
                  ADD       A0.7,A0FrP,#0xff
                  ADDHI     A0.7,A0.7,#0x80
                  ADDNV     A0.7,A0.7,#0xff
                  ADDNV     A0.7,CPC0,#0x7f
                  ADD       RA,A0.7,#0x7f
                  ADD       RAM8X32,A0.7,#0xff
                  ADD       RABZ,A0FrP,#0x80
                  ADD       RAWX,A0.7,#0x7f
                  ADD       RAMX,A0FrP,#0xff
                  ADD       D0Re0,A1LbP,#0x7f
                  ADD       PC,A1LbP,#0x80
                  ADD       TTEXEC,A1LbP,#0xff
                  ADD       D0Re0,A1.7,#0x80
                  ADD       PC,A1.7,#0xff
                  ADD       PCX,A1LbP,#0x7f
                  ADDNV     A1LbP,A1LbP,#0xff
                  ADD       TTCTRL,A1.7,#0x7f
                  ADDLE     A1LbP,A1.7,#0xff
                  ADDLE     A1LbP,CPC1,#0x7f
                  ADD       TTMARK,A1LbP,#0xff
                  ADD       TXMASKI,A1LbP,#0xff
                  ADD       GTEXEC,A1LbP,#0x7f
                  ADDNV     A1.7,A1LbP,#0x7f
                  ADD       D1.7,A1LbP,#0x80
                  ADD       A1.7,A1LbP,#0xff
                  ADDLT     A1.7,A1.7,#0x80
                  ADDLE     A1.7,A1.7,#0xff
                  ADDNV     A1.7,CPC1,#0x7f
                  ADD       RA,A1.7,#0xff
                  ADD       RAM8X,A1LbP,#0x80
                  ADD       RABZ,A1.7,#0x7f
                  ADD       RAWX,A1.7,#0xff
                  ADD       RAMX,A1.7,#0x7f
                  NEG       A0FrP,A1.7
                  SUB       A0FrP,A0FrP,A1LbP
                  SUB       A0FrP,A0FrP,D1.7
                  SUB       A0FrP,A0.7,RD
                  SUB       A0FrP,CPC0,D0.7
                  NEG       A0.7,A1.7
                  SUB       A0.7,A0FrP,A1LbP
                  SUB       A0.7,A0FrP,D1.7
                  SUB       A0.7,A0.7,RD
                  SUB       A0.7,CPC0,D0.7
                  NEG       A1LbP,D1.7
                  SUB       A1LbP,A1LbP,A1LbP
                  SUB       A1LbP,A1LbP,A0.7
                  SUB       A1LbP,A1.7,RD
                  SUB       A1LbP,CPC1,D0.7
                  NEG       A1.7,D1.7
                  SUB       A1.7,A1LbP,A1LbP
                  SUB       A1.7,A1LbP,A0.7
                  SUB       A1.7,A1.7,RD
                  SUB       A1.7,CPC1,D0.7
                  SUB       A0FrP,A0FrP,#0x8000
                  NEG       A0FrP,#0xffff
                  NEG       A0.7,#0x8000
                  SUBT      A0FrP,CPC0,#0x7fff
                  SUBT      A0.7,CPC0,#0x7fff
                  SUBT      A1LbP,A1LbP,#0x7fff
                  SUBT      A1LbP,A1LbP,#0xffff
                  SUBT      A1.7,A1.7,#0x8000
                  NEG       A1.7,#-0x1
                  SUB       A1LbP,CPC1,#-0x1
                  SUB       A1.7,CPC1,#-0x1
                  SUBVS     PC,A0FrP,A1LbP
                  SUBGE     D0Re0,A0FrP,A1.7
                  SUBVS     TTEXEC,A0FrP,A1.7
                  SUBGT     D0Re0,A0FrP,D0.7
                  SUBVS     D0Re0,A0FrP,RD
                  SUBNV     TTEXEC,A0FrP,RD
                  SUBLE     D1Re0,A0FrP,D1Re0
                  SUBLE     TTEXEC,A0FrP,D1Re0
                  SUBNV     D0Re0,A0FrP,D1.7
                  SUBNV     TXSTAT,A0FrP,D1.7
                  SUBNE     PC,A0.7,A0FrP
                  SUBCS     D0Re0,A0.7,A0.7
                  SUBNE     TTEXEC,A0.7,A0.7
                  SUBNV     TXENABLE,A0.7,D0.7
                  SUBEQ     D0Re0,A0.7,CPC0
                  SUBMI     TTEXEC,A0.7,CPC0
                  SUBLT     D1Re0,A0.7,D1Re0
                  SUBLT     TTEXEC,A0.7,D1Re0
                  SUBLE     D0Re0,A0.7,D1.7
                  SUBLE     TXSTAT,A0.7,D1.7
                  SUBGT     D1Re0,CPC0,A1LbP
                  SUBNV     TXENABLE,CPC0,A1.7
                  SUBNV     TXSTAT,CPC0,A1.7
                  SUBNV     TTEXEC,CPC0,D0Re0
                  SUBGE     TXENABLE,CPC0,RD
                  SUBVS     TXSTAT,CPC0,RD
                  SUBHI     TTEXEC,CPC0,D1Re0
                  SUBHI     TXSTAT,CPC0,D1.7
                  SUBGE     A1LbP,A0FrP,A1LbP
                  SUBNV     A1LbP,A0FrP,A1.7
                  SUBGT     TTCTRL,A0FrP,D0Re0
                  SUBGE     A1LbP,A0FrP,RD
                  SUBLT     TTCTRL,A0FrP,D1Re0
                  SUBNV     PCX,A0FrP,D1.7
                  SUBMI     TTCTRL,A0.7,A0FrP
                  SUBNE     TTCTRL,A0.7,A0.7
                  SUBNV     PCX,A0.7,D0.7
                  SUBMI     TTCTRL,A0.7,CPC0
                  SUBNV     A0FrP,A0.7,D1.7
                  SUBGE     A0FrP,CPC0,A1LbP
                  SUBCS     TTCTRL,CPC0,A0FrP
                  SUBNV     TTCTRL,CPC0,A1.7
                  SUBGT     TTCTRL,CPC0,D0.7
                  SUBVS     TTCTRL,CPC0,RD
                  SUBMI     PCX,CPC0,D1Re0
                  SUBLT     TTCTRL,CPC0,D1.7
                  SUBVS     TTMARK,A0FrP,D0.7
                  SUBLE     TTMARK,A0FrP,D1.7
                  SUBCC     TTMARK,A0.7,CPC0
                  SUBNV     TTMARK,A0.7,D1.7
                  SUBVS     TTMARK,CPC0,RD
                  SUBNV     TXMASKI,A0FrP,A1.7
                  SUBVS     TXMASKI,A0FrP,RD
                  SUBMI     TTREC,A0FrP,D1.7
                  SUBGT     TTREC,A0.7,A1.7
                  SUBVS     TTREC,A0.7,RD
                  SUBGT     TXMASKI,CPC0,A1LbP
                  SUBNV     TTREC,CPC0,D0Re0
                  SUBLT     TXMASKI,CPC0,D1Re0
                  SUBLT     TTREC,CPC0,D1.7
                  SUBVS     GTEXEC,A0FrP,D0.7
                  SUBLE     GTEXEC,A0FrP,D1.7
                  SUBCC     GTEXEC,A0.7,CPC0
                  SUBNV     GTEXEC,A0.7,D1.7
                  SUBVS     GTEXEC,CPC0,RD
                  SUBNV     A0.7,A0FrP,A1LbP
                  SUBVS     D1.7,A0FrP,A1.7
                  SUBNV     D1.7,A0FrP,D0Re0
                  SUBNV     TXGPIOO,A0FrP,D0.7
                  SUBNV     A1.7,A0FrP,RD
                  SUBHI     A1.7,A0FrP,D1Re0
                  SUBLT     A0.7,A0FrP,D1.7
                  SUBGT     D0.7,A0.7,A1LbP
                  SUBGT     TXGPIOO,A0.7,A1LbP
                  SUBGT     A1.7,A0.7,A1.7
                  SUBGT     D0.7,A0.7,D0.7
                  SUBVS     D1.7,A0.7,RD
                  SUBLE     D0.7,A0.7,D1Re0
                  SUBNV     TXGPIOO,A0.7,D1Re0
                  SUBLE     A1.7,A0.7,D1.7
                  SUBNV     A0.7,CPC0,A1LbP
                  SUBHI     D1.7,CPC0,A0.7
                  SUBGE     D1.7,CPC0,D0Re0
                  SUBGE     TXGPIOO,CPC0,D0.7
                  SUBGE     A1.7,CPC0,RD
                  SUBNV     D1.7,CPC0,D1Re0
                  SUBNV     D0.7,CPC0,D1.7
                  SUBMI     RA,A0FrP,A0FrP
                  SUBMI     RA,A0FrP,D1Re0
                  SUBVS     RA,A0.7,A1.7
                  SUBLE     RA,A0.7,D1.7
                  SUBMI     RA,CPC0,CPC0
                  SUBGT     RAM8X32,A0FrP,A1LbP
                  SUBMI     RAM8X32,A0FrP,D1.7
                  SUBGE     RAM8X32,A0.7,RD
                  SUBVS     RAM8X32,CPC0,D0.7
                  SUBGT     RAM8X,A0FrP,A1.7
                  SUBGT     RAM8X,A0.7,A1LbP
                  SUBMI     RAM8X,A0.7,D1.7
                  SUBGE     RAM8X,CPC0,RD
                  SUBVS     RABZ,A0FrP,D0.7
                  SUBGT     RABZ,A0.7,A1.7
                  SUBGT     RABZ,CPC0,A1LbP
                  SUBMI     RABZ,CPC0,D1.7
                  SUBGE     RAWX,A0FrP,RD
                  SUBVS     RAWX,A0.7,D0.7
                  SUBGT     RAWX,CPC0,A1.7
                  SUBGE     TXIDLECYC,A0FrP,A1LbP
                  SUBNV     RAMX,A0FrP,D0Re0
                  SUBVC     TXIDLECYC,A0FrP,D1Re0
                  SUBGE     TXIDLECYC,A0.7,A1LbP
                  SUBNV     RAMX,A0.7,D0Re0
                  SUBVC     TXIDLECYC,A0.7,D1Re0
                  SUBGE     TXIDLECYC,CPC0,A1LbP
                  SUBNV     RAMX,CPC0,D0Re0
                  SUBVC     TXIDLECYC,CPC0,D1Re0
                  SUBNV     D0Re0,A1LbP,D1Re0
                  SUBNE     PC,A1LbP,A1LbP
                  SUBVS     D1Re0,A1LbP,D1.7
                  SUBNV     D0Re0,A1LbP,D0Re0
                  SUBNV     PC,A1LbP,D0.7
                  SUBNV     D1Re0,A1LbP,RD
                  SUBNV     D0Re0,A1LbP,A0FrP
                  SUBNV     TXENABLE,A1LbP,A0.7
                  SUBNV     PC,A1LbP,A0.7
                  SUBNV     PC,A1.7,D1Re0
                  SUBMI     TTEXEC,A1.7,A1LbP
                  SUBGT     PC,A1.7,D1.7
                  SUBVS     PC,A1.7,D0Re0
                  SUBGE     TTEXEC,A1.7,D0.7
                  SUBVS     PC,A1.7,RD
                  SUBMI     PC,A1.7,A0FrP
                  SUBLE     D0Re0,A1.7,A0.7
                  SUBLE     TXSTAT,A1.7,A0.7
                  SUBGT     TTEXEC,CPC1,D1Re0
                  SUBGT     TXENABLE,CPC1,D1.7
                  SUBGE     TXSTAT,CPC1,D1.7
                  SUBGT     TTEXEC,CPC1,D0Re0
                  SUBVS     TXENABLE,CPC1,RD
                  SUBVS     TXSTAT,CPC1,RD
                  SUBCS     PC,CPC1,A0FrP
                  SUBNV     TXENABLE,CPC1,A0.7
                  SUBHI     TTEXEC,CPC1,A0.7
                  SUBCS     TTCTRL,A1LbP,A1LbP
                  SUBNV     TTCTRL,A1LbP,D1.7
                  SUBVS     TTCTRL,A1LbP,D0.7
                  SUBGE     TTCTRL,A1LbP,RD
                  SUBLT     A0FrP,A1LbP,A0.7
                  SUBNV     A0FrP,A1.7,D1Re0
                  SUBCC     A0FrP,A1.7,A1.7
                  SUBVS     A0FrP,A1.7,D0Re0
                  SUBNE     A0FrP,A1.7,CPC1
                  SUBMI     A0FrP,A1.7,A0FrP
                  SUBLE     A0FrP,A1.7,A0.7
                  SUBGT     A1LbP,CPC1,D1Re0
                  SUBGT     A0FrP,CPC1,D1.7
                  SUBNV     A1LbP,CPC1,D0Re0
                  SUBVS     A0FrP,CPC1,RD
                  SUBLE     A1LbP,CPC1,A0FrP
                  SUBNV     TTCTRL,CPC1,A0.7
                  SUBVS     TTMARK,A1LbP,RD
                  SUBCC     TTMARK,A1.7,A1.7
                  SUBLE     TTMARK,A1.7,A0FrP
                  SUBGT     TTMARK,CPC1,D0.7
                  SUBNV     TXMASKI,A1LbP,D1Re0
                  SUBVS     TXMASKI,A1LbP,D0Re0
                  SUBMI     TXMASKI,A1LbP,A0FrP
                  SUBNV     TTREC,A1.7,D1Re0
                  SUBNV     TTREC,A1.7,D0Re0
                  SUBNV     TTREC,A1.7,A0FrP
                  SUBMI     TXMASKI,CPC1,A1LbP
                  SUBVS     TXMASKI,CPC1,D0.7
                  SUBLE     TXMASKI,CPC1,A0FrP
                  SUBMI     TTREC,CPC1,A0.7
                  SUBVS     GTEXEC,A1LbP,RD
                  SUBCC     GTEXEC,A1.7,A1.7
                  SUBLE     GTEXEC,A1.7,A0FrP
                  SUBGT     GTEXEC,CPC1,D0.7
                  SUBGT     D0.7,A1LbP,D1Re0
                  SUBCC     A1.7,A1LbP,A1LbP
                  SUBCS     A1.7,A1LbP,A1.7
                  SUBVS     TXGPIOO,A1LbP,D0Re0
                  SUBEQ     D1.7,A1LbP,CPC1
                  SUBNV     D0.7,A1LbP,A0FrP
                  SUBNV     A1.7,A1LbP,A0FrP
                  SUBLE     A0.7,A1LbP,A0.7
                  SUBGT     TXGPIOO,A1.7,D1Re0
                  SUBMI     D1.7,A1.7,A1.7
                  SUBNV     D0.7,A1.7,D0Re0
                  SUBNV     A1.7,A1.7,D0.7
                  SUBCC     A1.7,A1.7,CPC1
                  SUBLE     A0.7,A1.7,A0FrP
                  SUBLT     D1.7,A1.7,A0.7
                  SUBGT     D0.7,CPC1,D1Re0
                  SUBCC     A1.7,CPC1,A1LbP
                  SUBCS     A1.7,CPC1,A1.7
                  SUBVS     TXGPIOO,CPC1,D0Re0
                  SUBEQ     D1.7,CPC1,CPC1
                  SUBMI     D0.7,CPC1,A0FrP
                  SUBNV     D1.7,CPC1,A0.7
                  SUBNE     RA,A1LbP,A1.7
                  SUBNV     RA,A1.7,D1Re0
                  SUBHI     RA,A1.7,A0FrP
                  SUBNE     RA,CPC1,CPC1
                  SUBEQ     RAM8X32,A1LbP,A1LbP
                  SUBNV     RAM8X32,A1LbP,A0.7
                  SUBVS     RAM8X32,A1.7,RD
                  SUBVS     RAM8X32,CPC1,D0.7
                  SUBNV     RAM8X,A1LbP,D1Re0
                  SUBCS     RAM8X,A1LbP,A0FrP
                  SUBGE     RAM8X,A1.7,D1.7
                  SUBNV     RAM8X,A1.7,A0FrP
                  SUBEQ     RAM8X,CPC1,CPC1
                  SUBGE     RABZ,A1LbP,D0Re0
                  SUBNE     RABZ,A1.7,A1.7
                  SUBNV     RABZ,CPC1,D1Re0
                  SUBCS     RABZ,CPC1,A0FrP
                  SUBVS     RAWX,A1LbP,D1.7
                  SUBEQ     RAWX,A1.7,A1LbP
                  SUBNV     RAWX,A1.7,A0.7
                  SUBVS     RAWX,CPC1,RD
                  SUBCC     TXIDLECYC,A1LbP,A1LbP
                  SUBGE     TXIDLECYC,A1LbP,D0.7
                  SUBNV     TXIDLECYC,A1LbP,A0FrP
                  SUBNV     RAMX,A1.7,D1Re0
                  SUBGE     RAMX,A1.7,D0Re0
                  SUBLE     TXIDLECYC,A1.7,A0FrP
                  SUBNV     TXIDLECYC,CPC1,D1Re0
                  SUBVS     TXIDLECYC,CPC1,D0Re0
                  SUBMI     TXIDLECYC,CPC1,A0FrP
                  SUBHI     RAMX,CPC1,A0.7
                  SUB       D0Re0,A0FrP,#0x80
                  SUB       PC,A0FrP,#0xff
                  SUB       TTEXEC,A0.7,#0x7f
                  SUB       D0Re0,A0.7,#0xff
                  SUB       TTCTRL,A0FrP,#0x7f
                  SUBGT     A0FrP,A0FrP,#0xff
                  SUB       A1LbP,A0.7,#0x7f
                  SUBNV     A0FrP,A0.7,#0xff
                  SUBLE     A0FrP,CPC0,#0x80
                  SUB       TTMARK,A0.7,#0x7f
                  SUB       TTREC,A0FrP,#0xff
                  SUB       GTEXEC,A0FrP,#0x80
                  SUBNV     A0.7,A0FrP,#0x7f
                  SUBNV     A0.7,A0FrP,#0x80
                  SUB       D1.7,A0FrP,#0xff
                  SUB       TXGPIOO,A0.7,#0x7f
                  SUBLE     A0.7,A0.7,#0xff
                  SUBLE     A0.7,CPC0,#0x7f
                  SUB       RA,A0FrP,#0xff
                  SUB       RAM8X32,A0.7,#0x80
                  SUB       RABZ,A0FrP,#0x7f
                  SUB       RAWX,A0FrP,#0xff
                  SUB       TXIDLECYC,A0FrP,#0xff
                  SUB       TXENABLE,A1LbP,#0x7f
                  SUB       D1Re0,A1LbP,#0x80
                  SUB       TXSTAT,A1LbP,#0xff
                  SUB       TXENABLE,A1.7,#0x80
                  SUB       D1Re0,A1.7,#0xff
                  SUB       A0FrP,A1LbP,#0x7f
                  SUB       TTCTRL,A1LbP,#0x80
                  SUB       PCX,A1.7,#0x7f
                  SUBLT     A1LbP,A1.7,#0xff
                  SUBLT     A1LbP,CPC1,#0x7f
                  SUB       TTMARK,A1LbP,#0x80
                  SUB       TTREC,A1LbP,#0x80
                  SUB       TTREC,A1.7,#0xff
                  SUBLE     A1.7,A1LbP,#0x7f
                  SUB       D0.7,A1LbP,#0x80
                  SUB       A0.7,A1LbP,#0xff
                  SUBCS     A1.7,A1.7,#0x80
                  SUBGT     A1.7,A1.7,#0xff
                  SUBLE     A1.7,CPC1,#0x7f
                  SUB       RA,A1.7,#0x80
                  SUB       RAM8X,A1LbP,#0x7f
                  SUB       RABZ,A1LbP,#0xff
                  SUB       RAWX,A1.7,#0x80
                  SUB       TXIDLECYC,A1.7,#0x7f
                  BCC       #+262143
                  BLT       #+262143
                  MOVBHI    D0Re0,RD
                  MOVDNV    TXSTAT,RD
                  MOVDHI    PCX,RD
                  MOVDLE    TTREC,RD
                  MOVWNV    D1.7,RD
                  MOVDVC    D1.7,RD
                  MOVDCC    RA,RD
                  MOVDLE    RABZ,RD
                  MOVDNV    RAMX,RD
                  MOVLLT    TTREC,A0FrP,A1LbP
                  MOVLLT    TTREC,D0.7,D1Re0
                  MOVLLE    TTREC,D1.7,D0.7
                  MOVLNV    TTREC,A0.7,CPC1
                  MOVLNV    D0Re0,D1.7,RD
                  MOVLLE    A1LbP,A0.7,RD
                  MOVLLT    A1.7,A0FrP,RD
                  MOVLLT    D0.7,D1.7,RD
                  MOVLNV    TTREC,CPC0,A1.7
                  MOVLT     D1Re0,TXENABLE
                  MOVNV     TXENABLE,D0Re0
                  MOVCS     TXSTAT,D0Re0
                  TTMOVNV   TXENABLE,D0Re0
                  SWAPCC    TXSTAT,D0Re0
                  MOVNV     TXENABLE,D1Re0
                  SWAPHI    TXENABLE,D1Re0
                  TTMOVGE   TXSTAT,D1Re0
                  MOVNV     D0Re0,PC
                  MOVEQ     D0Re0,TXSTAT
                  MOVNV     D1Re0,TXSTAT
                  MOVGT     D0Re0,TTEXEC
                  SWAPCC    D1Re0,TTEXEC
                  SWAPCC    A1LbP,TXENABLE
                  MOVMI     TTCTRL,D0Re0
                  TTMOVGE   TTCTRL,D0Re0
                  MOVNV     PCX,D1Re0
                  SWAPNE    TTCTRL,D1Re0
                  SWAPCS    A0FrP,PC
                  MOVLE     A1LbP,TXSTAT
                  MOVNV     A0FrP,TTEXEC
                  MOVLT     TTMARK,D0Re0
                  SWAPHI    TTMARK,D1Re0
                  MOVNV     TTREC,D0Re0
                  MOVNV     TXMASKI,D1Re0
                  MOVLT     GTEXEC,D0Re0
                  SWAPHI    GTEXEC,D1Re0
                  MOVCS     A1.7,TXENABLE
                  SWAPCC    A1.7,TXENABLE
                  MOVCS     TXGPIOO,D0Re0
                  SWAPCC    D1.7,D0Re0
                  MOVNV     D0.7,D1Re0
                  MOVNV     A1.7,D1Re0
                  TTMOVNV   A1.7,D1Re0
                  MOVLE     D1.7,PC
                  SWAPVS    A0.7,PC
                  MOVLT     A1.7,TXSTAT
                  TTMOVNV   A0.7,TXSTAT
                  MOVNV     D1.7,TTEXEC
                  TTMOVNV   A0.7,TTEXEC
                  MOVMI     RAM8X,D1Re0
                  TTMOVGE   TXIDLECYC,D0Re0
                  MOVVC     TXENABLE,A0FrP
                  MOVNV     PC,A0FrP
                  TTMOVNV   D1Re0,A0FrP
                  MOVVC     TXENABLE,A1LbP
                  MOVVC     D1Re0,A1LbP
                  MOVNV     TTEXEC,A1LbP
                  TTMOVGT   PC,A1LbP
                  MOVLE     D1Re0,PCX
                  MOVLT     D0Re0,TTCTRL
                  TTMOVNV   D0Re0,TTCTRL
                  MOVLT     PCX,A0FrP
                  TTMOVGT   PCX,A0FrP
                  MOVCS     TTCTRL,A1LbP
                  TTMOVNV   A1LbP,A1LbP
                  MOVMI     A1LbP,PCX
                  MOVLT     A1LbP,TTCTRL
                  SWAPCS    TTMARK,A0FrP
                  MOVMI     TTREC,A0FrP
                  MOVMI     TTREC,A1LbP
                  MOVMI     GTEXEC,A1LbP
                  MOVNV     D1.7,A0FrP
                  SWAPVS    D1.7,A0FrP
                  MOVLE     D0.7,A1LbP
                  MOVNV     TXGPIOO,A1LbP
                  TTMOVLE   A1.7,A1LbP
                  MOVCC     D1.7,PCX
                  MOVNV     A1.7,PCX
                  TTMOVVS   A1.7,PCX
                  MOVLE     D1.7,TTCTRL
                  SWAPMI    D0.7,TTCTRL
                  MOVVC     RA,A0FrP
                  MOVVC     RAM8X,A0FrP
                  MOVVC     RAWX,A0FrP
                  SWAPLT    TXIDLECYC,A0FrP
                  TTMOVLT   D0Re0,TTMARK
                  TTMOVLE   A0FrP,TTMARK
                  TTMOVGT   D0.7,TTMARK
                  TTMOVNV   A0.7,TTMARK
                  MOVNV     D1Re0,TXMASKI
                  TTMOVNV   D0Re0,TTREC
                  MOVLE     A1LbP,TXMASKI
                  TTMOVNV   A0FrP,TTREC
                  MOVCC     D1.7,TXMASKI
                  MOVNV     A1.7,TXMASKI
                  TTMOVVS   A1.7,TXMASKI
                  TTMOVLE   D1.7,TTREC
                  MOVMI     D0Re0,GTEXEC
                  MOVLT     A1LbP,GTEXEC
                  MOVLE     D0.7,GTEXEC
                  TTMOVVS   D1.7,GTEXEC
                  MOVGT     D0Re0,TXGPIOI
                  MOVVC     A0FrP,TXGPIOI
                  TTMOVLT   A1LbP,TXGPIOI
                  MOVLE     A0.7,TXGPIOI
                  TTMOVNV   A0.7,TXGPIOI
                  MOVLE     D0Re0,TXPOLLI
                  MOVLE     A0FrP,TXPOLLI
                  TTMOVLE   A1LbP,TXPOLLI
                  MOVNV     A0.7,TXPOLLI
                  TTMOVLT   A1.7,TXPOLLI
                  MOVNV     D0Re0,D0.7
                  MOVNV     TXSTAT,D0.7
                  TTMOVNV   D0Re0,D0.7
                  TTMOVGE   TTEXEC,D0.7
                  MOVLT     PC,D1.7
                  TTMOVGT   D0Re0,D1.7
                  MOVEQ     TXENABLE,A0.7
                  MOVNV     D0Re0,A0.7
                  MOVLE     TTEXEC,A0.7
                  SWAPNE    PC,A0.7
                  MOVNV     TXENABLE,A1.7
                  MOVCS     TXSTAT,A1.7
                  TTMOVNV   TXENABLE,A1.7
                  TTMOVGE   TXSTAT,A1.7
                  MOVNV     D0Re0,TXGPIOO
                  MOVHI     PCX,D0.7
                  SWAPMI    PCX,D0.7
                  MOVNV     A1LbP,D1.7
                  TTMOVNV   A1LbP,D1.7
                  MOVMI     A1LbP,A0.7
                  TTMOVGE   A1LbP,A0.7
                  MOVLT     TTCTRL,A1.7
                  TTMOVGT   A1LbP,A1.7
                  MOVLE     A0FrP,TXGPIOO
                  TTMOVLE   A1LbP,TXGPIOO
                  MOVCS     TTMARK,D1.7
                  TTMOVGE   TTMARK,A0.7
                  SWAPEQ    TTREC,D0.7
                  MOVLT     TXMASKI,A0.7
                  MOVLT     TXMASKI,A1.7
                  MOVHI     GTEXEC,D0.7
                  TTMOVGE   GTEXEC,A0.7
                  MOVLE     D1.7,D0.7
                  TTMOVLE   D0.7,D0.7
                  SWAPNE    TXGPIOO,D0.7
                  MOVLT     A0.7,D1.7
                  SWAPEQ    A0.7,D1.7
                  MOVNV     D0.7,A0.7
                  SWAPGE    D0.7,A0.7
                  TTMOVVS   TXGPIOO,A0.7
                  MOVLE     A0.7,A1.7
                  SWAPPL    A0.7,A1.7
                  MOVNV     D1.7,TXGPIOO
                  TTMOVLT   A0.7,TXGPIOO
                  MOVNV     RA,D0.7
                  MOVLE     RAM8X32,D0.7
                  MOVCC     RAM8X,D0.7
                  MOVHI     RAM8X,A1.7
                  MOVMI     RABZ,A0.7
                  MOVMI     RAWX,A0.7
                  MOVMI     TXIDLECYC,D1.7
                  MOVLE     TXIDLECYC,A0.7
                  MOVHI     RAMX,A1.7
                  MOVLE     D1Re0,TXIDLECYC
                  SWAPEQ    A0FrP,TXIDLECYC
                  MOVVC     A0.7,TXIDLECYC
                  SWAPCC    D1.7,TXIDLECYC
                  SETDLT    [D0Re0],TXENABLE
                  SETBGT    [D1Re0],D0Re0
                  SETWNV    [D1Re0],D1Re0
                  SETDMI    [D0Re0],PC
                  SETDLE    [A1LbP],TXENABLE
                  SETLNV    [A1LbP],D0Re0,D1Re0
                  SETLNV    [A1LbP],D1Re0,D0Re0
                  SETDCS    [A0FrP],TXSTAT
                  SETDCS    [A1.7],TXENABLE
                  SETDNV    [A0.7],TXENABLE
                  SETWNV    [A0.7],D0Re0
                  SETDNV    [D1.7],D0Re0
                  SETWNV    [D1.7],D1Re0
                  SETDCC    [A0.7],D1Re0
                  SETDMI    [A1.7],TXSTAT
                  SETDLE    [A1.7],TTEXEC
                  SETWGT    [D1Re0],A0FrP
                  SETWNV    [D1Re0],A1LbP
                  SETDLE    [D1Re0],PCX
                  SETBMI    [A0FrP],A0FrP
                  SETWNV    [A1LbP],A1LbP
                  SETDNV    [A0FrP],A1LbP
                  SETDHI    [A0FrP],TTCTRL
                  SETWNV    [A0.7],A0FrP
                  SETDPL    [A0.7],A0FrP
                  SETBNE    [A0.7],A1LbP
                  SETDCS    [A0.7],A1LbP
                  SETDNV    [D1.7],PCX
                  SETDMI    [D0Re0],TTMARK
                  SETDCS    [D1.7],TTMARK
                  SETDLE    [D0Re0],TXMASKI
                  SETDLE    [D1Re0],TTREC
                  SETDNV    [A1LbP],TTREC
                  SETDNV    [D0.7],TXMASKI
                  SETDLE    [A1.7],TTREC
                  SETDLE    [D1Re0],GTEXEC
                  SETDNV    [A1.7],GTEXEC
                  SETDLE    [D1Re0],TXGPIOI
                  SETDNV    [A1.7],TXGPIOI
                  SETDEQ    [D0Re0],TXPOLLI
                  SETDNV    [D1Re0],TXPOLLI
                  SETDLT    [D0.7],TXPOLLI
                  SETDLE    [A0.7],TXPOLLI
                  SETDNE    [D1Re0],D0.7
                  SETWVS    [D1Re0],D1.7
                  SETBCC    [D1Re0],A0.7
                  SETBMI    [D1Re0],A1.7
                  SETDLT    [D0Re0],TXGPIOO
                  SETWGE    [A1LbP],D0.7
                  SETWGT    [A1LbP],D1.7
                  SETWNV    [A1LbP],A0.7
                  SETDCS    [A0FrP],A0.7
                  SETDMI    [A0FrP],A1.7
                  SETWVS    [D0.7],D0.7
                  SETLGE    [D0.7],D0.7,D1.7
                  SETBCC    [A1.7],D1.7
                  SETDMI    [A1.7],D1.7
                  SETLNV    [A0.7],D1.7,D0.7
                  SETWGE    [A0.7],A0.7
                  SETDCC    [D1.7],A0.7
                  SETBMI    [D1.7],A1.7
                  SETDEQ    [D1.7],A1.7
                  SETDLE    [D0.7],TXGPIOO
                  SETBNE    [D0Re0],RD
                  SETBPL    [A1LbP],RD
                  SETBPL    [A1.7],RD
                  SETDNE    [A1.7],RD
                  SETDNV    [D0Re0],TXIDLECYC
                  SETB      [A1LbP+#0x7ff],D0Re0
                  SETB      [D0Re0+#0x7ff],D0Re0
                  SETB      [D1Re0+#0x7ff],D0Re0
                  SETB      [A0FrP+#0x7ff],D0Re0
                  SETB      [A1LbP+#-0x800],D0Re0
                  SETB      [D0Re0+#-0x800],D0Re0
                  SETB      [D1Re0+#-0x800],D0Re0
                  SETB      [A0FrP+#-0x800],D0Re0
                  SETB      [A1LbP+#-0x1],D0Re0
                  SETB      [D0Re0+#-0x1],D0Re0
                  SETB      [D1Re0+#-0x1],D0Re0
                  SETB      [A0FrP+#-0x1],D0Re0
                  SETB      [A1LbP+#0x7ff],A1LbP
                  SETB      [D0Re0+#0x7ff],A1LbP
                  SETB      [D1Re0+#0x7ff],A1LbP
                  SETB      [A0FrP+#0x7ff],A1LbP
                  SETB      [A1LbP+#-0x800],A1LbP
                  SETB      [D0Re0+#-0x800],A1LbP
                  SETB      [D1Re0+#-0x800],A1LbP
                  SETB      [A0FrP+#-0x800],A1LbP
                  SETB      [A1LbP+#-0x1],A1LbP
                  SETB      [D0Re0+#-0x1],A1LbP
                  SETB      [D1Re0+#-0x1],A1LbP
                  SETB      [A0FrP+#-0x1],A1LbP
                  SETB      [A1LbP+#0x7ff],A1.7
                  SETB      [A1LbP+#0x7ff],D1.7
                  SETB      [D0Re0+#0x7ff],A1.7
                  SETB      [D0Re0+#0x7ff],D1.7
                  SETB      [D1Re0+#0x7ff],A1.7
                  SETB      [D1Re0+#0x7ff],D1.7
                  SETB      [A0FrP+#0x7ff],A1.7
                  SETB      [A0FrP+#0x7ff],D1.7
                  SETB      [A1LbP+#-0x800],A1.7
                  SETB      [A1LbP+#-0x800],D1.7
                  SETB      [D0Re0+#-0x800],A1.7
                  SETB      [D0Re0+#-0x800],D1.7
                  SETB      [D1Re0+#-0x800],A1.7
                  SETB      [D1Re0+#-0x800],D1.7
                  SETB      [A0FrP+#-0x800],A1.7
                  SETB      [A0FrP+#-0x800],D1.7
                  SETB      [A1LbP+#-0x1],A1.7
                  SETB      [A1LbP+#-0x1],D1.7
                  SETB      [D0Re0+#-0x1],A1.7
                  SETB      [D0Re0+#-0x1],D1.7
                  SETB      [D1Re0+#-0x1],A1.7
                  SETB      [D1Re0+#-0x1],D1.7
                  SETB      [A0FrP+#-0x1],A1.7
                  SETB      [A0FrP+#-0x1],D1.7
                  MOVB      RA,[A1LbP+#0x7ff]
                  MOVB      RA,[D1Re0+#0x7ff]
                  MOVB      RA,[A1LbP+#-0x800]
                  MOVB      RA,[D1Re0+#-0x800]
                  MOVB      RA,[A1LbP+#-0x1]
                  MOVB      RA,[D1Re0+#-0x1]
                  MOVB      RAM8X32,[A1LbP+#0x7ff]
                  MOVB      RAM8X32,[D1Re0+#0x7ff]
                  MOVB      RAM8X32,[A1LbP+#-0x800]
                  MOVB      RAM8X32,[D1Re0+#-0x800]
                  MOVB      RAM8X32,[A1LbP+#-0x1]
                  MOVB      RAM8X32,[D1Re0+#-0x1]
                  MOVB      RAM8X,[A1LbP+#0x7ff]
                  MOVB      RAM8X,[D1Re0+#0x7ff]
                  MOVB      RAM8X,[A1LbP+#-0x800]
                  MOVB      RAM8X,[D1Re0+#-0x800]
                  MOVB      RAM8X,[A1LbP+#-0x1]
                  MOVB      RAM8X,[D1Re0+#-0x1]
                  MOVB      RABZ,[A1LbP+#0x7ff]
                  MOVB      RABZ,[D1Re0+#0x7ff]
                  MOVB      RABZ,[A1LbP+#-0x800]
                  MOVB      RABZ,[D1Re0+#-0x800]
                  MOVB      RABZ,[A1LbP+#-0x1]
                  MOVB      RABZ,[D1Re0+#-0x1]
                  MOVB      RAWX,[A1LbP+#0x7ff]
                  MOVB      RAWX,[D1Re0+#0x7ff]
                  MOVB      RAWX,[A1LbP+#-0x800]
                  MOVB      RAWX,[D1Re0+#-0x800]
                  MOVB      RAWX,[A1LbP+#-0x1]
                  MOVB      RAWX,[D1Re0+#-0x1]
                  MOVB      RAMX,[A1LbP+#0x7ff]
                  MOVB      RAMX,[D1Re0+#0x7ff]
                  MOVB      RAMX,[A1LbP+#-0x800]
                  MOVB      RAMX,[D1Re0+#-0x800]
                  MOVB      RAMX,[A1LbP+#-0x1]
                  MOVB      RAMX,[D1Re0+#-0x1]
                  GETB      D0Re0,[A1LbP+#0x7ff]
                  GETB      D0Re0,[D0Re0+#0x7ff]
                  GETB      D0Re0,[D1Re0+#0x7ff]
                  GETB      D0Re0,[A0FrP+#0x7ff]
                  GETB      D0Re0,[A1LbP+#-0x800]
                  GETB      D0Re0,[D0Re0+#-0x800]
                  GETB      D0Re0,[D1Re0+#-0x800]
                  GETB      D0Re0,[A0FrP+#-0x800]
                  GETB      D0Re0,[A1LbP+#-0x1]
                  GETB      D0Re0,[D0Re0+#-0x1]
                  GETB      D0Re0,[D1Re0+#-0x1]
                  GETB      D0Re0,[A0FrP+#-0x1]
                  GETB      A1LbP,[A1LbP+#0x7ff]
                  GETB      A1LbP,[D0Re0+#0x7ff]
                  GETB      A1LbP,[D1Re0+#0x7ff]
                  GETB      A1LbP,[A0FrP+#0x7ff]
                  GETB      A1LbP,[A1LbP+#-0x800]
                  GETB      A1LbP,[D0Re0+#-0x800]
                  GETB      A1LbP,[D1Re0+#-0x800]
                  GETB      A1LbP,[A0FrP+#-0x800]
                  GETB      A1LbP,[A1LbP+#-0x1]
                  GETB      A1LbP,[D0Re0+#-0x1]
                  GETB      A1LbP,[D1Re0+#-0x1]
                  GETB      A1LbP,[A0FrP+#-0x1]
                  GETB      A1.7,[A1LbP+#0x7ff]
                  GETB      D1.7,[A1LbP+#0x7ff]
                  GETB      A1.7,[D0Re0+#0x7ff]
                  GETB      D1.7,[D0Re0+#0x7ff]
                  GETB      A1.7,[D1Re0+#0x7ff]
                  GETB      D1.7,[D1Re0+#0x7ff]
                  GETB      A1.7,[A0FrP+#0x7ff]
                  GETB      D1.7,[A0FrP+#0x7ff]
                  GETB      A1.7,[A1LbP+#-0x800]
                  GETB      D1.7,[A1LbP+#-0x800]
                  GETB      A1.7,[D0Re0+#-0x800]
                  GETB      D1.7,[D0Re0+#-0x800]
                  GETB      A1.7,[D1Re0+#-0x800]
                  GETB      D1.7,[D1Re0+#-0x800]
                  GETB      A1.7,[A0FrP+#-0x800]
                  GETB      D1.7,[A0FrP+#-0x800]
                  GETB      A1.7,[A1LbP+#-0x1]
                  GETB      D1.7,[A1LbP+#-0x1]
                  GETB      A1.7,[D0Re0+#-0x1]
                  GETB      D1.7,[D0Re0+#-0x1]
                  GETB      A1.7,[D1Re0+#-0x1]
                  GETB      D1.7,[D1Re0+#-0x1]
                  GETB      A1.7,[A0FrP+#-0x1]
                  GETB      D1.7,[A0FrP+#-0x1]
                  LOCK0
                  MOVT      TXENABLE,#0x8000
                  MOV       TTEXEC,#0xffff
                  MOV       TTCTRL,#0xffff
                  MOV       TTMARK,#0xffff
                  MOV       TTREC,#0xffff
                  MOV       GTEXEC,#0xffff
                  MOV       TXIDLECYC,#0xffff
                  BEXD      D1Re0,D1Re0
                  BEXSD     D1Re0,D1Re0
                  XSDB      D1Re0,D1.7
                  XSDSB     D1Re0,D1.7
                  BEXL      D0Re0,D1.7
                  BEXD      D1.7,D1Re0
                  BEXSD     D1.7,D1Re0
                  XSDB      D1.7,D1.7
                  XSDSB     D1.7,D1.7
                  BEXL      D0.7,D1.7
                  CALLR     D1.7,#+262143
                  CALLR     D1.7,#-262144
                  CALLR     D1.7,#-1
                  JUMP      D1Re0,#-0x8000
                  JUMP      A0FrP,#0x7fff
                  JUMP      A0FrP,#-0x1
                  CALL      D0.7,#0x7fff
                  CALL      D0.7,#-0x8000
                  CALL      D0.7,#-0x1
                  CACHEWL   [D0Re0+#0x0],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x0]
                  CACHEWD   [D0Re0+#0x40],D0Re0
                  DCACHE    [D1Re0+#0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x8]
                  CACHEWL   [D0Re0+#0x80],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x10]
                  CACHEWD   [D0Re0+#0xc0],D0Re0
                  DCACHE    [D1Re0+#0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x18]
                  CACHEWL   [D0Re0+#0x100],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x20]
                  CACHEWD   [D0Re0+#0x140],D0Re0
                  DCACHE    [D1Re0+#0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x28]
                  CACHEWL   [D0Re0+#0x180],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x30]
                  CACHEWD   [D0Re0+#0x1c0],D0Re0
                  DCACHE    [D1Re0+#0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x38]
                  CACHEWL   [D0Re0+#0x200],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x40]
                  CACHEWD   [D0Re0+#0x240],D0Re0
                  DCACHE    [D1Re0+#0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x48]
                  CACHEWL   [D0Re0+#0x280],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x50]
                  CACHEWD   [D0Re0+#0x2c0],D0Re0
                  DCACHE    [D1Re0+#0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x58]
                  CACHEWL   [D0Re0+#0x300],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x60]
                  CACHEWD   [D0Re0+#0x340],D0Re0
                  DCACHE    [D1Re0+#0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x68]
                  CACHEWL   [D0Re0+#0x380],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x70]
                  CACHEWD   [D0Re0+#0x3c0],D0Re0
                  DCACHE    [D1Re0+#0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x78]
                  CACHEWL   [D0Re0+#0x400],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x80]
                  CACHEWD   [D0Re0+#0x440],D0Re0
                  DCACHE    [D1Re0+#0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x88]
                  CACHEWL   [D0Re0+#0x480],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0x90]
                  CACHEWD   [D0Re0+#0x4c0],D0Re0
                  DCACHE    [D1Re0+#0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0x98]
                  CACHEWL   [D0Re0+#0x500],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xa0]
                  CACHEWD   [D0Re0+#0x540],D0Re0
                  DCACHE    [D1Re0+#0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xa8]
                  CACHEWL   [D0Re0+#0x580],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xb0]
                  CACHEWD   [D0Re0+#0x5c0],D0Re0
                  DCACHE    [D1Re0+#0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xb8]
                  CACHEWL   [D0Re0+#0x600],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xc0]
                  CACHEWD   [D0Re0+#0x640],D0Re0
                  DCACHE    [D1Re0+#0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xc8]
                  CACHEWL   [D0Re0+#0x680],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xd0]
                  CACHEWD   [D0Re0+#0x6c0],D0Re0
                  DCACHE    [D1Re0+#0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xd8]
                  CACHEWL   [D0Re0+#0x700],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xe0]
                  CACHEWD   [D0Re0+#0x740],D0Re0
                  DCACHE    [D1Re0+#0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xe8]
                  CACHEWL   [D0Re0+#0x780],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#0xf0]
                  CACHEWD   [D0Re0+#0x7c0],D0Re0
                  DCACHE    [D1Re0+#0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#0xf8]
                  CACHEWL   [D0Re0+#-0x800],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x100]
                  CACHEWD   [D0Re0+#-0x7c0],D0Re0
                  DCACHE    [D1Re0+#-0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xf8]
                  CACHEWL   [D0Re0+#-0x780],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xf0]
                  CACHEWD   [D0Re0+#-0x740],D0Re0
                  DCACHE    [D1Re0+#-0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xe8]
                  CACHEWL   [D0Re0+#-0x700],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xe0]
                  CACHEWD   [D0Re0+#-0x6c0],D0Re0
                  DCACHE    [D1Re0+#-0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xd8]
                  CACHEWL   [D0Re0+#-0x680],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xd0]
                  CACHEWD   [D0Re0+#-0x640],D0Re0
                  DCACHE    [D1Re0+#-0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xc8]
                  CACHEWL   [D0Re0+#-0x600],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xc0]
                  CACHEWD   [D0Re0+#-0x5c0],D0Re0
                  DCACHE    [D1Re0+#-0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xb8]
                  CACHEWL   [D0Re0+#-0x580],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xb0]
                  CACHEWD   [D0Re0+#-0x540],D0Re0
                  DCACHE    [D1Re0+#-0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0xa8]
                  CACHEWL   [D0Re0+#-0x500],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0xa0]
                  CACHEWD   [D0Re0+#-0x4c0],D0Re0
                  DCACHE    [D1Re0+#-0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x98]
                  CACHEWL   [D0Re0+#-0x480],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x90]
                  CACHEWD   [D0Re0+#-0x440],D0Re0
                  DCACHE    [D1Re0+#-0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x88]
                  CACHEWL   [D0Re0+#-0x400],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x80]
                  CACHEWD   [D0Re0+#-0x3c0],D0Re0
                  DCACHE    [D1Re0+#-0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x78]
                  CACHEWL   [D0Re0+#-0x380],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x70]
                  CACHEWD   [D0Re0+#-0x340],D0Re0
                  DCACHE    [D1Re0+#-0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x68]
                  CACHEWL   [D0Re0+#-0x300],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x60]
                  CACHEWD   [D0Re0+#-0x2c0],D0Re0
                  DCACHE    [D1Re0+#-0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x58]
                  CACHEWL   [D0Re0+#-0x280],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x50]
                  CACHEWD   [D0Re0+#-0x240],D0Re0
                  DCACHE    [D1Re0+#-0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x48]
                  CACHEWL   [D0Re0+#-0x200],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x40]
                  CACHEWD   [D0Re0+#-0x1c0],D0Re0
                  DCACHE    [D1Re0+#-0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x38]
                  CACHEWL   [D0Re0+#-0x180],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x30]
                  CACHEWD   [D0Re0+#-0x140],D0Re0
                  DCACHE    [D1Re0+#-0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x28]
                  CACHEWL   [D0Re0+#-0x100],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x20]
                  CACHEWD   [D0Re0+#-0xc0],D0Re0
                  DCACHE    [D1Re0+#-0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x18]
                  CACHEWL   [D0Re0+#-0x80],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[D0Re0+#-0x10]
                  CACHEWD   [D0Re0+#-0x40],D0Re0
                  DCACHE    [D1Re0+#-0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[D1Re0+#-0x8]
                  CACHEWL   [A1LbP+#0x0],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x0]
                  CACHEWD   [A1LbP+#0x40],D0Re0
                  DCACHE    [A0FrP+#0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x8]
                  CACHEWL   [A1LbP+#0x80],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x10]
                  CACHEWD   [A1LbP+#0xc0],D0Re0
                  DCACHE    [A0FrP+#0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x18]
                  CACHEWL   [A1LbP+#0x100],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x20]
                  CACHEWD   [A1LbP+#0x140],D0Re0
                  DCACHE    [A0FrP+#0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x28]
                  CACHEWL   [A1LbP+#0x180],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x30]
                  CACHEWD   [A1LbP+#0x1c0],D0Re0
                  DCACHE    [A0FrP+#0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x38]
                  CACHEWL   [A1LbP+#0x200],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x40]
                  CACHEWD   [A1LbP+#0x240],D0Re0
                  DCACHE    [A0FrP+#0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x48]
                  CACHEWL   [A1LbP+#0x280],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x50]
                  CACHEWD   [A1LbP+#0x2c0],D0Re0
                  DCACHE    [A0FrP+#0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x58]
                  CACHEWL   [A1LbP+#0x300],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x60]
                  CACHEWD   [A1LbP+#0x340],D0Re0
                  DCACHE    [A0FrP+#0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x68]
                  CACHEWL   [A1LbP+#0x380],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x70]
                  CACHEWD   [A1LbP+#0x3c0],D0Re0
                  DCACHE    [A0FrP+#0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x78]
                  CACHEWL   [A1LbP+#0x400],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x80]
                  CACHEWD   [A1LbP+#0x440],D0Re0
                  DCACHE    [A0FrP+#0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x88]
                  CACHEWL   [A1LbP+#0x480],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0x90]
                  CACHEWD   [A1LbP+#0x4c0],D0Re0
                  DCACHE    [A0FrP+#0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0x98]
                  CACHEWL   [A1LbP+#0x500],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xa0]
                  CACHEWD   [A1LbP+#0x540],D0Re0
                  DCACHE    [A0FrP+#0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xa8]
                  CACHEWL   [A1LbP+#0x580],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xb0]
                  CACHEWD   [A1LbP+#0x5c0],D0Re0
                  DCACHE    [A0FrP+#0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xb8]
                  CACHEWL   [A1LbP+#0x600],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xc0]
                  CACHEWD   [A1LbP+#0x640],D0Re0
                  DCACHE    [A0FrP+#0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xc8]
                  CACHEWL   [A1LbP+#0x680],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xd0]
                  CACHEWD   [A1LbP+#0x6c0],D0Re0
                  DCACHE    [A0FrP+#0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xd8]
                  CACHEWL   [A1LbP+#0x700],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xe0]
                  CACHEWD   [A1LbP+#0x740],D0Re0
                  DCACHE    [A0FrP+#0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xe8]
                  CACHEWL   [A1LbP+#0x780],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#0xf0]
                  CACHEWD   [A1LbP+#0x7c0],D0Re0
                  DCACHE    [A0FrP+#0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#0xf8]
                  CACHEWL   [A1LbP+#-0x800],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x100]
                  CACHEWD   [A1LbP+#-0x7c0],D0Re0
                  DCACHE    [A0FrP+#-0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xf8]
                  CACHEWL   [A1LbP+#-0x780],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xf0]
                  CACHEWD   [A1LbP+#-0x740],D0Re0
                  DCACHE    [A0FrP+#-0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xe8]
                  CACHEWL   [A1LbP+#-0x700],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xe0]
                  CACHEWD   [A1LbP+#-0x6c0],D0Re0
                  DCACHE    [A0FrP+#-0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xd8]
                  CACHEWL   [A1LbP+#-0x680],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xd0]
                  CACHEWD   [A1LbP+#-0x640],D0Re0
                  DCACHE    [A0FrP+#-0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xc8]
                  CACHEWL   [A1LbP+#-0x600],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xc0]
                  CACHEWD   [A1LbP+#-0x5c0],D0Re0
                  DCACHE    [A0FrP+#-0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xb8]
                  CACHEWL   [A1LbP+#-0x580],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xb0]
                  CACHEWD   [A1LbP+#-0x540],D0Re0
                  DCACHE    [A0FrP+#-0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0xa8]
                  CACHEWL   [A1LbP+#-0x500],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0xa0]
                  CACHEWD   [A1LbP+#-0x4c0],D0Re0
                  DCACHE    [A0FrP+#-0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x98]
                  CACHEWL   [A1LbP+#-0x480],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x90]
                  CACHEWD   [A1LbP+#-0x440],D0Re0
                  DCACHE    [A0FrP+#-0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x88]
                  CACHEWL   [A1LbP+#-0x400],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x80]
                  CACHEWD   [A1LbP+#-0x3c0],D0Re0
                  DCACHE    [A0FrP+#-0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x78]
                  CACHEWL   [A1LbP+#-0x380],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x70]
                  CACHEWD   [A1LbP+#-0x340],D0Re0
                  DCACHE    [A0FrP+#-0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x68]
                  CACHEWL   [A1LbP+#-0x300],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x60]
                  CACHEWD   [A1LbP+#-0x2c0],D0Re0
                  DCACHE    [A0FrP+#-0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x58]
                  CACHEWL   [A1LbP+#-0x280],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x50]
                  CACHEWD   [A1LbP+#-0x240],D0Re0
                  DCACHE    [A0FrP+#-0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x48]
                  CACHEWL   [A1LbP+#-0x200],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x40]
                  CACHEWD   [A1LbP+#-0x1c0],D0Re0
                  DCACHE    [A0FrP+#-0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x38]
                  CACHEWL   [A1LbP+#-0x180],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x30]
                  CACHEWD   [A1LbP+#-0x140],D0Re0
                  DCACHE    [A0FrP+#-0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x28]
                  CACHEWL   [A1LbP+#-0x100],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x20]
                  CACHEWD   [A1LbP+#-0xc0],D0Re0
                  DCACHE    [A0FrP+#-0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x18]
                  CACHEWL   [A1LbP+#-0x80],D1Re0,D0Re0
                  CACHERL   D0Re0,D1Re0,[A1LbP+#-0x10]
                  CACHEWD   [A1LbP+#-0x40],D0Re0
                  DCACHE    [A0FrP+#-0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[A0FrP+#-0x8]
                  CACHEWL   [A1.7+#0x0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x0],D0Re0
                  DCACHE    [A0.7+#0x0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x0]
                  CACHEWL   [A1.7+#0x40],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x40],D0Re0
                  DCACHE    [A0.7+#0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x8]
                  CACHEWL   [A1.7+#0x80],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x80],D0Re0
                  DCACHE    [A0.7+#0x80],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x10]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x10]
                  CACHEWL   [A1.7+#0xc0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0xc0],D0Re0
                  DCACHE    [A0.7+#0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x18]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x18]
                  CACHEWL   [A1.7+#0x100],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x100],D0Re0
                  DCACHE    [A0.7+#0x100],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x20]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x20]
                  CACHEWL   [A1.7+#0x140],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x140],D0Re0
                  DCACHE    [A0.7+#0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x28]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x28]
                  CACHEWL   [A1.7+#0x180],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x180],D0Re0
                  DCACHE    [A0.7+#0x180],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x30]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x30]
                  CACHEWL   [A1.7+#0x1c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x1c0],D0Re0
                  DCACHE    [A0.7+#0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x38]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x38]
                  CACHEWL   [A1.7+#0x200],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x200],D0Re0
                  DCACHE    [A0.7+#0x200],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x40]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x40]
                  CACHEWL   [A1.7+#0x240],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x240],D0Re0
                  DCACHE    [A0.7+#0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x48]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x48]
                  CACHEWL   [A1.7+#0x280],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x280],D0Re0
                  DCACHE    [A0.7+#0x280],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x50]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x50]
                  CACHEWL   [A1.7+#0x2c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x2c0],D0Re0
                  DCACHE    [A0.7+#0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x58]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x58]
                  CACHEWL   [A1.7+#0x300],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x300],D0Re0
                  DCACHE    [A0.7+#0x300],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x60]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x60]
                  CACHEWL   [A1.7+#0x340],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x340],D0Re0
                  DCACHE    [A0.7+#0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x68]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x68]
                  CACHEWL   [A1.7+#0x380],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x380],D0Re0
                  DCACHE    [A0.7+#0x380],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x70]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x70]
                  CACHEWL   [A1.7+#0x3c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x3c0],D0Re0
                  DCACHE    [A0.7+#0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x78]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x78]
                  CACHEWL   [A1.7+#0x400],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x400],D0Re0
                  DCACHE    [A0.7+#0x400],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x80]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x80]
                  CACHEWL   [A1.7+#0x440],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x440],D0Re0
                  DCACHE    [A0.7+#0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x88]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x88]
                  CACHEWL   [A1.7+#0x480],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x480],D0Re0
                  DCACHE    [A0.7+#0x480],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x90]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x90]
                  CACHEWL   [A1.7+#0x4c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x4c0],D0Re0
                  DCACHE    [A0.7+#0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0x98]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0x98]
                  CACHEWL   [A1.7+#0x500],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x500],D0Re0
                  DCACHE    [A0.7+#0x500],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xa0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xa0]
                  CACHEWL   [A1.7+#0x540],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x540],D0Re0
                  DCACHE    [A0.7+#0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xa8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xa8]
                  CACHEWL   [A1.7+#0x580],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x580],D0Re0
                  DCACHE    [A0.7+#0x580],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xb0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xb0]
                  CACHEWL   [A1.7+#0x5c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x5c0],D0Re0
                  DCACHE    [A0.7+#0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xb8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xb8]
                  CACHEWL   [A1.7+#0x600],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x600],D0Re0
                  DCACHE    [A0.7+#0x600],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xc0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xc0]
                  CACHEWL   [A1.7+#0x640],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x640],D0Re0
                  DCACHE    [A0.7+#0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xc8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xc8]
                  CACHEWL   [A1.7+#0x680],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x680],D0Re0
                  DCACHE    [A0.7+#0x680],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xd0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xd0]
                  CACHEWL   [A1.7+#0x6c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x6c0],D0Re0
                  DCACHE    [A0.7+#0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xd8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xd8]
                  CACHEWL   [A1.7+#0x700],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x700],D0Re0
                  DCACHE    [A0.7+#0x700],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xe0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xe0]
                  CACHEWL   [A1.7+#0x740],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x740],D0Re0
                  DCACHE    [A0.7+#0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xe8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xe8]
                  CACHEWL   [A1.7+#0x780],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x780],D0Re0
                  DCACHE    [A0.7+#0x780],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xf0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xf0]
                  CACHEWL   [A1.7+#0x7c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#0x7c0],D0Re0
                  DCACHE    [A0.7+#0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#0xf8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#0xf8]
                  CACHEWL   [A1.7+#-0x800],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x800],D0Re0
                  DCACHE    [A0.7+#-0x800],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x100]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x100]
                  CACHEWL   [A1.7+#-0x7c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x7c0],D0Re0
                  DCACHE    [A0.7+#-0x7c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xf8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xf8]
                  CACHEWL   [A1.7+#-0x780],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x780],D0Re0
                  DCACHE    [A0.7+#-0x780],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xf0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xf0]
                  CACHEWL   [A1.7+#-0x740],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x740],D0Re0
                  DCACHE    [A0.7+#-0x740],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xe8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xe8]
                  CACHEWL   [A1.7+#-0x700],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x700],D0Re0
                  DCACHE    [A0.7+#-0x700],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xe0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xe0]
                  CACHEWL   [A1.7+#-0x6c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x6c0],D0Re0
                  DCACHE    [A0.7+#-0x6c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xd8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xd8]
                  CACHEWL   [A1.7+#-0x680],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x680],D0Re0
                  DCACHE    [A0.7+#-0x680],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xd0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xd0]
                  CACHEWL   [A1.7+#-0x640],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x640],D0Re0
                  DCACHE    [A0.7+#-0x640],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xc8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xc8]
                  CACHEWL   [A1.7+#-0x600],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x600],D0Re0
                  DCACHE    [A0.7+#-0x600],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xc0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xc0]
                  CACHEWL   [A1.7+#-0x5c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x5c0],D0Re0
                  DCACHE    [A0.7+#-0x5c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xb8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xb8]
                  CACHEWL   [A1.7+#-0x580],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x580],D0Re0
                  DCACHE    [A0.7+#-0x580],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xb0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xb0]
                  CACHEWL   [A1.7+#-0x540],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x540],D0Re0
                  DCACHE    [A0.7+#-0x540],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xa8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xa8]
                  CACHEWL   [A1.7+#-0x500],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x500],D0Re0
                  DCACHE    [A0.7+#-0x500],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0xa0]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0xa0]
                  CACHEWL   [A1.7+#-0x4c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x4c0],D0Re0
                  DCACHE    [A0.7+#-0x4c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x98]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x98]
                  CACHEWL   [A1.7+#-0x480],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x480],D0Re0
                  DCACHE    [A0.7+#-0x480],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x90]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x90]
                  CACHEWL   [A1.7+#-0x440],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x440],D0Re0
                  DCACHE    [A0.7+#-0x440],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x88]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x88]
                  CACHEWL   [A1.7+#-0x400],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x400],D0Re0
                  DCACHE    [A0.7+#-0x400],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x80]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x80]
                  CACHEWL   [A1.7+#-0x3c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x3c0],D0Re0
                  DCACHE    [A0.7+#-0x3c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x78]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x78]
                  CACHEWL   [A1.7+#-0x380],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x380],D0Re0
                  DCACHE    [A0.7+#-0x380],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x70]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x70]
                  CACHEWL   [A1.7+#-0x340],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x340],D0Re0
                  DCACHE    [A0.7+#-0x340],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x68]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x68]
                  CACHEWL   [A1.7+#-0x300],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x300],D0Re0
                  DCACHE    [A0.7+#-0x300],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x60]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x60]
                  CACHEWL   [A1.7+#-0x2c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x2c0],D0Re0
                  DCACHE    [A0.7+#-0x2c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x58]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x58]
                  CACHEWL   [A1.7+#-0x280],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x280],D0Re0
                  DCACHE    [A0.7+#-0x280],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x50]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x50]
                  CACHEWL   [A1.7+#-0x240],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x240],D0Re0
                  DCACHE    [A0.7+#-0x240],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x48]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x48]
                  CACHEWL   [A1.7+#-0x200],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x200],D0Re0
                  DCACHE    [A0.7+#-0x200],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x40]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x40]
                  CACHEWL   [A1.7+#-0x1c0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x1c0],D0Re0
                  DCACHE    [A0.7+#-0x1c0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x38]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x38]
                  CACHEWL   [A1.7+#-0x180],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x180],D0Re0
                  DCACHE    [A0.7+#-0x180],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x30]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x30]
                  CACHEWL   [A1.7+#-0x140],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x140],D0Re0
                  DCACHE    [A0.7+#-0x140],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x28]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x28]
                  CACHEWL   [A1.7+#-0x100],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x100],D0Re0
                  DCACHE    [A0.7+#-0x100],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x20]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x20]
                  CACHEWL   [A1.7+#-0xc0],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0xc0],D0Re0
                  DCACHE    [A0.7+#-0xc0],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x18]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x18]
                  CACHEWL   [A1.7+#-0x80],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x80],D0Re0
                  DCACHE    [A0.7+#-0x80],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x10]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x10]
                  CACHEWL   [A1.7+#-0x40],D1Re0,D0Re0
                  CACHEWD   [D1.7+#-0x40],D0Re0
                  DCACHE    [A0.7+#-0x40],D1Re0
                  CACHERL   D0Re0,D1Re0,[D0.7+#-0x8]
                  CACHERL   D0Re0,D1Re0,[A0.7+#-0x8]
                  CACHEWL   [D0Re0+#0x0],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x0]
                  CACHEWD   [D0Re0+#0x40],A1LbP
                  DCACHE    [D1Re0+#0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x8]
                  CACHEWL   [D0Re0+#0x80],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x10]
                  CACHEWD   [D0Re0+#0xc0],A1LbP
                  DCACHE    [D1Re0+#0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x18]
                  CACHEWL   [D0Re0+#0x100],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x20]
                  CACHEWD   [D0Re0+#0x140],A1LbP
                  DCACHE    [D1Re0+#0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x28]
                  CACHEWL   [D0Re0+#0x180],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x30]
                  CACHEWD   [D0Re0+#0x1c0],A1LbP
                  DCACHE    [D1Re0+#0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x38]
                  CACHEWL   [D0Re0+#0x200],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x40]
                  CACHEWD   [D0Re0+#0x240],A1LbP
                  DCACHE    [D1Re0+#0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x48]
                  CACHEWL   [D0Re0+#0x280],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x50]
                  CACHEWD   [D0Re0+#0x2c0],A1LbP
                  DCACHE    [D1Re0+#0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x58]
                  CACHEWL   [D0Re0+#0x300],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x60]
                  CACHEWD   [D0Re0+#0x340],A1LbP
                  DCACHE    [D1Re0+#0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x68]
                  CACHEWL   [D0Re0+#0x380],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x70]
                  CACHEWD   [D0Re0+#0x3c0],A1LbP
                  DCACHE    [D1Re0+#0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x78]
                  CACHEWL   [D0Re0+#0x400],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x80]
                  CACHEWD   [D0Re0+#0x440],A1LbP
                  DCACHE    [D1Re0+#0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x88]
                  CACHEWL   [D0Re0+#0x480],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0x90]
                  CACHEWD   [D0Re0+#0x4c0],A1LbP
                  DCACHE    [D1Re0+#0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0x98]
                  CACHEWL   [D0Re0+#0x500],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xa0]
                  CACHEWD   [D0Re0+#0x540],A1LbP
                  DCACHE    [D1Re0+#0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xa8]
                  CACHEWL   [D0Re0+#0x580],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xb0]
                  CACHEWD   [D0Re0+#0x5c0],A1LbP
                  DCACHE    [D1Re0+#0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xb8]
                  CACHEWL   [D0Re0+#0x600],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xc0]
                  CACHEWD   [D0Re0+#0x640],A1LbP
                  DCACHE    [D1Re0+#0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xc8]
                  CACHEWL   [D0Re0+#0x680],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xd0]
                  CACHEWD   [D0Re0+#0x6c0],A1LbP
                  DCACHE    [D1Re0+#0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xd8]
                  CACHEWL   [D0Re0+#0x700],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xe0]
                  CACHEWD   [D0Re0+#0x740],A1LbP
                  DCACHE    [D1Re0+#0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xe8]
                  CACHEWL   [D0Re0+#0x780],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#0xf0]
                  CACHEWD   [D0Re0+#0x7c0],A1LbP
                  DCACHE    [D1Re0+#0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#0xf8]
                  CACHEWL   [D0Re0+#-0x800],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x100]
                  CACHEWD   [D0Re0+#-0x7c0],A1LbP
                  DCACHE    [D1Re0+#-0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xf8]
                  CACHEWL   [D0Re0+#-0x780],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xf0]
                  CACHEWD   [D0Re0+#-0x740],A1LbP
                  DCACHE    [D1Re0+#-0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xe8]
                  CACHEWL   [D0Re0+#-0x700],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xe0]
                  CACHEWD   [D0Re0+#-0x6c0],A1LbP
                  DCACHE    [D1Re0+#-0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xd8]
                  CACHEWL   [D0Re0+#-0x680],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xd0]
                  CACHEWD   [D0Re0+#-0x640],A1LbP
                  DCACHE    [D1Re0+#-0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xc8]
                  CACHEWL   [D0Re0+#-0x600],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xc0]
                  CACHEWD   [D0Re0+#-0x5c0],A1LbP
                  DCACHE    [D1Re0+#-0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xb8]
                  CACHEWL   [D0Re0+#-0x580],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xb0]
                  CACHEWD   [D0Re0+#-0x540],A1LbP
                  DCACHE    [D1Re0+#-0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0xa8]
                  CACHEWL   [D0Re0+#-0x500],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0xa0]
                  CACHEWD   [D0Re0+#-0x4c0],A1LbP
                  DCACHE    [D1Re0+#-0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x98]
                  CACHEWL   [D0Re0+#-0x480],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x90]
                  CACHEWD   [D0Re0+#-0x440],A1LbP
                  DCACHE    [D1Re0+#-0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x88]
                  CACHEWL   [D0Re0+#-0x400],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x80]
                  CACHEWD   [D0Re0+#-0x3c0],A1LbP
                  DCACHE    [D1Re0+#-0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x78]
                  CACHEWL   [D0Re0+#-0x380],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x70]
                  CACHEWD   [D0Re0+#-0x340],A1LbP
                  DCACHE    [D1Re0+#-0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x68]
                  CACHEWL   [D0Re0+#-0x300],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x60]
                  CACHEWD   [D0Re0+#-0x2c0],A1LbP
                  DCACHE    [D1Re0+#-0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x58]
                  CACHEWL   [D0Re0+#-0x280],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x50]
                  CACHEWD   [D0Re0+#-0x240],A1LbP
                  DCACHE    [D1Re0+#-0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x48]
                  CACHEWL   [D0Re0+#-0x200],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x40]
                  CACHEWD   [D0Re0+#-0x1c0],A1LbP
                  DCACHE    [D1Re0+#-0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x38]
                  CACHEWL   [D0Re0+#-0x180],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x30]
                  CACHEWD   [D0Re0+#-0x140],A1LbP
                  DCACHE    [D1Re0+#-0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x28]
                  CACHEWL   [D0Re0+#-0x100],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x20]
                  CACHEWD   [D0Re0+#-0xc0],A1LbP
                  DCACHE    [D1Re0+#-0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x18]
                  CACHEWL   [D0Re0+#-0x80],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[D0Re0+#-0x10]
                  CACHEWD   [D0Re0+#-0x40],A1LbP
                  DCACHE    [D1Re0+#-0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[D1Re0+#-0x8]
                  CACHEWL   [A1LbP+#0x0],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x0]
                  CACHEWD   [A1LbP+#0x40],A1LbP
                  DCACHE    [A0FrP+#0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x8]
                  CACHEWL   [A1LbP+#0x80],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x10]
                  CACHEWD   [A1LbP+#0xc0],A1LbP
                  DCACHE    [A0FrP+#0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x18]
                  CACHEWL   [A1LbP+#0x100],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x20]
                  CACHEWD   [A1LbP+#0x140],A1LbP
                  DCACHE    [A0FrP+#0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x28]
                  CACHEWL   [A1LbP+#0x180],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x30]
                  CACHEWD   [A1LbP+#0x1c0],A1LbP
                  DCACHE    [A0FrP+#0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x38]
                  CACHEWL   [A1LbP+#0x200],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x40]
                  CACHEWD   [A1LbP+#0x240],A1LbP
                  DCACHE    [A0FrP+#0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x48]
                  CACHEWL   [A1LbP+#0x280],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x50]
                  CACHEWD   [A1LbP+#0x2c0],A1LbP
                  DCACHE    [A0FrP+#0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x58]
                  CACHEWL   [A1LbP+#0x300],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x60]
                  CACHEWD   [A1LbP+#0x340],A1LbP
                  DCACHE    [A0FrP+#0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x68]
                  CACHEWL   [A1LbP+#0x380],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x70]
                  CACHEWD   [A1LbP+#0x3c0],A1LbP
                  DCACHE    [A0FrP+#0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x78]
                  CACHEWL   [A1LbP+#0x400],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x80]
                  CACHEWD   [A1LbP+#0x440],A1LbP
                  DCACHE    [A0FrP+#0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x88]
                  CACHEWL   [A1LbP+#0x480],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0x90]
                  CACHEWD   [A1LbP+#0x4c0],A1LbP
                  DCACHE    [A0FrP+#0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0x98]
                  CACHEWL   [A1LbP+#0x500],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xa0]
                  CACHEWD   [A1LbP+#0x540],A1LbP
                  DCACHE    [A0FrP+#0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xa8]
                  CACHEWL   [A1LbP+#0x580],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xb0]
                  CACHEWD   [A1LbP+#0x5c0],A1LbP
                  DCACHE    [A0FrP+#0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xb8]
                  CACHEWL   [A1LbP+#0x600],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xc0]
                  CACHEWD   [A1LbP+#0x640],A1LbP
                  DCACHE    [A0FrP+#0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xc8]
                  CACHEWL   [A1LbP+#0x680],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xd0]
                  CACHEWD   [A1LbP+#0x6c0],A1LbP
                  DCACHE    [A0FrP+#0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xd8]
                  CACHEWL   [A1LbP+#0x700],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xe0]
                  CACHEWD   [A1LbP+#0x740],A1LbP
                  DCACHE    [A0FrP+#0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xe8]
                  CACHEWL   [A1LbP+#0x780],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#0xf0]
                  CACHEWD   [A1LbP+#0x7c0],A1LbP
                  DCACHE    [A0FrP+#0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#0xf8]
                  CACHEWL   [A1LbP+#-0x800],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x100]
                  CACHEWD   [A1LbP+#-0x7c0],A1LbP
                  DCACHE    [A0FrP+#-0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xf8]
                  CACHEWL   [A1LbP+#-0x780],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xf0]
                  CACHEWD   [A1LbP+#-0x740],A1LbP
                  DCACHE    [A0FrP+#-0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xe8]
                  CACHEWL   [A1LbP+#-0x700],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xe0]
                  CACHEWD   [A1LbP+#-0x6c0],A1LbP
                  DCACHE    [A0FrP+#-0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xd8]
                  CACHEWL   [A1LbP+#-0x680],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xd0]
                  CACHEWD   [A1LbP+#-0x640],A1LbP
                  DCACHE    [A0FrP+#-0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xc8]
                  CACHEWL   [A1LbP+#-0x600],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xc0]
                  CACHEWD   [A1LbP+#-0x5c0],A1LbP
                  DCACHE    [A0FrP+#-0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xb8]
                  CACHEWL   [A1LbP+#-0x580],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xb0]
                  CACHEWD   [A1LbP+#-0x540],A1LbP
                  DCACHE    [A0FrP+#-0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0xa8]
                  CACHEWL   [A1LbP+#-0x500],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0xa0]
                  CACHEWD   [A1LbP+#-0x4c0],A1LbP
                  DCACHE    [A0FrP+#-0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x98]
                  CACHEWL   [A1LbP+#-0x480],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x90]
                  CACHEWD   [A1LbP+#-0x440],A1LbP
                  DCACHE    [A0FrP+#-0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x88]
                  CACHEWL   [A1LbP+#-0x400],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x80]
                  CACHEWD   [A1LbP+#-0x3c0],A1LbP
                  DCACHE    [A0FrP+#-0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x78]
                  CACHEWL   [A1LbP+#-0x380],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x70]
                  CACHEWD   [A1LbP+#-0x340],A1LbP
                  DCACHE    [A0FrP+#-0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x68]
                  CACHEWL   [A1LbP+#-0x300],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x60]
                  CACHEWD   [A1LbP+#-0x2c0],A1LbP
                  DCACHE    [A0FrP+#-0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x58]
                  CACHEWL   [A1LbP+#-0x280],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x50]
                  CACHEWD   [A1LbP+#-0x240],A1LbP
                  DCACHE    [A0FrP+#-0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x48]
                  CACHEWL   [A1LbP+#-0x200],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x40]
                  CACHEWD   [A1LbP+#-0x1c0],A1LbP
                  DCACHE    [A0FrP+#-0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x38]
                  CACHEWL   [A1LbP+#-0x180],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x30]
                  CACHEWD   [A1LbP+#-0x140],A1LbP
                  DCACHE    [A0FrP+#-0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x28]
                  CACHEWL   [A1LbP+#-0x100],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x20]
                  CACHEWD   [A1LbP+#-0xc0],A1LbP
                  DCACHE    [A0FrP+#-0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x18]
                  CACHEWL   [A1LbP+#-0x80],A0FrP,A1LbP
                  CACHERL   A1LbP,A0FrP,[A1LbP+#-0x10]
                  CACHEWD   [A1LbP+#-0x40],A1LbP
                  DCACHE    [A0FrP+#-0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[A0FrP+#-0x8]
                  CACHEWL   [A1.7+#0x0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x0],A1LbP
                  DCACHE    [A0.7+#0x0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x0]
                  CACHEWL   [A1.7+#0x40],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x40],A1LbP
                  DCACHE    [A0.7+#0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x8]
                  CACHEWL   [A1.7+#0x80],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x80],A1LbP
                  DCACHE    [A0.7+#0x80],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x10]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x10]
                  CACHEWL   [A1.7+#0xc0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0xc0],A1LbP
                  DCACHE    [A0.7+#0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x18]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x18]
                  CACHEWL   [A1.7+#0x100],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x100],A1LbP
                  DCACHE    [A0.7+#0x100],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x20]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x20]
                  CACHEWL   [A1.7+#0x140],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x140],A1LbP
                  DCACHE    [A0.7+#0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x28]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x28]
                  CACHEWL   [A1.7+#0x180],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x180],A1LbP
                  DCACHE    [A0.7+#0x180],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x30]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x30]
                  CACHEWL   [A1.7+#0x1c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x1c0],A1LbP
                  DCACHE    [A0.7+#0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x38]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x38]
                  CACHEWL   [A1.7+#0x200],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x200],A1LbP
                  DCACHE    [A0.7+#0x200],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x40]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x40]
                  CACHEWL   [A1.7+#0x240],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x240],A1LbP
                  DCACHE    [A0.7+#0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x48]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x48]
                  CACHEWL   [A1.7+#0x280],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x280],A1LbP
                  DCACHE    [A0.7+#0x280],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x50]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x50]
                  CACHEWL   [A1.7+#0x2c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x2c0],A1LbP
                  DCACHE    [A0.7+#0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x58]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x58]
                  CACHEWL   [A1.7+#0x300],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x300],A1LbP
                  DCACHE    [A0.7+#0x300],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x60]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x60]
                  CACHEWL   [A1.7+#0x340],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x340],A1LbP
                  DCACHE    [A0.7+#0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x68]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x68]
                  CACHEWL   [A1.7+#0x380],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x380],A1LbP
                  DCACHE    [A0.7+#0x380],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x70]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x70]
                  CACHEWL   [A1.7+#0x3c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x3c0],A1LbP
                  DCACHE    [A0.7+#0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x78]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x78]
                  CACHEWL   [A1.7+#0x400],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x400],A1LbP
                  DCACHE    [A0.7+#0x400],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x80]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x80]
                  CACHEWL   [A1.7+#0x440],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x440],A1LbP
                  DCACHE    [A0.7+#0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x88]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x88]
                  CACHEWL   [A1.7+#0x480],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x480],A1LbP
                  DCACHE    [A0.7+#0x480],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x90]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x90]
                  CACHEWL   [A1.7+#0x4c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x4c0],A1LbP
                  DCACHE    [A0.7+#0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0x98]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0x98]
                  CACHEWL   [A1.7+#0x500],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x500],A1LbP
                  DCACHE    [A0.7+#0x500],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xa0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xa0]
                  CACHEWL   [A1.7+#0x540],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x540],A1LbP
                  DCACHE    [A0.7+#0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xa8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xa8]
                  CACHEWL   [A1.7+#0x580],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x580],A1LbP
                  DCACHE    [A0.7+#0x580],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xb0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xb0]
                  CACHEWL   [A1.7+#0x5c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x5c0],A1LbP
                  DCACHE    [A0.7+#0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xb8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xb8]
                  CACHEWL   [A1.7+#0x600],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x600],A1LbP
                  DCACHE    [A0.7+#0x600],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xc0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xc0]
                  CACHEWL   [A1.7+#0x640],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x640],A1LbP
                  DCACHE    [A0.7+#0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xc8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xc8]
                  CACHEWL   [A1.7+#0x680],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x680],A1LbP
                  DCACHE    [A0.7+#0x680],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xd0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xd0]
                  CACHEWL   [A1.7+#0x6c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x6c0],A1LbP
                  DCACHE    [A0.7+#0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xd8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xd8]
                  CACHEWL   [A1.7+#0x700],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x700],A1LbP
                  DCACHE    [A0.7+#0x700],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xe0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xe0]
                  CACHEWL   [A1.7+#0x740],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x740],A1LbP
                  DCACHE    [A0.7+#0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xe8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xe8]
                  CACHEWL   [A1.7+#0x780],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x780],A1LbP
                  DCACHE    [A0.7+#0x780],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xf0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xf0]
                  CACHEWL   [A1.7+#0x7c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#0x7c0],A1LbP
                  DCACHE    [A0.7+#0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#0xf8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#0xf8]
                  CACHEWL   [A1.7+#-0x800],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x800],A1LbP
                  DCACHE    [A0.7+#-0x800],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x100]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x100]
                  CACHEWL   [A1.7+#-0x7c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x7c0],A1LbP
                  DCACHE    [A0.7+#-0x7c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xf8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xf8]
                  CACHEWL   [A1.7+#-0x780],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x780],A1LbP
                  DCACHE    [A0.7+#-0x780],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xf0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xf0]
                  CACHEWL   [A1.7+#-0x740],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x740],A1LbP
                  DCACHE    [A0.7+#-0x740],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xe8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xe8]
                  CACHEWL   [A1.7+#-0x700],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x700],A1LbP
                  DCACHE    [A0.7+#-0x700],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xe0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xe0]
                  CACHEWL   [A1.7+#-0x6c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x6c0],A1LbP
                  DCACHE    [A0.7+#-0x6c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xd8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xd8]
                  CACHEWL   [A1.7+#-0x680],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x680],A1LbP
                  DCACHE    [A0.7+#-0x680],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xd0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xd0]
                  CACHEWL   [A1.7+#-0x640],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x640],A1LbP
                  DCACHE    [A0.7+#-0x640],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xc8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xc8]
                  CACHEWL   [A1.7+#-0x600],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x600],A1LbP
                  DCACHE    [A0.7+#-0x600],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xc0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xc0]
                  CACHEWL   [A1.7+#-0x5c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x5c0],A1LbP
                  DCACHE    [A0.7+#-0x5c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xb8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xb8]
                  CACHEWL   [A1.7+#-0x580],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x580],A1LbP
                  DCACHE    [A0.7+#-0x580],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xb0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xb0]
                  CACHEWL   [A1.7+#-0x540],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x540],A1LbP
                  DCACHE    [A0.7+#-0x540],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xa8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xa8]
                  CACHEWL   [A1.7+#-0x500],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x500],A1LbP
                  DCACHE    [A0.7+#-0x500],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0xa0]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0xa0]
                  CACHEWL   [A1.7+#-0x4c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x4c0],A1LbP
                  DCACHE    [A0.7+#-0x4c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x98]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x98]
                  CACHEWL   [A1.7+#-0x480],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x480],A1LbP
                  DCACHE    [A0.7+#-0x480],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x90]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x90]
                  CACHEWL   [A1.7+#-0x440],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x440],A1LbP
                  DCACHE    [A0.7+#-0x440],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x88]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x88]
                  CACHEWL   [A1.7+#-0x400],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x400],A1LbP
                  DCACHE    [A0.7+#-0x400],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x80]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x80]
                  CACHEWL   [A1.7+#-0x3c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x3c0],A1LbP
                  DCACHE    [A0.7+#-0x3c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x78]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x78]
                  CACHEWL   [A1.7+#-0x380],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x380],A1LbP
                  DCACHE    [A0.7+#-0x380],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x70]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x70]
                  CACHEWL   [A1.7+#-0x340],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x340],A1LbP
                  DCACHE    [A0.7+#-0x340],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x68]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x68]
                  CACHEWL   [A1.7+#-0x300],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x300],A1LbP
                  DCACHE    [A0.7+#-0x300],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x60]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x60]
                  CACHEWL   [A1.7+#-0x2c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x2c0],A1LbP
                  DCACHE    [A0.7+#-0x2c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x58]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x58]
                  CACHEWL   [A1.7+#-0x280],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x280],A1LbP
                  DCACHE    [A0.7+#-0x280],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x50]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x50]
                  CACHEWL   [A1.7+#-0x240],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x240],A1LbP
                  DCACHE    [A0.7+#-0x240],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x48]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x48]
                  CACHEWL   [A1.7+#-0x200],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x200],A1LbP
                  DCACHE    [A0.7+#-0x200],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x40]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x40]
                  CACHEWL   [A1.7+#-0x1c0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x1c0],A1LbP
                  DCACHE    [A0.7+#-0x1c0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x38]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x38]
                  CACHEWL   [A1.7+#-0x180],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x180],A1LbP
                  DCACHE    [A0.7+#-0x180],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x30]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x30]
                  CACHEWL   [A1.7+#-0x140],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x140],A1LbP
                  DCACHE    [A0.7+#-0x140],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x28]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x28]
                  CACHEWL   [A1.7+#-0x100],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x100],A1LbP
                  DCACHE    [A0.7+#-0x100],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x20]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x20]
                  CACHEWL   [A1.7+#-0xc0],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0xc0],A1LbP
                  DCACHE    [A0.7+#-0xc0],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x18]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x18]
                  CACHEWL   [A1.7+#-0x80],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x80],A1LbP
                  DCACHE    [A0.7+#-0x80],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x10]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x10]
                  CACHEWL   [A1.7+#-0x40],A0FrP,A1LbP
                  CACHEWD   [D1.7+#-0x40],A1LbP
                  DCACHE    [A0.7+#-0x40],A0FrP
                  CACHERL   A1LbP,A0FrP,[D0.7+#-0x8]
                  CACHERL   A1LbP,A0FrP,[A0.7+#-0x8]
                  CACHEWL   [D0Re0+#0x0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x0],A1.7
                  DCACHE    [D1Re0+#0x0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x0]
                  CACHEWL   [D0Re0+#0x40],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x40],A1.7
                  DCACHE    [D1Re0+#0x40],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x8]
                  CACHEWL   [D0Re0+#0x80],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x80],A1.7
                  DCACHE    [D1Re0+#0x80],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x10]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x10]
                  CACHEWL   [D0Re0+#0xc0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0xc0],A1.7
                  DCACHE    [D1Re0+#0xc0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x18]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x18]
                  CACHEWL   [D0Re0+#0x100],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x100],A1.7
                  DCACHE    [D1Re0+#0x100],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x20]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x20]
                  CACHEWL   [D0Re0+#0x140],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x140],A1.7
                  DCACHE    [D1Re0+#0x140],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x28]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x28]
                  CACHEWL   [D0Re0+#0x180],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x180],A1.7
                  DCACHE    [D1Re0+#0x180],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x30]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x30]
                  CACHEWL   [D0Re0+#0x1c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x1c0],A1.7
                  DCACHE    [D1Re0+#0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x38]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x38]
                  CACHEWL   [D0Re0+#0x200],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x200],A1.7
                  DCACHE    [D1Re0+#0x200],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x40]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x40]
                  CACHEWL   [D0Re0+#0x240],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x240],A1.7
                  DCACHE    [D1Re0+#0x240],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x48]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x48]
                  CACHEWL   [D0Re0+#0x280],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x280],A1.7
                  DCACHE    [D1Re0+#0x280],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x50]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x50]
                  CACHEWL   [D0Re0+#0x2c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x2c0],A1.7
                  DCACHE    [D1Re0+#0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x58]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x58]
                  CACHEWL   [D0Re0+#0x300],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x300],A1.7
                  DCACHE    [D1Re0+#0x300],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x60]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x60]
                  CACHEWL   [D0Re0+#0x340],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x340],A1.7
                  DCACHE    [D1Re0+#0x340],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x68]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x68]
                  CACHEWL   [D0Re0+#0x380],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x380],A1.7
                  DCACHE    [D1Re0+#0x380],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x70]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x70]
                  CACHEWL   [D0Re0+#0x3c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x3c0],A1.7
                  DCACHE    [D1Re0+#0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x78]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x78]
                  CACHEWL   [D0Re0+#0x400],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x400],A1.7
                  DCACHE    [D1Re0+#0x400],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x80]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x80]
                  CACHEWL   [D0Re0+#0x440],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x440],A1.7
                  DCACHE    [D1Re0+#0x440],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x88]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x88]
                  CACHEWL   [D0Re0+#0x480],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x480],A1.7
                  DCACHE    [D1Re0+#0x480],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x90]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x90]
                  CACHEWL   [D0Re0+#0x4c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x4c0],A1.7
                  DCACHE    [D1Re0+#0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0x98]
                  CACHERL   D1.7,D0.7,[D1Re0+#0x98]
                  CACHEWL   [D0Re0+#0x500],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x500],A1.7
                  DCACHE    [D1Re0+#0x500],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xa0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xa0]
                  CACHEWL   [D0Re0+#0x540],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x540],A1.7
                  DCACHE    [D1Re0+#0x540],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xa8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xa8]
                  CACHEWL   [D0Re0+#0x580],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x580],A1.7
                  DCACHE    [D1Re0+#0x580],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xb0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xb0]
                  CACHEWL   [D0Re0+#0x5c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x5c0],A1.7
                  DCACHE    [D1Re0+#0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xb8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xb8]
                  CACHEWL   [D0Re0+#0x600],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x600],A1.7
                  DCACHE    [D1Re0+#0x600],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xc0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xc0]
                  CACHEWL   [D0Re0+#0x640],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x640],A1.7
                  DCACHE    [D1Re0+#0x640],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xc8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xc8]
                  CACHEWL   [D0Re0+#0x680],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x680],A1.7
                  DCACHE    [D1Re0+#0x680],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xd0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xd0]
                  CACHEWL   [D0Re0+#0x6c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x6c0],A1.7
                  DCACHE    [D1Re0+#0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xd8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xd8]
                  CACHEWL   [D0Re0+#0x700],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x700],A1.7
                  DCACHE    [D1Re0+#0x700],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xe0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xe0]
                  CACHEWL   [D0Re0+#0x740],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x740],A1.7
                  DCACHE    [D1Re0+#0x740],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xe8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xe8]
                  CACHEWL   [D0Re0+#0x780],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x780],A1.7
                  DCACHE    [D1Re0+#0x780],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xf0]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xf0]
                  CACHEWL   [D0Re0+#0x7c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#0x7c0],A1.7
                  DCACHE    [D1Re0+#0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#0xf8]
                  CACHERL   D1.7,D0.7,[D1Re0+#0xf8]
                  CACHEWL   [D0Re0+#-0x800],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x800],A1.7
                  DCACHE    [D1Re0+#-0x800],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x100]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x100]
                  CACHEWL   [D0Re0+#-0x7c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x7c0],A1.7
                  DCACHE    [D1Re0+#-0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xf8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xf8]
                  CACHEWL   [D0Re0+#-0x780],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x780],A1.7
                  DCACHE    [D1Re0+#-0x780],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xf0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xf0]
                  CACHEWL   [D0Re0+#-0x740],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x740],A1.7
                  DCACHE    [D1Re0+#-0x740],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xe8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xe8]
                  CACHEWL   [D0Re0+#-0x700],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x700],A1.7
                  DCACHE    [D1Re0+#-0x700],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xe0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xe0]
                  CACHEWL   [D0Re0+#-0x6c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x6c0],A1.7
                  DCACHE    [D1Re0+#-0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xd8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xd8]
                  CACHEWL   [D0Re0+#-0x680],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x680],A1.7
                  DCACHE    [D1Re0+#-0x680],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xd0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xd0]
                  CACHEWL   [D0Re0+#-0x640],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x640],A1.7
                  DCACHE    [D1Re0+#-0x640],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xc8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xc8]
                  CACHEWL   [D0Re0+#-0x600],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x600],A1.7
                  DCACHE    [D1Re0+#-0x600],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xc0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xc0]
                  CACHEWL   [D0Re0+#-0x5c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x5c0],A1.7
                  DCACHE    [D1Re0+#-0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xb8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xb8]
                  CACHEWL   [D0Re0+#-0x580],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x580],A1.7
                  DCACHE    [D1Re0+#-0x580],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xb0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xb0]
                  CACHEWL   [D0Re0+#-0x540],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x540],A1.7
                  DCACHE    [D1Re0+#-0x540],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xa8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xa8]
                  CACHEWL   [D0Re0+#-0x500],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x500],A1.7
                  DCACHE    [D1Re0+#-0x500],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0xa0]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0xa0]
                  CACHEWL   [D0Re0+#-0x4c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x4c0],A1.7
                  DCACHE    [D1Re0+#-0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x98]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x98]
                  CACHEWL   [D0Re0+#-0x480],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x480],A1.7
                  DCACHE    [D1Re0+#-0x480],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x90]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x90]
                  CACHEWL   [D0Re0+#-0x440],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x440],A1.7
                  DCACHE    [D1Re0+#-0x440],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x88]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x88]
                  CACHEWL   [D0Re0+#-0x400],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x400],A1.7
                  DCACHE    [D1Re0+#-0x400],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x80]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x80]
                  CACHEWL   [D0Re0+#-0x3c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x3c0],A1.7
                  DCACHE    [D1Re0+#-0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x78]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x78]
                  CACHEWL   [D0Re0+#-0x380],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x380],A1.7
                  DCACHE    [D1Re0+#-0x380],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x70]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x70]
                  CACHEWL   [D0Re0+#-0x340],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x340],A1.7
                  DCACHE    [D1Re0+#-0x340],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x68]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x68]
                  CACHEWL   [D0Re0+#-0x300],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x300],A1.7
                  DCACHE    [D1Re0+#-0x300],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x60]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x60]
                  CACHEWL   [D0Re0+#-0x2c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x2c0],A1.7
                  DCACHE    [D1Re0+#-0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x58]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x58]
                  CACHEWL   [D0Re0+#-0x280],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x280],A1.7
                  DCACHE    [D1Re0+#-0x280],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x50]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x50]
                  CACHEWL   [D0Re0+#-0x240],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x240],A1.7
                  DCACHE    [D1Re0+#-0x240],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x48]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x48]
                  CACHEWL   [D0Re0+#-0x200],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x200],A1.7
                  DCACHE    [D1Re0+#-0x200],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x40]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x40]
                  CACHEWL   [D0Re0+#-0x1c0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x1c0],A1.7
                  DCACHE    [D1Re0+#-0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x38]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x38]
                  CACHEWL   [D0Re0+#-0x180],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x180],A1.7
                  DCACHE    [D1Re0+#-0x180],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x30]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x30]
                  CACHEWL   [D0Re0+#-0x140],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x140],A1.7
                  DCACHE    [D1Re0+#-0x140],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x28]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x28]
                  CACHEWL   [D0Re0+#-0x100],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x100],A1.7
                  DCACHE    [D1Re0+#-0x100],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x20]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x20]
                  CACHEWL   [D0Re0+#-0xc0],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0xc0],A1.7
                  DCACHE    [D1Re0+#-0xc0],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x18]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x18]
                  CACHEWL   [D0Re0+#-0x80],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x80],A1.7
                  DCACHE    [D1Re0+#-0x80],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x10]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x10]
                  CACHEWL   [D0Re0+#-0x40],D0.7,D1.7
                  CACHEWD   [D1Re0+#-0x40],A1.7
                  DCACHE    [D1Re0+#-0x40],A0.7
                  CACHERL   D1.7,D0.7,[D0Re0+#-0x8]
                  CACHERL   D1.7,D0.7,[D1Re0+#-0x8]
                  CACHEWL   [A1LbP+#0x0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x0],A1.7
                  DCACHE    [A0FrP+#0x0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x0]
                  CACHEWL   [A1LbP+#0x40],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x40],A1.7
                  DCACHE    [A0FrP+#0x40],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x8]
                  CACHEWL   [A1LbP+#0x80],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x80],A1.7
                  DCACHE    [A0FrP+#0x80],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x10]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x10]
                  CACHEWL   [A1LbP+#0xc0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0xc0],A1.7
                  DCACHE    [A0FrP+#0xc0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x18]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x18]
                  CACHEWL   [A1LbP+#0x100],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x100],A1.7
                  DCACHE    [A0FrP+#0x100],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x20]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x20]
                  CACHEWL   [A1LbP+#0x140],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x140],A1.7
                  DCACHE    [A0FrP+#0x140],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x28]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x28]
                  CACHEWL   [A1LbP+#0x180],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x180],A1.7
                  DCACHE    [A0FrP+#0x180],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x30]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x30]
                  CACHEWL   [A1LbP+#0x1c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x1c0],A1.7
                  DCACHE    [A0FrP+#0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x38]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x38]
                  CACHEWL   [A1LbP+#0x200],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x200],A1.7
                  DCACHE    [A0FrP+#0x200],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x40]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x40]
                  CACHEWL   [A1LbP+#0x240],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x240],A1.7
                  DCACHE    [A0FrP+#0x240],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x48]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x48]
                  CACHEWL   [A1LbP+#0x280],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x280],A1.7
                  DCACHE    [A0FrP+#0x280],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x50]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x50]
                  CACHEWL   [A1LbP+#0x2c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x2c0],A1.7
                  DCACHE    [A0FrP+#0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x58]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x58]
                  CACHEWL   [A1LbP+#0x300],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x300],A1.7
                  DCACHE    [A0FrP+#0x300],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x60]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x60]
                  CACHEWL   [A1LbP+#0x340],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x340],A1.7
                  DCACHE    [A0FrP+#0x340],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x68]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x68]
                  CACHEWL   [A1LbP+#0x380],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x380],A1.7
                  DCACHE    [A0FrP+#0x380],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x70]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x70]
                  CACHEWL   [A1LbP+#0x3c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x3c0],A1.7
                  DCACHE    [A0FrP+#0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x78]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x78]
                  CACHEWL   [A1LbP+#0x400],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x400],A1.7
                  DCACHE    [A0FrP+#0x400],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x80]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x80]
                  CACHEWL   [A1LbP+#0x440],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x440],A1.7
                  DCACHE    [A0FrP+#0x440],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x88]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x88]
                  CACHEWL   [A1LbP+#0x480],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x480],A1.7
                  DCACHE    [A0FrP+#0x480],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x90]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x90]
                  CACHEWL   [A1LbP+#0x4c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x4c0],A1.7
                  DCACHE    [A0FrP+#0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0x98]
                  CACHERL   D1.7,D0.7,[A0FrP+#0x98]
                  CACHEWL   [A1LbP+#0x500],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x500],A1.7
                  DCACHE    [A0FrP+#0x500],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xa0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xa0]
                  CACHEWL   [A1LbP+#0x540],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x540],A1.7
                  DCACHE    [A0FrP+#0x540],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xa8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xa8]
                  CACHEWL   [A1LbP+#0x580],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x580],A1.7
                  DCACHE    [A0FrP+#0x580],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xb0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xb0]
                  CACHEWL   [A1LbP+#0x5c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x5c0],A1.7
                  DCACHE    [A0FrP+#0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xb8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xb8]
                  CACHEWL   [A1LbP+#0x600],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x600],A1.7
                  DCACHE    [A0FrP+#0x600],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xc0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xc0]
                  CACHEWL   [A1LbP+#0x640],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x640],A1.7
                  DCACHE    [A0FrP+#0x640],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xc8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xc8]
                  CACHEWL   [A1LbP+#0x680],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x680],A1.7
                  DCACHE    [A0FrP+#0x680],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xd0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xd0]
                  CACHEWL   [A1LbP+#0x6c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x6c0],A1.7
                  DCACHE    [A0FrP+#0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xd8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xd8]
                  CACHEWL   [A1LbP+#0x700],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x700],A1.7
                  DCACHE    [A0FrP+#0x700],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xe0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xe0]
                  CACHEWL   [A1LbP+#0x740],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x740],A1.7
                  DCACHE    [A0FrP+#0x740],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xe8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xe8]
                  CACHEWL   [A1LbP+#0x780],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x780],A1.7
                  DCACHE    [A0FrP+#0x780],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xf0]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xf0]
                  CACHEWL   [A1LbP+#0x7c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#0x7c0],A1.7
                  DCACHE    [A0FrP+#0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#0xf8]
                  CACHERL   D1.7,D0.7,[A0FrP+#0xf8]
                  CACHEWL   [A1LbP+#-0x800],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x800],A1.7
                  DCACHE    [A0FrP+#-0x800],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x100]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x100]
                  CACHEWL   [A1LbP+#-0x7c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x7c0],A1.7
                  DCACHE    [A0FrP+#-0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xf8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xf8]
                  CACHEWL   [A1LbP+#-0x780],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x780],A1.7
                  DCACHE    [A0FrP+#-0x780],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xf0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xf0]
                  CACHEWL   [A1LbP+#-0x740],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x740],A1.7
                  DCACHE    [A0FrP+#-0x740],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xe8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xe8]
                  CACHEWL   [A1LbP+#-0x700],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x700],A1.7
                  DCACHE    [A0FrP+#-0x700],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xe0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xe0]
                  CACHEWL   [A1LbP+#-0x6c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x6c0],A1.7
                  DCACHE    [A0FrP+#-0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xd8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xd8]
                  CACHEWL   [A1LbP+#-0x680],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x680],A1.7
                  DCACHE    [A0FrP+#-0x680],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xd0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xd0]
                  CACHEWL   [A1LbP+#-0x640],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x640],A1.7
                  DCACHE    [A0FrP+#-0x640],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xc8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xc8]
                  CACHEWL   [A1LbP+#-0x600],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x600],A1.7
                  DCACHE    [A0FrP+#-0x600],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xc0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xc0]
                  CACHEWL   [A1LbP+#-0x5c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x5c0],A1.7
                  DCACHE    [A0FrP+#-0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xb8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xb8]
                  CACHEWL   [A1LbP+#-0x580],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x580],A1.7
                  DCACHE    [A0FrP+#-0x580],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xb0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xb0]
                  CACHEWL   [A1LbP+#-0x540],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x540],A1.7
                  DCACHE    [A0FrP+#-0x540],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xa8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xa8]
                  CACHEWL   [A1LbP+#-0x500],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x500],A1.7
                  DCACHE    [A0FrP+#-0x500],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0xa0]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0xa0]
                  CACHEWL   [A1LbP+#-0x4c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x4c0],A1.7
                  DCACHE    [A0FrP+#-0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x98]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x98]
                  CACHEWL   [A1LbP+#-0x480],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x480],A1.7
                  DCACHE    [A0FrP+#-0x480],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x90]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x90]
                  CACHEWL   [A1LbP+#-0x440],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x440],A1.7
                  DCACHE    [A0FrP+#-0x440],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x88]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x88]
                  CACHEWL   [A1LbP+#-0x400],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x400],A1.7
                  DCACHE    [A0FrP+#-0x400],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x80]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x80]
                  CACHEWL   [A1LbP+#-0x3c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x3c0],A1.7
                  DCACHE    [A0FrP+#-0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x78]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x78]
                  CACHEWL   [A1LbP+#-0x380],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x380],A1.7
                  DCACHE    [A0FrP+#-0x380],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x70]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x70]
                  CACHEWL   [A1LbP+#-0x340],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x340],A1.7
                  DCACHE    [A0FrP+#-0x340],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x68]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x68]
                  CACHEWL   [A1LbP+#-0x300],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x300],A1.7
                  DCACHE    [A0FrP+#-0x300],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x60]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x60]
                  CACHEWL   [A1LbP+#-0x2c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x2c0],A1.7
                  DCACHE    [A0FrP+#-0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x58]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x58]
                  CACHEWL   [A1LbP+#-0x280],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x280],A1.7
                  DCACHE    [A0FrP+#-0x280],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x50]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x50]
                  CACHEWL   [A1LbP+#-0x240],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x240],A1.7
                  DCACHE    [A0FrP+#-0x240],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x48]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x48]
                  CACHEWL   [A1LbP+#-0x200],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x200],A1.7
                  DCACHE    [A0FrP+#-0x200],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x40]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x40]
                  CACHEWL   [A1LbP+#-0x1c0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x1c0],A1.7
                  DCACHE    [A0FrP+#-0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x38]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x38]
                  CACHEWL   [A1LbP+#-0x180],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x180],A1.7
                  DCACHE    [A0FrP+#-0x180],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x30]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x30]
                  CACHEWL   [A1LbP+#-0x140],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x140],A1.7
                  DCACHE    [A0FrP+#-0x140],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x28]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x28]
                  CACHEWL   [A1LbP+#-0x100],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x100],A1.7
                  DCACHE    [A0FrP+#-0x100],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x20]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x20]
                  CACHEWL   [A1LbP+#-0xc0],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0xc0],A1.7
                  DCACHE    [A0FrP+#-0xc0],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x18]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x18]
                  CACHEWL   [A1LbP+#-0x80],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x80],A1.7
                  DCACHE    [A0FrP+#-0x80],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x10]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x10]
                  CACHEWL   [A1LbP+#-0x40],D0.7,D1.7
                  CACHEWD   [A0FrP+#-0x40],A1.7
                  DCACHE    [A0FrP+#-0x40],A0.7
                  CACHERL   D1.7,D0.7,[A1LbP+#-0x8]
                  CACHERL   D1.7,D0.7,[A0FrP+#-0x8]
                  CACHEWL   [A1.7+#0x0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x0],A1.7
                  DCACHE    [D0.7+#0x0],A0.7
                  CACHEWL   [D1.7+#0x0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x0],A1.7
                  DCACHE    [A0.7+#0x0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x0]
                  CACHERL   D1.7,D0.7,[D0.7+#0x0]
                  CACHERL   D1.7,D0.7,[D1.7+#0x0]
                  CACHERL   D1.7,D0.7,[A0.7+#0x0]
                  CACHEWL   [A1.7+#0x40],D0.7,D1.7
                  CACHEWD   [D0.7+#0x40],A1.7
                  DCACHE    [D0.7+#0x40],A0.7
                  CACHEWL   [D1.7+#0x40],D0.7,D1.7
                  CACHEWD   [A0.7+#0x40],A1.7
                  DCACHE    [A0.7+#0x40],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x8]
                  CACHERL   D1.7,D0.7,[D0.7+#0x8]
                  CACHERL   D1.7,D0.7,[D1.7+#0x8]
                  CACHERL   D1.7,D0.7,[A0.7+#0x8]
                  CACHEWL   [A1.7+#0x80],D0.7,D1.7
                  CACHEWD   [D0.7+#0x80],A1.7
                  DCACHE    [D0.7+#0x80],A0.7
                  CACHEWL   [D1.7+#0x80],D0.7,D1.7
                  CACHEWD   [A0.7+#0x80],A1.7
                  DCACHE    [A0.7+#0x80],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x10]
                  CACHERL   D1.7,D0.7,[D0.7+#0x10]
                  CACHERL   D1.7,D0.7,[D1.7+#0x10]
                  CACHERL   D1.7,D0.7,[A0.7+#0x10]
                  CACHEWL   [A1.7+#0xc0],D0.7,D1.7
                  CACHEWD   [D0.7+#0xc0],A1.7
                  DCACHE    [D0.7+#0xc0],A0.7
                  CACHEWL   [D1.7+#0xc0],D0.7,D1.7
                  CACHEWD   [A0.7+#0xc0],A1.7
                  DCACHE    [A0.7+#0xc0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x18]
                  CACHERL   D1.7,D0.7,[D0.7+#0x18]
                  CACHERL   D1.7,D0.7,[D1.7+#0x18]
                  CACHERL   D1.7,D0.7,[A0.7+#0x18]
                  CACHEWL   [A1.7+#0x100],D0.7,D1.7
                  CACHEWD   [D0.7+#0x100],A1.7
                  DCACHE    [D0.7+#0x100],A0.7
                  CACHEWL   [D1.7+#0x100],D0.7,D1.7
                  CACHEWD   [A0.7+#0x100],A1.7
                  DCACHE    [A0.7+#0x100],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x20]
                  CACHERL   D1.7,D0.7,[D0.7+#0x20]
                  CACHERL   D1.7,D0.7,[D1.7+#0x20]
                  CACHERL   D1.7,D0.7,[A0.7+#0x20]
                  CACHEWL   [A1.7+#0x140],D0.7,D1.7
                  CACHEWD   [D0.7+#0x140],A1.7
                  DCACHE    [D0.7+#0x140],A0.7
                  CACHEWL   [D1.7+#0x140],D0.7,D1.7
                  CACHEWD   [A0.7+#0x140],A1.7
                  DCACHE    [A0.7+#0x140],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x28]
                  CACHERL   D1.7,D0.7,[D0.7+#0x28]
                  CACHERL   D1.7,D0.7,[D1.7+#0x28]
                  CACHERL   D1.7,D0.7,[A0.7+#0x28]
                  CACHEWL   [A1.7+#0x180],D0.7,D1.7
                  CACHEWD   [D0.7+#0x180],A1.7
                  DCACHE    [D0.7+#0x180],A0.7
                  CACHEWL   [D1.7+#0x180],D0.7,D1.7
                  CACHEWD   [A0.7+#0x180],A1.7
                  DCACHE    [A0.7+#0x180],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x30]
                  CACHERL   D1.7,D0.7,[D0.7+#0x30]
                  CACHERL   D1.7,D0.7,[D1.7+#0x30]
                  CACHERL   D1.7,D0.7,[A0.7+#0x30]
                  CACHEWL   [A1.7+#0x1c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x1c0],A1.7
                  DCACHE    [D0.7+#0x1c0],A0.7
                  CACHEWL   [D1.7+#0x1c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x1c0],A1.7
                  DCACHE    [A0.7+#0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x38]
                  CACHERL   D1.7,D0.7,[D0.7+#0x38]
                  CACHERL   D1.7,D0.7,[D1.7+#0x38]
                  CACHERL   D1.7,D0.7,[A0.7+#0x38]
                  CACHEWL   [A1.7+#0x200],D0.7,D1.7
                  CACHEWD   [D0.7+#0x200],A1.7
                  DCACHE    [D0.7+#0x200],A0.7
                  CACHEWL   [D1.7+#0x200],D0.7,D1.7
                  CACHEWD   [A0.7+#0x200],A1.7
                  DCACHE    [A0.7+#0x200],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x40]
                  CACHERL   D1.7,D0.7,[D0.7+#0x40]
                  CACHERL   D1.7,D0.7,[D1.7+#0x40]
                  CACHERL   D1.7,D0.7,[A0.7+#0x40]
                  CACHEWL   [A1.7+#0x240],D0.7,D1.7
                  CACHEWD   [D0.7+#0x240],A1.7
                  DCACHE    [D0.7+#0x240],A0.7
                  CACHEWL   [D1.7+#0x240],D0.7,D1.7
                  CACHEWD   [A0.7+#0x240],A1.7
                  DCACHE    [A0.7+#0x240],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x48]
                  CACHERL   D1.7,D0.7,[D0.7+#0x48]
                  CACHERL   D1.7,D0.7,[D1.7+#0x48]
                  CACHERL   D1.7,D0.7,[A0.7+#0x48]
                  CACHEWL   [A1.7+#0x280],D0.7,D1.7
                  CACHEWD   [D0.7+#0x280],A1.7
                  DCACHE    [D0.7+#0x280],A0.7
                  CACHEWL   [D1.7+#0x280],D0.7,D1.7
                  CACHEWD   [A0.7+#0x280],A1.7
                  DCACHE    [A0.7+#0x280],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x50]
                  CACHERL   D1.7,D0.7,[D0.7+#0x50]
                  CACHERL   D1.7,D0.7,[D1.7+#0x50]
                  CACHERL   D1.7,D0.7,[A0.7+#0x50]
                  CACHEWL   [A1.7+#0x2c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x2c0],A1.7
                  DCACHE    [D0.7+#0x2c0],A0.7
                  CACHEWL   [D1.7+#0x2c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x2c0],A1.7
                  DCACHE    [A0.7+#0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x58]
                  CACHERL   D1.7,D0.7,[D0.7+#0x58]
                  CACHERL   D1.7,D0.7,[D1.7+#0x58]
                  CACHERL   D1.7,D0.7,[A0.7+#0x58]
                  CACHEWL   [A1.7+#0x300],D0.7,D1.7
                  CACHEWD   [D0.7+#0x300],A1.7
                  DCACHE    [D0.7+#0x300],A0.7
                  CACHEWL   [D1.7+#0x300],D0.7,D1.7
                  CACHEWD   [A0.7+#0x300],A1.7
                  DCACHE    [A0.7+#0x300],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x60]
                  CACHERL   D1.7,D0.7,[D0.7+#0x60]
                  CACHERL   D1.7,D0.7,[D1.7+#0x60]
                  CACHERL   D1.7,D0.7,[A0.7+#0x60]
                  CACHEWL   [A1.7+#0x340],D0.7,D1.7
                  CACHEWD   [D0.7+#0x340],A1.7
                  DCACHE    [D0.7+#0x340],A0.7
                  CACHEWL   [D1.7+#0x340],D0.7,D1.7
                  CACHEWD   [A0.7+#0x340],A1.7
                  DCACHE    [A0.7+#0x340],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x68]
                  CACHERL   D1.7,D0.7,[D0.7+#0x68]
                  CACHERL   D1.7,D0.7,[D1.7+#0x68]
                  CACHERL   D1.7,D0.7,[A0.7+#0x68]
                  CACHEWL   [A1.7+#0x380],D0.7,D1.7
                  CACHEWD   [D0.7+#0x380],A1.7
                  DCACHE    [D0.7+#0x380],A0.7
                  CACHEWL   [D1.7+#0x380],D0.7,D1.7
                  CACHEWD   [A0.7+#0x380],A1.7
                  DCACHE    [A0.7+#0x380],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x70]
                  CACHERL   D1.7,D0.7,[D0.7+#0x70]
                  CACHERL   D1.7,D0.7,[D1.7+#0x70]
                  CACHERL   D1.7,D0.7,[A0.7+#0x70]
                  CACHEWL   [A1.7+#0x3c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x3c0],A1.7
                  DCACHE    [D0.7+#0x3c0],A0.7
                  CACHEWL   [D1.7+#0x3c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x3c0],A1.7
                  DCACHE    [A0.7+#0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x78]
                  CACHERL   D1.7,D0.7,[D0.7+#0x78]
                  CACHERL   D1.7,D0.7,[D1.7+#0x78]
                  CACHERL   D1.7,D0.7,[A0.7+#0x78]
                  CACHEWL   [A1.7+#0x400],D0.7,D1.7
                  CACHEWD   [D0.7+#0x400],A1.7
                  DCACHE    [D0.7+#0x400],A0.7
                  CACHEWL   [D1.7+#0x400],D0.7,D1.7
                  CACHEWD   [A0.7+#0x400],A1.7
                  DCACHE    [A0.7+#0x400],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x80]
                  CACHERL   D1.7,D0.7,[D0.7+#0x80]
                  CACHERL   D1.7,D0.7,[D1.7+#0x80]
                  CACHERL   D1.7,D0.7,[A0.7+#0x80]
                  CACHEWL   [A1.7+#0x440],D0.7,D1.7
                  CACHEWD   [D0.7+#0x440],A1.7
                  DCACHE    [D0.7+#0x440],A0.7
                  CACHEWL   [D1.7+#0x440],D0.7,D1.7
                  CACHEWD   [A0.7+#0x440],A1.7
                  DCACHE    [A0.7+#0x440],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x88]
                  CACHERL   D1.7,D0.7,[D0.7+#0x88]
                  CACHERL   D1.7,D0.7,[D1.7+#0x88]
                  CACHERL   D1.7,D0.7,[A0.7+#0x88]
                  CACHEWL   [A1.7+#0x480],D0.7,D1.7
                  CACHEWD   [D0.7+#0x480],A1.7
                  DCACHE    [D0.7+#0x480],A0.7
                  CACHEWL   [D1.7+#0x480],D0.7,D1.7
                  CACHEWD   [A0.7+#0x480],A1.7
                  DCACHE    [A0.7+#0x480],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x90]
                  CACHERL   D1.7,D0.7,[D0.7+#0x90]
                  CACHERL   D1.7,D0.7,[D1.7+#0x90]
                  CACHERL   D1.7,D0.7,[A0.7+#0x90]
                  CACHEWL   [A1.7+#0x4c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x4c0],A1.7
                  DCACHE    [D0.7+#0x4c0],A0.7
                  CACHEWL   [D1.7+#0x4c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x4c0],A1.7
                  DCACHE    [A0.7+#0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0x98]
                  CACHERL   D1.7,D0.7,[D0.7+#0x98]
                  CACHERL   D1.7,D0.7,[D1.7+#0x98]
                  CACHERL   D1.7,D0.7,[A0.7+#0x98]
                  CACHEWL   [A1.7+#0x500],D0.7,D1.7
                  CACHEWD   [D0.7+#0x500],A1.7
                  DCACHE    [D0.7+#0x500],A0.7
                  CACHEWL   [D1.7+#0x500],D0.7,D1.7
                  CACHEWD   [A0.7+#0x500],A1.7
                  DCACHE    [A0.7+#0x500],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xa0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xa0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xa0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xa0]
                  CACHEWL   [A1.7+#0x540],D0.7,D1.7
                  CACHEWD   [D0.7+#0x540],A1.7
                  DCACHE    [D0.7+#0x540],A0.7
                  CACHEWL   [D1.7+#0x540],D0.7,D1.7
                  CACHEWD   [A0.7+#0x540],A1.7
                  DCACHE    [A0.7+#0x540],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xa8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xa8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xa8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xa8]
                  CACHEWL   [A1.7+#0x580],D0.7,D1.7
                  CACHEWD   [D0.7+#0x580],A1.7
                  DCACHE    [D0.7+#0x580],A0.7
                  CACHEWL   [D1.7+#0x580],D0.7,D1.7
                  CACHEWD   [A0.7+#0x580],A1.7
                  DCACHE    [A0.7+#0x580],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xb0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xb0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xb0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xb0]
                  CACHEWL   [A1.7+#0x5c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x5c0],A1.7
                  DCACHE    [D0.7+#0x5c0],A0.7
                  CACHEWL   [D1.7+#0x5c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x5c0],A1.7
                  DCACHE    [A0.7+#0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xb8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xb8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xb8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xb8]
                  CACHEWL   [A1.7+#0x600],D0.7,D1.7
                  CACHEWD   [D0.7+#0x600],A1.7
                  DCACHE    [D0.7+#0x600],A0.7
                  CACHEWL   [D1.7+#0x600],D0.7,D1.7
                  CACHEWD   [A0.7+#0x600],A1.7
                  DCACHE    [A0.7+#0x600],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xc0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xc0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xc0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xc0]
                  CACHEWL   [A1.7+#0x640],D0.7,D1.7
                  CACHEWD   [D0.7+#0x640],A1.7
                  DCACHE    [D0.7+#0x640],A0.7
                  CACHEWL   [D1.7+#0x640],D0.7,D1.7
                  CACHEWD   [A0.7+#0x640],A1.7
                  DCACHE    [A0.7+#0x640],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xc8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xc8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xc8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xc8]
                  CACHEWL   [A1.7+#0x680],D0.7,D1.7
                  CACHEWD   [D0.7+#0x680],A1.7
                  DCACHE    [D0.7+#0x680],A0.7
                  CACHEWL   [D1.7+#0x680],D0.7,D1.7
                  CACHEWD   [A0.7+#0x680],A1.7
                  DCACHE    [A0.7+#0x680],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xd0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xd0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xd0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xd0]
                  CACHEWL   [A1.7+#0x6c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x6c0],A1.7
                  DCACHE    [D0.7+#0x6c0],A0.7
                  CACHEWL   [D1.7+#0x6c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x6c0],A1.7
                  DCACHE    [A0.7+#0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xd8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xd8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xd8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xd8]
                  CACHEWL   [A1.7+#0x700],D0.7,D1.7
                  CACHEWD   [D0.7+#0x700],A1.7
                  DCACHE    [D0.7+#0x700],A0.7
                  CACHEWL   [D1.7+#0x700],D0.7,D1.7
                  CACHEWD   [A0.7+#0x700],A1.7
                  DCACHE    [A0.7+#0x700],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xe0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xe0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xe0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xe0]
                  CACHEWL   [A1.7+#0x740],D0.7,D1.7
                  CACHEWD   [D0.7+#0x740],A1.7
                  DCACHE    [D0.7+#0x740],A0.7
                  CACHEWL   [D1.7+#0x740],D0.7,D1.7
                  CACHEWD   [A0.7+#0x740],A1.7
                  DCACHE    [A0.7+#0x740],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xe8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xe8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xe8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xe8]
                  CACHEWL   [A1.7+#0x780],D0.7,D1.7
                  CACHEWD   [D0.7+#0x780],A1.7
                  DCACHE    [D0.7+#0x780],A0.7
                  CACHEWL   [D1.7+#0x780],D0.7,D1.7
                  CACHEWD   [A0.7+#0x780],A1.7
                  DCACHE    [A0.7+#0x780],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xf0]
                  CACHERL   D1.7,D0.7,[D0.7+#0xf0]
                  CACHERL   D1.7,D0.7,[D1.7+#0xf0]
                  CACHERL   D1.7,D0.7,[A0.7+#0xf0]
                  CACHEWL   [A1.7+#0x7c0],D0.7,D1.7
                  CACHEWD   [D0.7+#0x7c0],A1.7
                  DCACHE    [D0.7+#0x7c0],A0.7
                  CACHEWL   [D1.7+#0x7c0],D0.7,D1.7
                  CACHEWD   [A0.7+#0x7c0],A1.7
                  DCACHE    [A0.7+#0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#0xf8]
                  CACHERL   D1.7,D0.7,[D0.7+#0xf8]
                  CACHERL   D1.7,D0.7,[D1.7+#0xf8]
                  CACHERL   D1.7,D0.7,[A0.7+#0xf8]
                  CACHEWL   [A1.7+#-0x800],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x800],A1.7
                  DCACHE    [D0.7+#-0x800],A0.7
                  CACHEWL   [D1.7+#-0x800],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x800],A1.7
                  DCACHE    [A0.7+#-0x800],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x100]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x100]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x100]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x100]
                  CACHEWL   [A1.7+#-0x7c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x7c0],A1.7
                  DCACHE    [D0.7+#-0x7c0],A0.7
                  CACHEWL   [D1.7+#-0x7c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x7c0],A1.7
                  DCACHE    [A0.7+#-0x7c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xf8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xf8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xf8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xf8]
                  CACHEWL   [A1.7+#-0x780],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x780],A1.7
                  DCACHE    [D0.7+#-0x780],A0.7
                  CACHEWL   [D1.7+#-0x780],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x780],A1.7
                  DCACHE    [A0.7+#-0x780],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xf0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xf0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xf0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xf0]
                  CACHEWL   [A1.7+#-0x740],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x740],A1.7
                  DCACHE    [D0.7+#-0x740],A0.7
                  CACHEWL   [D1.7+#-0x740],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x740],A1.7
                  DCACHE    [A0.7+#-0x740],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xe8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xe8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xe8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xe8]
                  CACHEWL   [A1.7+#-0x700],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x700],A1.7
                  DCACHE    [D0.7+#-0x700],A0.7
                  CACHEWL   [D1.7+#-0x700],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x700],A1.7
                  DCACHE    [A0.7+#-0x700],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xe0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xe0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xe0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xe0]
                  CACHEWL   [A1.7+#-0x6c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x6c0],A1.7
                  DCACHE    [D0.7+#-0x6c0],A0.7
                  CACHEWL   [D1.7+#-0x6c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x6c0],A1.7
                  DCACHE    [A0.7+#-0x6c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xd8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xd8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xd8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xd8]
                  CACHEWL   [A1.7+#-0x680],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x680],A1.7
                  DCACHE    [D0.7+#-0x680],A0.7
                  CACHEWL   [D1.7+#-0x680],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x680],A1.7
                  DCACHE    [A0.7+#-0x680],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xd0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xd0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xd0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xd0]
                  CACHEWL   [A1.7+#-0x640],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x640],A1.7
                  DCACHE    [D0.7+#-0x640],A0.7
                  CACHEWL   [D1.7+#-0x640],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x640],A1.7
                  DCACHE    [A0.7+#-0x640],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xc8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xc8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xc8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xc8]
                  CACHEWL   [A1.7+#-0x600],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x600],A1.7
                  DCACHE    [D0.7+#-0x600],A0.7
                  CACHEWL   [D1.7+#-0x600],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x600],A1.7
                  DCACHE    [A0.7+#-0x600],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xc0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xc0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xc0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xc0]
                  CACHEWL   [A1.7+#-0x5c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x5c0],A1.7
                  DCACHE    [D0.7+#-0x5c0],A0.7
                  CACHEWL   [D1.7+#-0x5c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x5c0],A1.7
                  DCACHE    [A0.7+#-0x5c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xb8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xb8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xb8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xb8]
                  CACHEWL   [A1.7+#-0x580],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x580],A1.7
                  DCACHE    [D0.7+#-0x580],A0.7
                  CACHEWL   [D1.7+#-0x580],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x580],A1.7
                  DCACHE    [A0.7+#-0x580],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xb0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xb0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xb0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xb0]
                  CACHEWL   [A1.7+#-0x540],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x540],A1.7
                  DCACHE    [D0.7+#-0x540],A0.7
                  CACHEWL   [D1.7+#-0x540],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x540],A1.7
                  DCACHE    [A0.7+#-0x540],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xa8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xa8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xa8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xa8]
                  CACHEWL   [A1.7+#-0x500],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x500],A1.7
                  DCACHE    [D0.7+#-0x500],A0.7
                  CACHEWL   [D1.7+#-0x500],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x500],A1.7
                  DCACHE    [A0.7+#-0x500],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0xa0]
                  CACHERL   D1.7,D0.7,[D0.7+#-0xa0]
                  CACHERL   D1.7,D0.7,[D1.7+#-0xa0]
                  CACHERL   D1.7,D0.7,[A0.7+#-0xa0]
                  CACHEWL   [A1.7+#-0x4c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x4c0],A1.7
                  DCACHE    [D0.7+#-0x4c0],A0.7
                  CACHEWL   [D1.7+#-0x4c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x4c0],A1.7
                  DCACHE    [A0.7+#-0x4c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x98]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x98]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x98]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x98]
                  CACHEWL   [A1.7+#-0x480],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x480],A1.7
                  DCACHE    [D0.7+#-0x480],A0.7
                  CACHEWL   [D1.7+#-0x480],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x480],A1.7
                  DCACHE    [A0.7+#-0x480],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x90]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x90]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x90]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x90]
                  CACHEWL   [A1.7+#-0x440],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x440],A1.7
                  DCACHE    [D0.7+#-0x440],A0.7
                  CACHEWL   [D1.7+#-0x440],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x440],A1.7
                  DCACHE    [A0.7+#-0x440],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x88]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x88]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x88]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x88]
                  CACHEWL   [A1.7+#-0x400],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x400],A1.7
                  DCACHE    [D0.7+#-0x400],A0.7
                  CACHEWL   [D1.7+#-0x400],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x400],A1.7
                  DCACHE    [A0.7+#-0x400],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x80]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x80]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x80]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x80]
                  CACHEWL   [A1.7+#-0x3c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x3c0],A1.7
                  DCACHE    [D0.7+#-0x3c0],A0.7
                  CACHEWL   [D1.7+#-0x3c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x3c0],A1.7
                  DCACHE    [A0.7+#-0x3c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x78]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x78]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x78]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x78]
                  CACHEWL   [A1.7+#-0x380],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x380],A1.7
                  DCACHE    [D0.7+#-0x380],A0.7
                  CACHEWL   [D1.7+#-0x380],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x380],A1.7
                  DCACHE    [A0.7+#-0x380],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x70]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x70]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x70]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x70]
                  CACHEWL   [A1.7+#-0x340],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x340],A1.7
                  DCACHE    [D0.7+#-0x340],A0.7
                  CACHEWL   [D1.7+#-0x340],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x340],A1.7
                  DCACHE    [A0.7+#-0x340],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x68]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x68]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x68]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x68]
                  CACHEWL   [A1.7+#-0x300],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x300],A1.7
                  DCACHE    [D0.7+#-0x300],A0.7
                  CACHEWL   [D1.7+#-0x300],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x300],A1.7
                  DCACHE    [A0.7+#-0x300],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x60]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x60]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x60]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x60]
                  CACHEWL   [A1.7+#-0x2c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x2c0],A1.7
                  DCACHE    [D0.7+#-0x2c0],A0.7
                  CACHEWL   [D1.7+#-0x2c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x2c0],A1.7
                  DCACHE    [A0.7+#-0x2c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x58]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x58]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x58]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x58]
                  CACHEWL   [A1.7+#-0x280],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x280],A1.7
                  DCACHE    [D0.7+#-0x280],A0.7
                  CACHEWL   [D1.7+#-0x280],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x280],A1.7
                  DCACHE    [A0.7+#-0x280],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x50]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x50]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x50]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x50]
                  CACHEWL   [A1.7+#-0x240],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x240],A1.7
                  DCACHE    [D0.7+#-0x240],A0.7
                  CACHEWL   [D1.7+#-0x240],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x240],A1.7
                  DCACHE    [A0.7+#-0x240],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x48]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x48]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x48]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x48]
                  CACHEWL   [A1.7+#-0x200],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x200],A1.7
                  DCACHE    [D0.7+#-0x200],A0.7
                  CACHEWL   [D1.7+#-0x200],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x200],A1.7
                  DCACHE    [A0.7+#-0x200],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x40]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x40]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x40]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x40]
                  CACHEWL   [A1.7+#-0x1c0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x1c0],A1.7
                  DCACHE    [D0.7+#-0x1c0],A0.7
                  CACHEWL   [D1.7+#-0x1c0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x1c0],A1.7
                  DCACHE    [A0.7+#-0x1c0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x38]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x38]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x38]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x38]
                  CACHEWL   [A1.7+#-0x180],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x180],A1.7
                  DCACHE    [D0.7+#-0x180],A0.7
                  CACHEWL   [D1.7+#-0x180],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x180],A1.7
                  DCACHE    [A0.7+#-0x180],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x30]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x30]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x30]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x30]
                  CACHEWL   [A1.7+#-0x140],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x140],A1.7
                  DCACHE    [D0.7+#-0x140],A0.7
                  CACHEWL   [D1.7+#-0x140],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x140],A1.7
                  DCACHE    [A0.7+#-0x140],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x28]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x28]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x28]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x28]
                  CACHEWL   [A1.7+#-0x100],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x100],A1.7
                  DCACHE    [D0.7+#-0x100],A0.7
                  CACHEWL   [D1.7+#-0x100],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x100],A1.7
                  DCACHE    [A0.7+#-0x100],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x20]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x20]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x20]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x20]
                  CACHEWL   [A1.7+#-0xc0],D0.7,D1.7
                  CACHEWD   [D0.7+#-0xc0],A1.7
                  DCACHE    [D0.7+#-0xc0],A0.7
                  CACHEWL   [D1.7+#-0xc0],D0.7,D1.7
                  CACHEWD   [A0.7+#-0xc0],A1.7
                  DCACHE    [A0.7+#-0xc0],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x18]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x18]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x18]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x18]
                  CACHEWL   [A1.7+#-0x80],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x80],A1.7
                  DCACHE    [D0.7+#-0x80],A0.7
                  CACHEWL   [D1.7+#-0x80],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x80],A1.7
                  DCACHE    [A0.7+#-0x80],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x10]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x10]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x10]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x10]
                  CACHEWL   [A1.7+#-0x40],D0.7,D1.7
                  CACHEWD   [D0.7+#-0x40],A1.7
                  DCACHE    [D0.7+#-0x40],A0.7
                  CACHEWL   [D1.7+#-0x40],D0.7,D1.7
                  CACHEWD   [A0.7+#-0x40],A1.7
                  DCACHE    [A0.7+#-0x40],A0.7
                  CACHERL   D1.7,D0.7,[A1.7+#-0x8]
                  CACHERL   D1.7,D0.7,[D0.7+#-0x8]
                  CACHERL   D1.7,D0.7,[D1.7+#-0x8]
                  CACHERL   D1.7,D0.7,[A0.7+#-0x8]
                  SETB      [D0Re0++D0Re0],D1Re0
                  SETB      [D1Re0++D1.7],D0Re0
                  SETB      [A1LbP++A1LbP],D1Re0
                  SETB      [A0FrP+A0.7],D0Re0
                  SETB      [A0FrP++A0.7],D1Re0
                  SETB      [A1.7+A1LbP],D0Re0
                  SETB      [A0.7++A0FrP],D0Re0
                  SETB      [A0.7+A0.7],D0Re0
                  SETB      [D1.7++D1.7],D0Re0
                  SETB      [D1Re0+D1Re0],A0FrP
                  SETB      [D1Re0++D1Re0],A1LbP
                  SETB      [D0Re0++D0.7],A1LbP
                  SETB      [A1LbP++A1LbP],A0FrP
                  SETB      [A0FrP++A0.7],A1LbP
                  SETB      [D0.7++D0Re0],A1LbP
                  SETB      [A1.7++A1LbP],A0FrP
                  SETB      [D1.7+D1.7],A1LbP
                  SETB      [D1.7++D1.7],A0FrP
                  SETB      [D0Re0+D0Re0],A1.7
                  SETB      [D0Re0++D0Re0],A1.7
                  SETB      [D0Re0+D0.7],D1.7
                  SETB      [D0Re0++D0.7],A0.7
                  SETB      [D1Re0++D1.7],A1.7
                  SETB      [A1LbP++A1LbP],D0.7
                  SETB      [A0FrP++A0FrP],D1.7
                  SETB      [A0FrP+A0.7],D1.7
                  SETB      [A0FrP++A0.7],D0.7
                  SETB      [D0.7+D0Re0],A1.7
                  SETB      [D0.7++D0Re0],A1.7
                  SETB      [A1.7+A1LbP],D0.7
                  SETB      [A1.7++A1LbP],D1.7
                  SETB      [A0.7++A0FrP],A1.7
                  SETB      [D1.7+D1.7],D0.7
                  SETB      [A1.7++A1.7],D1.7
                  SETB      [D0.7++D0.7],A1.7
                  SETB      [A0.7++A0.7],D0.7
                  SETB      [D0Re0++D0Re0],RD
                  SETB      [D1Re0++D1.7],RD
                  SETB      [A1LbP+A1.7],RD
                  SETB      [D0.7++D0Re0],RD
                  SETB      [A0.7++A0FrP],RD
                  SETB      [D0.7++D0.7],RD
                  SETW      [D0Re0++D0Re0],D1Re0
                  SETW      [D1Re0++D1.7],D0Re0
                  SETW      [A1LbP++A1LbP],D1Re0
                  SETW      [A0FrP+A0.7],D0Re0
                  SETW      [A0FrP++A0.7],D1Re0
                  SETW      [A1.7+A1LbP],D0Re0
                  SETW      [A0.7++A0FrP],D0Re0
                  SETW      [A0.7+A0.7],D0Re0
                  SETW      [D1.7++D1.7],D0Re0
                  SETW      [D1Re0+D1Re0],A0FrP
                  SETW      [D1Re0++D1Re0],A1LbP
                  SETW      [D0Re0++D0.7],A1LbP
                  SETW      [A1LbP++A1LbP],A0FrP
                  SETW      [A0FrP++A0.7],A1LbP
                  SETW      [D0.7++D0Re0],A1LbP
                  SETW      [A1.7++A1LbP],A0FrP
                  SETW      [D1.7+D1.7],A1LbP
                  SETW      [D1.7++D1.7],A0FrP
                  SETW      [D0Re0+D0Re0],A1.7
                  SETW      [D0Re0++D0Re0],A1.7
                  SETW      [D0Re0+D0.7],D1.7
                  SETW      [D0Re0++D0.7],A0.7
                  SETW      [D1Re0++D1.7],A1.7
                  SETW      [A1LbP++A1LbP],D0.7
                  SETW      [A0FrP++A0FrP],D1.7
                  SETW      [A0FrP+A0.7],D1.7
                  SETW      [A0FrP++A0.7],D0.7
                  SETW      [D0.7+D0Re0],A1.7
                  SETW      [D0.7++D0Re0],A1.7
                  SETW      [A1.7+A1LbP],D0.7
                  SETW      [A1.7++A1LbP],D1.7
                  SETW      [A0.7++A0FrP],A1.7
                  SETW      [D1.7+D1.7],D0.7
                  SETW      [A1.7++A1.7],D1.7
                  SETW      [D0.7++D0.7],A1.7
                  SETW      [A0.7++A0.7],D0.7
                  SETW      [D0Re0++D0Re0],RD
                  SETW      [D1Re0++D1.7],RD
                  SETW      [A1LbP+A1.7],RD
                  SETW      [D0.7++D0Re0],RD
                  SETW      [A0.7++A0FrP],RD
                  SETW      [D0.7++D0.7],RD
                  SETB      [D0Re0++#0x1f],D1Re0
                  SETB      [D0Re0++#-0x20],D1Re0
                  SETB      [--D0Re0],D1Re0
                  SETB      [A1LbP++#0x1f],D1Re0
                  SETB      [A1LbP++#-0x20],D1Re0
                  SETB      [--A1LbP],D1Re0
                  SETB      [D0.7+#0x1f],D0Re0
                  SETB      [A1.7++#0x1f],D1Re0
                  SETB      [D1.7++#0x1f],D1Re0
                  SETB      [D0.7+#-0x20],D0Re0
                  SETB      [A1.7++#-0x20],D1Re0
                  SETB      [D1.7++#-0x20],D1Re0
                  SETB      [D0.7+#-0x1],D0Re0
                  SETB      [--A1.7],D1Re0
                  SETB      [--D1.7],D1Re0
                  SETB      [D0Re0++#0x1f],A1LbP
                  SETB      [D0Re0++#-0x20],A1LbP
                  SETB      [--D0Re0],A1LbP
                  SETB      [A1LbP++#0x1f],A1LbP
                  SETB      [A1LbP++#-0x20],A1LbP
                  SETB      [--A1LbP],A1LbP
                  SETB      [D0.7+#0x1f],A0FrP
                  SETB      [A1.7++#0x1f],A1LbP
                  SETB      [D1.7++#0x1f],A1LbP
                  SETB      [D0.7+#-0x20],A0FrP
                  SETB      [A1.7++#-0x20],A1LbP
                  SETB      [D1.7++#-0x20],A1LbP
                  SETB      [D0.7+#-0x1],A0FrP
                  SETB      [--A1.7],A1LbP
                  SETB      [--D1.7],A1LbP
                  SETB      [D0Re0++#0x1f],D1.7
                  SETB      [D1Re0++#0x1f],D1.7
                  SETB      [D0Re0++#-0x20],D1.7
                  SETB      [D1Re0++#-0x20],D1.7
                  SETB      [--D0Re0],D1.7
                  SETB      [--D1Re0],D1.7
                  SETB      [A1LbP++#0x1f],D1.7
                  SETB      [A0FrP++#0x1f],D1.7
                  SETB      [A1LbP++#-0x20],D1.7
                  SETB      [A0FrP++#-0x20],D1.7
                  SETB      [--A1LbP],D1.7
                  SETB      [--A0FrP],D1.7
                  SETB      [A1.7+#0x1f],A0.7
                  SETB      [D1.7+#0x1f],A0.7
                  SETB      [A1.7++#0x1f],D1.7
                  SETB      [D0.7++#0x1f],D1.7
                  SETB      [D1.7++#0x1f],D1.7
                  SETB      [A0.7++#0x1f],D1.7
                  SETB      [A1.7+#-0x20],A0.7
                  SETB      [D1.7+#-0x20],A0.7
                  SETB      [A1.7++#-0x20],D1.7
                  SETB      [D0.7++#-0x20],D1.7
                  SETB      [D1.7++#-0x20],D1.7
                  SETB      [A0.7++#-0x20],D1.7
                  SETB      [A1.7+#-0x1],A0.7
                  SETB      [D1.7+#-0x1],A0.7
                  SETB      [--A1.7],D1.7
                  SETB      [--D0.7],D1.7
                  SETB      [--D1.7],D1.7
                  SETB      [--A0.7],D1.7
                  SETB      [D0Re0++#0x1f],RD
                  SETB      [D1Re0++#-0x20],RD
                  SETB      [A1LbP+#0x1f],RD
                  SETB      [A1LbP++#-0x20],RD
                  SETB      [--A0FrP],RD
                  SETB      [D0.7++#0x1f],RD
                  SETB      [D1.7+#-0x20],RD
                  SETB      [A0.7++#-0x20],RD
                  SETB      [--D0.7],RD
                  SETW      [D0Re0++#0x3e],D1Re0
                  SETW      [D0Re0++#-0x40],D1Re0
                  SETW      [--D0Re0],D1Re0
                  SETW      [A1LbP++#0x3e],D1Re0
                  SETW      [A1LbP++#-0x40],D1Re0
                  SETW      [--A1LbP],D1Re0
                  SETW      [D0.7+#0x3e],D0Re0
                  SETW      [A1.7++#0x3e],D1Re0
                  SETW      [D1.7++#0x3e],D1Re0
                  SETW      [D0.7+#-0x40],D0Re0
                  SETW      [A1.7++#-0x40],D1Re0
                  SETW      [D1.7++#-0x40],D1Re0
                  SETW      [D0.7+#-0x2],D0Re0
                  SETW      [--A1.7],D1Re0
                  SETW      [--D1.7],D1Re0
                  SETW      [D0Re0++#0x3e],A1LbP
                  SETW      [D0Re0++#-0x40],A1LbP
                  SETW      [--D0Re0],A1LbP
                  SETW      [A1LbP++#0x3e],A1LbP
                  SETW      [A1LbP++#-0x40],A1LbP
                  SETW      [--A1LbP],A1LbP
                  SETW      [D0.7+#0x3e],A0FrP
                  SETW      [A1.7++#0x3e],A1LbP
                  SETW      [D1.7++#0x3e],A1LbP
                  SETW      [D0.7+#-0x40],A0FrP
                  SETW      [A1.7++#-0x40],A1LbP
                  SETW      [D1.7++#-0x40],A1LbP
                  SETW      [D0.7+#-0x2],A0FrP
                  SETW      [--A1.7],A1LbP
                  SETW      [--D1.7],A1LbP
                  SETW      [D0Re0++#0x3e],D1.7
                  SETW      [D1Re0++#0x3e],D1.7
                  SETW      [D0Re0++#-0x40],D1.7
                  SETW      [D1Re0++#-0x40],D1.7
                  SETW      [--D0Re0],D1.7
                  SETW      [--D1Re0],D1.7
                  SETW      [A1LbP++#0x3e],D1.7
                  SETW      [A0FrP++#0x3e],D1.7
                  SETW      [A1LbP++#-0x40],D1.7
                  SETW      [A0FrP++#-0x40],D1.7
                  SETW      [--A1LbP],D1.7
                  SETW      [--A0FrP],D1.7
                  SETW      [A1.7+#0x3e],A0.7
                  SETW      [D1.7+#0x3e],A0.7
                  SETW      [A1.7++#0x3e],D1.7
                  SETW      [D0.7++#0x3e],D1.7
                  SETW      [D1.7++#0x3e],D1.7
                  SETW      [A0.7++#0x3e],D1.7
                  SETW      [A1.7+#-0x40],A0.7
                  SETW      [D1.7+#-0x40],A0.7
                  SETW      [A1.7++#-0x40],D1.7
                  SETW      [D0.7++#-0x40],D1.7
                  SETW      [D1.7++#-0x40],D1.7
                  SETW      [A0.7++#-0x40],D1.7
                  SETW      [A1.7+#-0x2],A0.7
                  SETW      [D1.7+#-0x2],A0.7
                  SETW      [--A1.7],D1.7
                  SETW      [--D0.7],D1.7
                  SETW      [--D1.7],D1.7
                  SETW      [--A0.7],D1.7
                  SETW      [D0Re0++#0x3e],RD
                  SETW      [D1Re0++#-0x40],RD
                  SETW      [A1LbP+#0x3e],RD
                  SETW      [A1LbP++#-0x40],RD
                  SETW      [--A0FrP],RD
                  SETW      [D0.7++#0x3e],RD
                  SETW      [D1.7+#-0x40],RD
                  SETW      [A0.7++#-0x40],RD
                  SETW      [--D0.7],RD
                  SETD      [D0Re0+D0Re0],PC
                  SETD      [D0Re0++D0Re0],TXENABLE
                  SETD      [D0Re0++D0Re0],TTEXEC
                  SETD      [D1Re0++D1Re0],TXSTAT
                  SETD      [D0Re0+D0.7],TTEXEC
                  SETD      [D0Re0++D0.7],D1Re0
                  SETD      [D1Re0++D1.7],TXENABLE
                  SETD      [D1Re0++D1.7],TTEXEC
                  SETD      [A0FrP+A0FrP],TXENABLE
                  SETD      [A1LbP++A1LbP],D0Re0
                  SETD      [A1LbP++A1LbP],TTEXEC
                  SETD      [A0FrP++A0FrP],PC
                  SETD      [A1LbP+A1.7],D1Re0
                  SETD      [A0FrP+A0.7],TXSTAT
                  SETD      [A1LbP++A1.7],PC
                  SETD      [A0FrP++A0.7],D0Re0
                  SETD      [A0FrP++A0.7],TTEXEC
                  SETD      [D1.7+D1Re0],D0Re0
                  SETD      [D0.7++D0Re0],PC
                  SETD      [D1.7++D1Re0],D0Re0
                  SETD      [A1.7+A1LbP],TXENABLE
                  SETD      [A0.7+A0FrP],D1Re0
                  SETD      [A1.7++A1LbP],D1Re0
                  SETD      [A0.7++A0FrP],TXENABLE
                  SETD      [A0.7++A0FrP],TXSTAT
                  SETD      [A1.7+A1.7],TXSTAT
                  SETD      [D1.7+D1.7],D0Re0
                  SETD      [A0.7+A0.7],TXSTAT
                  SETD      [A1.7++A1.7],PC
                  SETD      [D0.7++D0.7],D1Re0
                  SETD      [D1.7++D1.7],TXENABLE
                  SETD      [D1.7++D1.7],TTEXEC
                  SETD      [A0.7++A0.7],PC
                  SETD      [D0Re0+D0Re0],PCX
                  SETD      [D0Re0++D0Re0],A1LbP
                  SETD      [D1Re0++D1Re0],A1LbP
                  SETD      [D0Re0+D0.7],PCX
                  SETD      [D0Re0++D0.7],A1LbP
                  SETD      [D1Re0++D1.7],A1LbP
                  SETD      [A1LbP+A1LbP],TTCTRL
                  SETD      [A1LbP++A1LbP],TTCTRL
                  SETD      [A1LbP+A1.7],A0FrP
                  SETD      [A1LbP++A1.7],PCX
                  SETD      [A0FrP++A0.7],TTCTRL
                  SETD      [D1.7+D1Re0],PCX
                  SETD      [D0.7++D0Re0],TTCTRL
                  SETD      [D1.7++D1Re0],TTCTRL
                  SETD      [A1.7++A1LbP],A0FrP
                  SETD      [A0.7++A0FrP],PCX
                  SETD      [D0.7+D0.7],A1LbP
                  SETD      [A0.7+A0.7],PCX
                  SETD      [D0.7++D0.7],A0FrP
                  SETD      [D1.7++D1.7],A0FrP
                  SETD      [A0.7++A0.7],A1LbP
                  SETD      [D0Re0++D0Re0],TTMARK
                  SETD      [D1Re0++D1.7],TTMARK
                  SETD      [A1LbP+A1.7],TTMARK
                  SETD      [D0.7++D0Re0],TTMARK
                  SETD      [A0.7++A0FrP],TTMARK
                  SETD      [D0.7++D0.7],TTMARK
                  SETD      [D1Re0+D1Re0],TXMASKI
                  SETD      [D1Re0++D1Re0],TTREC
                  SETD      [D0Re0++D0.7],TTREC
                  SETD      [A0FrP+A0FrP],TXMASKI
                  SETD      [A0FrP++A0FrP],TTREC
                  SETD      [A1LbP++A1.7],TTREC
                  SETD      [D1.7+D1Re0],TXMASKI
                  SETD      [D1.7++D1Re0],TTREC
                  SETD      [A1.7++A1LbP],TTREC
                  SETD      [D0.7+D0.7],TXMASKI
                  SETD      [A1.7++A1.7],TTREC
                  SETD      [D1.7++D1.7],TTREC
                  SETD      [D0Re0++D0Re0],GTEXEC
                  SETD      [D1Re0++D1.7],GTEXEC
                  SETD      [A1LbP+A1.7],GTEXEC
                  SETD      [D0.7++D0Re0],GTEXEC
                  SETD      [A0.7++A0FrP],GTEXEC
                  SETD      [D0.7++D0.7],GTEXEC
                  SETD      [D0Re0++D0Re0],TXGPIOI
                  SETD      [D1Re0++D1.7],TXGPIOI
                  SETD      [A1LbP+A1.7],TXGPIOI
                  SETD      [D0.7++D0Re0],TXGPIOI
                  SETD      [A0.7++A0FrP],TXGPIOI
                  SETD      [D0.7++D0.7],TXGPIOI
                  SETD      [D0Re0++D0Re0],TXPOLLI
                  SETD      [D1Re0++D1.7],TXPOLLI
                  SETD      [A1LbP+A1.7],TXPOLLI
                  SETD      [D0.7++D0Re0],TXPOLLI
                  SETD      [A0.7++A0FrP],TXPOLLI
                  SETD      [D0.7++D0.7],TXPOLLI
                  SETD      [D0Re0+D0Re0],A1.7
                  SETD      [D0Re0++D0Re0],A0.7
                  SETD      [D1Re0++D1Re0],A0.7
                  SETD      [D0Re0+D0.7],A1.7
                  SETD      [D0Re0++D0.7],A0.7
                  SETD      [D1Re0++D1.7],A0.7
                  SETD      [A1LbP+A1LbP],A0.7
                  SETD      [A1LbP++A1LbP],D1.7
                  SETD      [A0FrP++A0FrP],D1.7
                  SETD      [A1LbP+A1.7],A0.7
                  SETD      [A1LbP++A1.7],D1.7
                  SETD      [A0FrP++A0.7],D1.7
                  SETD      [D0.7+D0Re0],A1.7
                  SETD      [D0.7++D0Re0],A0.7
                  SETD      [D1.7++D1Re0],A0.7
                  SETD      [A1.7+A1LbP],A0.7
                  SETD      [A1.7++A1LbP],D1.7
                  SETD      [A0.7++A0FrP],D1.7
                  SETD      [A1.7+A1.7],A0.7
                  SETD      [D1.7+D1.7],A1.7
                  SETD      [A1.7++A1.7],D1.7
                  SETD      [D0.7++D0.7],A0.7
                  SETD      [D1.7++D1.7],A0.7
                  SETD      [A0.7++A0.7],D1.7
                  SETD      [D0Re0+D0Re0],RD
                  SETD      [D0Re0++D0Re0],RD
                  SETD      [D0Re0+D0.7],CPC0
                  SETD      [D0Re0++D0.7],CPC1
                  SETD      [D1Re0++D1.7],RD
                  SETD      [A1LbP++A1LbP],RD
                  SETD      [A0FrP+A0.7],CPC1
                  SETD      [A0FrP++A0.7],RD
                  SETD      [D0.7++D0Re0],CPC0
                  SETD      [D1.7++D1Re0],CPC1
                  SETD      [A1.7++A1LbP],CPC0
                  SETD      [A1.7+A1.7],CPC0
                  SETD      [A0.7+A0.7],CPC1
                  SETD      [D0.7++D0.7],CPC1
                  SETD      [D1.7++D1.7],RD
                  SETD      [D0Re0++D0Re0],TXIDLECYC
                  SETD      [D1Re0++D1.7],TXIDLECYC
                  SETD      [A1LbP+A1.7],TXIDLECYC
                  SETD      [D0.7++D0Re0],TXIDLECYC
                  SETD      [A0.7++A0FrP],TXIDLECYC
                  SETD      [D0.7++D0.7],TXIDLECYC
                  SETL      [A0FrP+A0FrP],D0Re0,D1Re0
                  SETL      [A0FrP++A0FrP],D1Re0,D0Re0
                  SETL      [A1LbP++A1.7],D1Re0,D0Re0
                  SETL      [A0.7+A0FrP],D0Re0,D1Re0
                  SETL      [A0.7++A0FrP],D1Re0,D0Re0
                  SETL      [A1.7++A1.7],D1Re0,D0Re0
                  SETL      [D1Re0+D1Re0],A0FrP,A1LbP
                  SETL      [D1Re0++D1Re0],A1LbP,A0FrP
                  SETL      [D0Re0++D0.7],A1LbP,A0FrP
                  SETL      [D1.7+D1Re0],A0FrP,A1LbP
                  SETL      [D1.7++D1Re0],A1LbP,A0FrP
                  SETL      [D0.7++D0.7],A1LbP,A0FrP
                  SETL      [D1Re0+D1Re0],A0.7,A1.7
                  SETL      [D1Re0++D1Re0],A1.7,A0.7
                  SETL      [D0Re0++D0.7],A1.7,A0.7
                  SETL      [A0FrP+A0FrP],D0.7,D1.7
                  SETL      [A0FrP++A0FrP],D1.7,D0.7
                  SETL      [A1LbP++A1.7],D1.7,D0.7
                  SETL      [D1.7+D1Re0],A0.7,A1.7
                  SETL      [D1.7++D1Re0],A1.7,A0.7
                  SETL      [A1.7++A1LbP],D1.7,D0.7
                  SETL      [D0.7+D0.7],A0.7,A1.7
                  SETL      [A1.7++A1.7],D1.7,D0.7
                  SETL      [D1.7++D1.7],A1.7,A0.7
                  SETL      [D0Re0++D0Re0],RD
                  SETL      [D1Re0++D1.7],RD
                  SETL      [A1LbP+A1.7],RD
                  SETL      [D0.7++D0Re0],RD
                  SETL      [A0.7++A0FrP],RD
                  SETL      [D0.7++D0.7],RD
                  SETD      [D0Re0+#0x7c],TXSTAT
                  SETD      [D0Re0++#0x7c],D0Re0
                  SETD      [D0Re0++#0x7c],TTEXEC
                  SETD      [D1Re0++#0x7c],PC
                  SETD      [D0Re0+#-0x80],TXSTAT
                  SETD      [D0Re0++#-0x80],D0Re0
                  SETD      [D0Re0++#-0x80],TTEXEC
                  SETD      [D1Re0++#-0x80],PC
                  SETD      [D0Re0+#-0x4],TXSTAT
                  SETD      [--D0Re0],D0Re0
                  SETD      [--D0Re0],TTEXEC
                  SETD      [--D1Re0],PC
                  SETD      [A1LbP+#0x7c],TXSTAT
                  SETD      [A1LbP++#0x7c],D0Re0
                  SETD      [A1LbP++#0x7c],TTEXEC
                  SETD      [A0FrP++#0x7c],PC
                  SETD      [A1LbP+#-0x80],TXSTAT
                  SETD      [A1LbP++#-0x80],D0Re0
                  SETD      [A1LbP++#-0x80],TTEXEC
                  SETD      [A0FrP++#-0x80],PC
                  SETD      [A1LbP+#-0x4],TXSTAT
                  SETD      [--A1LbP],D0Re0
                  SETD      [--A1LbP],TTEXEC
                  SETD      [--A0FrP],PC
                  SETD      [A1.7+#0x7c],D1Re0
                  SETD      [D0.7+#0x7c],TXSTAT
                  SETD      [A0.7+#0x7c],TXENABLE
                  SETD      [A1.7++#0x7c],D0Re0
                  SETD      [A1.7++#0x7c],TTEXEC
                  SETD      [D0.7++#0x7c],PC
                  SETD      [D1.7++#0x7c],D0Re0
                  SETD      [D1.7++#0x7c],TTEXEC
                  SETD      [A0.7++#0x7c],PC
                  SETD      [A1.7+#-0x80],D1Re0
                  SETD      [D0.7+#-0x80],TXSTAT
                  SETD      [A0.7+#-0x80],TXENABLE
                  SETD      [A1.7++#-0x80],D0Re0
                  SETD      [A1.7++#-0x80],TTEXEC
                  SETD      [D0.7++#-0x80],PC
                  SETD      [D1.7++#-0x80],D0Re0
                  SETD      [D1.7++#-0x80],TTEXEC
                  SETD      [A0.7++#-0x80],PC
                  SETD      [A1.7+#-0x4],D1Re0
                  SETD      [D0.7+#-0x4],TXSTAT
                  SETD      [A0.7+#-0x4],TXENABLE
                  SETD      [--A1.7],D0Re0
                  SETD      [--A1.7],TTEXEC
                  SETD      [--D0.7],PC
                  SETD      [--D1.7],D0Re0
                  SETD      [--D1.7],TTEXEC
                  SETD      [--A0.7],PC
                  SETD      [D1Re0+#0x7c],PCX
                  SETD      [D0Re0++#0x7c],TTCTRL
                  SETD      [D1Re0++#0x7c],TTCTRL
                  SETD      [D0Re0++#-0x80],A1LbP
                  SETD      [D1Re0++#-0x80],A1LbP
                  SETD      [D1Re0+#-0x4],PCX
                  SETD      [--D0Re0],TTCTRL
                  SETD      [--D1Re0],TTCTRL
                  SETD      [A1LbP++#0x7c],A1LbP
                  SETD      [A0FrP++#0x7c],A1LbP
                  SETD      [A0FrP+#-0x80],PCX
                  SETD      [A1LbP++#-0x80],TTCTRL
                  SETD      [A0FrP++#-0x80],TTCTRL
                  SETD      [--A1LbP],A1LbP
                  SETD      [--A0FrP],A1LbP
                  SETD      [A1.7+#0x7c],PCX
                  SETD      [D1.7+#0x7c],PCX
                  SETD      [A1.7++#0x7c],A1LbP
                  SETD      [D0.7++#0x7c],A1LbP
                  SETD      [D1.7++#0x7c],A1LbP
                  SETD      [A0.7++#0x7c],A1LbP
                  SETD      [A1.7+#-0x80],PCX
                  SETD      [D1.7+#-0x80],PCX
                  SETD      [A1.7++#-0x80],A1LbP
                  SETD      [D0.7++#-0x80],A1LbP
                  SETD      [D1.7++#-0x80],A1LbP
                  SETD      [A0.7++#-0x80],A1LbP
                  SETD      [A1.7+#-0x4],PCX
                  SETD      [D1.7+#-0x4],PCX
                  SETD      [--A1.7],A1LbP
                  SETD      [--D0.7],A1LbP
                  SETD      [--D1.7],A1LbP
                  SETD      [--A0.7],A1LbP
                  SETD      [D0Re0++#0x7c],TTMARK
                  SETD      [D1Re0++#-0x80],TTMARK
                  SETD      [A1LbP+#0x7c],TTMARK
                  SETD      [A1LbP++#-0x80],TTMARK
                  SETD      [--A0FrP],TTMARK
                  SETD      [D0.7++#0x7c],TTMARK
                  SETD      [D1.7+#-0x80],TTMARK
                  SETD      [A0.7++#-0x80],TTMARK
                  SETD      [--D0.7],TTMARK
                  SETD      [D1Re0+#0x7c],TXMASKI
                  SETD      [D1Re0++#0x7c],TTREC
                  SETD      [D0Re0++#-0x80],TTREC
                  SETD      [D1Re0+#-0x4],TXMASKI
                  SETD      [--D1Re0],TTREC
                  SETD      [A1LbP++#0x7c],TTREC
                  SETD      [A0FrP+#-0x80],TXMASKI
                  SETD      [A0FrP++#-0x80],TTREC
                  SETD      [--A1LbP],TTREC
                  SETD      [D0.7+#0x7c],TXMASKI
                  SETD      [A1.7++#0x7c],TTREC
                  SETD      [D1.7++#0x7c],TTREC
                  SETD      [D0.7+#-0x80],TXMASKI
                  SETD      [A1.7++#-0x80],TTREC
                  SETD      [D1.7++#-0x80],TTREC
                  SETD      [D0.7+#-0x4],TXMASKI
                  SETD      [--A1.7],TTREC
                  SETD      [--D1.7],TTREC
                  SETD      [D0Re0++#0x7c],GTEXEC
                  SETD      [D1Re0++#-0x80],GTEXEC
                  SETD      [A1LbP+#0x7c],GTEXEC
                  SETD      [A1LbP++#-0x80],GTEXEC
                  SETD      [--A0FrP],GTEXEC
                  SETD      [D0.7++#0x7c],GTEXEC
                  SETD      [D1.7+#-0x80],GTEXEC
                  SETD      [A0.7++#-0x80],GTEXEC
                  SETD      [--D0.7],GTEXEC
                  SETD      [D0Re0++#0x7c],TXGPIOI
                  SETD      [D1Re0++#-0x80],TXGPIOI
                  SETD      [A1LbP+#0x7c],TXGPIOI
                  SETD      [A1LbP++#-0x80],TXGPIOI
                  SETD      [--A0FrP],TXGPIOI
                  SETD      [D0.7++#0x7c],TXGPIOI
                  SETD      [D1.7+#-0x80],TXGPIOI
                  SETD      [A0.7++#-0x80],TXGPIOI
                  SETD      [--D0.7],TXGPIOI
                  SETD      [D0Re0++#0x7c],TXPOLLI
                  SETD      [D1Re0++#-0x80],TXPOLLI
                  SETD      [A1LbP+#0x7c],TXPOLLI
                  SETD      [A1LbP++#-0x80],TXPOLLI
                  SETD      [--A0FrP],TXPOLLI
                  SETD      [D0.7++#0x7c],TXPOLLI
                  SETD      [D1.7+#-0x80],TXPOLLI
                  SETD      [A0.7++#-0x80],TXPOLLI
                  SETD      [--D0.7],TXPOLLI
                  SETD      [D0Re0++#0x7c],D0.7
                  SETD      [D0Re0++#0x7c],TXGPIOO
                  SETD      [D1Re0++#0x7c],A1.7
                  SETD      [D0Re0++#-0x80],D1.7
                  SETD      [D1Re0++#-0x80],D0.7
                  SETD      [D1Re0++#-0x80],TXGPIOO
                  SETD      [--D0Re0],A0.7
                  SETD      [--D1Re0],D1.7
                  SETD      [A1LbP+#0x7c],TXGPIOO
                  SETD      [A1LbP++#0x7c],A1.7
                  SETD      [A0FrP++#0x7c],A0.7
                  SETD      [A1LbP++#-0x80],D0.7
                  SETD      [A1LbP++#-0x80],TXGPIOO
                  SETD      [A0FrP++#-0x80],A1.7
                  SETD      [--A1LbP],D1.7
                  SETD      [--A0FrP],D0.7
                  SETD      [--A0FrP],TXGPIOO
                  SETD      [D0.7+#0x7c],D1.7
                  SETD      [D1.7+#0x7c],TXGPIOO
                  SETD      [A1.7++#0x7c],D1.7
                  SETD      [D0.7++#0x7c],D0.7
                  SETD      [D0.7++#0x7c],TXGPIOO
                  SETD      [D1.7++#0x7c],A1.7
                  SETD      [A0.7++#0x7c],A0.7
                  SETD      [A1.7+#-0x80],A0.7
                  SETD      [D1.7+#-0x80],D0.7
                  SETD      [A0.7+#-0x80],A1.7
                  SETD      [A1.7++#-0x80],A1.7
                  SETD      [D0.7++#-0x80],A0.7
                  SETD      [D1.7++#-0x80],D1.7
                  SETD      [A0.7++#-0x80],D0.7
                  SETD      [A0.7++#-0x80],TXGPIOO
                  SETD      [D0.7+#-0x4],D1.7
                  SETD      [D1.7+#-0x4],TXGPIOO
                  SETD      [--A1.7],D1.7
                  SETD      [--D0.7],D0.7
                  SETD      [--D0.7],TXGPIOO
                  SETD      [--D1.7],A1.7
                  SETD      [--A0.7],A0.7
                  SETD      [D0Re0++#0x7c],CPC0
                  SETD      [D1Re0++#0x7c],CPC1
                  SETD      [D0Re0++#-0x80],CPC1
                  SETD      [D1Re0++#-0x80],RD
                  SETD      [--D0Re0],RD
                  SETD      [A1LbP+#0x7c],RD
                  SETD      [A0FrP++#0x7c],CPC0
                  SETD      [A1LbP++#-0x80],CPC0
                  SETD      [A0FrP++#-0x80],CPC1
                  SETD      [--A1LbP],CPC1
                  SETD      [--A0FrP],RD
                  SETD      [D1.7+#0x7c],CPC0
                  SETD      [A1.7++#0x7c],CPC1
                  SETD      [D0.7++#0x7c],RD
                  SETD      [A0.7++#0x7c],CPC0
                  SETD      [A1.7+#-0x80],RD
                  SETD      [A0.7+#-0x80],CPC1
                  SETD      [D0.7++#-0x80],CPC0
                  SETD      [D1.7++#-0x80],CPC1
                  SETD      [A0.7++#-0x80],RD
                  SETD      [D1.7+#-0x4],CPC0
                  SETD      [--A1.7],CPC1
                  SETD      [--D0.7],RD
                  SETD      [--A0.7],CPC0
                  SETD      [D0Re0++#0x7c],TXIDLECYC
                  SETD      [D1Re0++#-0x80],TXIDLECYC
                  SETD      [A1LbP+#0x7c],TXIDLECYC
                  SETD      [A1LbP++#-0x80],TXIDLECYC
                  SETD      [--A0FrP],TXIDLECYC
                  SETD      [D0.7++#0x7c],TXIDLECYC
                  SETD      [D1.7+#-0x80],TXIDLECYC
                  SETD      [A0.7++#-0x80],TXIDLECYC
                  SETD      [--D0.7],TXIDLECYC
                  SETL      [--D0Re0],D1Re0,D0Re0
                  SETL      [--A1LbP],D1Re0,D0Re0
                  SETL      [--A1.7],D1Re0,D0Re0
                  SETL      [--D1.7],D1Re0,D0Re0
                  SETL      [--D0Re0],A1LbP,A0FrP
                  SETL      [--A1LbP],A1LbP,A0FrP
                  SETL      [--A1.7],A1LbP,A0FrP
                  SETL      [--D1.7],A1LbP,A0FrP
                  SETL      [--D0Re0],D1.7,D0.7
                  SETL      [--D1Re0],D1.7,D0.7
                  SETL      [--A1LbP],D1.7,D0.7
                  SETL      [--A0FrP],D1.7,D0.7
                  SETL      [--A1.7],D1.7,D0.7
                  SETL      [--D0.7],D1.7,D0.7
                  SETL      [--D1.7],D1.7,D0.7
                  SETL      [--A0.7],D1.7,D0.7
                  SETL      [--D1Re0],RD
                  SETL      [--D0.7],RD
                  MSETD     [D1Re0++],D0Re0,D0.7
                  MSETD     [D0.7++],D0Re0,D0.7
                  MSETD     [D1Re0++],A1LbP,A1.7
                  MSETD     [D0.7++],A1LbP,A1.7
                  MSETL     [D1Re0++],D0Re0,D0.7
                  MSETL     [D0.7++],D0Re0,D0.7
                  MSETL     [D1Re0++],A1LbP,A1.7
                  MSETL     [D0.7++],A1LbP,A1.7
                  GETB      D0Re0,[D1Re0+D1Re0]
                  GETB      D1Re0,[D1Re0++D1Re0]
                  GETB      D1Re0,[D0Re0++D0.7]
                  GETB      D0Re0,[A0FrP+A0FrP]
                  GETB      D1Re0,[A0FrP++A0FrP]
                  GETB      D1Re0,[A1LbP++A1.7]
                  GETB      D0Re0,[D1.7+D1Re0]
                  GETB      D1Re0,[D1.7++D1Re0]
                  GETB      D1Re0,[A1.7++A1LbP]
                  GETB      D0Re0,[D0.7+D0.7]
                  GETB      D1Re0,[A1.7++A1.7]
                  GETB      D1Re0,[D1.7++D1.7]
                  GETB      A0FrP,[D1Re0+D1Re0]
                  GETB      A1LbP,[D1Re0++D1Re0]
                  GETB      A1LbP,[D0Re0++D0.7]
                  GETB      A0FrP,[A0FrP+A0FrP]
                  GETB      A1LbP,[A0FrP++A0FrP]
                  GETB      A1LbP,[A1LbP++A1.7]
                  GETB      A0FrP,[D1.7+D1Re0]
                  GETB      A1LbP,[D1.7++D1Re0]
                  GETB      A1LbP,[A1.7++A1LbP]
                  GETB      A0FrP,[D0.7+D0.7]
                  GETB      A1LbP,[A1.7++A1.7]
                  GETB      A1LbP,[D1.7++D1.7]
                  GETB      A0.7,[D0Re0+D0Re0]
                  GETB      D1.7,[D0Re0++D0Re0]
                  GETB      D1.7,[D1Re0++D1Re0]
                  GETB      A0.7,[D0Re0+D0.7]
                  GETB      D1.7,[D0Re0++D0.7]
                  GETB      D1.7,[D1Re0++D1.7]
                  GETB      A0.7,[A1LbP+A1LbP]
                  GETB      D1.7,[A1LbP++A1LbP]
                  GETB      D1.7,[A0FrP++A0FrP]
                  GETB      A0.7,[A1LbP+A1.7]
                  GETB      D1.7,[A1LbP++A1.7]
                  GETB      D1.7,[A0FrP++A0.7]
                  GETB      A0.7,[D0.7+D0Re0]
                  GETB      D1.7,[D0.7++D0Re0]
                  GETB      D1.7,[D1.7++D1Re0]
                  GETB      A0.7,[A1.7+A1LbP]
                  GETB      D1.7,[A1.7++A1LbP]
                  GETB      D1.7,[A0.7++A0FrP]
                  GETB      A0.7,[A1.7+A1.7]
                  GETB      A0.7,[D1.7+D1.7]
                  GETB      D1.7,[A1.7++A1.7]
                  GETB      D1.7,[D0.7++D0.7]
                  GETB      D1.7,[D1.7++D1.7]
                  GETB      D1.7,[A0.7++A0.7]
                  MOVB      RA,[D0Re0++D0Re0]
                  MOVB      RA,[D1Re0++D1.7]
                  MOVB      RA,[A1LbP+A1.7]
                  MOVB      RA,[D0.7++D0Re0]
                  MOVB      RA,[A0.7++A0FrP]
                  MOVB      RA,[D0.7++D0.7]
                  MOVB      RAM8X32,[D0Re0++D0Re0]
                  MOVB      RAM8X32,[D1Re0++D1.7]
                  MOVB      RAM8X32,[A1LbP+A1.7]
                  MOVB      RAM8X32,[D0.7++D0Re0]
                  MOVB      RAM8X32,[A0.7++A0FrP]
                  MOVB      RAM8X32,[D0.7++D0.7]
                  MOVB      RAM8X,[D0Re0++D0Re0]
                  MOVB      RAM8X,[D1Re0++D1.7]
                  MOVB      RAM8X,[A1LbP+A1.7]
                  MOVB      RAM8X,[D0.7++D0Re0]
                  MOVB      RAM8X,[A0.7++A0FrP]
                  MOVB      RAM8X,[D0.7++D0.7]
                  MOVB      RABZ,[D0Re0++D0Re0]
                  MOVB      RABZ,[D1Re0++D1.7]
                  MOVB      RABZ,[A1LbP+A1.7]
                  MOVB      RABZ,[D0.7++D0Re0]
                  MOVB      RABZ,[A0.7++A0FrP]
                  MOVB      RABZ,[D0.7++D0.7]
                  MOVB      RAWX,[D0Re0++D0Re0]
                  MOVB      RAWX,[D1Re0++D1.7]
                  MOVB      RAWX,[A1LbP+A1.7]
                  MOVB      RAWX,[D0.7++D0Re0]
                  MOVB      RAWX,[A0.7++A0FrP]
                  MOVB      RAWX,[D0.7++D0.7]
                  MOVB      RAMX,[D0Re0++D0Re0]
                  MOVB      RAMX,[D1Re0++D1.7]
                  MOVB      RAMX,[A1LbP+A1.7]
                  MOVB      RAMX,[D0.7++D0Re0]
                  MOVB      RAMX,[A0.7++A0FrP]
                  MOVB      RAMX,[D0.7++D0.7]
                  GETW      D0Re0,[D1Re0+D1Re0]
                  GETW      D1Re0,[D1Re0++D1Re0]
                  GETW      D1Re0,[D0Re0++D0.7]
                  GETW      D0Re0,[A0FrP+A0FrP]
                  GETW      D1Re0,[A0FrP++A0FrP]
                  GETW      D1Re0,[A1LbP++A1.7]
                  GETW      D0Re0,[D1.7+D1Re0]
                  GETW      D1Re0,[D1.7++D1Re0]
                  GETW      D1Re0,[A1.7++A1LbP]
                  GETW      D0Re0,[D0.7+D0.7]
                  GETW      D1Re0,[A1.7++A1.7]
                  GETW      D1Re0,[D1.7++D1.7]
                  GETW      A0FrP,[D1Re0+D1Re0]
                  GETW      A1LbP,[D1Re0++D1Re0]
                  GETW      A1LbP,[D0Re0++D0.7]
                  GETW      A0FrP,[A0FrP+A0FrP]
                  GETW      A1LbP,[A0FrP++A0FrP]
                  GETW      A1LbP,[A1LbP++A1.7]
                  GETW      A0FrP,[D1.7+D1Re0]
                  GETW      A1LbP,[D1.7++D1Re0]
                  GETW      A1LbP,[A1.7++A1LbP]
                  GETW      A0FrP,[D0.7+D0.7]
                  GETW      A1LbP,[A1.7++A1.7]
                  GETW      A1LbP,[D1.7++D1.7]
                  GETW      A0.7,[D0Re0+D0Re0]
                  GETW      D1.7,[D0Re0++D0Re0]
                  GETW      D1.7,[D1Re0++D1Re0]
                  GETW      A0.7,[D0Re0+D0.7]
                  GETW      D1.7,[D0Re0++D0.7]
                  GETW      D1.7,[D1Re0++D1.7]
                  GETW      A0.7,[A1LbP+A1LbP]
                  GETW      D1.7,[A1LbP++A1LbP]
                  GETW      D1.7,[A0FrP++A0FrP]
                  GETW      A0.7,[A1LbP+A1.7]
                  GETW      D1.7,[A1LbP++A1.7]
                  GETW      D1.7,[A0FrP++A0.7]
                  GETW      A0.7,[D0.7+D0Re0]
                  GETW      D1.7,[D0.7++D0Re0]
                  GETW      D1.7,[D1.7++D1Re0]
                  GETW      A0.7,[A1.7+A1LbP]
                  GETW      D1.7,[A1.7++A1LbP]
                  GETW      D1.7,[A0.7++A0FrP]
                  GETW      A0.7,[A1.7+A1.7]
                  GETW      A0.7,[D1.7+D1.7]
                  GETW      D1.7,[A1.7++A1.7]
                  GETW      D1.7,[D0.7++D0.7]
                  GETW      D1.7,[D1.7++D1.7]
                  GETW      D1.7,[A0.7++A0.7]
                  MOVW      RA,[D0Re0++D0Re0]
                  MOVW      RA,[D1Re0++D1.7]
                  MOVW      RA,[A1LbP+A1.7]
                  MOVW      RA,[D0.7++D0Re0]
                  MOVW      RA,[A0.7++A0FrP]
                  MOVW      RA,[D0.7++D0.7]
                  MOVW      RAM8X32,[D0Re0++D0Re0]
                  MOVW      RAM8X32,[D1Re0++D1.7]
                  MOVW      RAM8X32,[A1LbP+A1.7]
                  MOVW      RAM8X32,[D0.7++D0Re0]
                  MOVW      RAM8X32,[A0.7++A0FrP]
                  MOVW      RAM8X32,[D0.7++D0.7]
                  MOVW      RAM8X,[D0Re0++D0Re0]
                  MOVW      RAM8X,[D1Re0++D1.7]
                  MOVW      RAM8X,[A1LbP+A1.7]
                  MOVW      RAM8X,[D0.7++D0Re0]
                  MOVW      RAM8X,[A0.7++A0FrP]
                  MOVW      RAM8X,[D0.7++D0.7]
                  MOVW      RABZ,[D0Re0++D0Re0]
                  MOVW      RABZ,[D1Re0++D1.7]
                  MOVW      RABZ,[A1LbP+A1.7]
                  MOVW      RABZ,[D0.7++D0Re0]
                  MOVW      RABZ,[A0.7++A0FrP]
                  MOVW      RABZ,[D0.7++D0.7]
                  MOVW      RAWX,[D0Re0++D0Re0]
                  MOVW      RAWX,[D1Re0++D1.7]
                  MOVW      RAWX,[A1LbP+A1.7]
                  MOVW      RAWX,[D0.7++D0Re0]
                  MOVW      RAWX,[A0.7++A0FrP]
                  MOVW      RAWX,[D0.7++D0.7]
                  MOVW      RAMX,[D0Re0++D0Re0]
                  MOVW      RAMX,[D1Re0++D1.7]
                  MOVW      RAMX,[A1LbP+A1.7]
                  MOVW      RAMX,[D0.7++D0Re0]
                  MOVW      RAMX,[A0.7++A0FrP]
                  MOVW      RAMX,[D0.7++D0.7]
                  GETB      D1Re0,[D0Re0++#0x1f]
                  GETB      D1Re0,[D0Re0++#-0x20]
                  GETB      D1Re0,[--D0Re0]
                  GETB      D1Re0,[A1LbP++#0x1f]
                  GETB      D1Re0,[A1LbP++#-0x20]
                  GETB      D1Re0,[--A1LbP]
                  GETB      D0Re0,[D0.7+#0x1f]
                  GETB      D1Re0,[A1.7++#0x1f]
                  GETB      D1Re0,[D1.7++#0x1f]
                  GETB      D0Re0,[D0.7+#-0x20]
                  GETB      D1Re0,[A1.7++#-0x20]
                  GETB      D1Re0,[D1.7++#-0x20]
                  GETB      D0Re0,[D0.7+#-0x1]
                  GETB      D1Re0,[--A1.7]
                  GETB      D1Re0,[--D1.7]
                  GETB      A1LbP,[D0Re0++#0x1f]
                  GETB      A1LbP,[D0Re0++#-0x20]
                  GETB      A1LbP,[--D0Re0]
                  GETB      A1LbP,[A1LbP++#0x1f]
                  GETB      A1LbP,[A1LbP++#-0x20]
                  GETB      A1LbP,[--A1LbP]
                  GETB      A0FrP,[D0.7+#0x1f]
                  GETB      A1LbP,[A1.7++#0x1f]
                  GETB      A1LbP,[D1.7++#0x1f]
                  GETB      A0FrP,[D0.7+#-0x20]
                  GETB      A1LbP,[A1.7++#-0x20]
                  GETB      A1LbP,[D1.7++#-0x20]
                  GETB      A0FrP,[D0.7+#-0x1]
                  GETB      A1LbP,[--A1.7]
                  GETB      A1LbP,[--D1.7]
                  GETB      D1.7,[D0Re0++#0x1f]
                  GETB      D1.7,[D1Re0++#0x1f]
                  GETB      D1.7,[D0Re0++#-0x20]
                  GETB      D1.7,[D1Re0++#-0x20]
                  GETB      D1.7,[--D0Re0]
                  GETB      D1.7,[--D1Re0]
                  GETB      D1.7,[A1LbP++#0x1f]
                  GETB      D1.7,[A0FrP++#0x1f]
                  GETB      D1.7,[A1LbP++#-0x20]
                  GETB      D1.7,[A0FrP++#-0x20]
                  GETB      D1.7,[--A1LbP]
                  GETB      D1.7,[--A0FrP]
                  GETB      A0.7,[A1.7+#0x1f]
                  GETB      A0.7,[D1.7+#0x1f]
                  GETB      D1.7,[A1.7++#0x1f]
                  GETB      D1.7,[D0.7++#0x1f]
                  GETB      D1.7,[D1.7++#0x1f]
                  GETB      D1.7,[A0.7++#0x1f]
                  GETB      A0.7,[A1.7+#-0x20]
                  GETB      A0.7,[D1.7+#-0x20]
                  GETB      D1.7,[A1.7++#-0x20]
                  GETB      D1.7,[D0.7++#-0x20]
                  GETB      D1.7,[D1.7++#-0x20]
                  GETB      D1.7,[A0.7++#-0x20]
                  GETB      A0.7,[A1.7+#-0x1]
                  GETB      A0.7,[D1.7+#-0x1]
                  GETB      D1.7,[--A1.7]
                  GETB      D1.7,[--D0.7]
                  GETB      D1.7,[--D1.7]
                  GETB      D1.7,[--A0.7]
                  MOVB      RA,[D1Re0++#0x1f]
                  MOVB      RA,[--D1Re0]
                  MOVB      RA,[A0FrP++#-0x20]
                  MOVB      RA,[D0.7++#0x1f]
                  MOVB      RA,[D0.7++#-0x20]
                  MOVB      RA,[--D0.7]
                  MOVB      RAM8X32,[D1Re0++#0x1f]
                  MOVB      RAM8X32,[--D1Re0]
                  MOVB      RAM8X32,[A0FrP++#-0x20]
                  MOVB      RAM8X32,[D0.7++#0x1f]
                  MOVB      RAM8X32,[D0.7++#-0x20]
                  MOVB      RAM8X32,[--D0.7]
                  MOVB      RAM8X,[D1Re0++#0x1f]
                  MOVB      RAM8X,[--D1Re0]
                  MOVB      RAM8X,[A0FrP++#-0x20]
                  MOVB      RAM8X,[D0.7++#0x1f]
                  MOVB      RAM8X,[D0.7++#-0x20]
                  MOVB      RAM8X,[--D0.7]
                  MOVB      RABZ,[D1Re0++#0x1f]
                  MOVB      RABZ,[--D1Re0]
                  MOVB      RABZ,[A0FrP++#-0x20]
                  MOVB      RABZ,[D0.7++#0x1f]
                  MOVB      RABZ,[D0.7++#-0x20]
                  MOVB      RABZ,[--D0.7]
                  MOVB      RAWX,[D1Re0++#0x1f]
                  MOVB      RAWX,[--D1Re0]
                  MOVB      RAWX,[A0FrP++#-0x20]
                  MOVB      RAWX,[D0.7++#0x1f]
                  MOVB      RAWX,[D0.7++#-0x20]
                  MOVB      RAWX,[--D0.7]
                  MOVB      RAMX,[D1Re0++#0x1f]
                  MOVB      RAMX,[--D1Re0]
                  MOVB      RAMX,[A0FrP++#-0x20]
                  MOVB      RAMX,[D0.7++#0x1f]
                  MOVB      RAMX,[D0.7++#-0x20]
                  MOVB      RAMX,[--D0.7]
                  GETW      D1Re0,[D0Re0++#0x3e]
                  GETW      D1Re0,[D0Re0++#-0x40]
                  GETW      D1Re0,[--D0Re0]
                  GETW      D1Re0,[A1LbP++#0x3e]
                  GETW      D1Re0,[A1LbP++#-0x40]
                  GETW      D1Re0,[--A1LbP]
                  GETW      D0Re0,[D0.7+#0x3e]
                  GETW      D1Re0,[A1.7++#0x3e]
                  GETW      D1Re0,[D1.7++#0x3e]
                  GETW      D0Re0,[D0.7+#-0x40]
                  GETW      D1Re0,[A1.7++#-0x40]
                  GETW      D1Re0,[D1.7++#-0x40]
                  GETW      D0Re0,[D0.7+#-0x2]
                  GETW      D1Re0,[--A1.7]
                  GETW      D1Re0,[--D1.7]
                  GETW      A1LbP,[D0Re0++#0x3e]
                  GETW      A1LbP,[D0Re0++#-0x40]
                  GETW      A1LbP,[--D0Re0]
                  GETW      A1LbP,[A1LbP++#0x3e]
                  GETW      A1LbP,[A1LbP++#-0x40]
                  GETW      A1LbP,[--A1LbP]
                  GETW      A0FrP,[D0.7+#0x3e]
                  GETW      A1LbP,[A1.7++#0x3e]
                  GETW      A1LbP,[D1.7++#0x3e]
                  GETW      A0FrP,[D0.7+#-0x40]
                  GETW      A1LbP,[A1.7++#-0x40]
                  GETW      A1LbP,[D1.7++#-0x40]
                  GETW      A0FrP,[D0.7+#-0x2]
                  GETW      A1LbP,[--A1.7]
                  GETW      A1LbP,[--D1.7]
                  GETW      D1.7,[D0Re0++#0x3e]
                  GETW      D1.7,[D1Re0++#0x3e]
                  GETW      D1.7,[D0Re0++#-0x40]
                  GETW      D1.7,[D1Re0++#-0x40]
                  GETW      D1.7,[--D0Re0]
                  GETW      D1.7,[--D1Re0]
                  GETW      D1.7,[A1LbP++#0x3e]
                  GETW      D1.7,[A0FrP++#0x3e]
                  GETW      D1.7,[A1LbP++#-0x40]
                  GETW      D1.7,[A0FrP++#-0x40]
                  GETW      D1.7,[--A1LbP]
                  GETW      D1.7,[--A0FrP]
                  GETW      A0.7,[A1.7+#0x3e]
                  GETW      A0.7,[D1.7+#0x3e]
                  GETW      D1.7,[A1.7++#0x3e]
                  GETW      D1.7,[D0.7++#0x3e]
                  GETW      D1.7,[D1.7++#0x3e]
                  GETW      D1.7,[A0.7++#0x3e]
                  GETW      A0.7,[A1.7+#-0x40]
                  GETW      A0.7,[D1.7+#-0x40]
                  GETW      D1.7,[A1.7++#-0x40]
                  GETW      D1.7,[D0.7++#-0x40]
                  GETW      D1.7,[D1.7++#-0x40]
                  GETW      D1.7,[A0.7++#-0x40]
                  GETW      A0.7,[A1.7+#-0x2]
                  GETW      A0.7,[D1.7+#-0x2]
                  GETW      D1.7,[--A1.7]
                  GETW      D1.7,[--D0.7]
                  GETW      D1.7,[--D1.7]
                  GETW      D1.7,[--A0.7]
                  MOVW      RA,[D1Re0++#0x3e]
                  MOVW      RA,[--D1Re0]
                  MOVW      RA,[A0FrP++#-0x40]
                  MOVW      RA,[D0.7++#0x3e]
                  MOVW      RA,[D0.7++#-0x40]
                  MOVW      RA,[--D0.7]
                  MOVW      RAM8X32,[D1Re0++#0x3e]
                  MOVW      RAM8X32,[--D1Re0]
                  MOVW      RAM8X32,[A0FrP++#-0x40]
                  MOVW      RAM8X32,[D0.7++#0x3e]
                  MOVW      RAM8X32,[D0.7++#-0x40]
                  MOVW      RAM8X32,[--D0.7]
                  MOVW      RAM8X,[D1Re0++#0x3e]
                  MOVW      RAM8X,[--D1Re0]
                  MOVW      RAM8X,[A0FrP++#-0x40]
                  MOVW      RAM8X,[D0.7++#0x3e]
                  MOVW      RAM8X,[D0.7++#-0x40]
                  MOVW      RAM8X,[--D0.7]
                  MOVW      RABZ,[D1Re0++#0x3e]
                  MOVW      RABZ,[--D1Re0]
                  MOVW      RABZ,[A0FrP++#-0x40]
                  MOVW      RABZ,[D0.7++#0x3e]
                  MOVW      RABZ,[D0.7++#-0x40]
                  MOVW      RABZ,[--D0.7]
                  MOVW      RAWX,[D1Re0++#0x3e]
                  MOVW      RAWX,[--D1Re0]
                  MOVW      RAWX,[A0FrP++#-0x40]
                  MOVW      RAWX,[D0.7++#0x3e]
                  MOVW      RAWX,[D0.7++#-0x40]
                  MOVW      RAWX,[--D0.7]
                  MOVW      RAMX,[D1Re0++#0x3e]
                  MOVW      RAMX,[--D1Re0]
                  MOVW      RAMX,[A0FrP++#-0x40]
                  MOVW      RAMX,[D0.7++#0x3e]
                  MOVW      RAMX,[D0.7++#-0x40]
                  MOVW      RAMX,[--D0.7]
                  GETD      D1Re0,[D0Re0+D0Re0]
                  GETD      TXSTAT,[D1Re0+D1Re0]
                  GETD      PC,[D0Re0++D0Re0]
                  GETD      D0Re0,[D1Re0++D1Re0]
                  GETD      TTEXEC,[D1Re0++D1Re0]
                  GETD      TXENABLE,[D1Re0+D1.7]
                  GETD      D0Re0,[D0Re0++D0.7]
                  GETD      TTEXEC,[D0Re0++D0.7]
                  GETD      PC,[D1Re0++D1.7]
                  GETD      D1Re0,[A1LbP+A1LbP]
                  GETD      TXSTAT,[A0FrP+A0FrP]
                  GETD      PC,[A1LbP++A1LbP]
                  GETD      D0Re0,[A0FrP++A0FrP]
                  GETD      TTEXEC,[A0FrP++A0FrP]
                  GETD      TXENABLE,[A0FrP+A0.7]
                  GETD      D0Re0,[A1LbP++A1.7]
                  GETD      TTEXEC,[A1LbP++A1.7]
                  GETD      PC,[A0FrP++A0.7]
                  GETD      D1Re0,[D0.7+D0Re0]
                  GETD      TXSTAT,[D1.7+D1Re0]
                  GETD      PC,[D0.7++D0Re0]
                  GETD      D0Re0,[D1.7++D1Re0]
                  GETD      TTEXEC,[D1.7++D1Re0]
                  GETD      TXENABLE,[A0.7+A0FrP]
                  GETD      D0Re0,[A1.7++A1LbP]
                  GETD      TTEXEC,[A1.7++A1LbP]
                  GETD      PC,[A0.7++A0FrP]
                  GETD      D1Re0,[A1.7+A1.7]
                  GETD      TXSTAT,[D0.7+D0.7]
                  GETD      TXENABLE,[A0.7+A0.7]
                  GETD      D0Re0,[A1.7++A1.7]
                  GETD      TTEXEC,[A1.7++A1.7]
                  GETD      PC,[D0.7++D0.7]
                  GETD      D0Re0,[D1.7++D1.7]
                  GETD      TTEXEC,[D1.7++D1.7]
                  GETD      PC,[A0.7++A0.7]
                  GETD      PCX,[D0Re0+D0Re0]
                  GETD      A1LbP,[D0Re0++D0Re0]
                  GETD      A1LbP,[D1Re0++D1Re0]
                  GETD      PCX,[D0Re0+D0.7]
                  GETD      A1LbP,[D0Re0++D0.7]
                  GETD      A1LbP,[D1Re0++D1.7]
                  GETD      PCX,[A1LbP+A1LbP]
                  GETD      A1LbP,[A1LbP++A1LbP]
                  GETD      A1LbP,[A0FrP++A0FrP]
                  GETD      PCX,[A1LbP+A1.7]
                  GETD      A1LbP,[A1LbP++A1.7]
                  GETD      A1LbP,[A0FrP++A0.7]
                  GETD      PCX,[D0.7+D0Re0]
                  GETD      A1LbP,[D0.7++D0Re0]
                  GETD      A1LbP,[D1.7++D1Re0]
                  GETD      PCX,[A1.7+A1LbP]
                  GETD      A1LbP,[A1.7++A1LbP]
                  GETD      A1LbP,[A0.7++A0FrP]
                  GETD      PCX,[A1.7+A1.7]
                  GETD      PCX,[D1.7+D1.7]
                  GETD      A1LbP,[A1.7++A1.7]
                  GETD      A1LbP,[D0.7++D0.7]
                  GETD      A1LbP,[D1.7++D1.7]
                  GETD      A1LbP,[A0.7++A0.7]
                  GETD      TTMARK,[D0Re0++D0Re0]
                  GETD      TTMARK,[D1Re0++D1.7]
                  GETD      TTMARK,[A1LbP+A1.7]
                  GETD      TTMARK,[D0.7++D0Re0]
                  GETD      TTMARK,[A0.7++A0FrP]
                  GETD      TTMARK,[D0.7++D0.7]
                  GETD      TXMASKI,[D1Re0+D1Re0]
                  GETD      TTREC,[D1Re0++D1Re0]
                  GETD      TTREC,[D0Re0++D0.7]
                  GETD      TXMASKI,[A0FrP+A0FrP]
                  GETD      TTREC,[A0FrP++A0FrP]
                  GETD      TTREC,[A1LbP++A1.7]
                  GETD      TXMASKI,[D1.7+D1Re0]
                  GETD      TTREC,[D1.7++D1Re0]
                  GETD      TTREC,[A1.7++A1LbP]
                  GETD      TXMASKI,[D0.7+D0.7]
                  GETD      TTREC,[A1.7++A1.7]
                  GETD      TTREC,[D1.7++D1.7]
                  GETD      GTEXEC,[D0Re0++D0Re0]
                  GETD      GTEXEC,[D1Re0++D1.7]
                  GETD      GTEXEC,[A1LbP+A1.7]
                  GETD      GTEXEC,[D0.7++D0Re0]
                  GETD      GTEXEC,[A0.7++A0FrP]
                  GETD      GTEXEC,[D0.7++D0.7]
                  GETD      A0.7,[D0Re0+D0Re0]
                  GETD      D0.7,[D0Re0++D0Re0]
                  GETD      TXGPIOO,[D0Re0++D0Re0]
                  GETD      A1.7,[D1Re0++D1Re0]
                  GETD      TXGPIOO,[D0Re0+D0.7]
                  GETD      D1.7,[D0Re0++D0.7]
                  GETD      D0.7,[D1Re0++D1.7]
                  GETD      TXGPIOO,[D1Re0++D1.7]
                  GETD      D1.7,[A0FrP+A0FrP]
                  GETD      A0.7,[A1LbP++A1LbP]
                  GETD      D1.7,[A0FrP++A0FrP]
                  GETD      D0.7,[A1LbP+A1.7]
                  GETD      A1.7,[A0FrP+A0.7]
                  GETD      A1.7,[A1LbP++A1.7]
                  GETD      A0.7,[A0FrP++A0.7]
                  GETD      A0.7,[D0.7+D0Re0]
                  GETD      D0.7,[D0.7++D0Re0]
                  GETD      TXGPIOO,[D0.7++D0Re0]
                  GETD      A1.7,[D1.7++D1Re0]
                  GETD      TXGPIOO,[A1.7+A1LbP]
                  GETD      D1.7,[A1.7++A1LbP]
                  GETD      D0.7,[A0.7++A0FrP]
                  GETD      TXGPIOO,[A0.7++A0FrP]
                  GETD      D1.7,[D0.7+D0.7]
                  GETD      TXGPIOO,[D1.7+D1.7]
                  GETD      D1.7,[A1.7++A1.7]
                  GETD      D0.7,[D0.7++D0.7]
                  GETD      TXGPIOO,[D0.7++D0.7]
                  GETD      A1.7,[D1.7++D1.7]
                  GETD      A0.7,[A0.7++A0.7]
                  MOVD      RA,[D0Re0++D0Re0]
                  MOVD      RA,[D1Re0++D1.7]
                  MOVD      RA,[A1LbP+A1.7]
                  MOVD      RA,[D0.7++D0Re0]
                  MOVD      RA,[A0.7++A0FrP]
                  MOVD      RA,[D0.7++D0.7]
                  MOVD      RAM8X32,[D0Re0++D0Re0]
                  MOVD      RAM8X32,[D1Re0++D1.7]
                  MOVD      RAM8X32,[A1LbP+A1.7]
                  MOVD      RAM8X32,[D0.7++D0Re0]
                  MOVD      RAM8X32,[A0.7++A0FrP]
                  MOVD      RAM8X32,[D0.7++D0.7]
                  MOVD      RAM8X,[D0Re0++D0Re0]
                  MOVD      RAM8X,[D1Re0++D1.7]
                  MOVD      RAM8X,[A1LbP+A1.7]
                  MOVD      RAM8X,[D0.7++D0Re0]
                  MOVD      RAM8X,[A0.7++A0FrP]
                  MOVD      RAM8X,[D0.7++D0.7]
                  MOVD      RABZ,[D0Re0++D0Re0]
                  MOVD      RABZ,[D1Re0++D1.7]
                  MOVD      RABZ,[A1LbP+A1.7]
                  MOVD      RABZ,[D0.7++D0Re0]
                  MOVD      RABZ,[A0.7++A0FrP]
                  MOVD      RABZ,[D0.7++D0.7]
                  MOVD      RAWX,[D0Re0++D0Re0]
                  MOVD      RAWX,[D1Re0++D1.7]
                  MOVD      RAWX,[A1LbP+A1.7]
                  MOVD      RAWX,[D0.7++D0Re0]
                  MOVD      RAWX,[A0.7++A0FrP]
                  MOVD      RAWX,[D0.7++D0.7]
                  GETD      TXIDLECYC,[D1Re0+D1Re0]
                  MOVD      RAMX,[D1Re0++D1Re0]
                  MOVD      RAMX,[D0Re0++D0.7]
                  GETD      TXIDLECYC,[A0FrP+A0FrP]
                  MOVD      RAMX,[A0FrP++A0FrP]
                  MOVD      RAMX,[A1LbP++A1.7]
                  GETD      TXIDLECYC,[D1.7+D1Re0]
                  MOVD      RAMX,[D1.7++D1Re0]
                  MOVD      RAMX,[A1.7++A1LbP]
                  GETD      TXIDLECYC,[D0.7+D0.7]
                  MOVD      RAMX,[A1.7++A1.7]
                  MOVD      RAMX,[D1.7++D1.7]
                  GETL      D0Re0,D1Re0,[D1Re0+D1Re0]
                  GETL      D1Re0,D0Re0,[D1Re0++D1Re0]
                  GETL      D1Re0,D0Re0,[D0Re0++D0.7]
                  GETL      D0Re0,D1Re0,[A0FrP+A0FrP]
                  GETL      D1Re0,D0Re0,[A0FrP++A0FrP]
                  GETL      D1Re0,D0Re0,[A1LbP++A1.7]
                  GETL      D0Re0,D1Re0,[D1.7+D1Re0]
                  GETL      D1Re0,D0Re0,[D1.7++D1Re0]
                  GETL      D1Re0,D0Re0,[A1.7++A1LbP]
                  GETL      D0Re0,D1Re0,[D0.7+D0.7]
                  GETL      D1Re0,D0Re0,[A1.7++A1.7]
                  GETL      D1Re0,D0Re0,[D1.7++D1.7]
                  GETL      A0FrP,A1LbP,[D1Re0+D1Re0]
                  GETL      A1LbP,A0FrP,[D1Re0++D1Re0]
                  GETL      A1LbP,A0FrP,[D0Re0++D0.7]
                  GETL      A0FrP,A1LbP,[A0FrP+A0FrP]
                  GETL      A1LbP,A0FrP,[A0FrP++A0FrP]
                  GETL      A1LbP,A0FrP,[A1LbP++A1.7]
                  GETL      A0FrP,A1LbP,[D1.7+D1Re0]
                  GETL      A1LbP,A0FrP,[D1.7++D1Re0]
                  GETL      A1LbP,A0FrP,[A1.7++A1LbP]
                  GETL      A0FrP,A1LbP,[D0.7+D0.7]
                  GETL      A1LbP,A0FrP,[A1.7++A1.7]
                  GETL      A1LbP,A0FrP,[D1.7++D1.7]
                  GETL      A0.7,A1.7,[D0Re0+D0Re0]
                  GETL      D1.7,D0.7,[D0Re0++D0Re0]
                  GETL      D1.7,D0.7,[D1Re0++D1Re0]
                  GETL      A0.7,A1.7,[D0Re0+D0.7]
                  GETL      D1.7,D0.7,[D0Re0++D0.7]
                  GETL      D1.7,D0.7,[D1Re0++D1.7]
                  GETL      A0.7,A1.7,[A1LbP+A1LbP]
                  GETL      D1.7,D0.7,[A1LbP++A1LbP]
                  GETL      D1.7,D0.7,[A0FrP++A0FrP]
                  GETL      A0.7,A1.7,[A1LbP+A1.7]
                  GETL      D1.7,D0.7,[A1LbP++A1.7]
                  GETL      D1.7,D0.7,[A0FrP++A0.7]
                  GETL      A0.7,A1.7,[D0.7+D0Re0]
                  GETL      D1.7,D0.7,[D0.7++D0Re0]
                  GETL      D1.7,D0.7,[D1.7++D1Re0]
                  GETL      A0.7,A1.7,[A1.7+A1LbP]
                  GETL      D1.7,D0.7,[A1.7++A1LbP]
                  GETL      D1.7,D0.7,[A0.7++A0FrP]
                  GETL      A0.7,A1.7,[A1.7+A1.7]
                  GETL      A0.7,A1.7,[D1.7+D1.7]
                  GETL      D1.7,D0.7,[A1.7++A1.7]
                  GETL      D1.7,D0.7,[D0.7++D0.7]
                  GETL      D1.7,D0.7,[D1.7++D1.7]
                  GETL      D1.7,D0.7,[A0.7++A0.7]
                  MOVL      RA,[D0Re0++D0Re0]
                  MOVL      RA,[D1Re0++D1.7]
                  MOVL      RA,[A1LbP+A1.7]
                  MOVL      RA,[D0.7++D0Re0]
                  MOVL      RA,[A0.7++A0FrP]
                  MOVL      RA,[D0.7++D0.7]
                  MOVL      RAM8X32,[D0Re0++D0Re0]
                  MOVL      RAM8X32,[D1Re0++D1.7]
                  MOVL      RAM8X32,[A1LbP+A1.7]
                  MOVL      RAM8X32,[D0.7++D0Re0]
                  MOVL      RAM8X32,[A0.7++A0FrP]
                  MOVL      RAM8X32,[D0.7++D0.7]
                  MOVL      RAM8X,[D0Re0++D0Re0]
                  MOVL      RAM8X,[D1Re0++D1.7]
                  MOVL      RAM8X,[A1LbP+A1.7]
                  MOVL      RAM8X,[D0.7++D0Re0]
                  MOVL      RAM8X,[A0.7++A0FrP]
                  MOVL      RAM8X,[D0.7++D0.7]
                  MOVL      RABZ,[D0Re0++D0Re0]
                  MOVL      RABZ,[D1Re0++D1.7]
                  MOVL      RABZ,[A1LbP+A1.7]
                  MOVL      RABZ,[D0.7++D0Re0]
                  MOVL      RABZ,[A0.7++A0FrP]
                  MOVL      RABZ,[D0.7++D0.7]
                  MOVL      RAWX,[D0Re0++D0Re0]
                  MOVL      RAWX,[D1Re0++D1.7]
                  MOVL      RAWX,[A1LbP+A1.7]
                  MOVL      RAWX,[D0.7++D0Re0]
                  MOVL      RAWX,[A0.7++A0FrP]
                  MOVL      RAWX,[D0.7++D0.7]
                  MOVL      RAMX,[D0Re0++D0Re0]
                  MOVL      RAMX,[D1Re0++D1.7]
                  MOVL      RAMX,[A1LbP+A1.7]
                  MOVL      RAMX,[D0.7++D0Re0]
                  MOVL      RAMX,[A0.7++A0FrP]
                  MOVL      RAMX,[D0.7++D0.7]
                  GETD      TXSTAT,[D0Re0+#0x7c]
                  GETD      D0Re0,[D0Re0++#0x7c]
                  GETD      TTEXEC,[D0Re0++#0x7c]
                  GETD      PC,[D1Re0++#0x7c]
                  GETD      TXSTAT,[D0Re0+#-0x80]
                  GETD      D0Re0,[D0Re0++#-0x80]
                  GETD      TTEXEC,[D0Re0++#-0x80]
                  GETD      PC,[D1Re0++#-0x80]
                  GETD      TXSTAT,[D0Re0+#-0x4]
                  GETD      D0Re0,[--D0Re0]
                  GETD      TTEXEC,[--D0Re0]
                  GETD      PC,[--D1Re0]
                  GETD      TXSTAT,[A1LbP+#0x7c]
                  GETD      D0Re0,[A1LbP++#0x7c]
                  GETD      TTEXEC,[A1LbP++#0x7c]
                  GETD      PC,[A0FrP++#0x7c]
                  GETD      TXSTAT,[A1LbP+#-0x80]
                  GETD      D0Re0,[A1LbP++#-0x80]
                  GETD      TTEXEC,[A1LbP++#-0x80]
                  GETD      PC,[A0FrP++#-0x80]
                  GETD      TXSTAT,[A1LbP+#-0x4]
                  GETD      D0Re0,[--A1LbP]
                  GETD      TTEXEC,[--A1LbP]
                  GETD      PC,[--A0FrP]
                  GETD      D1Re0,[A1.7+#0x7c]
                  GETD      TXSTAT,[D0.7+#0x7c]
                  GETD      TXENABLE,[A0.7+#0x7c]
                  GETD      D0Re0,[A1.7++#0x7c]
                  GETD      TTEXEC,[A1.7++#0x7c]
                  GETD      PC,[D0.7++#0x7c]
                  GETD      D0Re0,[D1.7++#0x7c]
                  GETD      TTEXEC,[D1.7++#0x7c]
                  GETD      PC,[A0.7++#0x7c]
                  GETD      D1Re0,[A1.7+#-0x80]
                  GETD      TXSTAT,[D0.7+#-0x80]
                  GETD      TXENABLE,[A0.7+#-0x80]
                  GETD      D0Re0,[A1.7++#-0x80]
                  GETD      TTEXEC,[A1.7++#-0x80]
                  GETD      PC,[D0.7++#-0x80]
                  GETD      D0Re0,[D1.7++#-0x80]
                  GETD      TTEXEC,[D1.7++#-0x80]
                  GETD      PC,[A0.7++#-0x80]
                  GETD      D1Re0,[A1.7+#-0x4]
                  GETD      TXSTAT,[D0.7+#-0x4]
                  GETD      TXENABLE,[A0.7+#-0x4]
                  GETD      D0Re0,[--A1.7]
                  GETD      TTEXEC,[--A1.7]
                  GETD      PC,[--D0.7]
                  GETD      D0Re0,[--D1.7]
                  GETD      TTEXEC,[--D1.7]
                  GETD      PC,[--A0.7]
                  GETD      PCX,[D1Re0+#0x7c]
                  GETD      TTCTRL,[D0Re0++#0x7c]
                  GETD      TTCTRL,[D1Re0++#0x7c]
                  GETD      A1LbP,[D0Re0++#-0x80]
                  GETD      A1LbP,[D1Re0++#-0x80]
                  GETD      PCX,[D1Re0+#-0x4]
                  GETD      TTCTRL,[--D0Re0]
                  GETD      TTCTRL,[--D1Re0]
                  GETD      A1LbP,[A1LbP++#0x7c]
                  GETD      A1LbP,[A0FrP++#0x7c]
                  GETD      PCX,[A0FrP+#-0x80]
                  GETD      TTCTRL,[A1LbP++#-0x80]
                  GETD      TTCTRL,[A0FrP++#-0x80]
                  GETD      A1LbP,[--A1LbP]
                  GETD      A1LbP,[--A0FrP]
                  GETD      PCX,[A1.7+#0x7c]
                  GETD      PCX,[D1.7+#0x7c]
                  GETD      A1LbP,[A1.7++#0x7c]
                  GETD      A1LbP,[D0.7++#0x7c]
                  GETD      A1LbP,[D1.7++#0x7c]
                  GETD      A1LbP,[A0.7++#0x7c]
                  GETD      PCX,[A1.7+#-0x80]
                  GETD      PCX,[D1.7+#-0x80]
                  GETD      A1LbP,[A1.7++#-0x80]
                  GETD      A1LbP,[D0.7++#-0x80]
                  GETD      A1LbP,[D1.7++#-0x80]
                  GETD      A1LbP,[A0.7++#-0x80]
                  GETD      PCX,[A1.7+#-0x4]
                  GETD      PCX,[D1.7+#-0x4]
                  GETD      A1LbP,[--A1.7]
                  GETD      A1LbP,[--D0.7]
                  GETD      A1LbP,[--D1.7]
                  GETD      A1LbP,[--A0.7]
                  GETD      TTMARK,[D0Re0++#0x7c]
                  GETD      TTMARK,[D1Re0++#-0x80]
                  GETD      TTMARK,[A1LbP+#0x7c]
                  GETD      TTMARK,[A1LbP++#-0x80]
                  GETD      TTMARK,[--A0FrP]
                  GETD      TTMARK,[D0.7++#0x7c]
                  GETD      TTMARK,[D1.7+#-0x80]
                  GETD      TTMARK,[A0.7++#-0x80]
                  GETD      TTMARK,[--D0.7]
                  GETD      TXMASKI,[D1Re0+#0x7c]
                  GETD      TTREC,[D1Re0++#0x7c]
                  GETD      TTREC,[D0Re0++#-0x80]
                  GETD      TXMASKI,[D1Re0+#-0x4]
                  GETD      TTREC,[--D1Re0]
                  GETD      TTREC,[A1LbP++#0x7c]
                  GETD      TXMASKI,[A0FrP+#-0x80]
                  GETD      TTREC,[A0FrP++#-0x80]
                  GETD      TTREC,[--A1LbP]
                  GETD      TXMASKI,[D0.7+#0x7c]
                  GETD      TTREC,[A1.7++#0x7c]
                  GETD      TTREC,[D1.7++#0x7c]
                  GETD      TXMASKI,[D0.7+#-0x80]
                  GETD      TTREC,[A1.7++#-0x80]
                  GETD      TTREC,[D1.7++#-0x80]
                  GETD      TXMASKI,[D0.7+#-0x4]
                  GETD      TTREC,[--A1.7]
                  GETD      TTREC,[--D1.7]
                  GETD      GTEXEC,[D0Re0++#0x7c]
                  GETD      GTEXEC,[D1Re0++#-0x80]
                  GETD      GTEXEC,[A1LbP+#0x7c]
                  GETD      GTEXEC,[A1LbP++#-0x80]
                  GETD      GTEXEC,[--A0FrP]
                  GETD      GTEXEC,[D0.7++#0x7c]
                  GETD      GTEXEC,[D1.7+#-0x80]
                  GETD      GTEXEC,[A0.7++#-0x80]
                  GETD      GTEXEC,[--D0.7]
                  GETD      D0.7,[D0Re0++#0x7c]
                  GETD      TXGPIOO,[D0Re0++#0x7c]
                  GETD      A1.7,[D1Re0++#0x7c]
                  GETD      D1.7,[D0Re0++#-0x80]
                  GETD      D0.7,[D1Re0++#-0x80]
                  GETD      TXGPIOO,[D1Re0++#-0x80]
                  GETD      A0.7,[--D0Re0]
                  GETD      D1.7,[--D1Re0]
                  GETD      TXGPIOO,[A1LbP+#0x7c]
                  GETD      A1.7,[A1LbP++#0x7c]
                  GETD      A0.7,[A0FrP++#0x7c]
                  GETD      D0.7,[A1LbP++#-0x80]
                  GETD      TXGPIOO,[A1LbP++#-0x80]
                  GETD      A1.7,[A0FrP++#-0x80]
                  GETD      D1.7,[--A1LbP]
                  GETD      D0.7,[--A0FrP]
                  GETD      TXGPIOO,[--A0FrP]
                  GETD      D1.7,[D0.7+#0x7c]
                  GETD      TXGPIOO,[D1.7+#0x7c]
                  GETD      D1.7,[A1.7++#0x7c]
                  GETD      D0.7,[D0.7++#0x7c]
                  GETD      TXGPIOO,[D0.7++#0x7c]
                  GETD      A1.7,[D1.7++#0x7c]
                  GETD      A0.7,[A0.7++#0x7c]
                  GETD      A0.7,[A1.7+#-0x80]
                  GETD      D0.7,[D1.7+#-0x80]
                  GETD      A1.7,[A0.7+#-0x80]
                  GETD      A1.7,[A1.7++#-0x80]
                  GETD      A0.7,[D0.7++#-0x80]
                  GETD      D1.7,[D1.7++#-0x80]
                  GETD      D0.7,[A0.7++#-0x80]
                  GETD      TXGPIOO,[A0.7++#-0x80]
                  GETD      D1.7,[D0.7+#-0x4]
                  GETD      TXGPIOO,[D1.7+#-0x4]
                  GETD      D1.7,[--A1.7]
                  GETD      D0.7,[--D0.7]
                  GETD      TXGPIOO,[--D0.7]
                  GETD      A1.7,[--D1.7]
                  GETD      A0.7,[--A0.7]
                  MOVD      RA,[D1Re0++#0x7c]
                  MOVD      RA,[--D1Re0]
                  MOVD      RA,[A0FrP++#-0x80]
                  MOVD      RA,[D0.7++#0x7c]
                  MOVD      RA,[D0.7++#-0x80]
                  MOVD      RA,[--D0.7]
                  MOVD      RAM8X32,[D1Re0++#0x7c]
                  MOVD      RAM8X32,[--D1Re0]
                  MOVD      RAM8X32,[A0FrP++#-0x80]
                  MOVD      RAM8X32,[D0.7++#0x7c]
                  MOVD      RAM8X32,[D0.7++#-0x80]
                  MOVD      RAM8X32,[--D0.7]
                  MOVD      RAM8X,[D1Re0++#0x7c]
                  MOVD      RAM8X,[--D1Re0]
                  MOVD      RAM8X,[A0FrP++#-0x80]
                  MOVD      RAM8X,[D0.7++#0x7c]
                  MOVD      RAM8X,[D0.7++#-0x80]
                  MOVD      RAM8X,[--D0.7]
                  MOVD      RABZ,[D1Re0++#0x7c]
                  MOVD      RABZ,[--D1Re0]
                  MOVD      RABZ,[A0FrP++#-0x80]
                  MOVD      RABZ,[D0.7++#0x7c]
                  MOVD      RABZ,[D0.7++#-0x80]
                  MOVD      RABZ,[--D0.7]
                  MOVD      RAWX,[D1Re0++#0x7c]
                  MOVD      RAWX,[--D1Re0]
                  MOVD      RAWX,[A0FrP++#-0x80]
                  MOVD      RAWX,[D0.7++#0x7c]
                  MOVD      RAWX,[D0.7++#-0x80]
                  MOVD      RAWX,[--D0.7]
                  GETD      TXIDLECYC,[D0Re0++#0x7c]
                  GETD      TXIDLECYC,[D0Re0+#-0x80]
                  MOVD      RAMX,[D1Re0++#-0x80]
                  GETD      TXIDLECYC,[--D1Re0]
                  MOVD      RAMX,[A1LbP++#0x7c]
                  GETD      TXIDLECYC,[A1LbP++#-0x80]
                  GETD      TXIDLECYC,[A1LbP+#-0x4]
                  MOVD      RAMX,[--A0FrP]
                  MOVD      RAMX,[A1.7++#0x7c]
                  MOVD      RAMX,[D1.7++#0x7c]
                  GETD      TXIDLECYC,[D1.7+#-0x80]
                  MOVD      RAMX,[D0.7++#-0x80]
                  MOVD      RAMX,[A0.7++#-0x80]
                  MOVD      RAMX,[--A1.7]
                  MOVD      RAMX,[--D1.7]
                  GETL      D1Re0,D0Re0,[D0Re0++#0xf8]
                  GETL      D1Re0,D0Re0,[D0Re0++#-0x100]
                  GETL      D1Re0,D0Re0,[--D0Re0]
                  GETL      D1Re0,D0Re0,[A1LbP++#0xf8]
                  GETL      D1Re0,D0Re0,[A1LbP++#-0x100]
                  GETL      D1Re0,D0Re0,[--A1LbP]
                  GETL      D0Re0,D1Re0,[D0.7+#0xf8]
                  GETL      D1Re0,D0Re0,[A1.7++#0xf8]
                  GETL      D1Re0,D0Re0,[D1.7++#0xf8]
                  GETL      D0Re0,D1Re0,[D0.7+#-0x100]
                  GETL      D1Re0,D0Re0,[A1.7++#-0x100]
                  GETL      D1Re0,D0Re0,[D1.7++#-0x100]
                  GETL      D0Re0,D1Re0,[D0.7+#-0x8]
                  GETL      D1Re0,D0Re0,[--A1.7]
                  GETL      D1Re0,D0Re0,[--D1.7]
                  GETL      A1LbP,A0FrP,[D0Re0++#0xf8]
                  GETL      A1LbP,A0FrP,[D0Re0++#-0x100]
                  GETL      A1LbP,A0FrP,[--D0Re0]
                  GETL      A1LbP,A0FrP,[A1LbP++#0xf8]
                  GETL      A1LbP,A0FrP,[A1LbP++#-0x100]
                  GETL      A1LbP,A0FrP,[--A1LbP]
                  GETL      A0FrP,A1LbP,[D0.7+#0xf8]
                  GETL      A1LbP,A0FrP,[A1.7++#0xf8]
                  GETL      A1LbP,A0FrP,[D1.7++#0xf8]
                  GETL      A0FrP,A1LbP,[D0.7+#-0x100]
                  GETL      A1LbP,A0FrP,[A1.7++#-0x100]
                  GETL      A1LbP,A0FrP,[D1.7++#-0x100]
                  GETL      A0FrP,A1LbP,[D0.7+#-0x8]
                  GETL      A1LbP,A0FrP,[--A1.7]
                  GETL      A1LbP,A0FrP,[--D1.7]
                  GETL      D1.7,D0.7,[D0Re0++#0xf8]
                  GETL      D1.7,D0.7,[D1Re0++#0xf8]
                  GETL      D1.7,D0.7,[D0Re0++#-0x100]
                  GETL      D1.7,D0.7,[D1Re0++#-0x100]
                  GETL      D1.7,D0.7,[--D0Re0]
                  GETL      D1.7,D0.7,[--D1Re0]
                  GETL      D1.7,D0.7,[A1LbP++#0xf8]
                  GETL      D1.7,D0.7,[A0FrP++#0xf8]
                  GETL      D1.7,D0.7,[A1LbP++#-0x100]
                  GETL      D1.7,D0.7,[A0FrP++#-0x100]
                  GETL      D1.7,D0.7,[--A1LbP]
                  GETL      D1.7,D0.7,[--A0FrP]
                  GETL      A0.7,A1.7,[A1.7+#0xf8]
                  GETL      A0.7,A1.7,[D1.7+#0xf8]
                  GETL      D1.7,D0.7,[A1.7++#0xf8]
                  GETL      D1.7,D0.7,[D0.7++#0xf8]
                  GETL      D1.7,D0.7,[D1.7++#0xf8]
                  GETL      D1.7,D0.7,[A0.7++#0xf8]
                  GETL      A0.7,A1.7,[A1.7+#-0x100]
                  GETL      A0.7,A1.7,[D1.7+#-0x100]
                  GETL      D1.7,D0.7,[A1.7++#-0x100]
                  GETL      D1.7,D0.7,[D0.7++#-0x100]
                  GETL      D1.7,D0.7,[D1.7++#-0x100]
                  GETL      D1.7,D0.7,[A0.7++#-0x100]
                  GETL      A0.7,A1.7,[A1.7+#-0x8]
                  GETL      A0.7,A1.7,[D1.7+#-0x8]
                  GETL      D1.7,D0.7,[--A1.7]
                  GETL      D1.7,D0.7,[--D0.7]
                  GETL      D1.7,D0.7,[--D1.7]
                  GETL      D1.7,D0.7,[--A0.7]
                  MOVL      RA,[D1Re0++#0xf8]
                  MOVL      RA,[--D1Re0]
                  MOVL      RA,[A0FrP++#-0x100]
                  MOVL      RA,[D0.7++#0xf8]
                  MOVL      RA,[D0.7++#-0x100]
                  MOVL      RA,[--D0.7]
                  MOVL      RAM8X32,[D1Re0++#0xf8]
                  MOVL      RAM8X32,[--D1Re0]
                  MOVL      RAM8X32,[A0FrP++#-0x100]
                  MOVL      RAM8X32,[D0.7++#0xf8]
                  MOVL      RAM8X32,[D0.7++#-0x100]
                  MOVL      RAM8X32,[--D0.7]
                  MOVL      RAM8X,[D1Re0++#0xf8]
                  MOVL      RAM8X,[--D1Re0]
                  MOVL      RAM8X,[A0FrP++#-0x100]
                  MOVL      RAM8X,[D0.7++#0xf8]
                  MOVL      RAM8X,[D0.7++#-0x100]
                  MOVL      RAM8X,[--D0.7]
                  MOVL      RABZ,[D1Re0++#0xf8]
                  MOVL      RABZ,[--D1Re0]
                  MOVL      RABZ,[A0FrP++#-0x100]
                  MOVL      RABZ,[D0.7++#0xf8]
                  MOVL      RABZ,[D0.7++#-0x100]
                  MOVL      RABZ,[--D0.7]
                  MOVL      RAWX,[D1Re0++#0xf8]
                  MOVL      RAWX,[--D1Re0]
                  MOVL      RAWX,[A0FrP++#-0x100]
                  MOVL      RAWX,[D0.7++#0xf8]
                  MOVL      RAWX,[D0.7++#-0x100]
                  MOVL      RAWX,[--D0.7]
                  MOVL      RAMX,[D1Re0++#0xf8]
                  MOVL      RAMX,[--D1Re0]
                  MOVL      RAMX,[A0FrP++#-0x100]
                  MOVL      RAMX,[D0.7++#0xf8]
                  MOVL      RAMX,[D0.7++#-0x100]
                  MOVL      RAMX,[--D0.7]
                  MGETD     D0Re0,D0.7,[A1LbP++]
                  MGETD     D0Re0,D0.7,[A0.7++]
                  MGETD     A0FrP,A0.7,[A1.7++]
                  MGETL     D0Re0,D0.7,[A0FrP++]
                  MGETL     A1LbP,A1.7,[D1Re0++]
                  MMOVD     RA,RA,RA,[D0Re0++]
                  MMOVD     RA,RA,RA,RA,RA,RA,RA,[D0Re0++]
                  MMOVD     RA,RA,RA,RA,[A1LbP++]
                  MMOVD     RA,RA,RA,RA,RA,RA,RA,RA,[A1LbP++]
                  MMOVD     RA,RA,RA,[D1.7++]
                  MMOVD     RA,RA,RA,RA,RA,[D1.7++]
                  MMOVD     RA,RA,RA,RA,RA,RA,RA,[D1.7++]
                  MMOVD     RABZ,RABZ,RABZ,[D0Re0++]
                  MMOVD     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[D0Re0++]
                  MMOVD     RABZ,RABZ,RABZ,RABZ,[A1LbP++]
                  MMOVD     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[A1LbP++]
                  MMOVD     RABZ,RABZ,RABZ,[D1.7++]
                  MMOVD     RABZ,RABZ,RABZ,RABZ,RABZ,[D1.7++]
                  MMOVD     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[D1.7++]
                  MMOVD     RAWX,RAWX,RAWX,[D0Re0++]
                  MMOVD     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[D0Re0++]
                  MMOVD     RAWX,RAWX,RAWX,RAWX,[A1LbP++]
                  MMOVD     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[A1LbP++]
                  MMOVD     RAWX,RAWX,RAWX,[D1.7++]
                  MMOVD     RAWX,RAWX,RAWX,RAWX,RAWX,[D1.7++]
                  MMOVD     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[D1.7++]
                  MMOVL     RA,RA,RA,[D0Re0++]
                  MMOVL     RA,RA,RA,RA,RA,RA,RA,[D0Re0++]
                  MMOVL     RA,RA,RA,RA,[A1LbP++]
                  MMOVL     RA,RA,RA,RA,RA,RA,RA,RA,[A1LbP++]
                  MMOVL     RA,RA,RA,[D1.7++]
                  MMOVL     RA,RA,RA,RA,RA,[D1.7++]
                  MMOVL     RA,RA,RA,RA,RA,RA,RA,[D1.7++]
                  MMOVL     RABZ,RABZ,RABZ,[D0Re0++]
                  MMOVL     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[D0Re0++]
                  MMOVL     RABZ,RABZ,RABZ,RABZ,[A1LbP++]
                  MMOVL     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[A1LbP++]
                  MMOVL     RABZ,RABZ,RABZ,[D1.7++]
                  MMOVL     RABZ,RABZ,RABZ,RABZ,RABZ,[D1.7++]
                  MMOVL     RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,RABZ,[D1.7++]
                  MMOVL     RAWX,RAWX,[D1Re0++]
                  MMOVL     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[D1Re0++]
                  MMOVL     RAWX,RAWX,RAWX,[A0FrP++]
                  MMOVL     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[A0FrP++]
                  MMOVL     RAWX,RAWX,RAWX,[D0.7++]
                  MMOVL     RAWX,RAWX,RAWX,RAWX,RAWX,[D0.7++]
                  MMOVL     RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,RAWX,[D0.7++]
                  MDRD      #0x1
                  MMOVD     D1Re0,D1Ar5,D1Ar3,RD
                  MMOVD     D1Re0,D1Ar5,D1.7,RD
                  MMOVD     D1Ar5,D1Ar3,RD
                  MMOVD     D1Ar5,D1.7,RD
                  MMOVD     A1LbP,A1.2,A1.3,A1.7,RD
                  MMOVD     A1.2,A1.3,A1.7,RD
                  MMOVL     D0Re0,D0Ar6,D0Ar4,RD
                  MMOVL     D0Re0,D0Ar6,D0Ar4,D0.7,RD
                  MMOVL     A1LbP,A1.2,A1.3,RD
                  MMOVL     D1Ar5,D1Ar3,D1.7,RD
                  MMOVL     A1.2,A1.7,RD
                  XFRD      [D1Re0+D1Re0],[D0Re0+D0Re0]
                  XFRD      [A1LbP+A1.7],[D0Re0+D0Re0]
                  XFRD      [A1.7+A1LbP],[D1Re0+D1Re0]
                  XFRD      [D1Re0+D1Re0],[D0Re0+D0.7]
                  XFRD      [A1LbP+A1.7],[D0Re0+D0.7]
                  XFRD      [A1.7+A1LbP],[D1Re0+D1.7]
                  XFRD      [D0Re0+D0Re0],[A1LbP+A1LbP]
                  XFRD      [A0FrP+A0FrP],[A1LbP+A1LbP]
                  XFRD      [A0.7+A0FrP],[A1LbP+A1LbP]
                  XFRD      [D0Re0+D0Re0],[A1LbP+A1.7]
                  XFRD      [A0FrP+A0FrP],[A1LbP+A1.7]
                  XFRD      [A0.7+A0FrP],[A1LbP+A1.7]
                  XFRD      [D1Re0+D1Re0],[D0.7+D0Re0]
                  XFRD      [A1LbP+A1.7],[D0.7+D0Re0]
                  XFRD      [A1.7+A1LbP],[D1.7+D1Re0]
                  XFRD      [D0Re0+D0Re0],[A1.7+A1LbP]
                  XFRD      [A0FrP+A0FrP],[A1.7+A1LbP]
                  XFRD      [A0.7+A0FrP],[A1.7+A1LbP]
                  XFRD      [D0Re0+D0Re0],[A1.7+A1.7]
                  XFRD      [D1Re0+D1.7],[D0.7+D0.7]
                  XFRD      [A0FrP+A0FrP],[D1.7+D1.7]
                  XFRD      [D0.7+D0Re0],[A1.7+A1.7]
                  XFRD      [A0.7+A0FrP],[D0.7+D0.7]
                  XFRD      [D1.7+D1.7],[D0.7+D0.7]
                  XFRL      [D1Re0+D1Re0],[D0Re0+D0Re0]
                  XFRL      [A1LbP+A1.7],[D0Re0+D0Re0]
                  XFRL      [A1.7+A1LbP],[D1Re0+D1Re0]
                  XFRL      [D1Re0+D1Re0],[D0Re0+D0.7]
                  XFRL      [A1LbP+A1.7],[D0Re0+D0.7]
                  XFRL      [A1.7+A1LbP],[D1Re0+D1.7]
                  XFRL      [D0Re0+D0Re0],[A1LbP+A1LbP]
                  XFRL      [A0FrP+A0FrP],[A1LbP+A1LbP]
                  XFRL      [A0.7+A0FrP],[A1LbP+A1LbP]
                  XFRL      [D0Re0+D0Re0],[A1LbP+A1.7]
                  XFRL      [A0FrP+A0FrP],[A1LbP+A1.7]
                  XFRL      [A0.7+A0FrP],[A1LbP+A1.7]
                  XFRL      [D1Re0+D1Re0],[D0.7+D0Re0]
                  XFRL      [A1LbP+A1.7],[D0.7+D0Re0]
                  XFRL      [A1.7+A1LbP],[D1.7+D1Re0]
                  XFRL      [D0Re0+D0Re0],[A1.7+A1LbP]
                  XFRL      [A0FrP+A0FrP],[A1.7+A1LbP]
                  XFRL      [A0.7+A0FrP],[A1.7+A1LbP]
                  XFRL      [D0Re0+D0Re0],[A1.7+A1.7]
                  XFRL      [D1Re0+D1.7],[D0.7+D0.7]
                  XFRL      [A0FrP+A0FrP],[D1.7+D1.7]
                  XFRL      [D0.7+D0Re0],[A1.7+A1.7]
                  XFRL      [A0.7+A0FrP],[D0.7+D0.7]
                  XFRL      [D1.7+D1.7],[D0.7+D0.7]
                  XFRD      [D1Re0++D1Re0],[D0Re0+D0Re0]
                  XFRD      [A1LbP++A1.7],[D0Re0+D0Re0]
                  XFRD      [A1.7++A1LbP],[D1Re0+D1Re0]
                  XFRD      [D1Re0++D1Re0],[D0Re0+D0.7]
                  XFRD      [A1LbP++A1.7],[D0Re0+D0.7]
                  XFRD      [A1.7++A1LbP],[D1Re0+D1.7]
                  XFRD      [D0Re0++D0Re0],[A1LbP+A1LbP]
                  XFRD      [A0FrP++A0FrP],[A1LbP+A1LbP]
                  XFRD      [A0.7++A0FrP],[A1LbP+A1LbP]
                  XFRD      [D0Re0++D0Re0],[A1LbP+A1.7]
                  XFRD      [A0FrP++A0FrP],[A1LbP+A1.7]
                  XFRD      [A0.7++A0FrP],[A1LbP+A1.7]
                  XFRD      [D1Re0++D1Re0],[D0.7+D0Re0]
                  XFRD      [A1LbP++A1.7],[D0.7+D0Re0]
                  XFRD      [A1.7++A1LbP],[D1.7+D1Re0]
                  XFRD      [D0Re0++D0Re0],[A1.7+A1LbP]
                  XFRD      [A0FrP++A0FrP],[A1.7+A1LbP]
                  XFRD      [A0.7++A0FrP],[A1.7+A1LbP]
                  XFRD      [D0Re0++D0Re0],[A1.7+A1.7]
                  XFRD      [D1Re0++D1.7],[D0.7+D0.7]
                  XFRD      [A0FrP++A0FrP],[D1.7+D1.7]
                  XFRD      [D0.7++D0Re0],[A1.7+A1.7]
                  XFRD      [A0.7++A0FrP],[D0.7+D0.7]
                  XFRD      [D1.7++D1.7],[D0.7+D0.7]
                  XFRD      [D1Re0+D1Re0++],[D0Re0+D0Re0]
                  XFRD      [A1LbP+A1.7++],[D0Re0+D0Re0]
                  XFRD      [A1.7+A1LbP++],[D1Re0+D1Re0]
                  XFRD      [D1Re0+D1Re0++],[D0Re0+D0.7]
                  XFRD      [A1LbP+A1.7++],[D0Re0+D0.7]
                  XFRD      [A1.7+A1LbP++],[D1Re0+D1.7]
                  XFRD      [D0Re0+D0Re0++],[A1LbP+A1LbP]
                  XFRD      [A0FrP+A0FrP++],[A1LbP+A1LbP]
                  XFRD      [A0.7+A0FrP++],[A1LbP+A1LbP]
                  XFRD      [D0Re0+D0Re0++],[A1LbP+A1.7]
                  XFRD      [A0FrP+A0FrP++],[A1LbP+A1.7]
                  XFRD      [A0.7+A0FrP++],[A1LbP+A1.7]
                  XFRD      [D1Re0+D1Re0++],[D0.7+D0Re0]
                  XFRD      [A1LbP+A1.7++],[D0.7+D0Re0]
                  XFRD      [A1.7+A1LbP++],[D1.7+D1Re0]
                  XFRD      [D0Re0+D0Re0++],[A1.7+A1LbP]
                  XFRD      [A0FrP+A0FrP++],[A1.7+A1LbP]
                  XFRD      [A0.7+A0FrP++],[A1.7+A1LbP]
                  XFRD      [D0Re0+D0Re0++],[A1.7+A1.7]
                  XFRD      [D1Re0+D1.7++],[D0.7+D0.7]
                  XFRD      [A0FrP+A0FrP++],[D1.7+D1.7]
                  XFRD      [D0.7+D0Re0++],[A1.7+A1.7]
                  XFRD      [A0.7+A0FrP++],[D0.7+D0.7]
                  XFRD      [D1.7+D1.7++],[D0.7+D0.7]
                  XFRL      [D1Re0++D1Re0],[D0Re0+D0Re0]
                  XFRL      [A1LbP++A1.7],[D0Re0+D0Re0]
                  XFRL      [A1.7++A1LbP],[D1Re0+D1Re0]
                  XFRL      [D1Re0++D1Re0],[D0Re0+D0.7]
                  XFRL      [A1LbP++A1.7],[D0Re0+D0.7]
                  XFRL      [A1.7++A1LbP],[D1Re0+D1.7]
                  XFRL      [D0Re0++D0Re0],[A1LbP+A1LbP]
                  XFRL      [A0FrP++A0FrP],[A1LbP+A1LbP]
                  XFRL      [A0.7++A0FrP],[A1LbP+A1LbP]
                  XFRL      [D0Re0++D0Re0],[A1LbP+A1.7]
                  XFRL      [A0FrP++A0FrP],[A1LbP+A1.7]
                  XFRL      [A0.7++A0FrP],[A1LbP+A1.7]
                  XFRL      [D1Re0++D1Re0],[D0.7+D0Re0]
                  XFRL      [A1LbP++A1.7],[D0.7+D0Re0]
                  XFRL      [A1.7++A1LbP],[D1.7+D1Re0]
                  XFRL      [D0Re0++D0Re0],[A1.7+A1LbP]
                  XFRL      [A0FrP++A0FrP],[A1.7+A1LbP]
                  XFRL      [A0.7++A0FrP],[A1.7+A1LbP]
                  XFRL      [D0Re0++D0Re0],[A1.7+A1.7]
                  XFRL      [D1Re0++D1.7],[D0.7+D0.7]
                  XFRL      [A0FrP++A0FrP],[D1.7+D1.7]
                  XFRL      [D0.7++D0Re0],[A1.7+A1.7]
                  XFRL      [A0.7++A0FrP],[D0.7+D0.7]
                  XFRL      [D1.7++D1.7],[D0.7+D0.7]
                  XFRL      [D1Re0+D1Re0++],[D0Re0+D0Re0]
                  XFRL      [A1LbP+A1.7++],[D0Re0+D0Re0]
                  XFRL      [A1.7+A1LbP++],[D1Re0+D1Re0]
                  XFRL      [D1Re0+D1Re0++],[D0Re0+D0.7]
                  XFRL      [A1LbP+A1.7++],[D0Re0+D0.7]
                  XFRL      [A1.7+A1LbP++],[D1Re0+D1.7]
                  XFRL      [D0Re0+D0Re0++],[A1LbP+A1LbP]
                  XFRL      [A0FrP+A0FrP++],[A1LbP+A1LbP]
                  XFRL      [A0.7+A0FrP++],[A1LbP+A1LbP]
                  XFRL      [D0Re0+D0Re0++],[A1LbP+A1.7]
                  XFRL      [A0FrP+A0FrP++],[A1LbP+A1.7]
                  XFRL      [A0.7+A0FrP++],[A1LbP+A1.7]
                  XFRL      [D1Re0+D1Re0++],[D0.7+D0Re0]
                  XFRL      [A1LbP+A1.7++],[D0.7+D0Re0]
                  XFRL      [A1.7+A1LbP++],[D1.7+D1Re0]
                  XFRL      [D0Re0+D0Re0++],[A1.7+A1LbP]
                  XFRL      [A0FrP+A0FrP++],[A1.7+A1LbP]
                  XFRL      [A0.7+A0FrP++],[A1.7+A1LbP]
                  XFRL      [D0Re0+D0Re0++],[A1.7+A1.7]
                  XFRL      [D1Re0+D1.7++],[D0.7+D0.7]
                  XFRL      [A0FrP+A0FrP++],[D1.7+D1.7]
                  XFRL      [D0.7+D0Re0++],[A1.7+A1.7]
                  XFRL      [A0.7+A0FrP++],[D0.7+D0.7]
                  XFRL      [D1.7+D1.7++],[D0.7+D0.7]
                  XFRD      [D1Re0+D1Re0],[D0Re0++D0Re0]
                  XFRD      [A1LbP+A1.7],[D0Re0++D0Re0]
                  XFRD      [A1.7+A1LbP],[D1Re0++D1Re0]
                  XFRD      [D1Re0+D1Re0],[D0Re0++D0.7]
                  XFRD      [A1LbP+A1.7],[D0Re0++D0.7]
                  XFRD      [A1.7+A1LbP],[D1Re0++D1.7]
                  XFRD      [D0Re0+D0Re0],[A1LbP++A1LbP]
                  XFRD      [A0FrP+A0FrP],[A1LbP++A1LbP]
                  XFRD      [A0.7+A0FrP],[A1LbP++A1LbP]
                  XFRD      [D0Re0+D0Re0],[A1LbP++A1.7]
                  XFRD      [A0FrP+A0FrP],[A1LbP++A1.7]
                  XFRD      [A0.7+A0FrP],[A1LbP++A1.7]
                  XFRD      [D1Re0+D1Re0],[D0.7++D0Re0]
                  XFRD      [A1LbP+A1.7],[D0.7++D0Re0]
                  XFRD      [A1.7+A1LbP],[D1.7++D1Re0]
                  XFRD      [D0Re0+D0Re0],[A1.7++A1LbP]
                  XFRD      [A0FrP+A0FrP],[A1.7++A1LbP]
                  XFRD      [A0.7+A0FrP],[A1.7++A1LbP]
                  XFRD      [D0Re0+D0Re0],[A1.7++A1.7]
                  XFRD      [D1Re0+D1.7],[D0.7++D0.7]
                  XFRD      [A0FrP+A0FrP],[D1.7++D1.7]
                  XFRD      [D0.7+D0Re0],[A1.7++A1.7]
                  XFRD      [A0.7+A0FrP],[D0.7++D0.7]
                  XFRD      [D1.7+D1.7],[D0.7++D0.7]
                  XFRD      [D1Re0+D1Re0],[D0Re0+D0Re0++]
                  XFRD      [A1LbP+A1.7],[D0Re0+D0Re0++]
                  XFRD      [A1.7+A1LbP],[D1Re0+D1Re0++]
                  XFRD      [D1Re0+D1Re0],[D0Re0+D0.7++]
                  XFRD      [A1LbP+A1.7],[D0Re0+D0.7++]
                  XFRD      [A1.7+A1LbP],[D1Re0+D1.7++]
                  XFRD      [D0Re0+D0Re0],[A1LbP+A1LbP++]
                  XFRD      [A0FrP+A0FrP],[A1LbP+A1LbP++]
                  XFRD      [A0.7+A0FrP],[A1LbP+A1LbP++]
                  XFRD      [D0Re0+D0Re0],[A1LbP+A1.7++]
                  XFRD      [A0FrP+A0FrP],[A1LbP+A1.7++]
                  XFRD      [A0.7+A0FrP],[A1LbP+A1.7++]
                  XFRD      [D1Re0+D1Re0],[D0.7+D0Re0++]
                  XFRD      [A1LbP+A1.7],[D0.7+D0Re0++]
                  XFRD      [A1.7+A1LbP],[D1.7+D1Re0++]
                  XFRD      [D0Re0+D0Re0],[A1.7+A1LbP++]
                  XFRD      [A0FrP+A0FrP],[A1.7+A1LbP++]
                  XFRD      [A0.7+A0FrP],[A1.7+A1LbP++]
                  XFRD      [D0Re0+D0Re0],[A1.7+A1.7++]
                  XFRD      [D1Re0+D1.7],[D0.7+D0.7++]
                  XFRD      [A0FrP+A0FrP],[D1.7+D1.7++]
                  XFRD      [D0.7+D0Re0],[A1.7+A1.7++]
                  XFRD      [A0.7+A0FrP],[D0.7+D0.7++]
                  XFRD      [D1.7+D1.7],[D0.7+D0.7++]
                  XFRL      [D1Re0+D1Re0],[D0Re0++D0Re0]
                  XFRL      [A1LbP+A1.7],[D0Re0++D0Re0]
                  XFRL      [A1.7+A1LbP],[D1Re0++D1Re0]
                  XFRL      [D1Re0+D1Re0],[D0Re0++D0.7]
                  XFRL      [A1LbP+A1.7],[D0Re0++D0.7]
                  XFRL      [A1.7+A1LbP],[D1Re0++D1.7]
                  XFRL      [D0Re0+D0Re0],[A1LbP++A1LbP]
                  XFRL      [A0FrP+A0FrP],[A1LbP++A1LbP]
                  XFRL      [A0.7+A0FrP],[A1LbP++A1LbP]
                  XFRL      [D0Re0+D0Re0],[A1LbP++A1.7]
                  XFRL      [A0FrP+A0FrP],[A1LbP++A1.7]
                  XFRL      [A0.7+A0FrP],[A1LbP++A1.7]
                  XFRL      [D1Re0+D1Re0],[D0.7++D0Re0]
                  XFRL      [A1LbP+A1.7],[D0.7++D0Re0]
                  XFRL      [A1.7+A1LbP],[D1.7++D1Re0]
                  XFRL      [D0Re0+D0Re0],[A1.7++A1LbP]
                  XFRL      [A0FrP+A0FrP],[A1.7++A1LbP]
                  XFRL      [A0.7+A0FrP],[A1.7++A1LbP]
                  XFRL      [D0Re0+D0Re0],[A1.7++A1.7]
                  XFRL      [D1Re0+D1.7],[D0.7++D0.7]
                  XFRL      [A0FrP+A0FrP],[D1.7++D1.7]
                  XFRL      [D0.7+D0Re0],[A1.7++A1.7]
                  XFRL      [A0.7+A0FrP],[D0.7++D0.7]
                  XFRL      [D1.7+D1.7],[D0.7++D0.7]
                  XFRL      [D1Re0+D1Re0],[D0Re0+D0Re0++]
                  XFRL      [A1LbP+A1.7],[D0Re0+D0Re0++]
                  XFRL      [A1.7+A1LbP],[D1Re0+D1Re0++]
                  XFRL      [D1Re0+D1Re0],[D0Re0+D0.7++]
                  XFRL      [A1LbP+A1.7],[D0Re0+D0.7++]
                  XFRL      [A1.7+A1LbP],[D1Re0+D1.7++]
                  XFRL      [D0Re0+D0Re0],[A1LbP+A1LbP++]
                  XFRL      [A0FrP+A0FrP],[A1LbP+A1LbP++]
                  XFRL      [A0.7+A0FrP],[A1LbP+A1LbP++]
                  XFRL      [D0Re0+D0Re0],[A1LbP+A1.7++]
                  XFRL      [A0FrP+A0FrP],[A1LbP+A1.7++]
                  XFRL      [A0.7+A0FrP],[A1LbP+A1.7++]
                  XFRL      [D1Re0+D1Re0],[D0.7+D0Re0++]
                  XFRL      [A1LbP+A1.7],[D0.7+D0Re0++]
                  XFRL      [A1.7+A1LbP],[D1.7+D1Re0++]
                  XFRL      [D0Re0+D0Re0],[A1.7+A1LbP++]
                  XFRL      [A0FrP+A0FrP],[A1.7+A1LbP++]
                  XFRL      [A0.7+A0FrP],[A1.7+A1LbP++]
                  XFRL      [D0Re0+D0Re0],[A1.7+A1.7++]
                  XFRL      [D1Re0+D1.7],[D0.7+D0.7++]
                  XFRL      [A0FrP+A0FrP],[D1.7+D1.7++]
                  XFRL      [D0.7+D0Re0],[A1.7+A1.7++]
                  XFRL      [A0.7+A0FrP],[D0.7+D0.7++]
                  XFRL      [D1.7+D1.7],[D0.7+D0.7++]
                  XFRD      [D1Re0++D1Re0],[D0Re0++D0Re0]
                  XFRD      [A1LbP++A1.7],[D0Re0++D0Re0]
                  XFRD      [A1.7++A1LbP],[D1Re0++D1Re0]
                  XFRD      [D1Re0++D1Re0],[D0Re0++D0.7]
                  XFRD      [A1LbP++A1.7],[D0Re0++D0.7]
                  XFRD      [A1.7++A1LbP],[D1Re0++D1.7]
                  XFRD      [D0Re0++D0Re0],[A1LbP++A1LbP]
                  XFRD      [A0FrP++A0FrP],[A1LbP++A1LbP]
                  XFRD      [A0.7++A0FrP],[A1LbP++A1LbP]
                  XFRD      [D0Re0++D0Re0],[A1LbP++A1.7]
                  XFRD      [A0FrP++A0FrP],[A1LbP++A1.7]
                  XFRD      [A0.7++A0FrP],[A1LbP++A1.7]
                  XFRD      [D1Re0++D1Re0],[D0.7++D0Re0]
                  XFRD      [A1LbP++A1.7],[D0.7++D0Re0]
                  XFRD      [A1.7++A1LbP],[D1.7++D1Re0]
                  XFRD      [D0Re0++D0Re0],[A1.7++A1LbP]
                  XFRD      [A0FrP++A0FrP],[A1.7++A1LbP]
                  XFRD      [A0.7++A0FrP],[A1.7++A1LbP]
                  XFRD      [D0Re0++D0Re0],[A1.7++A1.7]
                  XFRD      [D1Re0++D1.7],[D0.7++D0.7]
                  XFRD      [A0FrP++A0FrP],[D1.7++D1.7]
                  XFRD      [D0.7++D0Re0],[A1.7++A1.7]
                  XFRD      [A0.7++A0FrP],[D0.7++D0.7]
                  XFRD      [D1.7++D1.7],[D0.7++D0.7]
                  XFRD      [D1Re0+D1Re0++],[D0Re0+D0Re0++]
                  XFRD      [A1LbP+A1.7++],[D0Re0+D0Re0++]
                  XFRD      [A1.7+A1LbP++],[D1Re0+D1Re0++]
                  XFRD      [D1Re0+D1Re0++],[D0Re0+D0.7++]
                  XFRD      [A1LbP+A1.7++],[D0Re0+D0.7++]
                  XFRD      [A1.7+A1LbP++],[D1Re0+D1.7++]
                  XFRD      [D0Re0+D0Re0++],[A1LbP+A1LbP++]
                  XFRD      [A0FrP+A0FrP++],[A1LbP+A1LbP++]
                  XFRD      [A0.7+A0FrP++],[A1LbP+A1LbP++]
                  XFRD      [D0Re0+D0Re0++],[A1LbP+A1.7++]
                  XFRD      [A0FrP+A0FrP++],[A1LbP+A1.7++]
                  XFRD      [A0.7+A0FrP++],[A1LbP+A1.7++]
                  XFRD      [D1Re0+D1Re0++],[D0.7+D0Re0++]
                  XFRD      [A1LbP+A1.7++],[D0.7+D0Re0++]
                  XFRD      [A1.7+A1LbP++],[D1.7+D1Re0++]
                  XFRD      [D0Re0+D0Re0++],[A1.7+A1LbP++]
                  XFRD      [A0FrP+A0FrP++],[A1.7+A1LbP++]
                  XFRD      [A0.7+A0FrP++],[A1.7+A1LbP++]
                  XFRD      [D0Re0+D0Re0++],[A1.7+A1.7++]
                  XFRD      [D1Re0+D1.7++],[D0.7+D0.7++]
                  XFRD      [A0FrP+A0FrP++],[D1.7+D1.7++]
                  XFRD      [D0.7+D0Re0++],[A1.7+A1.7++]
                  XFRD      [A0.7+A0FrP++],[D0.7+D0.7++]
                  XFRD      [D1.7+D1.7++],[D0.7+D0.7++]
                  XFRL      [D1Re0++D1Re0],[D0Re0++D0Re0]
                  XFRL      [A1LbP++A1.7],[D0Re0++D0Re0]
                  XFRL      [A1.7++A1LbP],[D1Re0++D1Re0]
                  XFRL      [D1Re0++D1Re0],[D0Re0++D0.7]
                  XFRL      [A1LbP++A1.7],[D0Re0++D0.7]
                  XFRL      [A1.7++A1LbP],[D1Re0++D1.7]
                  XFRL      [D0Re0++D0Re0],[A1LbP++A1LbP]
                  XFRL      [A0FrP++A0FrP],[A1LbP++A1LbP]
                  XFRL      [A0.7++A0FrP],[A1LbP++A1LbP]
                  XFRL      [D0Re0++D0Re0],[A1LbP++A1.7]
                  XFRL      [A0FrP++A0FrP],[A1LbP++A1.7]
                  XFRL      [A0.7++A0FrP],[A1LbP++A1.7]
                  XFRL      [D1Re0++D1Re0],[D0.7++D0Re0]
                  XFRL      [A1LbP++A1.7],[D0.7++D0Re0]
                  XFRL      [A1.7++A1LbP],[D1.7++D1Re0]
                  XFRL      [D0Re0++D0Re0],[A1.7++A1LbP]
                  XFRL      [A0FrP++A0FrP],[A1.7++A1LbP]
                  XFRL      [A0.7++A0FrP],[A1.7++A1LbP]
                  XFRL      [D0Re0++D0Re0],[A1.7++A1.7]
                  XFRL      [D1Re0++D1.7],[D0.7++D0.7]
                  XFRL      [A0FrP++A0FrP],[D1.7++D1.7]
                  XFRL      [D0.7++D0Re0],[A1.7++A1.7]
                  XFRL      [A0.7++A0FrP],[D0.7++D0.7]
                  XFRL      [D1.7++D1.7],[D0.7++D0.7]
                  XFRL      [D1Re0+D1Re0++],[D0Re0+D0Re0++]
                  XFRL      [A1LbP+A1.7++],[D0Re0+D0Re0++]
                  XFRL      [A1.7+A1LbP++],[D1Re0+D1Re0++]
                  XFRL      [D1Re0+D1Re0++],[D0Re0+D0.7++]
                  XFRL      [A1LbP+A1.7++],[D0Re0+D0.7++]
                  XFRL      [A1.7+A1LbP++],[D1Re0+D1.7++]
                  XFRL      [D0Re0+D0Re0++],[A1LbP+A1LbP++]
                  XFRL      [A0FrP+A0FrP++],[A1LbP+A1LbP++]
                  XFRL      [A0.7+A0FrP++],[A1LbP+A1LbP++]
                  XFRL      [D0Re0+D0Re0++],[A1LbP+A1.7++]
                  XFRL      [A0FrP+A0FrP++],[A1LbP+A1.7++]
                  XFRL      [A0.7+A0FrP++],[A1LbP+A1.7++]
                  XFRL      [D1Re0+D1Re0++],[D0.7+D0Re0++]
                  XFRL      [A1LbP+A1.7++],[D0.7+D0Re0++]
                  XFRL      [A1.7+A1LbP++],[D1.7+D1Re0++]
                  XFRL      [D0Re0+D0Re0++],[A1.7+A1LbP++]
                  XFRL      [A0FrP+A0FrP++],[A1.7+A1LbP++]
                  XFRL      [A0.7+A0FrP++],[A1.7+A1LbP++]
                  XFRL      [D0Re0+D0Re0++],[A1.7+A1.7++]
                  XFRL      [D1Re0+D1.7++],[D0.7+D0.7++]
                  XFRL      [A0FrP+A0FrP++],[D1.7+D1.7++]
                  XFRL      [D0.7+D0Re0++],[A1.7+A1.7++]
                  XFRL      [A0.7+A0FrP++],[D0.7+D0.7++]
                  XFRL      [D1.7+D1.7++],[D0.7+D0.7++]
